""" Cisco_IOS_XR_invmgr_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR invmgr package operational data.

This module contains definitions
for the following management objects\:
  inventory\: Inventory information

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""


import re
import collections

from enum import Enum

from ydk.types import Empty, YList, YLeafList, DELETE, Decimal64, FixedBitsDict

from ydk.errors import YPYError, YPYModelError



class CardResetReasonEnum(Enum):
    """
    CardResetReasonEnum

    Card reset reason

    .. data:: reset_unknown = 1

    	reset unknown

    .. data:: power_up = 2

    	power up

    .. data:: parity_error = 3

    	parity error

    .. data:: clear_config_reset = 4

    	clear config reset

    .. data:: manual_reset = 5

    	manual reset

    .. data:: watch_dog_timeout_reset = 6

    	watch dog timeout reset

    .. data:: resource_overflow_reset = 7

    	resource overflow reset

    .. data:: missing_task_reset = 8

    	missing task reset

    .. data:: low_voltage_reset = 9

    	low voltage reset

    .. data:: controller_reset = 10

    	controller reset

    .. data:: system_reset = 11

    	system reset

    .. data:: switchover_reset = 12

    	switchover reset

    .. data:: upgrade_reset = 13

    	upgrade reset

    .. data:: downgrade_reset = 14

    	downgrade reset

    .. data:: cache_error_reset = 15

    	cache error reset

    .. data:: device_driver_reset = 16

    	device driver reset

    .. data:: software_exception_reset = 17

    	software exception reset

    .. data:: restore_config_reset = 18

    	restore config reset

    .. data:: abort_rev_reset = 19

    	abort rev reset

    .. data:: burn_boot_reset = 20

    	burn boot reset

    .. data:: standby_cd_healthier_reset = 21

    	standby cd healthier reset

    .. data:: non_native_config_clear_reset = 22

    	non native config clear reset

    .. data:: memory_protection_error_reset = 23

    	memory protection error reset

    .. data:: card_reset_reason_max = 24

    	card reset reason max

    """

    reset_unknown = 1

    power_up = 2

    parity_error = 3

    clear_config_reset = 4

    manual_reset = 5

    watch_dog_timeout_reset = 6

    resource_overflow_reset = 7

    missing_task_reset = 8

    low_voltage_reset = 9

    controller_reset = 10

    system_reset = 11

    switchover_reset = 12

    upgrade_reset = 13

    downgrade_reset = 14

    cache_error_reset = 15

    device_driver_reset = 16

    software_exception_reset = 17

    restore_config_reset = 18

    abort_rev_reset = 19

    burn_boot_reset = 20

    standby_cd_healthier_reset = 21

    non_native_config_clear_reset = 22

    memory_protection_error_reset = 23

    card_reset_reason_max = 24


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
        return meta._meta_table['CardResetReasonEnum']


class SensorDataEnum(Enum):
    """
    SensorDataEnum

    Sensor measurement data types

    .. data:: unknown = 2

    	Datatype unknown

    .. data:: ac_volts = 3

    	AC volts

    .. data:: dc_volts = 4

    	DC volts

    .. data:: amperes = 5

    	Amperes

    .. data:: watts = 6

    	Power in watts

    .. data:: hertz = 7

    	Frequency in hertz

    .. data:: celsius = 8

    	Celsius

    .. data:: rpm = 10

    	Rotations per minute

    .. data:: dbm = 14

    	Power in dBm

    .. data:: db = 15

    	Power in dB

    """

    unknown = 2

    ac_volts = 3

    dc_volts = 4

    amperes = 5

    watts = 6

    hertz = 7

    celsius = 8

    rpm = 10

    dbm = 14

    db = 15


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
        return meta._meta_table['SensorDataEnum']


class SensorStatusEnum(Enum):
    """
    SensorStatusEnum

    Sensor status

    .. data:: ok = 1

    	State ok

    .. data:: unavailable = 2

    	State Unavailable

    .. data:: non_operational = 3

    	State no operational

    """

    ok = 1

    unavailable = 2

    non_operational = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
        return meta._meta_table['SensorStatusEnum']


class ThresholdRelationEnum(Enum):
    """
    ThresholdRelationEnum

    Threshold relation

    .. data:: less_than = 1

    	Sensor value is less than threshold

    .. data:: less_or_equal = 2

    	Sensor value is lesser than  or equal to

    	threshold

    .. data:: greater_than = 3

    	Sensor value is greater than threshold

    .. data:: greater_or_equal = 4

    	Sensor value is greater than or equal to

    	threshold

    .. data:: equal = 5

    	Sensor value is equal to threshold

    .. data:: not_equal = 6

    	Sensor value is not equal to threshold

    """

    less_than = 1

    less_or_equal = 2

    greater_than = 3

    greater_or_equal = 4

    equal = 5

    not_equal = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
        return meta._meta_table['ThresholdRelationEnum']


class ThresholdSeverityEnum(Enum):
    """
    ThresholdSeverityEnum

    Threshold severity

    .. data:: other = 1

    	Other

    .. data:: minor = 10

    	Minor

    .. data:: major = 20

    	Major

    .. data:: critical = 30

    	Critical

    """

    other = 1

    minor = 10

    major = 20

    critical = 30


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
        return meta._meta_table['ThresholdSeverityEnum']


class UnitEnum(Enum):
    """
    UnitEnum

    Unit information

    .. data:: celsius = 0

    	Degree in celsius

    .. data:: milli_volts = 1

    	Milli volts

    .. data:: milli_amperes = 2

    	Milli amperes

    .. data:: rpm = 3

    	Rotations per minute

    .. data:: watts = 4

    	Watts

    .. data:: dbm = 5

    	dBm

    .. data:: db = 6

    	dB

    """

    celsius = 0

    milli_volts = 1

    milli_amperes = 2

    rpm = 3

    watts = 4

    dbm = 5

    db = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
        return meta._meta_table['UnitEnum']



class Inventory(object):
    """
    Inventory information
    
    .. attribute:: entities
    
    	Entities Table
    	**type**\:   :py:class:`Entities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Entities>`
    
    .. attribute:: racks
    
    	RackTable
    	**type**\:   :py:class:`Racks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks>`
    
    

    """

    _prefix = 'invmgr-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.entities = Inventory.Entities()
        self.entities.parent = self
        self.racks = Inventory.Racks()
        self.racks.parent = self


    class Entities(object):
        """
        Entities Table
        
        .. attribute:: entity
        
        	Entity name
        	**type**\: list of    :py:class:`Entity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Entities.Entity>`
        
        

        """

        _prefix = 'invmgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.entity = YList()
            self.entity.parent = self
            self.entity.name = 'entity'


        class Entity(object):
            """
            Entity name
            
            .. attribute:: name  <key>
            
            	Entity name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: attributes
            
            	Attributes
            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Entities.Entity.Attributes>`
            
            .. attribute:: subentities
            
            	SubEntities Table
            	**type**\:   :py:class:`Subentities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Entities.Entity.Subentities>`
            
            

            """

            _prefix = 'invmgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.name = None
                self.attributes = Inventory.Entities.Entity.Attributes()
                self.attributes.parent = self
                self.subentities = Inventory.Entities.Entity.Subentities()
                self.subentities.parent = self


            class Subentities(object):
                """
                SubEntities Table
                
                .. attribute:: subentity
                
                	Subentity name
                	**type**\: list of    :py:class:`Subentity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Entities.Entity.Subentities.Subentity>`
                
                

                """

                _prefix = 'invmgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.subentity = YList()
                    self.subentity.parent = self
                    self.subentity.name = 'subentity'


                class Subentity(object):
                    """
                    Subentity name
                    
                    .. attribute:: name  <key>
                    
                    	Subentity name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: name_xr
                    
                    	Subentity name
                    	**type**\:  str
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.name = None
                        self.name_xr = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.name is None:
                            raise YPYModelError('Key property name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:subentity[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.name is not None:
                            return True

                        if self.name_xr is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Entities.Entity.Subentities.Subentity']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:subentities'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.subentity is not None:
                        for child_ref in self.subentity:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                    return meta._meta_table['Inventory.Entities.Entity.Subentities']['meta_info']


            class Attributes(object):
                """
                Attributes
                
                .. attribute:: inv_asset_bag
                
                	Inventory Asset Bag
                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Entities.Entity.Attributes.InvAssetBag>`
                
                .. attribute:: inv_basic_bag
                
                	Inventory Basic Bag
                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Entities.Entity.Attributes.InvBasicBag>`
                
                

                """

                _prefix = 'invmgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.inv_asset_bag = Inventory.Entities.Entity.Attributes.InvAssetBag()
                    self.inv_asset_bag.parent = self
                    self.inv_basic_bag = Inventory.Entities.Entity.Attributes.InvBasicBag()
                    self.inv_basic_bag.parent = self


                class InvBasicBag(object):
                    """
                    Inventory Basic Bag
                    
                    .. attribute:: alias
                    
                    	useful for storing an entity alias 
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: asset_id_str
                    
                    	asset Identification string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: asset_identification
                    
                    	asset Identification
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ceport
                    
                    	1 if ce port found, 0 if not
                    	**type**\:  bool
                    
                    .. attribute:: chip_hardware_revision
                    
                    	chip module hw revision string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: composite_class_code
                    
                    	Major&minor class of the entity
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: description
                    
                    	describes in user\-readable terms       what the entity in question does
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: environmental_monitor_path
                    
                    	sysdb name of sensor in the envmon EDM
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: firmware_revision
                    
                    	firmware revision string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: group_flag
                    
                    	indicates if this entity is group       or not
                    	**type**\:  bool
                    
                    .. attribute:: hardware_revision
                    
                    	hw revision string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: is_field_replaceable_unit
                    
                    	1 if Field Replaceable Unit 0, if not
                    	**type**\:  bool
                    
                    .. attribute:: manufacturer_asset_tags
                    
                    	Manufacture Asset Tags
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: manufacturer_name
                    
                    	manufacturer's name
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: memory_size
                    
                    	Size of memory associated with       the entity where applicable
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: model_name
                    
                    	model name
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: name
                    
                    	name string for the entity
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: new_deviation_number
                    
                    	integer value for New Deviation Number 0x88
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: physical_layer_interface_module_type
                    
                    	integer value for plim type if     applicable to this entity
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: redundancystate
                    
                    	integer value for Redundancy State if     applicable to this entity
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: serial_number
                    
                    	serial number
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: software_revision
                    
                    	software revision string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: unique_id
                    
                    	Unique id for an entity
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: unrecognized_fru
                    
                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                    	**type**\:  bool
                    
                    .. attribute:: vendor_type
                    
                    	maps to the vendor OID string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: xr_scoped
                    
                    	1 if xr scoped, 0 if not
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.alias = None
                        self.asset_id_str = None
                        self.asset_identification = None
                        self.ceport = None
                        self.chip_hardware_revision = None
                        self.composite_class_code = None
                        self.description = None
                        self.environmental_monitor_path = None
                        self.firmware_revision = None
                        self.group_flag = None
                        self.hardware_revision = None
                        self.is_field_replaceable_unit = None
                        self.manufacturer_asset_tags = None
                        self.manufacturer_name = None
                        self.memory_size = None
                        self.model_name = None
                        self.name = None
                        self.new_deviation_number = None
                        self.physical_layer_interface_module_type = None
                        self.redundancystate = None
                        self.serial_number = None
                        self.software_revision = None
                        self.unique_id = None
                        self.unrecognized_fru = None
                        self.vendor_type = None
                        self.xr_scoped = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.alias is not None:
                            return True

                        if self.asset_id_str is not None:
                            return True

                        if self.asset_identification is not None:
                            return True

                        if self.ceport is not None:
                            return True

                        if self.chip_hardware_revision is not None:
                            return True

                        if self.composite_class_code is not None:
                            return True

                        if self.description is not None:
                            return True

                        if self.environmental_monitor_path is not None:
                            return True

                        if self.firmware_revision is not None:
                            return True

                        if self.group_flag is not None:
                            return True

                        if self.hardware_revision is not None:
                            return True

                        if self.is_field_replaceable_unit is not None:
                            return True

                        if self.manufacturer_asset_tags is not None:
                            return True

                        if self.manufacturer_name is not None:
                            return True

                        if self.memory_size is not None:
                            return True

                        if self.model_name is not None:
                            return True

                        if self.name is not None:
                            return True

                        if self.new_deviation_number is not None:
                            return True

                        if self.physical_layer_interface_module_type is not None:
                            return True

                        if self.redundancystate is not None:
                            return True

                        if self.serial_number is not None:
                            return True

                        if self.software_revision is not None:
                            return True

                        if self.unique_id is not None:
                            return True

                        if self.unrecognized_fru is not None:
                            return True

                        if self.vendor_type is not None:
                            return True

                        if self.xr_scoped is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Entities.Entity.Attributes.InvBasicBag']['meta_info']


                class InvAssetBag(object):
                    """
                    Inventory Asset Bag
                    
                    .. attribute:: manufacturer_assembly_number
                    
                    	Manufacture Assembly number
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: manufacturer_assembly_revision
                    
                    	Manufacture assembly revision
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: manufacturer_common_language_equipment_identifier
                    
                    	Common Language Equipment           Identifier number
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: manufacturer_firmware_identifier
                    
                    	
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: manufacturer_software_identifier
                    
                    	
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: original_equipment_manufacturer_string
                    
                    	String containing OEM information           if applicable
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: part_number
                    
                    	
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.manufacturer_assembly_number = None
                        self.manufacturer_assembly_revision = None
                        self.manufacturer_common_language_equipment_identifier = None
                        self.manufacturer_firmware_identifier = None
                        self.manufacturer_software_identifier = None
                        self.original_equipment_manufacturer_string = None
                        self.part_number = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.manufacturer_assembly_number is not None:
                            return True

                        if self.manufacturer_assembly_revision is not None:
                            return True

                        if self.manufacturer_common_language_equipment_identifier is not None:
                            return True

                        if self.manufacturer_firmware_identifier is not None:
                            return True

                        if self.manufacturer_software_identifier is not None:
                            return True

                        if self.original_equipment_manufacturer_string is not None:
                            return True

                        if self.part_number is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Entities.Entity.Attributes.InvAssetBag']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                        return True

                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                    return meta._meta_table['Inventory.Entities.Entity.Attributes']['meta_info']

            @property
            def _common_path(self):
                if self.name is None:
                    raise YPYModelError('Key property name is None')

                return '/Cisco-IOS-XR-invmgr-oper:inventory/Cisco-IOS-XR-invmgr-oper:entities/Cisco-IOS-XR-invmgr-oper:entity[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.name is not None:
                    return True

                if self.attributes is not None and self.attributes._has_data():
                    return True

                if self.subentities is not None and self.subentities._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                return meta._meta_table['Inventory.Entities.Entity']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-invmgr-oper:inventory/Cisco-IOS-XR-invmgr-oper:entities'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.entity is not None:
                for child_ref in self.entity:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
            return meta._meta_table['Inventory.Entities']['meta_info']


    class Racks(object):
        """
        RackTable
        
        .. attribute:: rack
        
        	Rack name
        	**type**\: list of    :py:class:`Rack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack>`
        
        

        """

        _prefix = 'invmgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.rack = YList()
            self.rack.parent = self
            self.rack.name = 'rack'


        class Rack(object):
            """
            Rack name
            
            .. attribute:: name  <key>
            
            	Rack name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: attributes
            
            	Attributes
            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes>`
            
            .. attribute:: entity
            
            	Entity information
            	**type**\:   :py:class:`Entity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity>`
            
            .. attribute:: fantray
            
            	Fantray information
            	**type**\:   :py:class:`Fantray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray>`
            
            .. attribute:: powershelf
            
            	Powershelf information
            	**type**\:   :py:class:`Powershelf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf>`
            
            

            """

            _prefix = 'invmgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.name = None
                self.attributes = Inventory.Racks.Rack.Attributes()
                self.attributes.parent = self
                self.entity = Inventory.Racks.Rack.Entity()
                self.entity.parent = self
                self.fantray = Inventory.Racks.Rack.Fantray()
                self.fantray.parent = self
                self.powershelf = Inventory.Racks.Rack.Powershelf()
                self.powershelf.parent = self


            class Entity(object):
                """
                Entity information
                
                .. attribute:: slot
                
                	Slot number
                	**type**\: list of    :py:class:`Slot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot>`
                
                

                """

                _prefix = 'invmgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.slot = YList()
                    self.slot.parent = self
                    self.slot.name = 'slot'


                class Slot(object):
                    """
                    Slot number
                    
                    .. attribute:: name  <key>
                    
                    	Slot name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: attributes
                    
                    	Attributes
                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes>`
                    
                    .. attribute:: tsi1s
                    
                    	Entity Level 1
                    	**type**\:   :py:class:`Tsi1S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S>`
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.name = None
                        self.attributes = Inventory.Racks.Rack.Entity.Slot.Attributes()
                        self.attributes.parent = self
                        self.tsi1s = Inventory.Racks.Rack.Entity.Slot.Tsi1S()
                        self.tsi1s.parent = self


                    class Tsi1S(object):
                        """
                        Entity Level 1
                        
                        .. attribute:: tsi1
                        
                        	TSI1
                        	**type**\: list of    :py:class:`Tsi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1>`
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tsi1 = YList()
                            self.tsi1.parent = self
                            self.tsi1.name = 'tsi1'


                        class Tsi1(object):
                            """
                            TSI1
                            
                            .. attribute:: name  <key>
                            
                            	TSI1
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: attributes
                            
                            	Attributes
                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes>`
                            
                            .. attribute:: tsi2s
                            
                            	Entity Level 2
                            	**type**\:   :py:class:`Tsi2S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S>`
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.name = None
                                self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes()
                                self.attributes.parent = self
                                self.tsi2s = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S()
                                self.tsi2s.parent = self


                            class Tsi2S(object):
                                """
                                Entity Level 2
                                
                                .. attribute:: tsi2
                                
                                	TSI2
                                	**type**\: list of    :py:class:`Tsi2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tsi2 = YList()
                                    self.tsi2.parent = self
                                    self.tsi2.name = 'tsi2'


                                class Tsi2(object):
                                    """
                                    TSI2
                                    
                                    .. attribute:: name  <key>
                                    
                                    	TSI2
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: attributes
                                    
                                    	Attributes
                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes>`
                                    
                                    .. attribute:: tsi3s
                                    
                                    	Entity Level 3
                                    	**type**\:   :py:class:`Tsi3S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S>`
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.name = None
                                        self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes()
                                        self.attributes.parent = self
                                        self.tsi3s = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S()
                                        self.tsi3s.parent = self


                                    class Tsi3S(object):
                                        """
                                        Entity Level 3
                                        
                                        .. attribute:: tsi3
                                        
                                        	TSI3
                                        	**type**\: list of    :py:class:`Tsi3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tsi3 = YList()
                                            self.tsi3.parent = self
                                            self.tsi3.name = 'tsi3'


                                        class Tsi3(object):
                                            """
                                            TSI3
                                            
                                            .. attribute:: name  <key>
                                            
                                            	TSI3
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: attributes
                                            
                                            	Attributes
                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes>`
                                            
                                            .. attribute:: tsi4s
                                            
                                            	Entity Level 4
                                            	**type**\:   :py:class:`Tsi4S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S>`
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.name = None
                                                self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes()
                                                self.attributes.parent = self
                                                self.tsi4s = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S()
                                                self.tsi4s.parent = self


                                            class Tsi4S(object):
                                                """
                                                Entity Level 4
                                                
                                                .. attribute:: tsi4
                                                
                                                	TSI4
                                                	**type**\: list of    :py:class:`Tsi4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.tsi4 = YList()
                                                    self.tsi4.parent = self
                                                    self.tsi4.name = 'tsi4'


                                                class Tsi4(object):
                                                    """
                                                    TSI4
                                                    
                                                    .. attribute:: name  <key>
                                                    
                                                    	TSI4
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: attributes
                                                    
                                                    	Attributes
                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes>`
                                                    
                                                    .. attribute:: tsi5s
                                                    
                                                    	Entity Level 5
                                                    	**type**\:   :py:class:`Tsi5S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.name = None
                                                        self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes()
                                                        self.attributes.parent = self
                                                        self.tsi5s = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S()
                                                        self.tsi5s.parent = self


                                                    class Tsi5S(object):
                                                        """
                                                        Entity Level 5
                                                        
                                                        .. attribute:: tsi5
                                                        
                                                        	TSI5
                                                        	**type**\: list of    :py:class:`Tsi5 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.tsi5 = YList()
                                                            self.tsi5.parent = self
                                                            self.tsi5.name = 'tsi5'


                                                        class Tsi5(object):
                                                            """
                                                            TSI5
                                                            
                                                            .. attribute:: name  <key>
                                                            
                                                            	TSI5
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                            
                                                            .. attribute:: attributes
                                                            
                                                            	Attributes
                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes>`
                                                            
                                                            .. attribute:: tsi6s
                                                            
                                                            	Entity Level 6
                                                            	**type**\:   :py:class:`Tsi6S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.name = None
                                                                self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes()
                                                                self.attributes.parent = self
                                                                self.tsi6s = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S()
                                                                self.tsi6s.parent = self


                                                            class Tsi6S(object):
                                                                """
                                                                Entity Level 6
                                                                
                                                                .. attribute:: tsi6
                                                                
                                                                	TSI6
                                                                	**type**\: list of    :py:class:`Tsi6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.tsi6 = YList()
                                                                    self.tsi6.parent = self
                                                                    self.tsi6.name = 'tsi6'


                                                                class Tsi6(object):
                                                                    """
                                                                    TSI6
                                                                    
                                                                    .. attribute:: name  <key>
                                                                    
                                                                    	TSI6
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                    
                                                                    .. attribute:: attributes
                                                                    
                                                                    	Attributes
                                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes>`
                                                                    
                                                                    .. attribute:: tsi7s
                                                                    
                                                                    	Entity Level 7
                                                                    	**type**\:   :py:class:`Tsi7S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.name = None
                                                                        self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes()
                                                                        self.attributes.parent = self
                                                                        self.tsi7s = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S()
                                                                        self.tsi7s.parent = self


                                                                    class Tsi7S(object):
                                                                        """
                                                                        Entity Level 7
                                                                        
                                                                        .. attribute:: tsi7
                                                                        
                                                                        	TSI7
                                                                        	**type**\: list of    :py:class:`Tsi7 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.tsi7 = YList()
                                                                            self.tsi7.parent = self
                                                                            self.tsi7.name = 'tsi7'


                                                                        class Tsi7(object):
                                                                            """
                                                                            TSI7
                                                                            
                                                                            .. attribute:: name  <key>
                                                                            
                                                                            	TSI7
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                            
                                                                            .. attribute:: attributes
                                                                            
                                                                            	Attributes
                                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes>`
                                                                            
                                                                            .. attribute:: tsi8s
                                                                            
                                                                            	Entity Level 8
                                                                            	**type**\:   :py:class:`Tsi8S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.name = None
                                                                                self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes()
                                                                                self.attributes.parent = self
                                                                                self.tsi8s = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S()
                                                                                self.tsi8s.parent = self


                                                                            class Tsi8S(object):
                                                                                """
                                                                                Entity Level 8
                                                                                
                                                                                .. attribute:: tsi8
                                                                                
                                                                                	TSI8
                                                                                	**type**\: list of    :py:class:`Tsi8 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.tsi8 = YList()
                                                                                    self.tsi8.parent = self
                                                                                    self.tsi8.name = 'tsi8'


                                                                                class Tsi8(object):
                                                                                    """
                                                                                    TSI8
                                                                                    
                                                                                    .. attribute:: name  <key>
                                                                                    
                                                                                    	TSI8
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                    
                                                                                    .. attribute:: attributes
                                                                                    
                                                                                    	Attributes
                                                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes>`
                                                                                    
                                                                                    .. attribute:: tsi9s
                                                                                    
                                                                                    	Entity Level 9
                                                                                    	**type**\:   :py:class:`Tsi9S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S>`
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.name = None
                                                                                        self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes()
                                                                                        self.attributes.parent = self
                                                                                        self.tsi9s = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S()
                                                                                        self.tsi9s.parent = self


                                                                                    class Tsi9S(object):
                                                                                        """
                                                                                        Entity Level 9
                                                                                        
                                                                                        .. attribute:: tsi9
                                                                                        
                                                                                        	TSI9
                                                                                        	**type**\: list of    :py:class:`Tsi9 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.tsi9 = YList()
                                                                                            self.tsi9.parent = self
                                                                                            self.tsi9.name = 'tsi9'


                                                                                        class Tsi9(object):
                                                                                            """
                                                                                            TSI9
                                                                                            
                                                                                            .. attribute:: name  <key>
                                                                                            
                                                                                            	TSI9
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                            
                                                                                            .. attribute:: attributes
                                                                                            
                                                                                            	Attributes
                                                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes>`
                                                                                            
                                                                                            .. attribute:: tsi10s
                                                                                            
                                                                                            	Entity Level 10
                                                                                            	**type**\:   :py:class:`Tsi10S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S>`
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.name = None
                                                                                                self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes()
                                                                                                self.attributes.parent = self
                                                                                                self.tsi10s = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S()
                                                                                                self.tsi10s.parent = self


                                                                                            class Tsi10S(object):
                                                                                                """
                                                                                                Entity Level 10
                                                                                                
                                                                                                .. attribute:: tsi10
                                                                                                
                                                                                                	TSI10
                                                                                                	**type**\: list of    :py:class:`Tsi10 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.tsi10 = YList()
                                                                                                    self.tsi10.parent = self
                                                                                                    self.tsi10.name = 'tsi10'


                                                                                                class Tsi10(object):
                                                                                                    """
                                                                                                    TSI10
                                                                                                    
                                                                                                    .. attribute:: name  <key>
                                                                                                    
                                                                                                    	TSI10
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                                    
                                                                                                    .. attribute:: attributes
                                                                                                    
                                                                                                    	Attributes
                                                                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes>`
                                                                                                    
                                                                                                    .. attribute:: tsi11s
                                                                                                    
                                                                                                    	Entity Level 11
                                                                                                    	**type**\:   :py:class:`Tsi11S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S>`
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.name = None
                                                                                                        self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes()
                                                                                                        self.attributes.parent = self
                                                                                                        self.tsi11s = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S()
                                                                                                        self.tsi11s.parent = self


                                                                                                    class Tsi11S(object):
                                                                                                        """
                                                                                                        Entity Level 11
                                                                                                        
                                                                                                        .. attribute:: tsi11
                                                                                                        
                                                                                                        	TSI11
                                                                                                        	**type**\: list of    :py:class:`Tsi11 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.tsi11 = YList()
                                                                                                            self.tsi11.parent = self
                                                                                                            self.tsi11.name = 'tsi11'


                                                                                                        class Tsi11(object):
                                                                                                            """
                                                                                                            TSI11
                                                                                                            
                                                                                                            .. attribute:: name  <key>
                                                                                                            
                                                                                                            	TSI11
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                                            
                                                                                                            .. attribute:: attributes
                                                                                                            
                                                                                                            	Attributes
                                                                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes>`
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.name = None
                                                                                                                self.attributes = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes()
                                                                                                                self.attributes.parent = self


                                                                                                            class Attributes(object):
                                                                                                                """
                                                                                                                Attributes
                                                                                                                
                                                                                                                .. attribute:: env_sensor_info
                                                                                                                
                                                                                                                	Environment sensor info
                                                                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfo>`
                                                                                                                
                                                                                                                .. attribute:: env_sensor_info_xml
                                                                                                                
                                                                                                                	Environment sensor info XML
                                                                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml>`
                                                                                                                
                                                                                                                .. attribute:: fru_info
                                                                                                                
                                                                                                                	Inventory EDM FRU info
                                                                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo>`
                                                                                                                
                                                                                                                .. attribute:: inv_asset_bag
                                                                                                                
                                                                                                                	Inventory Asset Bag
                                                                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvAssetBag>`
                                                                                                                
                                                                                                                .. attribute:: inv_basic_bag
                                                                                                                
                                                                                                                	Inventory Basic Bag
                                                                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvBasicBag>`
                                                                                                                
                                                                                                                .. attribute:: inv_eeprom_info
                                                                                                                
                                                                                                                	Inventory EDM EEPROM Information Bag
                                                                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo>`
                                                                                                                
                                                                                                                .. attribute:: module_done
                                                                                                                
                                                                                                                	Inventory EDM Module Done Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**default value**\: 1
                                                                                                                
                                                                                                                .. attribute:: node_id
                                                                                                                
                                                                                                                	Node ID Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** 0..4294967295
                                                                                                                
                                                                                                                .. attribute:: pwg_info
                                                                                                                
                                                                                                                	Inventory EDM PWG info
                                                                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.PwgInfo>`
                                                                                                                
                                                                                                                .. attribute:: threshold
                                                                                                                
                                                                                                                	Threshold
                                                                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold>`
                                                                                                                
                                                                                                                .. attribute:: vm_done
                                                                                                                
                                                                                                                	VM Done Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                .. attribute:: vm_node_id
                                                                                                                
                                                                                                                	VM Node ID Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** 0..4294967295
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfo()
                                                                                                                    self.env_sensor_info.parent = self
                                                                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml()
                                                                                                                    self.env_sensor_info_xml.parent = self
                                                                                                                    self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo()
                                                                                                                    self.fru_info.parent = self
                                                                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvAssetBag()
                                                                                                                    self.inv_asset_bag.parent = self
                                                                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvBasicBag()
                                                                                                                    self.inv_basic_bag.parent = self
                                                                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo()
                                                                                                                    self.inv_eeprom_info.parent = self
                                                                                                                    self.module_done = None
                                                                                                                    self.node_id = None
                                                                                                                    self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.PwgInfo()
                                                                                                                    self.pwg_info.parent = self
                                                                                                                    self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold()
                                                                                                                    self.threshold.parent = self
                                                                                                                    self.vm_done = None
                                                                                                                    self.vm_node_id = None


                                                                                                                class EnvSensorInfo(object):
                                                                                                                    """
                                                                                                                    Environment sensor info
                                                                                                                    
                                                                                                                    .. attribute:: age_time_stamp
                                                                                                                    
                                                                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: alarm_type
                                                                                                                    
                                                                                                                    	Indicates threshold violation
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: data_type
                                                                                                                    
                                                                                                                    	Sensor data type enums
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: device_description
                                                                                                                    
                                                                                                                    	Device Name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: device_id
                                                                                                                    
                                                                                                                    	Identifier for this device
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: field_validity_bitmap
                                                                                                                    
                                                                                                                    	Sensor valid bitmap
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: precision
                                                                                                                    
                                                                                                                    	Sensor precision range
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: scale
                                                                                                                    
                                                                                                                    	Sensor scale enums
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: status
                                                                                                                    
                                                                                                                    	Sensor operation state enums
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: units
                                                                                                                    
                                                                                                                    	Units of variable being read
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: update_rate
                                                                                                                    
                                                                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: value
                                                                                                                    
                                                                                                                    	Current reading of sensor
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.age_time_stamp = None
                                                                                                                        self.alarm_type = None
                                                                                                                        self.data_type = None
                                                                                                                        self.device_description = None
                                                                                                                        self.device_id = None
                                                                                                                        self.field_validity_bitmap = None
                                                                                                                        self.precision = None
                                                                                                                        self.scale = None
                                                                                                                        self.status = None
                                                                                                                        self.units = None
                                                                                                                        self.update_rate = None
                                                                                                                        self.value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.age_time_stamp is not None:
                                                                                                                            return True

                                                                                                                        if self.alarm_type is not None:
                                                                                                                            return True

                                                                                                                        if self.data_type is not None:
                                                                                                                            return True

                                                                                                                        if self.device_description is not None:
                                                                                                                            return True

                                                                                                                        if self.device_id is not None:
                                                                                                                            return True

                                                                                                                        if self.field_validity_bitmap is not None:
                                                                                                                            return True

                                                                                                                        if self.precision is not None:
                                                                                                                            return True

                                                                                                                        if self.scale is not None:
                                                                                                                            return True

                                                                                                                        if self.status is not None:
                                                                                                                            return True

                                                                                                                        if self.units is not None:
                                                                                                                            return True

                                                                                                                        if self.update_rate is not None:
                                                                                                                            return True

                                                                                                                        if self.value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfo']['meta_info']


                                                                                                                class PwgInfo(object):
                                                                                                                    """
                                                                                                                    Inventory EDM PWG info
                                                                                                                    
                                                                                                                    .. attribute:: power_group_available_current
                                                                                                                    
                                                                                                                    	available current
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_group_drawn_current
                                                                                                                    
                                                                                                                    	drawn current
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_group_power_units
                                                                                                                    
                                                                                                                    	power units
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    .. attribute:: power_group_redundancy_mode
                                                                                                                    
                                                                                                                    	redundancy mode
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.power_group_available_current = None
                                                                                                                        self.power_group_drawn_current = None
                                                                                                                        self.power_group_power_units = None
                                                                                                                        self.power_group_redundancy_mode = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.power_group_available_current is not None:
                                                                                                                            return True

                                                                                                                        if self.power_group_drawn_current is not None:
                                                                                                                            return True

                                                                                                                        if self.power_group_power_units is not None:
                                                                                                                            return True

                                                                                                                        if self.power_group_redundancy_mode is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.PwgInfo']['meta_info']


                                                                                                                class EnvSensorInfoXml(object):
                                                                                                                    """
                                                                                                                    Environment sensor info XML
                                                                                                                    
                                                                                                                    .. attribute:: data_type
                                                                                                                    
                                                                                                                    	Sensor data type
                                                                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: description
                                                                                                                    
                                                                                                                    	Device Name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: status
                                                                                                                    
                                                                                                                    	Sensor operation state
                                                                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: threshold
                                                                                                                    
                                                                                                                    	Threshold information
                                                                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                                                    
                                                                                                                    .. attribute:: units
                                                                                                                    
                                                                                                                    	Units of variable being read
                                                                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: update_rate
                                                                                                                    
                                                                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: value
                                                                                                                    
                                                                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.data_type = None
                                                                                                                        self.description = None
                                                                                                                        self.status = None
                                                                                                                        self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                                        self.threshold.parent = self
                                                                                                                        self.units = None
                                                                                                                        self.update_rate = None
                                                                                                                        self.value = None


                                                                                                                    class Threshold(object):
                                                                                                                        """
                                                                                                                        Threshold information
                                                                                                                        
                                                                                                                        .. attribute:: threshold_array
                                                                                                                        
                                                                                                                        	Array of threshold
                                                                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.threshold_array = YList()
                                                                                                                            self.threshold_array.parent = self
                                                                                                                            self.threshold_array.name = 'threshold_array'


                                                                                                                        class ThresholdArray(object):
                                                                                                                            """
                                                                                                                            Array of threshold
                                                                                                                            
                                                                                                                            .. attribute:: threshold_name
                                                                                                                            
                                                                                                                            	Threshold name
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..50
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_name = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_name is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.threshold_array is not None:
                                                                                                                                for child_ref in self.threshold_array:
                                                                                                                                    if child_ref._has_data():
                                                                                                                                        return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.data_type is not None:
                                                                                                                            return True

                                                                                                                        if self.description is not None:
                                                                                                                            return True

                                                                                                                        if self.status is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                                                                            return True

                                                                                                                        if self.units is not None:
                                                                                                                            return True

                                                                                                                        if self.update_rate is not None:
                                                                                                                            return True

                                                                                                                        if self.value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                                                class InvAssetBag(object):
                                                                                                                    """
                                                                                                                    Inventory Asset Bag
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_assembly_number
                                                                                                                    
                                                                                                                    	Manufacture Assembly number
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_assembly_revision
                                                                                                                    
                                                                                                                    	Manufacture assembly revision
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                                                    
                                                                                                                    	Common Language Equipment           Identifier number
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                                                                    
                                                                                                                    	
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_software_identifier
                                                                                                                    
                                                                                                                    	
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                                                                    
                                                                                                                    	String containing OEM information           if applicable
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: part_number
                                                                                                                    
                                                                                                                    	
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.manufacturer_assembly_number = None
                                                                                                                        self.manufacturer_assembly_revision = None
                                                                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                                                                        self.manufacturer_firmware_identifier = None
                                                                                                                        self.manufacturer_software_identifier = None
                                                                                                                        self.original_equipment_manufacturer_string = None
                                                                                                                        self.part_number = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.manufacturer_assembly_number is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_assembly_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_software_identifier is not None:
                                                                                                                            return True

                                                                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                                                                            return True

                                                                                                                        if self.part_number is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvAssetBag']['meta_info']


                                                                                                                class Threshold(object):
                                                                                                                    """
                                                                                                                    Threshold
                                                                                                                    
                                                                                                                    .. attribute:: critical_hi
                                                                                                                    
                                                                                                                    	Critical High
                                                                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi>`
                                                                                                                    
                                                                                                                    .. attribute:: critical_lo
                                                                                                                    
                                                                                                                    	Critical Low
                                                                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo>`
                                                                                                                    
                                                                                                                    .. attribute:: major_hi
                                                                                                                    
                                                                                                                    	Major High
                                                                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi>`
                                                                                                                    
                                                                                                                    .. attribute:: major_lo
                                                                                                                    
                                                                                                                    	Major Low
                                                                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo>`
                                                                                                                    
                                                                                                                    .. attribute:: minor_hi
                                                                                                                    
                                                                                                                    	Minor High
                                                                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi>`
                                                                                                                    
                                                                                                                    .. attribute:: minor_lo
                                                                                                                    
                                                                                                                    	Minor Low
                                                                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo>`
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi()
                                                                                                                        self.critical_hi.parent = self
                                                                                                                        self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo()
                                                                                                                        self.critical_lo.parent = self
                                                                                                                        self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi()
                                                                                                                        self.major_hi.parent = self
                                                                                                                        self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo()
                                                                                                                        self.major_lo.parent = self
                                                                                                                        self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi()
                                                                                                                        self.minor_hi.parent = self
                                                                                                                        self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo()
                                                                                                                        self.minor_lo.parent = self


                                                                                                                    class MajorLo(object):
                                                                                                                        """
                                                                                                                        Major Low
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo']['meta_info']


                                                                                                                    class CriticalHi(object):
                                                                                                                        """
                                                                                                                        Critical High
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                                                    class MinorHi(object):
                                                                                                                        """
                                                                                                                        Minor High
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi']['meta_info']


                                                                                                                    class MajorHi(object):
                                                                                                                        """
                                                                                                                        Major High
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi']['meta_info']


                                                                                                                    class CriticalLo(object):
                                                                                                                        """
                                                                                                                        Critical Low
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                                                    class MinorLo(object):
                                                                                                                        """
                                                                                                                        Minor Low
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                                            return True

                                                                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                                            return True

                                                                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                                                                            return True

                                                                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                                                                            return True

                                                                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                                            return True

                                                                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold']['meta_info']


                                                                                                                class FruInfo(object):
                                                                                                                    """
                                                                                                                    Inventory EDM FRU info
                                                                                                                    
                                                                                                                    .. attribute:: card_administrative_state
                                                                                                                    
                                                                                                                    	card admin state\: shutdown or not
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: card_monitor_state
                                                                                                                    
                                                                                                                    	card is monitored by a manager or left unmonitored
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: card_operational_state
                                                                                                                    
                                                                                                                    	card operation state
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: card_reset_reason
                                                                                                                    
                                                                                                                    	card reset reason enum
                                                                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: card_up_time
                                                                                                                    
                                                                                                                    	card up time
                                                                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.CardUpTime>`
                                                                                                                    
                                                                                                                    .. attribute:: last_operational_state_change
                                                                                                                    
                                                                                                                    	last card oper change state
                                                                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                                                    
                                                                                                                    .. attribute:: power_administrative_state
                                                                                                                    
                                                                                                                    	power admin state\: up or down
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_current_measurement
                                                                                                                    
                                                                                                                    	power current\: not implemented
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_operational_state
                                                                                                                    
                                                                                                                    	Power operation state
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.card_administrative_state = None
                                                                                                                        self.card_monitor_state = None
                                                                                                                        self.card_operational_state = None
                                                                                                                        self.card_reset_reason = None
                                                                                                                        self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.CardUpTime()
                                                                                                                        self.card_up_time.parent = self
                                                                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                                        self.last_operational_state_change.parent = self
                                                                                                                        self.power_administrative_state = None
                                                                                                                        self.power_current_measurement = None
                                                                                                                        self.power_operational_state = None


                                                                                                                    class LastOperationalStateChange(object):
                                                                                                                        """
                                                                                                                        last card oper change state
                                                                                                                        
                                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                                        
                                                                                                                        	Time Value in Nano\-seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: nanosecond
                                                                                                                        
                                                                                                                        .. attribute:: time_in_seconds
                                                                                                                        
                                                                                                                        	Time Value in Seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: second
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.time_in_nano_seconds = None
                                                                                                                            self.time_in_seconds = None

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                                return True

                                                                                                                            if self.time_in_seconds is not None:
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                                                    class CardUpTime(object):
                                                                                                                        """
                                                                                                                        card up time
                                                                                                                        
                                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                                        
                                                                                                                        	Time Value in Nano\-seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: nanosecond
                                                                                                                        
                                                                                                                        .. attribute:: time_in_seconds
                                                                                                                        
                                                                                                                        	Time Value in Seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: second
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.time_in_nano_seconds = None
                                                                                                                            self.time_in_seconds = None

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                                return True

                                                                                                                            if self.time_in_seconds is not None:
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.card_administrative_state is not None:
                                                                                                                            return True

                                                                                                                        if self.card_monitor_state is not None:
                                                                                                                            return True

                                                                                                                        if self.card_operational_state is not None:
                                                                                                                            return True

                                                                                                                        if self.card_reset_reason is not None:
                                                                                                                            return True

                                                                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                                            return True

                                                                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                                            return True

                                                                                                                        if self.power_administrative_state is not None:
                                                                                                                            return True

                                                                                                                        if self.power_current_measurement is not None:
                                                                                                                            return True

                                                                                                                        if self.power_operational_state is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo']['meta_info']


                                                                                                                class InvBasicBag(object):
                                                                                                                    """
                                                                                                                    Inventory Basic Bag
                                                                                                                    
                                                                                                                    .. attribute:: alias
                                                                                                                    
                                                                                                                    	useful for storing an entity alias 
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: asset_id_str
                                                                                                                    
                                                                                                                    	asset Identification string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: asset_identification
                                                                                                                    
                                                                                                                    	asset Identification
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: ceport
                                                                                                                    
                                                                                                                    	1 if ce port found, 0 if not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: chip_hardware_revision
                                                                                                                    
                                                                                                                    	chip module hw revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: composite_class_code
                                                                                                                    
                                                                                                                    	Major&minor class of the entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: description
                                                                                                                    
                                                                                                                    	describes in user\-readable terms       what the entity in question does
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: environmental_monitor_path
                                                                                                                    
                                                                                                                    	sysdb name of sensor in the envmon EDM
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: firmware_revision
                                                                                                                    
                                                                                                                    	firmware revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: group_flag
                                                                                                                    
                                                                                                                    	indicates if this entity is group       or not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: hardware_revision
                                                                                                                    
                                                                                                                    	hw revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: is_field_replaceable_unit
                                                                                                                    
                                                                                                                    	1 if Field Replaceable Unit 0, if not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_asset_tags
                                                                                                                    
                                                                                                                    	Manufacture Asset Tags
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_name
                                                                                                                    
                                                                                                                    	manufacturer's name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: memory_size
                                                                                                                    
                                                                                                                    	Size of memory associated with       the entity where applicable
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: model_name
                                                                                                                    
                                                                                                                    	model name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: name
                                                                                                                    
                                                                                                                    	name string for the entity
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: new_deviation_number
                                                                                                                    
                                                                                                                    	integer value for New Deviation Number 0x88
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: physical_layer_interface_module_type
                                                                                                                    
                                                                                                                    	integer value for plim type if     applicable to this entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: redundancystate
                                                                                                                    
                                                                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: serial_number
                                                                                                                    
                                                                                                                    	serial number
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: software_revision
                                                                                                                    
                                                                                                                    	software revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: unique_id
                                                                                                                    
                                                                                                                    	Unique id for an entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: unrecognized_fru
                                                                                                                    
                                                                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: vendor_type
                                                                                                                    
                                                                                                                    	maps to the vendor OID string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: xr_scoped
                                                                                                                    
                                                                                                                    	1 if xr scoped, 0 if not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.alias = None
                                                                                                                        self.asset_id_str = None
                                                                                                                        self.asset_identification = None
                                                                                                                        self.ceport = None
                                                                                                                        self.chip_hardware_revision = None
                                                                                                                        self.composite_class_code = None
                                                                                                                        self.description = None
                                                                                                                        self.environmental_monitor_path = None
                                                                                                                        self.firmware_revision = None
                                                                                                                        self.group_flag = None
                                                                                                                        self.hardware_revision = None
                                                                                                                        self.is_field_replaceable_unit = None
                                                                                                                        self.manufacturer_asset_tags = None
                                                                                                                        self.manufacturer_name = None
                                                                                                                        self.memory_size = None
                                                                                                                        self.model_name = None
                                                                                                                        self.name = None
                                                                                                                        self.new_deviation_number = None
                                                                                                                        self.physical_layer_interface_module_type = None
                                                                                                                        self.redundancystate = None
                                                                                                                        self.serial_number = None
                                                                                                                        self.software_revision = None
                                                                                                                        self.unique_id = None
                                                                                                                        self.unrecognized_fru = None
                                                                                                                        self.vendor_type = None
                                                                                                                        self.xr_scoped = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.alias is not None:
                                                                                                                            return True

                                                                                                                        if self.asset_id_str is not None:
                                                                                                                            return True

                                                                                                                        if self.asset_identification is not None:
                                                                                                                            return True

                                                                                                                        if self.ceport is not None:
                                                                                                                            return True

                                                                                                                        if self.chip_hardware_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.composite_class_code is not None:
                                                                                                                            return True

                                                                                                                        if self.description is not None:
                                                                                                                            return True

                                                                                                                        if self.environmental_monitor_path is not None:
                                                                                                                            return True

                                                                                                                        if self.firmware_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.group_flag is not None:
                                                                                                                            return True

                                                                                                                        if self.hardware_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.is_field_replaceable_unit is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_asset_tags is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_name is not None:
                                                                                                                            return True

                                                                                                                        if self.memory_size is not None:
                                                                                                                            return True

                                                                                                                        if self.model_name is not None:
                                                                                                                            return True

                                                                                                                        if self.name is not None:
                                                                                                                            return True

                                                                                                                        if self.new_deviation_number is not None:
                                                                                                                            return True

                                                                                                                        if self.physical_layer_interface_module_type is not None:
                                                                                                                            return True

                                                                                                                        if self.redundancystate is not None:
                                                                                                                            return True

                                                                                                                        if self.serial_number is not None:
                                                                                                                            return True

                                                                                                                        if self.software_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.unique_id is not None:
                                                                                                                            return True

                                                                                                                        if self.unrecognized_fru is not None:
                                                                                                                            return True

                                                                                                                        if self.vendor_type is not None:
                                                                                                                            return True

                                                                                                                        if self.xr_scoped is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvBasicBag']['meta_info']


                                                                                                                class InvEepromInfo(object):
                                                                                                                    """
                                                                                                                    Inventory EDM EEPROM Information Bag
                                                                                                                    
                                                                                                                    .. attribute:: description
                                                                                                                    
                                                                                                                    	A textual description of physical entity
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: eeprom
                                                                                                                    
                                                                                                                    	EEPROM data not from hex data
                                                                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom>`
                                                                                                                    
                                                                                                                    .. attribute:: has_eeprom
                                                                                                                    
                                                                                                                    	use eeprom instead of opaque data
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: inv_card_type
                                                                                                                    
                                                                                                                    	Inventory card type
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: opaque_data
                                                                                                                    
                                                                                                                    	EEPROM hex data
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                                                    
                                                                                                                    .. attribute:: opaque_data_size
                                                                                                                    
                                                                                                                    	size of the EEPROM hex data
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.description = None
                                                                                                                        self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom()
                                                                                                                        self.eeprom.parent = self
                                                                                                                        self.has_eeprom = None
                                                                                                                        self.inv_card_type = None
                                                                                                                        self.opaque_data = None
                                                                                                                        self.opaque_data_size = None


                                                                                                                    class Eeprom(object):
                                                                                                                        """
                                                                                                                        EEPROM data not from hex data
                                                                                                                        
                                                                                                                        .. attribute:: asset_alias
                                                                                                                        
                                                                                                                        	Asset Alias
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: asset_id
                                                                                                                        
                                                                                                                        	Asset ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address1
                                                                                                                        
                                                                                                                        	Base Mac Address #1
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address2
                                                                                                                        
                                                                                                                        	Base Mac Address #2
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address3
                                                                                                                        
                                                                                                                        	Base Mac Address #3
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address4
                                                                                                                        
                                                                                                                        	Base Mac Address #4
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_checksum
                                                                                                                        
                                                                                                                        	Block Checksum
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_count
                                                                                                                        
                                                                                                                        	Block Count
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_length
                                                                                                                        
                                                                                                                        	Block Length
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_signature
                                                                                                                        
                                                                                                                        	Block Signature
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_version
                                                                                                                        
                                                                                                                        	Block Version
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: chassis_sid
                                                                                                                        
                                                                                                                        	Chassis serial number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: clei
                                                                                                                        
                                                                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: controller_family
                                                                                                                        
                                                                                                                        	Controller family
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: controller_type
                                                                                                                        
                                                                                                                        	Controller type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: description
                                                                                                                        
                                                                                                                        	A textual description of physical entity
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num1
                                                                                                                        
                                                                                                                        	Deviation Number # 1
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num2
                                                                                                                        
                                                                                                                        	Deviation Number # 2
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num3
                                                                                                                        
                                                                                                                        	Deviation Number # 3
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num4
                                                                                                                        
                                                                                                                        	Deviation Number # 4
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num5
                                                                                                                        
                                                                                                                        	Deviation Number # 5
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num6
                                                                                                                        
                                                                                                                        	Deviation Number # 6
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num7
                                                                                                                        
                                                                                                                        	Deviation Number # 7
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: eci
                                                                                                                        
                                                                                                                        	Equipment Catalog Item (ECI) number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: eeprom_size
                                                                                                                        
                                                                                                                        	EEPROM Size
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: engineer_use
                                                                                                                        
                                                                                                                        	Engineer Use
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: fru_major_type
                                                                                                                        
                                                                                                                        	FRU Major Type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: fru_minor_type
                                                                                                                        
                                                                                                                        	FRU Minor Type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: hw_version
                                                                                                                        
                                                                                                                        	Hardware Version
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: hwid
                                                                                                                        
                                                                                                                        	Hardware Revision
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: idprom_format_rev
                                                                                                                        
                                                                                                                        	IDPROM Format Revision
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size1
                                                                                                                        
                                                                                                                        	Mac Address Block Size #1
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size2
                                                                                                                        
                                                                                                                        	Mac Address Block Size #2
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size3
                                                                                                                        
                                                                                                                        	Mac Address Block Size #3
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size4
                                                                                                                        
                                                                                                                        	Mac Address Block Size #4
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: manu_test_data
                                                                                                                        
                                                                                                                        	Manufacturing Test Data
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mfg_bits
                                                                                                                        
                                                                                                                        	MFG Bits
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mfg_deviation
                                                                                                                        
                                                                                                                        	MFG Deviation
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: oem_string
                                                                                                                        
                                                                                                                        	OEM String
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: part_number
                                                                                                                        
                                                                                                                        	Part Number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: part_revision
                                                                                                                        
                                                                                                                        	Part Revision
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pca_num
                                                                                                                        
                                                                                                                        	PCA number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pcavid
                                                                                                                        
                                                                                                                        	PCA revision ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pcb_serial_num
                                                                                                                        
                                                                                                                        	PCB Serial Number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pid
                                                                                                                        
                                                                                                                        	Product ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: power_consumption
                                                                                                                        
                                                                                                                        	Power Consumption
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: power_supply_type
                                                                                                                        
                                                                                                                        	Power Supply Type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: product_id
                                                                                                                        
                                                                                                                        	Product ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: rma
                                                                                                                        
                                                                                                                        	RMA Data
                                                                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                                        
                                                                                                                        .. attribute:: rma_code
                                                                                                                        
                                                                                                                        	RMA Code
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: serial_number
                                                                                                                        
                                                                                                                        	Serial Number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: snmpoid
                                                                                                                        
                                                                                                                        	SNMP OID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: top_assem_part_num
                                                                                                                        
                                                                                                                        	Top assembly part number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: top_assem_vid
                                                                                                                        
                                                                                                                        	Top assembly revision number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: udi_description
                                                                                                                        
                                                                                                                        	UDI description
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: udi_name
                                                                                                                        
                                                                                                                        	UDI name
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: vid
                                                                                                                        
                                                                                                                        	Version ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.asset_alias = None
                                                                                                                            self.asset_id = None
                                                                                                                            self.base_mac_address1 = None
                                                                                                                            self.base_mac_address2 = None
                                                                                                                            self.base_mac_address3 = None
                                                                                                                            self.base_mac_address4 = None
                                                                                                                            self.block_checksum = None
                                                                                                                            self.block_count = None
                                                                                                                            self.block_length = None
                                                                                                                            self.block_signature = None
                                                                                                                            self.block_version = None
                                                                                                                            self.chassis_sid = None
                                                                                                                            self.clei = None
                                                                                                                            self.controller_family = None
                                                                                                                            self.controller_type = None
                                                                                                                            self.description = None
                                                                                                                            self.dev_num1 = None
                                                                                                                            self.dev_num2 = None
                                                                                                                            self.dev_num3 = None
                                                                                                                            self.dev_num4 = None
                                                                                                                            self.dev_num5 = None
                                                                                                                            self.dev_num6 = None
                                                                                                                            self.dev_num7 = None
                                                                                                                            self.eci = None
                                                                                                                            self.eeprom_size = None
                                                                                                                            self.engineer_use = None
                                                                                                                            self.fru_major_type = None
                                                                                                                            self.fru_minor_type = None
                                                                                                                            self.hw_version = None
                                                                                                                            self.hwid = None
                                                                                                                            self.idprom_format_rev = None
                                                                                                                            self.mac_add_blk_size1 = None
                                                                                                                            self.mac_add_blk_size2 = None
                                                                                                                            self.mac_add_blk_size3 = None
                                                                                                                            self.mac_add_blk_size4 = None
                                                                                                                            self.manu_test_data = None
                                                                                                                            self.mfg_bits = None
                                                                                                                            self.mfg_deviation = None
                                                                                                                            self.oem_string = None
                                                                                                                            self.part_number = None
                                                                                                                            self.part_revision = None
                                                                                                                            self.pca_num = None
                                                                                                                            self.pcavid = None
                                                                                                                            self.pcb_serial_num = None
                                                                                                                            self.pid = None
                                                                                                                            self.power_consumption = None
                                                                                                                            self.power_supply_type = None
                                                                                                                            self.product_id = None
                                                                                                                            self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                                            self.rma.parent = self
                                                                                                                            self.rma_code = None
                                                                                                                            self.serial_number = None
                                                                                                                            self.snmpoid = None
                                                                                                                            self.top_assem_part_num = None
                                                                                                                            self.top_assem_vid = None
                                                                                                                            self.udi_description = None
                                                                                                                            self.udi_name = None
                                                                                                                            self.vid = None


                                                                                                                        class Rma(object):
                                                                                                                            """
                                                                                                                            RMA Data
                                                                                                                            
                                                                                                                            .. attribute:: rma_history
                                                                                                                            
                                                                                                                            	RMA history
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..255
                                                                                                                            
                                                                                                                            .. attribute:: rma_number
                                                                                                                            
                                                                                                                            	RMA tracking number format is N\-N\-N
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..255
                                                                                                                            
                                                                                                                            .. attribute:: test_history
                                                                                                                            
                                                                                                                            	Test history
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..255
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.rma_history = None
                                                                                                                                self.rma_number = None
                                                                                                                                self.test_history = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.rma_history is not None:
                                                                                                                                    return True

                                                                                                                                if self.rma_number is not None:
                                                                                                                                    return True

                                                                                                                                if self.test_history is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.asset_alias is not None:
                                                                                                                                return True

                                                                                                                            if self.asset_id is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address1 is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address2 is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address3 is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address4 is not None:
                                                                                                                                return True

                                                                                                                            if self.block_checksum is not None:
                                                                                                                                return True

                                                                                                                            if self.block_count is not None:
                                                                                                                                return True

                                                                                                                            if self.block_length is not None:
                                                                                                                                return True

                                                                                                                            if self.block_signature is not None:
                                                                                                                                return True

                                                                                                                            if self.block_version is not None:
                                                                                                                                return True

                                                                                                                            if self.chassis_sid is not None:
                                                                                                                                return True

                                                                                                                            if self.clei is not None:
                                                                                                                                return True

                                                                                                                            if self.controller_family is not None:
                                                                                                                                return True

                                                                                                                            if self.controller_type is not None:
                                                                                                                                return True

                                                                                                                            if self.description is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num1 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num2 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num3 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num4 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num5 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num6 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num7 is not None:
                                                                                                                                return True

                                                                                                                            if self.eci is not None:
                                                                                                                                return True

                                                                                                                            if self.eeprom_size is not None:
                                                                                                                                return True

                                                                                                                            if self.engineer_use is not None:
                                                                                                                                return True

                                                                                                                            if self.fru_major_type is not None:
                                                                                                                                return True

                                                                                                                            if self.fru_minor_type is not None:
                                                                                                                                return True

                                                                                                                            if self.hw_version is not None:
                                                                                                                                return True

                                                                                                                            if self.hwid is not None:
                                                                                                                                return True

                                                                                                                            if self.idprom_format_rev is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size1 is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size2 is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size3 is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size4 is not None:
                                                                                                                                return True

                                                                                                                            if self.manu_test_data is not None:
                                                                                                                                return True

                                                                                                                            if self.mfg_bits is not None:
                                                                                                                                return True

                                                                                                                            if self.mfg_deviation is not None:
                                                                                                                                return True

                                                                                                                            if self.oem_string is not None:
                                                                                                                                return True

                                                                                                                            if self.part_number is not None:
                                                                                                                                return True

                                                                                                                            if self.part_revision is not None:
                                                                                                                                return True

                                                                                                                            if self.pca_num is not None:
                                                                                                                                return True

                                                                                                                            if self.pcavid is not None:
                                                                                                                                return True

                                                                                                                            if self.pcb_serial_num is not None:
                                                                                                                                return True

                                                                                                                            if self.pid is not None:
                                                                                                                                return True

                                                                                                                            if self.power_consumption is not None:
                                                                                                                                return True

                                                                                                                            if self.power_supply_type is not None:
                                                                                                                                return True

                                                                                                                            if self.product_id is not None:
                                                                                                                                return True

                                                                                                                            if self.rma is not None and self.rma._has_data():
                                                                                                                                return True

                                                                                                                            if self.rma_code is not None:
                                                                                                                                return True

                                                                                                                            if self.serial_number is not None:
                                                                                                                                return True

                                                                                                                            if self.snmpoid is not None:
                                                                                                                                return True

                                                                                                                            if self.top_assem_part_num is not None:
                                                                                                                                return True

                                                                                                                            if self.top_assem_vid is not None:
                                                                                                                                return True

                                                                                                                            if self.udi_description is not None:
                                                                                                                                return True

                                                                                                                            if self.udi_name is not None:
                                                                                                                                return True

                                                                                                                            if self.vid is not None:
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.description is not None:
                                                                                                                            return True

                                                                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                                                                            return True

                                                                                                                        if self.has_eeprom is not None:
                                                                                                                            return True

                                                                                                                        if self.inv_card_type is not None:
                                                                                                                            return True

                                                                                                                        if self.opaque_data is not None:
                                                                                                                            return True

                                                                                                                        if self.opaque_data_size is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                                        return True

                                                                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                                        return True

                                                                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                                        return True

                                                                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.module_done is not None:
                                                                                                                        return True

                                                                                                                    if self.node_id is not None:
                                                                                                                        return True

                                                                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                                                                        return True

                                                                                                                    if self.vm_done is not None:
                                                                                                                        return True

                                                                                                                    if self.vm_node_id is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                                                if self.name is None:
                                                                                                                    raise YPYModelError('Key property name is None')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi11[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.name is not None:
                                                                                                                    return True

                                                                                                                if self.attributes is not None and self.attributes._has_data():
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi11s'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.tsi11 is not None:
                                                                                                                for child_ref in self.tsi11:
                                                                                                                    if child_ref._has_data():
                                                                                                                        return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S']['meta_info']


                                                                                                    class Attributes(object):
                                                                                                        """
                                                                                                        Attributes
                                                                                                        
                                                                                                        .. attribute:: env_sensor_info
                                                                                                        
                                                                                                        	Environment sensor info
                                                                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfo>`
                                                                                                        
                                                                                                        .. attribute:: env_sensor_info_xml
                                                                                                        
                                                                                                        	Environment sensor info XML
                                                                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml>`
                                                                                                        
                                                                                                        .. attribute:: fru_info
                                                                                                        
                                                                                                        	Inventory EDM FRU info
                                                                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo>`
                                                                                                        
                                                                                                        .. attribute:: inv_asset_bag
                                                                                                        
                                                                                                        	Inventory Asset Bag
                                                                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvAssetBag>`
                                                                                                        
                                                                                                        .. attribute:: inv_basic_bag
                                                                                                        
                                                                                                        	Inventory Basic Bag
                                                                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvBasicBag>`
                                                                                                        
                                                                                                        .. attribute:: inv_eeprom_info
                                                                                                        
                                                                                                        	Inventory EDM EEPROM Information Bag
                                                                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo>`
                                                                                                        
                                                                                                        .. attribute:: module_done
                                                                                                        
                                                                                                        	Inventory EDM Module Done Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**default value**\: 1
                                                                                                        
                                                                                                        .. attribute:: node_id
                                                                                                        
                                                                                                        	Node ID Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** 0..4294967295
                                                                                                        
                                                                                                        .. attribute:: pwg_info
                                                                                                        
                                                                                                        	Inventory EDM PWG info
                                                                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.PwgInfo>`
                                                                                                        
                                                                                                        .. attribute:: threshold
                                                                                                        
                                                                                                        	Threshold
                                                                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold>`
                                                                                                        
                                                                                                        .. attribute:: vm_done
                                                                                                        
                                                                                                        	VM Done Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        .. attribute:: vm_node_id
                                                                                                        
                                                                                                        	VM Node ID Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** 0..4294967295
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfo()
                                                                                                            self.env_sensor_info.parent = self
                                                                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml()
                                                                                                            self.env_sensor_info_xml.parent = self
                                                                                                            self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo()
                                                                                                            self.fru_info.parent = self
                                                                                                            self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvAssetBag()
                                                                                                            self.inv_asset_bag.parent = self
                                                                                                            self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvBasicBag()
                                                                                                            self.inv_basic_bag.parent = self
                                                                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo()
                                                                                                            self.inv_eeprom_info.parent = self
                                                                                                            self.module_done = None
                                                                                                            self.node_id = None
                                                                                                            self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.PwgInfo()
                                                                                                            self.pwg_info.parent = self
                                                                                                            self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold()
                                                                                                            self.threshold.parent = self
                                                                                                            self.vm_done = None
                                                                                                            self.vm_node_id = None


                                                                                                        class EnvSensorInfo(object):
                                                                                                            """
                                                                                                            Environment sensor info
                                                                                                            
                                                                                                            .. attribute:: age_time_stamp
                                                                                                            
                                                                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: alarm_type
                                                                                                            
                                                                                                            	Indicates threshold violation
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: data_type
                                                                                                            
                                                                                                            	Sensor data type enums
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: device_description
                                                                                                            
                                                                                                            	Device Name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: device_id
                                                                                                            
                                                                                                            	Identifier for this device
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: field_validity_bitmap
                                                                                                            
                                                                                                            	Sensor valid bitmap
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: precision
                                                                                                            
                                                                                                            	Sensor precision range
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: scale
                                                                                                            
                                                                                                            	Sensor scale enums
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: status
                                                                                                            
                                                                                                            	Sensor operation state enums
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: units
                                                                                                            
                                                                                                            	Units of variable being read
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: update_rate
                                                                                                            
                                                                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: value
                                                                                                            
                                                                                                            	Current reading of sensor
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.age_time_stamp = None
                                                                                                                self.alarm_type = None
                                                                                                                self.data_type = None
                                                                                                                self.device_description = None
                                                                                                                self.device_id = None
                                                                                                                self.field_validity_bitmap = None
                                                                                                                self.precision = None
                                                                                                                self.scale = None
                                                                                                                self.status = None
                                                                                                                self.units = None
                                                                                                                self.update_rate = None
                                                                                                                self.value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.age_time_stamp is not None:
                                                                                                                    return True

                                                                                                                if self.alarm_type is not None:
                                                                                                                    return True

                                                                                                                if self.data_type is not None:
                                                                                                                    return True

                                                                                                                if self.device_description is not None:
                                                                                                                    return True

                                                                                                                if self.device_id is not None:
                                                                                                                    return True

                                                                                                                if self.field_validity_bitmap is not None:
                                                                                                                    return True

                                                                                                                if self.precision is not None:
                                                                                                                    return True

                                                                                                                if self.scale is not None:
                                                                                                                    return True

                                                                                                                if self.status is not None:
                                                                                                                    return True

                                                                                                                if self.units is not None:
                                                                                                                    return True

                                                                                                                if self.update_rate is not None:
                                                                                                                    return True

                                                                                                                if self.value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfo']['meta_info']


                                                                                                        class PwgInfo(object):
                                                                                                            """
                                                                                                            Inventory EDM PWG info
                                                                                                            
                                                                                                            .. attribute:: power_group_available_current
                                                                                                            
                                                                                                            	available current
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_group_drawn_current
                                                                                                            
                                                                                                            	drawn current
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_group_power_units
                                                                                                            
                                                                                                            	power units
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            .. attribute:: power_group_redundancy_mode
                                                                                                            
                                                                                                            	redundancy mode
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.power_group_available_current = None
                                                                                                                self.power_group_drawn_current = None
                                                                                                                self.power_group_power_units = None
                                                                                                                self.power_group_redundancy_mode = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.power_group_available_current is not None:
                                                                                                                    return True

                                                                                                                if self.power_group_drawn_current is not None:
                                                                                                                    return True

                                                                                                                if self.power_group_power_units is not None:
                                                                                                                    return True

                                                                                                                if self.power_group_redundancy_mode is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.PwgInfo']['meta_info']


                                                                                                        class EnvSensorInfoXml(object):
                                                                                                            """
                                                                                                            Environment sensor info XML
                                                                                                            
                                                                                                            .. attribute:: data_type
                                                                                                            
                                                                                                            	Sensor data type
                                                                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                                            
                                                                                                            .. attribute:: description
                                                                                                            
                                                                                                            	Device Name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: status
                                                                                                            
                                                                                                            	Sensor operation state
                                                                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                                            
                                                                                                            .. attribute:: threshold
                                                                                                            
                                                                                                            	Threshold information
                                                                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                                            
                                                                                                            .. attribute:: units
                                                                                                            
                                                                                                            	Units of variable being read
                                                                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                                            
                                                                                                            .. attribute:: update_rate
                                                                                                            
                                                                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: value
                                                                                                            
                                                                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.data_type = None
                                                                                                                self.description = None
                                                                                                                self.status = None
                                                                                                                self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                                self.threshold.parent = self
                                                                                                                self.units = None
                                                                                                                self.update_rate = None
                                                                                                                self.value = None


                                                                                                            class Threshold(object):
                                                                                                                """
                                                                                                                Threshold information
                                                                                                                
                                                                                                                .. attribute:: threshold_array
                                                                                                                
                                                                                                                	Array of threshold
                                                                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.threshold_array = YList()
                                                                                                                    self.threshold_array.parent = self
                                                                                                                    self.threshold_array.name = 'threshold_array'


                                                                                                                class ThresholdArray(object):
                                                                                                                    """
                                                                                                                    Array of threshold
                                                                                                                    
                                                                                                                    .. attribute:: threshold_name
                                                                                                                    
                                                                                                                    	Threshold name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_name = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_name is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.threshold_array is not None:
                                                                                                                        for child_ref in self.threshold_array:
                                                                                                                            if child_ref._has_data():
                                                                                                                                return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.data_type is not None:
                                                                                                                    return True

                                                                                                                if self.description is not None:
                                                                                                                    return True

                                                                                                                if self.status is not None:
                                                                                                                    return True

                                                                                                                if self.threshold is not None and self.threshold._has_data():
                                                                                                                    return True

                                                                                                                if self.units is not None:
                                                                                                                    return True

                                                                                                                if self.update_rate is not None:
                                                                                                                    return True

                                                                                                                if self.value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                                        class InvAssetBag(object):
                                                                                                            """
                                                                                                            Inventory Asset Bag
                                                                                                            
                                                                                                            .. attribute:: manufacturer_assembly_number
                                                                                                            
                                                                                                            	Manufacture Assembly number
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_assembly_revision
                                                                                                            
                                                                                                            	Manufacture assembly revision
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                                            
                                                                                                            	Common Language Equipment           Identifier number
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_firmware_identifier
                                                                                                            
                                                                                                            	
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_software_identifier
                                                                                                            
                                                                                                            	
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: original_equipment_manufacturer_string
                                                                                                            
                                                                                                            	String containing OEM information           if applicable
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: part_number
                                                                                                            
                                                                                                            	
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.manufacturer_assembly_number = None
                                                                                                                self.manufacturer_assembly_revision = None
                                                                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                                                                self.manufacturer_firmware_identifier = None
                                                                                                                self.manufacturer_software_identifier = None
                                                                                                                self.original_equipment_manufacturer_string = None
                                                                                                                self.part_number = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.manufacturer_assembly_number is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_assembly_revision is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_firmware_identifier is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_software_identifier is not None:
                                                                                                                    return True

                                                                                                                if self.original_equipment_manufacturer_string is not None:
                                                                                                                    return True

                                                                                                                if self.part_number is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvAssetBag']['meta_info']


                                                                                                        class Threshold(object):
                                                                                                            """
                                                                                                            Threshold
                                                                                                            
                                                                                                            .. attribute:: critical_hi
                                                                                                            
                                                                                                            	Critical High
                                                                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi>`
                                                                                                            
                                                                                                            .. attribute:: critical_lo
                                                                                                            
                                                                                                            	Critical Low
                                                                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo>`
                                                                                                            
                                                                                                            .. attribute:: major_hi
                                                                                                            
                                                                                                            	Major High
                                                                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi>`
                                                                                                            
                                                                                                            .. attribute:: major_lo
                                                                                                            
                                                                                                            	Major Low
                                                                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo>`
                                                                                                            
                                                                                                            .. attribute:: minor_hi
                                                                                                            
                                                                                                            	Minor High
                                                                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi>`
                                                                                                            
                                                                                                            .. attribute:: minor_lo
                                                                                                            
                                                                                                            	Minor Low
                                                                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo>`
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi()
                                                                                                                self.critical_hi.parent = self
                                                                                                                self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo()
                                                                                                                self.critical_lo.parent = self
                                                                                                                self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi()
                                                                                                                self.major_hi.parent = self
                                                                                                                self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo()
                                                                                                                self.major_lo.parent = self
                                                                                                                self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi()
                                                                                                                self.minor_hi.parent = self
                                                                                                                self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo()
                                                                                                                self.minor_lo.parent = self


                                                                                                            class MajorLo(object):
                                                                                                                """
                                                                                                                Major Low
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo']['meta_info']


                                                                                                            class CriticalHi(object):
                                                                                                                """
                                                                                                                Critical High
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                                            class MinorHi(object):
                                                                                                                """
                                                                                                                Minor High
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi']['meta_info']


                                                                                                            class MajorHi(object):
                                                                                                                """
                                                                                                                Major High
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi']['meta_info']


                                                                                                            class CriticalLo(object):
                                                                                                                """
                                                                                                                Critical Low
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                                            class MinorLo(object):
                                                                                                                """
                                                                                                                Minor Low
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                                    return True

                                                                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                                    return True

                                                                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                                                                    return True

                                                                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                                                                    return True

                                                                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                                    return True

                                                                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold']['meta_info']


                                                                                                        class FruInfo(object):
                                                                                                            """
                                                                                                            Inventory EDM FRU info
                                                                                                            
                                                                                                            .. attribute:: card_administrative_state
                                                                                                            
                                                                                                            	card admin state\: shutdown or not
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: card_monitor_state
                                                                                                            
                                                                                                            	card is monitored by a manager or left unmonitored
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: card_operational_state
                                                                                                            
                                                                                                            	card operation state
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: card_reset_reason
                                                                                                            
                                                                                                            	card reset reason enum
                                                                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                                            
                                                                                                            .. attribute:: card_up_time
                                                                                                            
                                                                                                            	card up time
                                                                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.CardUpTime>`
                                                                                                            
                                                                                                            .. attribute:: last_operational_state_change
                                                                                                            
                                                                                                            	last card oper change state
                                                                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                                            
                                                                                                            .. attribute:: power_administrative_state
                                                                                                            
                                                                                                            	power admin state\: up or down
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_current_measurement
                                                                                                            
                                                                                                            	power current\: not implemented
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_operational_state
                                                                                                            
                                                                                                            	Power operation state
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.card_administrative_state = None
                                                                                                                self.card_monitor_state = None
                                                                                                                self.card_operational_state = None
                                                                                                                self.card_reset_reason = None
                                                                                                                self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.CardUpTime()
                                                                                                                self.card_up_time.parent = self
                                                                                                                self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                                self.last_operational_state_change.parent = self
                                                                                                                self.power_administrative_state = None
                                                                                                                self.power_current_measurement = None
                                                                                                                self.power_operational_state = None


                                                                                                            class LastOperationalStateChange(object):
                                                                                                                """
                                                                                                                last card oper change state
                                                                                                                
                                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                                
                                                                                                                	Time Value in Nano\-seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: nanosecond
                                                                                                                
                                                                                                                .. attribute:: time_in_seconds
                                                                                                                
                                                                                                                	Time Value in Seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: second
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.time_in_nano_seconds = None
                                                                                                                    self.time_in_seconds = None

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                                        return True

                                                                                                                    if self.time_in_seconds is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                                            class CardUpTime(object):
                                                                                                                """
                                                                                                                card up time
                                                                                                                
                                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                                
                                                                                                                	Time Value in Nano\-seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: nanosecond
                                                                                                                
                                                                                                                .. attribute:: time_in_seconds
                                                                                                                
                                                                                                                	Time Value in Seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: second
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.time_in_nano_seconds = None
                                                                                                                    self.time_in_seconds = None

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                                        return True

                                                                                                                    if self.time_in_seconds is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.card_administrative_state is not None:
                                                                                                                    return True

                                                                                                                if self.card_monitor_state is not None:
                                                                                                                    return True

                                                                                                                if self.card_operational_state is not None:
                                                                                                                    return True

                                                                                                                if self.card_reset_reason is not None:
                                                                                                                    return True

                                                                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                                    return True

                                                                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                                    return True

                                                                                                                if self.power_administrative_state is not None:
                                                                                                                    return True

                                                                                                                if self.power_current_measurement is not None:
                                                                                                                    return True

                                                                                                                if self.power_operational_state is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo']['meta_info']


                                                                                                        class InvBasicBag(object):
                                                                                                            """
                                                                                                            Inventory Basic Bag
                                                                                                            
                                                                                                            .. attribute:: alias
                                                                                                            
                                                                                                            	useful for storing an entity alias 
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: asset_id_str
                                                                                                            
                                                                                                            	asset Identification string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: asset_identification
                                                                                                            
                                                                                                            	asset Identification
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: ceport
                                                                                                            
                                                                                                            	1 if ce port found, 0 if not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: chip_hardware_revision
                                                                                                            
                                                                                                            	chip module hw revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: composite_class_code
                                                                                                            
                                                                                                            	Major&minor class of the entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: description
                                                                                                            
                                                                                                            	describes in user\-readable terms       what the entity in question does
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: environmental_monitor_path
                                                                                                            
                                                                                                            	sysdb name of sensor in the envmon EDM
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: firmware_revision
                                                                                                            
                                                                                                            	firmware revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: group_flag
                                                                                                            
                                                                                                            	indicates if this entity is group       or not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: hardware_revision
                                                                                                            
                                                                                                            	hw revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: is_field_replaceable_unit
                                                                                                            
                                                                                                            	1 if Field Replaceable Unit 0, if not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: manufacturer_asset_tags
                                                                                                            
                                                                                                            	Manufacture Asset Tags
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: manufacturer_name
                                                                                                            
                                                                                                            	manufacturer's name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: memory_size
                                                                                                            
                                                                                                            	Size of memory associated with       the entity where applicable
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: model_name
                                                                                                            
                                                                                                            	model name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: name
                                                                                                            
                                                                                                            	name string for the entity
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: new_deviation_number
                                                                                                            
                                                                                                            	integer value for New Deviation Number 0x88
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: physical_layer_interface_module_type
                                                                                                            
                                                                                                            	integer value for plim type if     applicable to this entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: redundancystate
                                                                                                            
                                                                                                            	integer value for Redundancy State if     applicable to this entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: serial_number
                                                                                                            
                                                                                                            	serial number
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: software_revision
                                                                                                            
                                                                                                            	software revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: unique_id
                                                                                                            
                                                                                                            	Unique id for an entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: unrecognized_fru
                                                                                                            
                                                                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: vendor_type
                                                                                                            
                                                                                                            	maps to the vendor OID string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: xr_scoped
                                                                                                            
                                                                                                            	1 if xr scoped, 0 if not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.alias = None
                                                                                                                self.asset_id_str = None
                                                                                                                self.asset_identification = None
                                                                                                                self.ceport = None
                                                                                                                self.chip_hardware_revision = None
                                                                                                                self.composite_class_code = None
                                                                                                                self.description = None
                                                                                                                self.environmental_monitor_path = None
                                                                                                                self.firmware_revision = None
                                                                                                                self.group_flag = None
                                                                                                                self.hardware_revision = None
                                                                                                                self.is_field_replaceable_unit = None
                                                                                                                self.manufacturer_asset_tags = None
                                                                                                                self.manufacturer_name = None
                                                                                                                self.memory_size = None
                                                                                                                self.model_name = None
                                                                                                                self.name = None
                                                                                                                self.new_deviation_number = None
                                                                                                                self.physical_layer_interface_module_type = None
                                                                                                                self.redundancystate = None
                                                                                                                self.serial_number = None
                                                                                                                self.software_revision = None
                                                                                                                self.unique_id = None
                                                                                                                self.unrecognized_fru = None
                                                                                                                self.vendor_type = None
                                                                                                                self.xr_scoped = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.alias is not None:
                                                                                                                    return True

                                                                                                                if self.asset_id_str is not None:
                                                                                                                    return True

                                                                                                                if self.asset_identification is not None:
                                                                                                                    return True

                                                                                                                if self.ceport is not None:
                                                                                                                    return True

                                                                                                                if self.chip_hardware_revision is not None:
                                                                                                                    return True

                                                                                                                if self.composite_class_code is not None:
                                                                                                                    return True

                                                                                                                if self.description is not None:
                                                                                                                    return True

                                                                                                                if self.environmental_monitor_path is not None:
                                                                                                                    return True

                                                                                                                if self.firmware_revision is not None:
                                                                                                                    return True

                                                                                                                if self.group_flag is not None:
                                                                                                                    return True

                                                                                                                if self.hardware_revision is not None:
                                                                                                                    return True

                                                                                                                if self.is_field_replaceable_unit is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_asset_tags is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_name is not None:
                                                                                                                    return True

                                                                                                                if self.memory_size is not None:
                                                                                                                    return True

                                                                                                                if self.model_name is not None:
                                                                                                                    return True

                                                                                                                if self.name is not None:
                                                                                                                    return True

                                                                                                                if self.new_deviation_number is not None:
                                                                                                                    return True

                                                                                                                if self.physical_layer_interface_module_type is not None:
                                                                                                                    return True

                                                                                                                if self.redundancystate is not None:
                                                                                                                    return True

                                                                                                                if self.serial_number is not None:
                                                                                                                    return True

                                                                                                                if self.software_revision is not None:
                                                                                                                    return True

                                                                                                                if self.unique_id is not None:
                                                                                                                    return True

                                                                                                                if self.unrecognized_fru is not None:
                                                                                                                    return True

                                                                                                                if self.vendor_type is not None:
                                                                                                                    return True

                                                                                                                if self.xr_scoped is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvBasicBag']['meta_info']


                                                                                                        class InvEepromInfo(object):
                                                                                                            """
                                                                                                            Inventory EDM EEPROM Information Bag
                                                                                                            
                                                                                                            .. attribute:: description
                                                                                                            
                                                                                                            	A textual description of physical entity
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: eeprom
                                                                                                            
                                                                                                            	EEPROM data not from hex data
                                                                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom>`
                                                                                                            
                                                                                                            .. attribute:: has_eeprom
                                                                                                            
                                                                                                            	use eeprom instead of opaque data
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: inv_card_type
                                                                                                            
                                                                                                            	Inventory card type
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..255
                                                                                                            
                                                                                                            .. attribute:: opaque_data
                                                                                                            
                                                                                                            	EEPROM hex data
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                                            
                                                                                                            .. attribute:: opaque_data_size
                                                                                                            
                                                                                                            	size of the EEPROM hex data
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.description = None
                                                                                                                self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom()
                                                                                                                self.eeprom.parent = self
                                                                                                                self.has_eeprom = None
                                                                                                                self.inv_card_type = None
                                                                                                                self.opaque_data = None
                                                                                                                self.opaque_data_size = None


                                                                                                            class Eeprom(object):
                                                                                                                """
                                                                                                                EEPROM data not from hex data
                                                                                                                
                                                                                                                .. attribute:: asset_alias
                                                                                                                
                                                                                                                	Asset Alias
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: asset_id
                                                                                                                
                                                                                                                	Asset ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address1
                                                                                                                
                                                                                                                	Base Mac Address #1
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address2
                                                                                                                
                                                                                                                	Base Mac Address #2
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address3
                                                                                                                
                                                                                                                	Base Mac Address #3
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address4
                                                                                                                
                                                                                                                	Base Mac Address #4
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_checksum
                                                                                                                
                                                                                                                	Block Checksum
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_count
                                                                                                                
                                                                                                                	Block Count
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_length
                                                                                                                
                                                                                                                	Block Length
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_signature
                                                                                                                
                                                                                                                	Block Signature
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_version
                                                                                                                
                                                                                                                	Block Version
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: chassis_sid
                                                                                                                
                                                                                                                	Chassis serial number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: clei
                                                                                                                
                                                                                                                	Common Language Equipment Identifier (CLEI) code
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: controller_family
                                                                                                                
                                                                                                                	Controller family
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: controller_type
                                                                                                                
                                                                                                                	Controller type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: description
                                                                                                                
                                                                                                                	A textual description of physical entity
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num1
                                                                                                                
                                                                                                                	Deviation Number # 1
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num2
                                                                                                                
                                                                                                                	Deviation Number # 2
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num3
                                                                                                                
                                                                                                                	Deviation Number # 3
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num4
                                                                                                                
                                                                                                                	Deviation Number # 4
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num5
                                                                                                                
                                                                                                                	Deviation Number # 5
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num6
                                                                                                                
                                                                                                                	Deviation Number # 6
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num7
                                                                                                                
                                                                                                                	Deviation Number # 7
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: eci
                                                                                                                
                                                                                                                	Equipment Catalog Item (ECI) number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: eeprom_size
                                                                                                                
                                                                                                                	EEPROM Size
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: engineer_use
                                                                                                                
                                                                                                                	Engineer Use
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: fru_major_type
                                                                                                                
                                                                                                                	FRU Major Type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: fru_minor_type
                                                                                                                
                                                                                                                	FRU Minor Type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: hw_version
                                                                                                                
                                                                                                                	Hardware Version
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: hwid
                                                                                                                
                                                                                                                	Hardware Revision
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: idprom_format_rev
                                                                                                                
                                                                                                                	IDPROM Format Revision
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size1
                                                                                                                
                                                                                                                	Mac Address Block Size #1
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size2
                                                                                                                
                                                                                                                	Mac Address Block Size #2
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size3
                                                                                                                
                                                                                                                	Mac Address Block Size #3
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size4
                                                                                                                
                                                                                                                	Mac Address Block Size #4
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: manu_test_data
                                                                                                                
                                                                                                                	Manufacturing Test Data
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mfg_bits
                                                                                                                
                                                                                                                	MFG Bits
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mfg_deviation
                                                                                                                
                                                                                                                	MFG Deviation
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: oem_string
                                                                                                                
                                                                                                                	OEM String
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: part_number
                                                                                                                
                                                                                                                	Part Number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: part_revision
                                                                                                                
                                                                                                                	Part Revision
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pca_num
                                                                                                                
                                                                                                                	PCA number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pcavid
                                                                                                                
                                                                                                                	PCA revision ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pcb_serial_num
                                                                                                                
                                                                                                                	PCB Serial Number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pid
                                                                                                                
                                                                                                                	Product ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: power_consumption
                                                                                                                
                                                                                                                	Power Consumption
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: power_supply_type
                                                                                                                
                                                                                                                	Power Supply Type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: product_id
                                                                                                                
                                                                                                                	Product ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: rma
                                                                                                                
                                                                                                                	RMA Data
                                                                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                                
                                                                                                                .. attribute:: rma_code
                                                                                                                
                                                                                                                	RMA Code
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: serial_number
                                                                                                                
                                                                                                                	Serial Number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: snmpoid
                                                                                                                
                                                                                                                	SNMP OID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: top_assem_part_num
                                                                                                                
                                                                                                                	Top assembly part number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: top_assem_vid
                                                                                                                
                                                                                                                	Top assembly revision number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: udi_description
                                                                                                                
                                                                                                                	UDI description
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: udi_name
                                                                                                                
                                                                                                                	UDI name
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: vid
                                                                                                                
                                                                                                                	Version ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.asset_alias = None
                                                                                                                    self.asset_id = None
                                                                                                                    self.base_mac_address1 = None
                                                                                                                    self.base_mac_address2 = None
                                                                                                                    self.base_mac_address3 = None
                                                                                                                    self.base_mac_address4 = None
                                                                                                                    self.block_checksum = None
                                                                                                                    self.block_count = None
                                                                                                                    self.block_length = None
                                                                                                                    self.block_signature = None
                                                                                                                    self.block_version = None
                                                                                                                    self.chassis_sid = None
                                                                                                                    self.clei = None
                                                                                                                    self.controller_family = None
                                                                                                                    self.controller_type = None
                                                                                                                    self.description = None
                                                                                                                    self.dev_num1 = None
                                                                                                                    self.dev_num2 = None
                                                                                                                    self.dev_num3 = None
                                                                                                                    self.dev_num4 = None
                                                                                                                    self.dev_num5 = None
                                                                                                                    self.dev_num6 = None
                                                                                                                    self.dev_num7 = None
                                                                                                                    self.eci = None
                                                                                                                    self.eeprom_size = None
                                                                                                                    self.engineer_use = None
                                                                                                                    self.fru_major_type = None
                                                                                                                    self.fru_minor_type = None
                                                                                                                    self.hw_version = None
                                                                                                                    self.hwid = None
                                                                                                                    self.idprom_format_rev = None
                                                                                                                    self.mac_add_blk_size1 = None
                                                                                                                    self.mac_add_blk_size2 = None
                                                                                                                    self.mac_add_blk_size3 = None
                                                                                                                    self.mac_add_blk_size4 = None
                                                                                                                    self.manu_test_data = None
                                                                                                                    self.mfg_bits = None
                                                                                                                    self.mfg_deviation = None
                                                                                                                    self.oem_string = None
                                                                                                                    self.part_number = None
                                                                                                                    self.part_revision = None
                                                                                                                    self.pca_num = None
                                                                                                                    self.pcavid = None
                                                                                                                    self.pcb_serial_num = None
                                                                                                                    self.pid = None
                                                                                                                    self.power_consumption = None
                                                                                                                    self.power_supply_type = None
                                                                                                                    self.product_id = None
                                                                                                                    self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                                    self.rma.parent = self
                                                                                                                    self.rma_code = None
                                                                                                                    self.serial_number = None
                                                                                                                    self.snmpoid = None
                                                                                                                    self.top_assem_part_num = None
                                                                                                                    self.top_assem_vid = None
                                                                                                                    self.udi_description = None
                                                                                                                    self.udi_name = None
                                                                                                                    self.vid = None


                                                                                                                class Rma(object):
                                                                                                                    """
                                                                                                                    RMA Data
                                                                                                                    
                                                                                                                    .. attribute:: rma_history
                                                                                                                    
                                                                                                                    	RMA history
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: rma_number
                                                                                                                    
                                                                                                                    	RMA tracking number format is N\-N\-N
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: test_history
                                                                                                                    
                                                                                                                    	Test history
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.rma_history = None
                                                                                                                        self.rma_number = None
                                                                                                                        self.test_history = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.rma_history is not None:
                                                                                                                            return True

                                                                                                                        if self.rma_number is not None:
                                                                                                                            return True

                                                                                                                        if self.test_history is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.asset_alias is not None:
                                                                                                                        return True

                                                                                                                    if self.asset_id is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address1 is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address2 is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address3 is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address4 is not None:
                                                                                                                        return True

                                                                                                                    if self.block_checksum is not None:
                                                                                                                        return True

                                                                                                                    if self.block_count is not None:
                                                                                                                        return True

                                                                                                                    if self.block_length is not None:
                                                                                                                        return True

                                                                                                                    if self.block_signature is not None:
                                                                                                                        return True

                                                                                                                    if self.block_version is not None:
                                                                                                                        return True

                                                                                                                    if self.chassis_sid is not None:
                                                                                                                        return True

                                                                                                                    if self.clei is not None:
                                                                                                                        return True

                                                                                                                    if self.controller_family is not None:
                                                                                                                        return True

                                                                                                                    if self.controller_type is not None:
                                                                                                                        return True

                                                                                                                    if self.description is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num1 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num2 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num3 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num4 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num5 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num6 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num7 is not None:
                                                                                                                        return True

                                                                                                                    if self.eci is not None:
                                                                                                                        return True

                                                                                                                    if self.eeprom_size is not None:
                                                                                                                        return True

                                                                                                                    if self.engineer_use is not None:
                                                                                                                        return True

                                                                                                                    if self.fru_major_type is not None:
                                                                                                                        return True

                                                                                                                    if self.fru_minor_type is not None:
                                                                                                                        return True

                                                                                                                    if self.hw_version is not None:
                                                                                                                        return True

                                                                                                                    if self.hwid is not None:
                                                                                                                        return True

                                                                                                                    if self.idprom_format_rev is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size1 is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size2 is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size3 is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size4 is not None:
                                                                                                                        return True

                                                                                                                    if self.manu_test_data is not None:
                                                                                                                        return True

                                                                                                                    if self.mfg_bits is not None:
                                                                                                                        return True

                                                                                                                    if self.mfg_deviation is not None:
                                                                                                                        return True

                                                                                                                    if self.oem_string is not None:
                                                                                                                        return True

                                                                                                                    if self.part_number is not None:
                                                                                                                        return True

                                                                                                                    if self.part_revision is not None:
                                                                                                                        return True

                                                                                                                    if self.pca_num is not None:
                                                                                                                        return True

                                                                                                                    if self.pcavid is not None:
                                                                                                                        return True

                                                                                                                    if self.pcb_serial_num is not None:
                                                                                                                        return True

                                                                                                                    if self.pid is not None:
                                                                                                                        return True

                                                                                                                    if self.power_consumption is not None:
                                                                                                                        return True

                                                                                                                    if self.power_supply_type is not None:
                                                                                                                        return True

                                                                                                                    if self.product_id is not None:
                                                                                                                        return True

                                                                                                                    if self.rma is not None and self.rma._has_data():
                                                                                                                        return True

                                                                                                                    if self.rma_code is not None:
                                                                                                                        return True

                                                                                                                    if self.serial_number is not None:
                                                                                                                        return True

                                                                                                                    if self.snmpoid is not None:
                                                                                                                        return True

                                                                                                                    if self.top_assem_part_num is not None:
                                                                                                                        return True

                                                                                                                    if self.top_assem_vid is not None:
                                                                                                                        return True

                                                                                                                    if self.udi_description is not None:
                                                                                                                        return True

                                                                                                                    if self.udi_name is not None:
                                                                                                                        return True

                                                                                                                    if self.vid is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.description is not None:
                                                                                                                    return True

                                                                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                                                                    return True

                                                                                                                if self.has_eeprom is not None:
                                                                                                                    return True

                                                                                                                if self.inv_card_type is not None:
                                                                                                                    return True

                                                                                                                if self.opaque_data is not None:
                                                                                                                    return True

                                                                                                                if self.opaque_data_size is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                                return True

                                                                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                                return True

                                                                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                                                                return True

                                                                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                                return True

                                                                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                                return True

                                                                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                                return True

                                                                                                            if self.module_done is not None:
                                                                                                                return True

                                                                                                            if self.node_id is not None:
                                                                                                                return True

                                                                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                                return True

                                                                                                            if self.threshold is not None and self.threshold._has_data():
                                                                                                                return True

                                                                                                            if self.vm_done is not None:
                                                                                                                return True

                                                                                                            if self.vm_node_id is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                                        if self.name is None:
                                                                                                            raise YPYModelError('Key property name is None')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi10[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.name is not None:
                                                                                                            return True

                                                                                                        if self.attributes is not None and self.attributes._has_data():
                                                                                                            return True

                                                                                                        if self.tsi11s is not None and self.tsi11s._has_data():
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi10s'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.tsi10 is not None:
                                                                                                        for child_ref in self.tsi10:
                                                                                                            if child_ref._has_data():
                                                                                                                return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S']['meta_info']


                                                                                            class Attributes(object):
                                                                                                """
                                                                                                Attributes
                                                                                                
                                                                                                .. attribute:: env_sensor_info
                                                                                                
                                                                                                	Environment sensor info
                                                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfo>`
                                                                                                
                                                                                                .. attribute:: env_sensor_info_xml
                                                                                                
                                                                                                	Environment sensor info XML
                                                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml>`
                                                                                                
                                                                                                .. attribute:: fru_info
                                                                                                
                                                                                                	Inventory EDM FRU info
                                                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo>`
                                                                                                
                                                                                                .. attribute:: inv_asset_bag
                                                                                                
                                                                                                	Inventory Asset Bag
                                                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvAssetBag>`
                                                                                                
                                                                                                .. attribute:: inv_basic_bag
                                                                                                
                                                                                                	Inventory Basic Bag
                                                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvBasicBag>`
                                                                                                
                                                                                                .. attribute:: inv_eeprom_info
                                                                                                
                                                                                                	Inventory EDM EEPROM Information Bag
                                                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo>`
                                                                                                
                                                                                                .. attribute:: module_done
                                                                                                
                                                                                                	Inventory EDM Module Done Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**default value**\: 1
                                                                                                
                                                                                                .. attribute:: node_id
                                                                                                
                                                                                                	Node ID Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** 0..4294967295
                                                                                                
                                                                                                .. attribute:: pwg_info
                                                                                                
                                                                                                	Inventory EDM PWG info
                                                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.PwgInfo>`
                                                                                                
                                                                                                .. attribute:: threshold
                                                                                                
                                                                                                	Threshold
                                                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold>`
                                                                                                
                                                                                                .. attribute:: vm_done
                                                                                                
                                                                                                	VM Done Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                .. attribute:: vm_node_id
                                                                                                
                                                                                                	VM Node ID Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** 0..4294967295
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfo()
                                                                                                    self.env_sensor_info.parent = self
                                                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml()
                                                                                                    self.env_sensor_info_xml.parent = self
                                                                                                    self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo()
                                                                                                    self.fru_info.parent = self
                                                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvAssetBag()
                                                                                                    self.inv_asset_bag.parent = self
                                                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvBasicBag()
                                                                                                    self.inv_basic_bag.parent = self
                                                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo()
                                                                                                    self.inv_eeprom_info.parent = self
                                                                                                    self.module_done = None
                                                                                                    self.node_id = None
                                                                                                    self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.PwgInfo()
                                                                                                    self.pwg_info.parent = self
                                                                                                    self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold()
                                                                                                    self.threshold.parent = self
                                                                                                    self.vm_done = None
                                                                                                    self.vm_node_id = None


                                                                                                class EnvSensorInfo(object):
                                                                                                    """
                                                                                                    Environment sensor info
                                                                                                    
                                                                                                    .. attribute:: age_time_stamp
                                                                                                    
                                                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: alarm_type
                                                                                                    
                                                                                                    	Indicates threshold violation
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: data_type
                                                                                                    
                                                                                                    	Sensor data type enums
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: device_description
                                                                                                    
                                                                                                    	Device Name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: device_id
                                                                                                    
                                                                                                    	Identifier for this device
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: field_validity_bitmap
                                                                                                    
                                                                                                    	Sensor valid bitmap
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: precision
                                                                                                    
                                                                                                    	Sensor precision range
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: scale
                                                                                                    
                                                                                                    	Sensor scale enums
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: status
                                                                                                    
                                                                                                    	Sensor operation state enums
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: units
                                                                                                    
                                                                                                    	Units of variable being read
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: update_rate
                                                                                                    
                                                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: value
                                                                                                    
                                                                                                    	Current reading of sensor
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.age_time_stamp = None
                                                                                                        self.alarm_type = None
                                                                                                        self.data_type = None
                                                                                                        self.device_description = None
                                                                                                        self.device_id = None
                                                                                                        self.field_validity_bitmap = None
                                                                                                        self.precision = None
                                                                                                        self.scale = None
                                                                                                        self.status = None
                                                                                                        self.units = None
                                                                                                        self.update_rate = None
                                                                                                        self.value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.age_time_stamp is not None:
                                                                                                            return True

                                                                                                        if self.alarm_type is not None:
                                                                                                            return True

                                                                                                        if self.data_type is not None:
                                                                                                            return True

                                                                                                        if self.device_description is not None:
                                                                                                            return True

                                                                                                        if self.device_id is not None:
                                                                                                            return True

                                                                                                        if self.field_validity_bitmap is not None:
                                                                                                            return True

                                                                                                        if self.precision is not None:
                                                                                                            return True

                                                                                                        if self.scale is not None:
                                                                                                            return True

                                                                                                        if self.status is not None:
                                                                                                            return True

                                                                                                        if self.units is not None:
                                                                                                            return True

                                                                                                        if self.update_rate is not None:
                                                                                                            return True

                                                                                                        if self.value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfo']['meta_info']


                                                                                                class PwgInfo(object):
                                                                                                    """
                                                                                                    Inventory EDM PWG info
                                                                                                    
                                                                                                    .. attribute:: power_group_available_current
                                                                                                    
                                                                                                    	available current
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_group_drawn_current
                                                                                                    
                                                                                                    	drawn current
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_group_power_units
                                                                                                    
                                                                                                    	power units
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    .. attribute:: power_group_redundancy_mode
                                                                                                    
                                                                                                    	redundancy mode
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.power_group_available_current = None
                                                                                                        self.power_group_drawn_current = None
                                                                                                        self.power_group_power_units = None
                                                                                                        self.power_group_redundancy_mode = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.power_group_available_current is not None:
                                                                                                            return True

                                                                                                        if self.power_group_drawn_current is not None:
                                                                                                            return True

                                                                                                        if self.power_group_power_units is not None:
                                                                                                            return True

                                                                                                        if self.power_group_redundancy_mode is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.PwgInfo']['meta_info']


                                                                                                class EnvSensorInfoXml(object):
                                                                                                    """
                                                                                                    Environment sensor info XML
                                                                                                    
                                                                                                    .. attribute:: data_type
                                                                                                    
                                                                                                    	Sensor data type
                                                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                                    
                                                                                                    .. attribute:: description
                                                                                                    
                                                                                                    	Device Name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: status
                                                                                                    
                                                                                                    	Sensor operation state
                                                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                                    
                                                                                                    .. attribute:: threshold
                                                                                                    
                                                                                                    	Threshold information
                                                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                                    
                                                                                                    .. attribute:: units
                                                                                                    
                                                                                                    	Units of variable being read
                                                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                                    
                                                                                                    .. attribute:: update_rate
                                                                                                    
                                                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: value
                                                                                                    
                                                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.data_type = None
                                                                                                        self.description = None
                                                                                                        self.status = None
                                                                                                        self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                        self.threshold.parent = self
                                                                                                        self.units = None
                                                                                                        self.update_rate = None
                                                                                                        self.value = None


                                                                                                    class Threshold(object):
                                                                                                        """
                                                                                                        Threshold information
                                                                                                        
                                                                                                        .. attribute:: threshold_array
                                                                                                        
                                                                                                        	Array of threshold
                                                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.threshold_array = YList()
                                                                                                            self.threshold_array.parent = self
                                                                                                            self.threshold_array.name = 'threshold_array'


                                                                                                        class ThresholdArray(object):
                                                                                                            """
                                                                                                            Array of threshold
                                                                                                            
                                                                                                            .. attribute:: threshold_name
                                                                                                            
                                                                                                            	Threshold name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_name = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_name is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.threshold_array is not None:
                                                                                                                for child_ref in self.threshold_array:
                                                                                                                    if child_ref._has_data():
                                                                                                                        return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.data_type is not None:
                                                                                                            return True

                                                                                                        if self.description is not None:
                                                                                                            return True

                                                                                                        if self.status is not None:
                                                                                                            return True

                                                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                                                            return True

                                                                                                        if self.units is not None:
                                                                                                            return True

                                                                                                        if self.update_rate is not None:
                                                                                                            return True

                                                                                                        if self.value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                                class InvAssetBag(object):
                                                                                                    """
                                                                                                    Inventory Asset Bag
                                                                                                    
                                                                                                    .. attribute:: manufacturer_assembly_number
                                                                                                    
                                                                                                    	Manufacture Assembly number
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_assembly_revision
                                                                                                    
                                                                                                    	Manufacture assembly revision
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                                    
                                                                                                    	Common Language Equipment           Identifier number
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                                                    
                                                                                                    	
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_software_identifier
                                                                                                    
                                                                                                    	
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                                                    
                                                                                                    	String containing OEM information           if applicable
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: part_number
                                                                                                    
                                                                                                    	
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.manufacturer_assembly_number = None
                                                                                                        self.manufacturer_assembly_revision = None
                                                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                                                        self.manufacturer_firmware_identifier = None
                                                                                                        self.manufacturer_software_identifier = None
                                                                                                        self.original_equipment_manufacturer_string = None
                                                                                                        self.part_number = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.manufacturer_assembly_number is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_assembly_revision is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_software_identifier is not None:
                                                                                                            return True

                                                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                                                            return True

                                                                                                        if self.part_number is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvAssetBag']['meta_info']


                                                                                                class Threshold(object):
                                                                                                    """
                                                                                                    Threshold
                                                                                                    
                                                                                                    .. attribute:: critical_hi
                                                                                                    
                                                                                                    	Critical High
                                                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi>`
                                                                                                    
                                                                                                    .. attribute:: critical_lo
                                                                                                    
                                                                                                    	Critical Low
                                                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo>`
                                                                                                    
                                                                                                    .. attribute:: major_hi
                                                                                                    
                                                                                                    	Major High
                                                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi>`
                                                                                                    
                                                                                                    .. attribute:: major_lo
                                                                                                    
                                                                                                    	Major Low
                                                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo>`
                                                                                                    
                                                                                                    .. attribute:: minor_hi
                                                                                                    
                                                                                                    	Minor High
                                                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi>`
                                                                                                    
                                                                                                    .. attribute:: minor_lo
                                                                                                    
                                                                                                    	Minor Low
                                                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo>`
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi()
                                                                                                        self.critical_hi.parent = self
                                                                                                        self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo()
                                                                                                        self.critical_lo.parent = self
                                                                                                        self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi()
                                                                                                        self.major_hi.parent = self
                                                                                                        self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo()
                                                                                                        self.major_lo.parent = self
                                                                                                        self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi()
                                                                                                        self.minor_hi.parent = self
                                                                                                        self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo()
                                                                                                        self.minor_lo.parent = self


                                                                                                    class MajorLo(object):
                                                                                                        """
                                                                                                        Major Low
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo']['meta_info']


                                                                                                    class CriticalHi(object):
                                                                                                        """
                                                                                                        Critical High
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                                    class MinorHi(object):
                                                                                                        """
                                                                                                        Minor High
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi']['meta_info']


                                                                                                    class MajorHi(object):
                                                                                                        """
                                                                                                        Major High
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi']['meta_info']


                                                                                                    class CriticalLo(object):
                                                                                                        """
                                                                                                        Critical Low
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                                    class MinorLo(object):
                                                                                                        """
                                                                                                        Minor Low
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                            return True

                                                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                            return True

                                                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                                                            return True

                                                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                                                            return True

                                                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                            return True

                                                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold']['meta_info']


                                                                                                class FruInfo(object):
                                                                                                    """
                                                                                                    Inventory EDM FRU info
                                                                                                    
                                                                                                    .. attribute:: card_administrative_state
                                                                                                    
                                                                                                    	card admin state\: shutdown or not
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: card_monitor_state
                                                                                                    
                                                                                                    	card is monitored by a manager or left unmonitored
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: card_operational_state
                                                                                                    
                                                                                                    	card operation state
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: card_reset_reason
                                                                                                    
                                                                                                    	card reset reason enum
                                                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                                    
                                                                                                    .. attribute:: card_up_time
                                                                                                    
                                                                                                    	card up time
                                                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.CardUpTime>`
                                                                                                    
                                                                                                    .. attribute:: last_operational_state_change
                                                                                                    
                                                                                                    	last card oper change state
                                                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                                    
                                                                                                    .. attribute:: power_administrative_state
                                                                                                    
                                                                                                    	power admin state\: up or down
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_current_measurement
                                                                                                    
                                                                                                    	power current\: not implemented
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_operational_state
                                                                                                    
                                                                                                    	Power operation state
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.card_administrative_state = None
                                                                                                        self.card_monitor_state = None
                                                                                                        self.card_operational_state = None
                                                                                                        self.card_reset_reason = None
                                                                                                        self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.CardUpTime()
                                                                                                        self.card_up_time.parent = self
                                                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                        self.last_operational_state_change.parent = self
                                                                                                        self.power_administrative_state = None
                                                                                                        self.power_current_measurement = None
                                                                                                        self.power_operational_state = None


                                                                                                    class LastOperationalStateChange(object):
                                                                                                        """
                                                                                                        last card oper change state
                                                                                                        
                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                        
                                                                                                        	Time Value in Nano\-seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: nanosecond
                                                                                                        
                                                                                                        .. attribute:: time_in_seconds
                                                                                                        
                                                                                                        	Time Value in Seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: second
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.time_in_nano_seconds = None
                                                                                                            self.time_in_seconds = None

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                return True

                                                                                                            if self.time_in_seconds is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                                    class CardUpTime(object):
                                                                                                        """
                                                                                                        card up time
                                                                                                        
                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                        
                                                                                                        	Time Value in Nano\-seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: nanosecond
                                                                                                        
                                                                                                        .. attribute:: time_in_seconds
                                                                                                        
                                                                                                        	Time Value in Seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: second
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.time_in_nano_seconds = None
                                                                                                            self.time_in_seconds = None

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                return True

                                                                                                            if self.time_in_seconds is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.card_administrative_state is not None:
                                                                                                            return True

                                                                                                        if self.card_monitor_state is not None:
                                                                                                            return True

                                                                                                        if self.card_operational_state is not None:
                                                                                                            return True

                                                                                                        if self.card_reset_reason is not None:
                                                                                                            return True

                                                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                            return True

                                                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                            return True

                                                                                                        if self.power_administrative_state is not None:
                                                                                                            return True

                                                                                                        if self.power_current_measurement is not None:
                                                                                                            return True

                                                                                                        if self.power_operational_state is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo']['meta_info']


                                                                                                class InvBasicBag(object):
                                                                                                    """
                                                                                                    Inventory Basic Bag
                                                                                                    
                                                                                                    .. attribute:: alias
                                                                                                    
                                                                                                    	useful for storing an entity alias 
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: asset_id_str
                                                                                                    
                                                                                                    	asset Identification string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: asset_identification
                                                                                                    
                                                                                                    	asset Identification
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: ceport
                                                                                                    
                                                                                                    	1 if ce port found, 0 if not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: chip_hardware_revision
                                                                                                    
                                                                                                    	chip module hw revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: composite_class_code
                                                                                                    
                                                                                                    	Major&minor class of the entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: description
                                                                                                    
                                                                                                    	describes in user\-readable terms       what the entity in question does
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: environmental_monitor_path
                                                                                                    
                                                                                                    	sysdb name of sensor in the envmon EDM
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: firmware_revision
                                                                                                    
                                                                                                    	firmware revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: group_flag
                                                                                                    
                                                                                                    	indicates if this entity is group       or not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: hardware_revision
                                                                                                    
                                                                                                    	hw revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: is_field_replaceable_unit
                                                                                                    
                                                                                                    	1 if Field Replaceable Unit 0, if not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: manufacturer_asset_tags
                                                                                                    
                                                                                                    	Manufacture Asset Tags
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: manufacturer_name
                                                                                                    
                                                                                                    	manufacturer's name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: memory_size
                                                                                                    
                                                                                                    	Size of memory associated with       the entity where applicable
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: model_name
                                                                                                    
                                                                                                    	model name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: name
                                                                                                    
                                                                                                    	name string for the entity
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: new_deviation_number
                                                                                                    
                                                                                                    	integer value for New Deviation Number 0x88
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: physical_layer_interface_module_type
                                                                                                    
                                                                                                    	integer value for plim type if     applicable to this entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: redundancystate
                                                                                                    
                                                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: serial_number
                                                                                                    
                                                                                                    	serial number
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: software_revision
                                                                                                    
                                                                                                    	software revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: unique_id
                                                                                                    
                                                                                                    	Unique id for an entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: unrecognized_fru
                                                                                                    
                                                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: vendor_type
                                                                                                    
                                                                                                    	maps to the vendor OID string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: xr_scoped
                                                                                                    
                                                                                                    	1 if xr scoped, 0 if not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.alias = None
                                                                                                        self.asset_id_str = None
                                                                                                        self.asset_identification = None
                                                                                                        self.ceport = None
                                                                                                        self.chip_hardware_revision = None
                                                                                                        self.composite_class_code = None
                                                                                                        self.description = None
                                                                                                        self.environmental_monitor_path = None
                                                                                                        self.firmware_revision = None
                                                                                                        self.group_flag = None
                                                                                                        self.hardware_revision = None
                                                                                                        self.is_field_replaceable_unit = None
                                                                                                        self.manufacturer_asset_tags = None
                                                                                                        self.manufacturer_name = None
                                                                                                        self.memory_size = None
                                                                                                        self.model_name = None
                                                                                                        self.name = None
                                                                                                        self.new_deviation_number = None
                                                                                                        self.physical_layer_interface_module_type = None
                                                                                                        self.redundancystate = None
                                                                                                        self.serial_number = None
                                                                                                        self.software_revision = None
                                                                                                        self.unique_id = None
                                                                                                        self.unrecognized_fru = None
                                                                                                        self.vendor_type = None
                                                                                                        self.xr_scoped = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.alias is not None:
                                                                                                            return True

                                                                                                        if self.asset_id_str is not None:
                                                                                                            return True

                                                                                                        if self.asset_identification is not None:
                                                                                                            return True

                                                                                                        if self.ceport is not None:
                                                                                                            return True

                                                                                                        if self.chip_hardware_revision is not None:
                                                                                                            return True

                                                                                                        if self.composite_class_code is not None:
                                                                                                            return True

                                                                                                        if self.description is not None:
                                                                                                            return True

                                                                                                        if self.environmental_monitor_path is not None:
                                                                                                            return True

                                                                                                        if self.firmware_revision is not None:
                                                                                                            return True

                                                                                                        if self.group_flag is not None:
                                                                                                            return True

                                                                                                        if self.hardware_revision is not None:
                                                                                                            return True

                                                                                                        if self.is_field_replaceable_unit is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_asset_tags is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_name is not None:
                                                                                                            return True

                                                                                                        if self.memory_size is not None:
                                                                                                            return True

                                                                                                        if self.model_name is not None:
                                                                                                            return True

                                                                                                        if self.name is not None:
                                                                                                            return True

                                                                                                        if self.new_deviation_number is not None:
                                                                                                            return True

                                                                                                        if self.physical_layer_interface_module_type is not None:
                                                                                                            return True

                                                                                                        if self.redundancystate is not None:
                                                                                                            return True

                                                                                                        if self.serial_number is not None:
                                                                                                            return True

                                                                                                        if self.software_revision is not None:
                                                                                                            return True

                                                                                                        if self.unique_id is not None:
                                                                                                            return True

                                                                                                        if self.unrecognized_fru is not None:
                                                                                                            return True

                                                                                                        if self.vendor_type is not None:
                                                                                                            return True

                                                                                                        if self.xr_scoped is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvBasicBag']['meta_info']


                                                                                                class InvEepromInfo(object):
                                                                                                    """
                                                                                                    Inventory EDM EEPROM Information Bag
                                                                                                    
                                                                                                    .. attribute:: description
                                                                                                    
                                                                                                    	A textual description of physical entity
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: eeprom
                                                                                                    
                                                                                                    	EEPROM data not from hex data
                                                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom>`
                                                                                                    
                                                                                                    .. attribute:: has_eeprom
                                                                                                    
                                                                                                    	use eeprom instead of opaque data
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: inv_card_type
                                                                                                    
                                                                                                    	Inventory card type
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..255
                                                                                                    
                                                                                                    .. attribute:: opaque_data
                                                                                                    
                                                                                                    	EEPROM hex data
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                                    
                                                                                                    .. attribute:: opaque_data_size
                                                                                                    
                                                                                                    	size of the EEPROM hex data
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.description = None
                                                                                                        self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom()
                                                                                                        self.eeprom.parent = self
                                                                                                        self.has_eeprom = None
                                                                                                        self.inv_card_type = None
                                                                                                        self.opaque_data = None
                                                                                                        self.opaque_data_size = None


                                                                                                    class Eeprom(object):
                                                                                                        """
                                                                                                        EEPROM data not from hex data
                                                                                                        
                                                                                                        .. attribute:: asset_alias
                                                                                                        
                                                                                                        	Asset Alias
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: asset_id
                                                                                                        
                                                                                                        	Asset ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address1
                                                                                                        
                                                                                                        	Base Mac Address #1
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address2
                                                                                                        
                                                                                                        	Base Mac Address #2
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address3
                                                                                                        
                                                                                                        	Base Mac Address #3
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address4
                                                                                                        
                                                                                                        	Base Mac Address #4
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_checksum
                                                                                                        
                                                                                                        	Block Checksum
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_count
                                                                                                        
                                                                                                        	Block Count
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_length
                                                                                                        
                                                                                                        	Block Length
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_signature
                                                                                                        
                                                                                                        	Block Signature
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_version
                                                                                                        
                                                                                                        	Block Version
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: chassis_sid
                                                                                                        
                                                                                                        	Chassis serial number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: clei
                                                                                                        
                                                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: controller_family
                                                                                                        
                                                                                                        	Controller family
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: controller_type
                                                                                                        
                                                                                                        	Controller type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: description
                                                                                                        
                                                                                                        	A textual description of physical entity
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num1
                                                                                                        
                                                                                                        	Deviation Number # 1
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num2
                                                                                                        
                                                                                                        	Deviation Number # 2
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num3
                                                                                                        
                                                                                                        	Deviation Number # 3
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num4
                                                                                                        
                                                                                                        	Deviation Number # 4
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num5
                                                                                                        
                                                                                                        	Deviation Number # 5
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num6
                                                                                                        
                                                                                                        	Deviation Number # 6
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num7
                                                                                                        
                                                                                                        	Deviation Number # 7
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: eci
                                                                                                        
                                                                                                        	Equipment Catalog Item (ECI) number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: eeprom_size
                                                                                                        
                                                                                                        	EEPROM Size
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: engineer_use
                                                                                                        
                                                                                                        	Engineer Use
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: fru_major_type
                                                                                                        
                                                                                                        	FRU Major Type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: fru_minor_type
                                                                                                        
                                                                                                        	FRU Minor Type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: hw_version
                                                                                                        
                                                                                                        	Hardware Version
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: hwid
                                                                                                        
                                                                                                        	Hardware Revision
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: idprom_format_rev
                                                                                                        
                                                                                                        	IDPROM Format Revision
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size1
                                                                                                        
                                                                                                        	Mac Address Block Size #1
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size2
                                                                                                        
                                                                                                        	Mac Address Block Size #2
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size3
                                                                                                        
                                                                                                        	Mac Address Block Size #3
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size4
                                                                                                        
                                                                                                        	Mac Address Block Size #4
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: manu_test_data
                                                                                                        
                                                                                                        	Manufacturing Test Data
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mfg_bits
                                                                                                        
                                                                                                        	MFG Bits
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mfg_deviation
                                                                                                        
                                                                                                        	MFG Deviation
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: oem_string
                                                                                                        
                                                                                                        	OEM String
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: part_number
                                                                                                        
                                                                                                        	Part Number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: part_revision
                                                                                                        
                                                                                                        	Part Revision
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pca_num
                                                                                                        
                                                                                                        	PCA number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pcavid
                                                                                                        
                                                                                                        	PCA revision ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pcb_serial_num
                                                                                                        
                                                                                                        	PCB Serial Number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pid
                                                                                                        
                                                                                                        	Product ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: power_consumption
                                                                                                        
                                                                                                        	Power Consumption
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: power_supply_type
                                                                                                        
                                                                                                        	Power Supply Type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: product_id
                                                                                                        
                                                                                                        	Product ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: rma
                                                                                                        
                                                                                                        	RMA Data
                                                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                        
                                                                                                        .. attribute:: rma_code
                                                                                                        
                                                                                                        	RMA Code
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: serial_number
                                                                                                        
                                                                                                        	Serial Number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: snmpoid
                                                                                                        
                                                                                                        	SNMP OID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: top_assem_part_num
                                                                                                        
                                                                                                        	Top assembly part number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: top_assem_vid
                                                                                                        
                                                                                                        	Top assembly revision number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: udi_description
                                                                                                        
                                                                                                        	UDI description
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: udi_name
                                                                                                        
                                                                                                        	UDI name
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: vid
                                                                                                        
                                                                                                        	Version ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.asset_alias = None
                                                                                                            self.asset_id = None
                                                                                                            self.base_mac_address1 = None
                                                                                                            self.base_mac_address2 = None
                                                                                                            self.base_mac_address3 = None
                                                                                                            self.base_mac_address4 = None
                                                                                                            self.block_checksum = None
                                                                                                            self.block_count = None
                                                                                                            self.block_length = None
                                                                                                            self.block_signature = None
                                                                                                            self.block_version = None
                                                                                                            self.chassis_sid = None
                                                                                                            self.clei = None
                                                                                                            self.controller_family = None
                                                                                                            self.controller_type = None
                                                                                                            self.description = None
                                                                                                            self.dev_num1 = None
                                                                                                            self.dev_num2 = None
                                                                                                            self.dev_num3 = None
                                                                                                            self.dev_num4 = None
                                                                                                            self.dev_num5 = None
                                                                                                            self.dev_num6 = None
                                                                                                            self.dev_num7 = None
                                                                                                            self.eci = None
                                                                                                            self.eeprom_size = None
                                                                                                            self.engineer_use = None
                                                                                                            self.fru_major_type = None
                                                                                                            self.fru_minor_type = None
                                                                                                            self.hw_version = None
                                                                                                            self.hwid = None
                                                                                                            self.idprom_format_rev = None
                                                                                                            self.mac_add_blk_size1 = None
                                                                                                            self.mac_add_blk_size2 = None
                                                                                                            self.mac_add_blk_size3 = None
                                                                                                            self.mac_add_blk_size4 = None
                                                                                                            self.manu_test_data = None
                                                                                                            self.mfg_bits = None
                                                                                                            self.mfg_deviation = None
                                                                                                            self.oem_string = None
                                                                                                            self.part_number = None
                                                                                                            self.part_revision = None
                                                                                                            self.pca_num = None
                                                                                                            self.pcavid = None
                                                                                                            self.pcb_serial_num = None
                                                                                                            self.pid = None
                                                                                                            self.power_consumption = None
                                                                                                            self.power_supply_type = None
                                                                                                            self.product_id = None
                                                                                                            self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                            self.rma.parent = self
                                                                                                            self.rma_code = None
                                                                                                            self.serial_number = None
                                                                                                            self.snmpoid = None
                                                                                                            self.top_assem_part_num = None
                                                                                                            self.top_assem_vid = None
                                                                                                            self.udi_description = None
                                                                                                            self.udi_name = None
                                                                                                            self.vid = None


                                                                                                        class Rma(object):
                                                                                                            """
                                                                                                            RMA Data
                                                                                                            
                                                                                                            .. attribute:: rma_history
                                                                                                            
                                                                                                            	RMA history
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: rma_number
                                                                                                            
                                                                                                            	RMA tracking number format is N\-N\-N
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: test_history
                                                                                                            
                                                                                                            	Test history
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.rma_history = None
                                                                                                                self.rma_number = None
                                                                                                                self.test_history = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.rma_history is not None:
                                                                                                                    return True

                                                                                                                if self.rma_number is not None:
                                                                                                                    return True

                                                                                                                if self.test_history is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.asset_alias is not None:
                                                                                                                return True

                                                                                                            if self.asset_id is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address1 is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address2 is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address3 is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address4 is not None:
                                                                                                                return True

                                                                                                            if self.block_checksum is not None:
                                                                                                                return True

                                                                                                            if self.block_count is not None:
                                                                                                                return True

                                                                                                            if self.block_length is not None:
                                                                                                                return True

                                                                                                            if self.block_signature is not None:
                                                                                                                return True

                                                                                                            if self.block_version is not None:
                                                                                                                return True

                                                                                                            if self.chassis_sid is not None:
                                                                                                                return True

                                                                                                            if self.clei is not None:
                                                                                                                return True

                                                                                                            if self.controller_family is not None:
                                                                                                                return True

                                                                                                            if self.controller_type is not None:
                                                                                                                return True

                                                                                                            if self.description is not None:
                                                                                                                return True

                                                                                                            if self.dev_num1 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num2 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num3 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num4 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num5 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num6 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num7 is not None:
                                                                                                                return True

                                                                                                            if self.eci is not None:
                                                                                                                return True

                                                                                                            if self.eeprom_size is not None:
                                                                                                                return True

                                                                                                            if self.engineer_use is not None:
                                                                                                                return True

                                                                                                            if self.fru_major_type is not None:
                                                                                                                return True

                                                                                                            if self.fru_minor_type is not None:
                                                                                                                return True

                                                                                                            if self.hw_version is not None:
                                                                                                                return True

                                                                                                            if self.hwid is not None:
                                                                                                                return True

                                                                                                            if self.idprom_format_rev is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size1 is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size2 is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size3 is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size4 is not None:
                                                                                                                return True

                                                                                                            if self.manu_test_data is not None:
                                                                                                                return True

                                                                                                            if self.mfg_bits is not None:
                                                                                                                return True

                                                                                                            if self.mfg_deviation is not None:
                                                                                                                return True

                                                                                                            if self.oem_string is not None:
                                                                                                                return True

                                                                                                            if self.part_number is not None:
                                                                                                                return True

                                                                                                            if self.part_revision is not None:
                                                                                                                return True

                                                                                                            if self.pca_num is not None:
                                                                                                                return True

                                                                                                            if self.pcavid is not None:
                                                                                                                return True

                                                                                                            if self.pcb_serial_num is not None:
                                                                                                                return True

                                                                                                            if self.pid is not None:
                                                                                                                return True

                                                                                                            if self.power_consumption is not None:
                                                                                                                return True

                                                                                                            if self.power_supply_type is not None:
                                                                                                                return True

                                                                                                            if self.product_id is not None:
                                                                                                                return True

                                                                                                            if self.rma is not None and self.rma._has_data():
                                                                                                                return True

                                                                                                            if self.rma_code is not None:
                                                                                                                return True

                                                                                                            if self.serial_number is not None:
                                                                                                                return True

                                                                                                            if self.snmpoid is not None:
                                                                                                                return True

                                                                                                            if self.top_assem_part_num is not None:
                                                                                                                return True

                                                                                                            if self.top_assem_vid is not None:
                                                                                                                return True

                                                                                                            if self.udi_description is not None:
                                                                                                                return True

                                                                                                            if self.udi_name is not None:
                                                                                                                return True

                                                                                                            if self.vid is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.description is not None:
                                                                                                            return True

                                                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                                                            return True

                                                                                                        if self.has_eeprom is not None:
                                                                                                            return True

                                                                                                        if self.inv_card_type is not None:
                                                                                                            return True

                                                                                                        if self.opaque_data is not None:
                                                                                                            return True

                                                                                                        if self.opaque_data_size is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                        return True

                                                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                        return True

                                                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                                                        return True

                                                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                        return True

                                                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                        return True

                                                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                        return True

                                                                                                    if self.module_done is not None:
                                                                                                        return True

                                                                                                    if self.node_id is not None:
                                                                                                        return True

                                                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                        return True

                                                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                                                        return True

                                                                                                    if self.vm_done is not None:
                                                                                                        return True

                                                                                                    if self.vm_node_id is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                                if self.name is None:
                                                                                                    raise YPYModelError('Key property name is None')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi9[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.name is not None:
                                                                                                    return True

                                                                                                if self.attributes is not None and self.attributes._has_data():
                                                                                                    return True

                                                                                                if self.tsi10s is not None and self.tsi10s._has_data():
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi9s'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.tsi9 is not None:
                                                                                                for child_ref in self.tsi9:
                                                                                                    if child_ref._has_data():
                                                                                                        return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S']['meta_info']


                                                                                    class Attributes(object):
                                                                                        """
                                                                                        Attributes
                                                                                        
                                                                                        .. attribute:: env_sensor_info
                                                                                        
                                                                                        	Environment sensor info
                                                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfo>`
                                                                                        
                                                                                        .. attribute:: env_sensor_info_xml
                                                                                        
                                                                                        	Environment sensor info XML
                                                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml>`
                                                                                        
                                                                                        .. attribute:: fru_info
                                                                                        
                                                                                        	Inventory EDM FRU info
                                                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo>`
                                                                                        
                                                                                        .. attribute:: inv_asset_bag
                                                                                        
                                                                                        	Inventory Asset Bag
                                                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvAssetBag>`
                                                                                        
                                                                                        .. attribute:: inv_basic_bag
                                                                                        
                                                                                        	Inventory Basic Bag
                                                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvBasicBag>`
                                                                                        
                                                                                        .. attribute:: inv_eeprom_info
                                                                                        
                                                                                        	Inventory EDM EEPROM Information Bag
                                                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo>`
                                                                                        
                                                                                        .. attribute:: module_done
                                                                                        
                                                                                        	Inventory EDM Module Done Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**default value**\: 1
                                                                                        
                                                                                        .. attribute:: node_id
                                                                                        
                                                                                        	Node ID Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** 0..4294967295
                                                                                        
                                                                                        .. attribute:: pwg_info
                                                                                        
                                                                                        	Inventory EDM PWG info
                                                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.PwgInfo>`
                                                                                        
                                                                                        .. attribute:: threshold
                                                                                        
                                                                                        	Threshold
                                                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold>`
                                                                                        
                                                                                        .. attribute:: vm_done
                                                                                        
                                                                                        	VM Done Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        .. attribute:: vm_node_id
                                                                                        
                                                                                        	VM Node ID Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** 0..4294967295
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfo()
                                                                                            self.env_sensor_info.parent = self
                                                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml()
                                                                                            self.env_sensor_info_xml.parent = self
                                                                                            self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo()
                                                                                            self.fru_info.parent = self
                                                                                            self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvAssetBag()
                                                                                            self.inv_asset_bag.parent = self
                                                                                            self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvBasicBag()
                                                                                            self.inv_basic_bag.parent = self
                                                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo()
                                                                                            self.inv_eeprom_info.parent = self
                                                                                            self.module_done = None
                                                                                            self.node_id = None
                                                                                            self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.PwgInfo()
                                                                                            self.pwg_info.parent = self
                                                                                            self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold()
                                                                                            self.threshold.parent = self
                                                                                            self.vm_done = None
                                                                                            self.vm_node_id = None


                                                                                        class EnvSensorInfo(object):
                                                                                            """
                                                                                            Environment sensor info
                                                                                            
                                                                                            .. attribute:: age_time_stamp
                                                                                            
                                                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: alarm_type
                                                                                            
                                                                                            	Indicates threshold violation
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: data_type
                                                                                            
                                                                                            	Sensor data type enums
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: device_description
                                                                                            
                                                                                            	Device Name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: device_id
                                                                                            
                                                                                            	Identifier for this device
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: field_validity_bitmap
                                                                                            
                                                                                            	Sensor valid bitmap
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: precision
                                                                                            
                                                                                            	Sensor precision range
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: scale
                                                                                            
                                                                                            	Sensor scale enums
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: status
                                                                                            
                                                                                            	Sensor operation state enums
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: units
                                                                                            
                                                                                            	Units of variable being read
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: update_rate
                                                                                            
                                                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: value
                                                                                            
                                                                                            	Current reading of sensor
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.age_time_stamp = None
                                                                                                self.alarm_type = None
                                                                                                self.data_type = None
                                                                                                self.device_description = None
                                                                                                self.device_id = None
                                                                                                self.field_validity_bitmap = None
                                                                                                self.precision = None
                                                                                                self.scale = None
                                                                                                self.status = None
                                                                                                self.units = None
                                                                                                self.update_rate = None
                                                                                                self.value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.age_time_stamp is not None:
                                                                                                    return True

                                                                                                if self.alarm_type is not None:
                                                                                                    return True

                                                                                                if self.data_type is not None:
                                                                                                    return True

                                                                                                if self.device_description is not None:
                                                                                                    return True

                                                                                                if self.device_id is not None:
                                                                                                    return True

                                                                                                if self.field_validity_bitmap is not None:
                                                                                                    return True

                                                                                                if self.precision is not None:
                                                                                                    return True

                                                                                                if self.scale is not None:
                                                                                                    return True

                                                                                                if self.status is not None:
                                                                                                    return True

                                                                                                if self.units is not None:
                                                                                                    return True

                                                                                                if self.update_rate is not None:
                                                                                                    return True

                                                                                                if self.value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfo']['meta_info']


                                                                                        class PwgInfo(object):
                                                                                            """
                                                                                            Inventory EDM PWG info
                                                                                            
                                                                                            .. attribute:: power_group_available_current
                                                                                            
                                                                                            	available current
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_group_drawn_current
                                                                                            
                                                                                            	drawn current
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_group_power_units
                                                                                            
                                                                                            	power units
                                                                                            	**type**\:  str
                                                                                            
                                                                                            .. attribute:: power_group_redundancy_mode
                                                                                            
                                                                                            	redundancy mode
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.power_group_available_current = None
                                                                                                self.power_group_drawn_current = None
                                                                                                self.power_group_power_units = None
                                                                                                self.power_group_redundancy_mode = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.power_group_available_current is not None:
                                                                                                    return True

                                                                                                if self.power_group_drawn_current is not None:
                                                                                                    return True

                                                                                                if self.power_group_power_units is not None:
                                                                                                    return True

                                                                                                if self.power_group_redundancy_mode is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.PwgInfo']['meta_info']


                                                                                        class EnvSensorInfoXml(object):
                                                                                            """
                                                                                            Environment sensor info XML
                                                                                            
                                                                                            .. attribute:: data_type
                                                                                            
                                                                                            	Sensor data type
                                                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                            
                                                                                            .. attribute:: description
                                                                                            
                                                                                            	Device Name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: status
                                                                                            
                                                                                            	Sensor operation state
                                                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                            
                                                                                            .. attribute:: threshold
                                                                                            
                                                                                            	Threshold information
                                                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                            
                                                                                            .. attribute:: units
                                                                                            
                                                                                            	Units of variable being read
                                                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                            
                                                                                            .. attribute:: update_rate
                                                                                            
                                                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: value
                                                                                            
                                                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.data_type = None
                                                                                                self.description = None
                                                                                                self.status = None
                                                                                                self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                self.threshold.parent = self
                                                                                                self.units = None
                                                                                                self.update_rate = None
                                                                                                self.value = None


                                                                                            class Threshold(object):
                                                                                                """
                                                                                                Threshold information
                                                                                                
                                                                                                .. attribute:: threshold_array
                                                                                                
                                                                                                	Array of threshold
                                                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.threshold_array = YList()
                                                                                                    self.threshold_array.parent = self
                                                                                                    self.threshold_array.name = 'threshold_array'


                                                                                                class ThresholdArray(object):
                                                                                                    """
                                                                                                    Array of threshold
                                                                                                    
                                                                                                    .. attribute:: threshold_name
                                                                                                    
                                                                                                    	Threshold name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_name = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_name is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.threshold_array is not None:
                                                                                                        for child_ref in self.threshold_array:
                                                                                                            if child_ref._has_data():
                                                                                                                return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.data_type is not None:
                                                                                                    return True

                                                                                                if self.description is not None:
                                                                                                    return True

                                                                                                if self.status is not None:
                                                                                                    return True

                                                                                                if self.threshold is not None and self.threshold._has_data():
                                                                                                    return True

                                                                                                if self.units is not None:
                                                                                                    return True

                                                                                                if self.update_rate is not None:
                                                                                                    return True

                                                                                                if self.value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                        class InvAssetBag(object):
                                                                                            """
                                                                                            Inventory Asset Bag
                                                                                            
                                                                                            .. attribute:: manufacturer_assembly_number
                                                                                            
                                                                                            	Manufacture Assembly number
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_assembly_revision
                                                                                            
                                                                                            	Manufacture assembly revision
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                            
                                                                                            	Common Language Equipment           Identifier number
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_firmware_identifier
                                                                                            
                                                                                            	
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_software_identifier
                                                                                            
                                                                                            	
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: original_equipment_manufacturer_string
                                                                                            
                                                                                            	String containing OEM information           if applicable
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: part_number
                                                                                            
                                                                                            	
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.manufacturer_assembly_number = None
                                                                                                self.manufacturer_assembly_revision = None
                                                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                                                self.manufacturer_firmware_identifier = None
                                                                                                self.manufacturer_software_identifier = None
                                                                                                self.original_equipment_manufacturer_string = None
                                                                                                self.part_number = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.manufacturer_assembly_number is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_assembly_revision is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_firmware_identifier is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_software_identifier is not None:
                                                                                                    return True

                                                                                                if self.original_equipment_manufacturer_string is not None:
                                                                                                    return True

                                                                                                if self.part_number is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvAssetBag']['meta_info']


                                                                                        class Threshold(object):
                                                                                            """
                                                                                            Threshold
                                                                                            
                                                                                            .. attribute:: critical_hi
                                                                                            
                                                                                            	Critical High
                                                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi>`
                                                                                            
                                                                                            .. attribute:: critical_lo
                                                                                            
                                                                                            	Critical Low
                                                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo>`
                                                                                            
                                                                                            .. attribute:: major_hi
                                                                                            
                                                                                            	Major High
                                                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi>`
                                                                                            
                                                                                            .. attribute:: major_lo
                                                                                            
                                                                                            	Major Low
                                                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo>`
                                                                                            
                                                                                            .. attribute:: minor_hi
                                                                                            
                                                                                            	Minor High
                                                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi>`
                                                                                            
                                                                                            .. attribute:: minor_lo
                                                                                            
                                                                                            	Minor Low
                                                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo>`
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi()
                                                                                                self.critical_hi.parent = self
                                                                                                self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo()
                                                                                                self.critical_lo.parent = self
                                                                                                self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi()
                                                                                                self.major_hi.parent = self
                                                                                                self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo()
                                                                                                self.major_lo.parent = self
                                                                                                self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi()
                                                                                                self.minor_hi.parent = self
                                                                                                self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo()
                                                                                                self.minor_lo.parent = self


                                                                                            class MajorLo(object):
                                                                                                """
                                                                                                Major Low
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo']['meta_info']


                                                                                            class CriticalHi(object):
                                                                                                """
                                                                                                Critical High
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                            class MinorHi(object):
                                                                                                """
                                                                                                Minor High
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi']['meta_info']


                                                                                            class MajorHi(object):
                                                                                                """
                                                                                                Major High
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi']['meta_info']


                                                                                            class CriticalLo(object):
                                                                                                """
                                                                                                Critical Low
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                            class MinorLo(object):
                                                                                                """
                                                                                                Minor Low
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                    return True

                                                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                    return True

                                                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                                                    return True

                                                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                                                    return True

                                                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                    return True

                                                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold']['meta_info']


                                                                                        class FruInfo(object):
                                                                                            """
                                                                                            Inventory EDM FRU info
                                                                                            
                                                                                            .. attribute:: card_administrative_state
                                                                                            
                                                                                            	card admin state\: shutdown or not
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: card_monitor_state
                                                                                            
                                                                                            	card is monitored by a manager or left unmonitored
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: card_operational_state
                                                                                            
                                                                                            	card operation state
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: card_reset_reason
                                                                                            
                                                                                            	card reset reason enum
                                                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                            
                                                                                            .. attribute:: card_up_time
                                                                                            
                                                                                            	card up time
                                                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.CardUpTime>`
                                                                                            
                                                                                            .. attribute:: last_operational_state_change
                                                                                            
                                                                                            	last card oper change state
                                                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                            
                                                                                            .. attribute:: power_administrative_state
                                                                                            
                                                                                            	power admin state\: up or down
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_current_measurement
                                                                                            
                                                                                            	power current\: not implemented
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_operational_state
                                                                                            
                                                                                            	Power operation state
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.card_administrative_state = None
                                                                                                self.card_monitor_state = None
                                                                                                self.card_operational_state = None
                                                                                                self.card_reset_reason = None
                                                                                                self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.CardUpTime()
                                                                                                self.card_up_time.parent = self
                                                                                                self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                self.last_operational_state_change.parent = self
                                                                                                self.power_administrative_state = None
                                                                                                self.power_current_measurement = None
                                                                                                self.power_operational_state = None


                                                                                            class LastOperationalStateChange(object):
                                                                                                """
                                                                                                last card oper change state
                                                                                                
                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                
                                                                                                	Time Value in Nano\-seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: nanosecond
                                                                                                
                                                                                                .. attribute:: time_in_seconds
                                                                                                
                                                                                                	Time Value in Seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: second
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.time_in_nano_seconds = None
                                                                                                    self.time_in_seconds = None

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                        return True

                                                                                                    if self.time_in_seconds is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                            class CardUpTime(object):
                                                                                                """
                                                                                                card up time
                                                                                                
                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                
                                                                                                	Time Value in Nano\-seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: nanosecond
                                                                                                
                                                                                                .. attribute:: time_in_seconds
                                                                                                
                                                                                                	Time Value in Seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: second
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.time_in_nano_seconds = None
                                                                                                    self.time_in_seconds = None

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                        return True

                                                                                                    if self.time_in_seconds is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.card_administrative_state is not None:
                                                                                                    return True

                                                                                                if self.card_monitor_state is not None:
                                                                                                    return True

                                                                                                if self.card_operational_state is not None:
                                                                                                    return True

                                                                                                if self.card_reset_reason is not None:
                                                                                                    return True

                                                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                    return True

                                                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                    return True

                                                                                                if self.power_administrative_state is not None:
                                                                                                    return True

                                                                                                if self.power_current_measurement is not None:
                                                                                                    return True

                                                                                                if self.power_operational_state is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo']['meta_info']


                                                                                        class InvBasicBag(object):
                                                                                            """
                                                                                            Inventory Basic Bag
                                                                                            
                                                                                            .. attribute:: alias
                                                                                            
                                                                                            	useful for storing an entity alias 
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: asset_id_str
                                                                                            
                                                                                            	asset Identification string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: asset_identification
                                                                                            
                                                                                            	asset Identification
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: ceport
                                                                                            
                                                                                            	1 if ce port found, 0 if not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: chip_hardware_revision
                                                                                            
                                                                                            	chip module hw revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: composite_class_code
                                                                                            
                                                                                            	Major&minor class of the entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: description
                                                                                            
                                                                                            	describes in user\-readable terms       what the entity in question does
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: environmental_monitor_path
                                                                                            
                                                                                            	sysdb name of sensor in the envmon EDM
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: firmware_revision
                                                                                            
                                                                                            	firmware revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: group_flag
                                                                                            
                                                                                            	indicates if this entity is group       or not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: hardware_revision
                                                                                            
                                                                                            	hw revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: is_field_replaceable_unit
                                                                                            
                                                                                            	1 if Field Replaceable Unit 0, if not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: manufacturer_asset_tags
                                                                                            
                                                                                            	Manufacture Asset Tags
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: manufacturer_name
                                                                                            
                                                                                            	manufacturer's name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: memory_size
                                                                                            
                                                                                            	Size of memory associated with       the entity where applicable
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: model_name
                                                                                            
                                                                                            	model name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: name
                                                                                            
                                                                                            	name string for the entity
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: new_deviation_number
                                                                                            
                                                                                            	integer value for New Deviation Number 0x88
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: physical_layer_interface_module_type
                                                                                            
                                                                                            	integer value for plim type if     applicable to this entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: redundancystate
                                                                                            
                                                                                            	integer value for Redundancy State if     applicable to this entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: serial_number
                                                                                            
                                                                                            	serial number
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: software_revision
                                                                                            
                                                                                            	software revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: unique_id
                                                                                            
                                                                                            	Unique id for an entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: unrecognized_fru
                                                                                            
                                                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: vendor_type
                                                                                            
                                                                                            	maps to the vendor OID string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: xr_scoped
                                                                                            
                                                                                            	1 if xr scoped, 0 if not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.alias = None
                                                                                                self.asset_id_str = None
                                                                                                self.asset_identification = None
                                                                                                self.ceport = None
                                                                                                self.chip_hardware_revision = None
                                                                                                self.composite_class_code = None
                                                                                                self.description = None
                                                                                                self.environmental_monitor_path = None
                                                                                                self.firmware_revision = None
                                                                                                self.group_flag = None
                                                                                                self.hardware_revision = None
                                                                                                self.is_field_replaceable_unit = None
                                                                                                self.manufacturer_asset_tags = None
                                                                                                self.manufacturer_name = None
                                                                                                self.memory_size = None
                                                                                                self.model_name = None
                                                                                                self.name = None
                                                                                                self.new_deviation_number = None
                                                                                                self.physical_layer_interface_module_type = None
                                                                                                self.redundancystate = None
                                                                                                self.serial_number = None
                                                                                                self.software_revision = None
                                                                                                self.unique_id = None
                                                                                                self.unrecognized_fru = None
                                                                                                self.vendor_type = None
                                                                                                self.xr_scoped = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.alias is not None:
                                                                                                    return True

                                                                                                if self.asset_id_str is not None:
                                                                                                    return True

                                                                                                if self.asset_identification is not None:
                                                                                                    return True

                                                                                                if self.ceport is not None:
                                                                                                    return True

                                                                                                if self.chip_hardware_revision is not None:
                                                                                                    return True

                                                                                                if self.composite_class_code is not None:
                                                                                                    return True

                                                                                                if self.description is not None:
                                                                                                    return True

                                                                                                if self.environmental_monitor_path is not None:
                                                                                                    return True

                                                                                                if self.firmware_revision is not None:
                                                                                                    return True

                                                                                                if self.group_flag is not None:
                                                                                                    return True

                                                                                                if self.hardware_revision is not None:
                                                                                                    return True

                                                                                                if self.is_field_replaceable_unit is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_asset_tags is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_name is not None:
                                                                                                    return True

                                                                                                if self.memory_size is not None:
                                                                                                    return True

                                                                                                if self.model_name is not None:
                                                                                                    return True

                                                                                                if self.name is not None:
                                                                                                    return True

                                                                                                if self.new_deviation_number is not None:
                                                                                                    return True

                                                                                                if self.physical_layer_interface_module_type is not None:
                                                                                                    return True

                                                                                                if self.redundancystate is not None:
                                                                                                    return True

                                                                                                if self.serial_number is not None:
                                                                                                    return True

                                                                                                if self.software_revision is not None:
                                                                                                    return True

                                                                                                if self.unique_id is not None:
                                                                                                    return True

                                                                                                if self.unrecognized_fru is not None:
                                                                                                    return True

                                                                                                if self.vendor_type is not None:
                                                                                                    return True

                                                                                                if self.xr_scoped is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvBasicBag']['meta_info']


                                                                                        class InvEepromInfo(object):
                                                                                            """
                                                                                            Inventory EDM EEPROM Information Bag
                                                                                            
                                                                                            .. attribute:: description
                                                                                            
                                                                                            	A textual description of physical entity
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: eeprom
                                                                                            
                                                                                            	EEPROM data not from hex data
                                                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom>`
                                                                                            
                                                                                            .. attribute:: has_eeprom
                                                                                            
                                                                                            	use eeprom instead of opaque data
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: inv_card_type
                                                                                            
                                                                                            	Inventory card type
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..255
                                                                                            
                                                                                            .. attribute:: opaque_data
                                                                                            
                                                                                            	EEPROM hex data
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                            
                                                                                            .. attribute:: opaque_data_size
                                                                                            
                                                                                            	size of the EEPROM hex data
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.description = None
                                                                                                self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom()
                                                                                                self.eeprom.parent = self
                                                                                                self.has_eeprom = None
                                                                                                self.inv_card_type = None
                                                                                                self.opaque_data = None
                                                                                                self.opaque_data_size = None


                                                                                            class Eeprom(object):
                                                                                                """
                                                                                                EEPROM data not from hex data
                                                                                                
                                                                                                .. attribute:: asset_alias
                                                                                                
                                                                                                	Asset Alias
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: asset_id
                                                                                                
                                                                                                	Asset ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address1
                                                                                                
                                                                                                	Base Mac Address #1
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address2
                                                                                                
                                                                                                	Base Mac Address #2
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address3
                                                                                                
                                                                                                	Base Mac Address #3
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address4
                                                                                                
                                                                                                	Base Mac Address #4
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_checksum
                                                                                                
                                                                                                	Block Checksum
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_count
                                                                                                
                                                                                                	Block Count
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_length
                                                                                                
                                                                                                	Block Length
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_signature
                                                                                                
                                                                                                	Block Signature
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_version
                                                                                                
                                                                                                	Block Version
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: chassis_sid
                                                                                                
                                                                                                	Chassis serial number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: clei
                                                                                                
                                                                                                	Common Language Equipment Identifier (CLEI) code
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: controller_family
                                                                                                
                                                                                                	Controller family
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: controller_type
                                                                                                
                                                                                                	Controller type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: description
                                                                                                
                                                                                                	A textual description of physical entity
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num1
                                                                                                
                                                                                                	Deviation Number # 1
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num2
                                                                                                
                                                                                                	Deviation Number # 2
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num3
                                                                                                
                                                                                                	Deviation Number # 3
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num4
                                                                                                
                                                                                                	Deviation Number # 4
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num5
                                                                                                
                                                                                                	Deviation Number # 5
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num6
                                                                                                
                                                                                                	Deviation Number # 6
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num7
                                                                                                
                                                                                                	Deviation Number # 7
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: eci
                                                                                                
                                                                                                	Equipment Catalog Item (ECI) number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: eeprom_size
                                                                                                
                                                                                                	EEPROM Size
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: engineer_use
                                                                                                
                                                                                                	Engineer Use
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: fru_major_type
                                                                                                
                                                                                                	FRU Major Type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: fru_minor_type
                                                                                                
                                                                                                	FRU Minor Type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: hw_version
                                                                                                
                                                                                                	Hardware Version
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: hwid
                                                                                                
                                                                                                	Hardware Revision
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: idprom_format_rev
                                                                                                
                                                                                                	IDPROM Format Revision
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size1
                                                                                                
                                                                                                	Mac Address Block Size #1
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size2
                                                                                                
                                                                                                	Mac Address Block Size #2
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size3
                                                                                                
                                                                                                	Mac Address Block Size #3
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size4
                                                                                                
                                                                                                	Mac Address Block Size #4
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: manu_test_data
                                                                                                
                                                                                                	Manufacturing Test Data
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mfg_bits
                                                                                                
                                                                                                	MFG Bits
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mfg_deviation
                                                                                                
                                                                                                	MFG Deviation
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: oem_string
                                                                                                
                                                                                                	OEM String
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: part_number
                                                                                                
                                                                                                	Part Number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: part_revision
                                                                                                
                                                                                                	Part Revision
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pca_num
                                                                                                
                                                                                                	PCA number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pcavid
                                                                                                
                                                                                                	PCA revision ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pcb_serial_num
                                                                                                
                                                                                                	PCB Serial Number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pid
                                                                                                
                                                                                                	Product ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: power_consumption
                                                                                                
                                                                                                	Power Consumption
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: power_supply_type
                                                                                                
                                                                                                	Power Supply Type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: product_id
                                                                                                
                                                                                                	Product ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: rma
                                                                                                
                                                                                                	RMA Data
                                                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                
                                                                                                .. attribute:: rma_code
                                                                                                
                                                                                                	RMA Code
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: serial_number
                                                                                                
                                                                                                	Serial Number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: snmpoid
                                                                                                
                                                                                                	SNMP OID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: top_assem_part_num
                                                                                                
                                                                                                	Top assembly part number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: top_assem_vid
                                                                                                
                                                                                                	Top assembly revision number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: udi_description
                                                                                                
                                                                                                	UDI description
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: udi_name
                                                                                                
                                                                                                	UDI name
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: vid
                                                                                                
                                                                                                	Version ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.asset_alias = None
                                                                                                    self.asset_id = None
                                                                                                    self.base_mac_address1 = None
                                                                                                    self.base_mac_address2 = None
                                                                                                    self.base_mac_address3 = None
                                                                                                    self.base_mac_address4 = None
                                                                                                    self.block_checksum = None
                                                                                                    self.block_count = None
                                                                                                    self.block_length = None
                                                                                                    self.block_signature = None
                                                                                                    self.block_version = None
                                                                                                    self.chassis_sid = None
                                                                                                    self.clei = None
                                                                                                    self.controller_family = None
                                                                                                    self.controller_type = None
                                                                                                    self.description = None
                                                                                                    self.dev_num1 = None
                                                                                                    self.dev_num2 = None
                                                                                                    self.dev_num3 = None
                                                                                                    self.dev_num4 = None
                                                                                                    self.dev_num5 = None
                                                                                                    self.dev_num6 = None
                                                                                                    self.dev_num7 = None
                                                                                                    self.eci = None
                                                                                                    self.eeprom_size = None
                                                                                                    self.engineer_use = None
                                                                                                    self.fru_major_type = None
                                                                                                    self.fru_minor_type = None
                                                                                                    self.hw_version = None
                                                                                                    self.hwid = None
                                                                                                    self.idprom_format_rev = None
                                                                                                    self.mac_add_blk_size1 = None
                                                                                                    self.mac_add_blk_size2 = None
                                                                                                    self.mac_add_blk_size3 = None
                                                                                                    self.mac_add_blk_size4 = None
                                                                                                    self.manu_test_data = None
                                                                                                    self.mfg_bits = None
                                                                                                    self.mfg_deviation = None
                                                                                                    self.oem_string = None
                                                                                                    self.part_number = None
                                                                                                    self.part_revision = None
                                                                                                    self.pca_num = None
                                                                                                    self.pcavid = None
                                                                                                    self.pcb_serial_num = None
                                                                                                    self.pid = None
                                                                                                    self.power_consumption = None
                                                                                                    self.power_supply_type = None
                                                                                                    self.product_id = None
                                                                                                    self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                    self.rma.parent = self
                                                                                                    self.rma_code = None
                                                                                                    self.serial_number = None
                                                                                                    self.snmpoid = None
                                                                                                    self.top_assem_part_num = None
                                                                                                    self.top_assem_vid = None
                                                                                                    self.udi_description = None
                                                                                                    self.udi_name = None
                                                                                                    self.vid = None


                                                                                                class Rma(object):
                                                                                                    """
                                                                                                    RMA Data
                                                                                                    
                                                                                                    .. attribute:: rma_history
                                                                                                    
                                                                                                    	RMA history
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: rma_number
                                                                                                    
                                                                                                    	RMA tracking number format is N\-N\-N
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: test_history
                                                                                                    
                                                                                                    	Test history
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.rma_history = None
                                                                                                        self.rma_number = None
                                                                                                        self.test_history = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.rma_history is not None:
                                                                                                            return True

                                                                                                        if self.rma_number is not None:
                                                                                                            return True

                                                                                                        if self.test_history is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.asset_alias is not None:
                                                                                                        return True

                                                                                                    if self.asset_id is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address1 is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address2 is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address3 is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address4 is not None:
                                                                                                        return True

                                                                                                    if self.block_checksum is not None:
                                                                                                        return True

                                                                                                    if self.block_count is not None:
                                                                                                        return True

                                                                                                    if self.block_length is not None:
                                                                                                        return True

                                                                                                    if self.block_signature is not None:
                                                                                                        return True

                                                                                                    if self.block_version is not None:
                                                                                                        return True

                                                                                                    if self.chassis_sid is not None:
                                                                                                        return True

                                                                                                    if self.clei is not None:
                                                                                                        return True

                                                                                                    if self.controller_family is not None:
                                                                                                        return True

                                                                                                    if self.controller_type is not None:
                                                                                                        return True

                                                                                                    if self.description is not None:
                                                                                                        return True

                                                                                                    if self.dev_num1 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num2 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num3 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num4 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num5 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num6 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num7 is not None:
                                                                                                        return True

                                                                                                    if self.eci is not None:
                                                                                                        return True

                                                                                                    if self.eeprom_size is not None:
                                                                                                        return True

                                                                                                    if self.engineer_use is not None:
                                                                                                        return True

                                                                                                    if self.fru_major_type is not None:
                                                                                                        return True

                                                                                                    if self.fru_minor_type is not None:
                                                                                                        return True

                                                                                                    if self.hw_version is not None:
                                                                                                        return True

                                                                                                    if self.hwid is not None:
                                                                                                        return True

                                                                                                    if self.idprom_format_rev is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size1 is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size2 is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size3 is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size4 is not None:
                                                                                                        return True

                                                                                                    if self.manu_test_data is not None:
                                                                                                        return True

                                                                                                    if self.mfg_bits is not None:
                                                                                                        return True

                                                                                                    if self.mfg_deviation is not None:
                                                                                                        return True

                                                                                                    if self.oem_string is not None:
                                                                                                        return True

                                                                                                    if self.part_number is not None:
                                                                                                        return True

                                                                                                    if self.part_revision is not None:
                                                                                                        return True

                                                                                                    if self.pca_num is not None:
                                                                                                        return True

                                                                                                    if self.pcavid is not None:
                                                                                                        return True

                                                                                                    if self.pcb_serial_num is not None:
                                                                                                        return True

                                                                                                    if self.pid is not None:
                                                                                                        return True

                                                                                                    if self.power_consumption is not None:
                                                                                                        return True

                                                                                                    if self.power_supply_type is not None:
                                                                                                        return True

                                                                                                    if self.product_id is not None:
                                                                                                        return True

                                                                                                    if self.rma is not None and self.rma._has_data():
                                                                                                        return True

                                                                                                    if self.rma_code is not None:
                                                                                                        return True

                                                                                                    if self.serial_number is not None:
                                                                                                        return True

                                                                                                    if self.snmpoid is not None:
                                                                                                        return True

                                                                                                    if self.top_assem_part_num is not None:
                                                                                                        return True

                                                                                                    if self.top_assem_vid is not None:
                                                                                                        return True

                                                                                                    if self.udi_description is not None:
                                                                                                        return True

                                                                                                    if self.udi_name is not None:
                                                                                                        return True

                                                                                                    if self.vid is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.description is not None:
                                                                                                    return True

                                                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                                                    return True

                                                                                                if self.has_eeprom is not None:
                                                                                                    return True

                                                                                                if self.inv_card_type is not None:
                                                                                                    return True

                                                                                                if self.opaque_data is not None:
                                                                                                    return True

                                                                                                if self.opaque_data_size is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                return True

                                                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                return True

                                                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                                                return True

                                                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                return True

                                                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                return True

                                                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                return True

                                                                                            if self.module_done is not None:
                                                                                                return True

                                                                                            if self.node_id is not None:
                                                                                                return True

                                                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                return True

                                                                                            if self.threshold is not None and self.threshold._has_data():
                                                                                                return True

                                                                                            if self.vm_done is not None:
                                                                                                return True

                                                                                            if self.vm_node_id is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                        if self.name is None:
                                                                                            raise YPYModelError('Key property name is None')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi8[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.name is not None:
                                                                                            return True

                                                                                        if self.attributes is not None and self.attributes._has_data():
                                                                                            return True

                                                                                        if self.tsi9s is not None and self.tsi9s._has_data():
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi8s'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.tsi8 is not None:
                                                                                        for child_ref in self.tsi8:
                                                                                            if child_ref._has_data():
                                                                                                return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S']['meta_info']


                                                                            class Attributes(object):
                                                                                """
                                                                                Attributes
                                                                                
                                                                                .. attribute:: env_sensor_info
                                                                                
                                                                                	Environment sensor info
                                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfo>`
                                                                                
                                                                                .. attribute:: env_sensor_info_xml
                                                                                
                                                                                	Environment sensor info XML
                                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml>`
                                                                                
                                                                                .. attribute:: fru_info
                                                                                
                                                                                	Inventory EDM FRU info
                                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo>`
                                                                                
                                                                                .. attribute:: inv_asset_bag
                                                                                
                                                                                	Inventory Asset Bag
                                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvAssetBag>`
                                                                                
                                                                                .. attribute:: inv_basic_bag
                                                                                
                                                                                	Inventory Basic Bag
                                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvBasicBag>`
                                                                                
                                                                                .. attribute:: inv_eeprom_info
                                                                                
                                                                                	Inventory EDM EEPROM Information Bag
                                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo>`
                                                                                
                                                                                .. attribute:: module_done
                                                                                
                                                                                	Inventory EDM Module Done Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**default value**\: 1
                                                                                
                                                                                .. attribute:: node_id
                                                                                
                                                                                	Node ID Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: pwg_info
                                                                                
                                                                                	Inventory EDM PWG info
                                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.PwgInfo>`
                                                                                
                                                                                .. attribute:: threshold
                                                                                
                                                                                	Threshold
                                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold>`
                                                                                
                                                                                .. attribute:: vm_done
                                                                                
                                                                                	VM Done Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                .. attribute:: vm_node_id
                                                                                
                                                                                	VM Node ID Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfo()
                                                                                    self.env_sensor_info.parent = self
                                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml()
                                                                                    self.env_sensor_info_xml.parent = self
                                                                                    self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo()
                                                                                    self.fru_info.parent = self
                                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvAssetBag()
                                                                                    self.inv_asset_bag.parent = self
                                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvBasicBag()
                                                                                    self.inv_basic_bag.parent = self
                                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo()
                                                                                    self.inv_eeprom_info.parent = self
                                                                                    self.module_done = None
                                                                                    self.node_id = None
                                                                                    self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.PwgInfo()
                                                                                    self.pwg_info.parent = self
                                                                                    self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold()
                                                                                    self.threshold.parent = self
                                                                                    self.vm_done = None
                                                                                    self.vm_node_id = None


                                                                                class EnvSensorInfo(object):
                                                                                    """
                                                                                    Environment sensor info
                                                                                    
                                                                                    .. attribute:: age_time_stamp
                                                                                    
                                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: alarm_type
                                                                                    
                                                                                    	Indicates threshold violation
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: data_type
                                                                                    
                                                                                    	Sensor data type enums
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: device_description
                                                                                    
                                                                                    	Device Name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: device_id
                                                                                    
                                                                                    	Identifier for this device
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: field_validity_bitmap
                                                                                    
                                                                                    	Sensor valid bitmap
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: precision
                                                                                    
                                                                                    	Sensor precision range
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: scale
                                                                                    
                                                                                    	Sensor scale enums
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: status
                                                                                    
                                                                                    	Sensor operation state enums
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: units
                                                                                    
                                                                                    	Units of variable being read
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: update_rate
                                                                                    
                                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                    	Current reading of sensor
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.age_time_stamp = None
                                                                                        self.alarm_type = None
                                                                                        self.data_type = None
                                                                                        self.device_description = None
                                                                                        self.device_id = None
                                                                                        self.field_validity_bitmap = None
                                                                                        self.precision = None
                                                                                        self.scale = None
                                                                                        self.status = None
                                                                                        self.units = None
                                                                                        self.update_rate = None
                                                                                        self.value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.age_time_stamp is not None:
                                                                                            return True

                                                                                        if self.alarm_type is not None:
                                                                                            return True

                                                                                        if self.data_type is not None:
                                                                                            return True

                                                                                        if self.device_description is not None:
                                                                                            return True

                                                                                        if self.device_id is not None:
                                                                                            return True

                                                                                        if self.field_validity_bitmap is not None:
                                                                                            return True

                                                                                        if self.precision is not None:
                                                                                            return True

                                                                                        if self.scale is not None:
                                                                                            return True

                                                                                        if self.status is not None:
                                                                                            return True

                                                                                        if self.units is not None:
                                                                                            return True

                                                                                        if self.update_rate is not None:
                                                                                            return True

                                                                                        if self.value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfo']['meta_info']


                                                                                class PwgInfo(object):
                                                                                    """
                                                                                    Inventory EDM PWG info
                                                                                    
                                                                                    .. attribute:: power_group_available_current
                                                                                    
                                                                                    	available current
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_group_drawn_current
                                                                                    
                                                                                    	drawn current
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_group_power_units
                                                                                    
                                                                                    	power units
                                                                                    	**type**\:  str
                                                                                    
                                                                                    .. attribute:: power_group_redundancy_mode
                                                                                    
                                                                                    	redundancy mode
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.power_group_available_current = None
                                                                                        self.power_group_drawn_current = None
                                                                                        self.power_group_power_units = None
                                                                                        self.power_group_redundancy_mode = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.power_group_available_current is not None:
                                                                                            return True

                                                                                        if self.power_group_drawn_current is not None:
                                                                                            return True

                                                                                        if self.power_group_power_units is not None:
                                                                                            return True

                                                                                        if self.power_group_redundancy_mode is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.PwgInfo']['meta_info']


                                                                                class EnvSensorInfoXml(object):
                                                                                    """
                                                                                    Environment sensor info XML
                                                                                    
                                                                                    .. attribute:: data_type
                                                                                    
                                                                                    	Sensor data type
                                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                    
                                                                                    .. attribute:: description
                                                                                    
                                                                                    	Device Name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: status
                                                                                    
                                                                                    	Sensor operation state
                                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                    
                                                                                    .. attribute:: threshold
                                                                                    
                                                                                    	Threshold information
                                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                    
                                                                                    .. attribute:: units
                                                                                    
                                                                                    	Units of variable being read
                                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                    
                                                                                    .. attribute:: update_rate
                                                                                    
                                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.data_type = None
                                                                                        self.description = None
                                                                                        self.status = None
                                                                                        self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold()
                                                                                        self.threshold.parent = self
                                                                                        self.units = None
                                                                                        self.update_rate = None
                                                                                        self.value = None


                                                                                    class Threshold(object):
                                                                                        """
                                                                                        Threshold information
                                                                                        
                                                                                        .. attribute:: threshold_array
                                                                                        
                                                                                        	Array of threshold
                                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.threshold_array = YList()
                                                                                            self.threshold_array.parent = self
                                                                                            self.threshold_array.name = 'threshold_array'


                                                                                        class ThresholdArray(object):
                                                                                            """
                                                                                            Array of threshold
                                                                                            
                                                                                            .. attribute:: threshold_name
                                                                                            
                                                                                            	Threshold name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_name = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_name is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.threshold_array is not None:
                                                                                                for child_ref in self.threshold_array:
                                                                                                    if child_ref._has_data():
                                                                                                        return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.data_type is not None:
                                                                                            return True

                                                                                        if self.description is not None:
                                                                                            return True

                                                                                        if self.status is not None:
                                                                                            return True

                                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                                            return True

                                                                                        if self.units is not None:
                                                                                            return True

                                                                                        if self.update_rate is not None:
                                                                                            return True

                                                                                        if self.value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                class InvAssetBag(object):
                                                                                    """
                                                                                    Inventory Asset Bag
                                                                                    
                                                                                    .. attribute:: manufacturer_assembly_number
                                                                                    
                                                                                    	Manufacture Assembly number
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_assembly_revision
                                                                                    
                                                                                    	Manufacture assembly revision
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                    
                                                                                    	Common Language Equipment           Identifier number
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                                    
                                                                                    	
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_software_identifier
                                                                                    
                                                                                    	
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                                    
                                                                                    	String containing OEM information           if applicable
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: part_number
                                                                                    
                                                                                    	
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.manufacturer_assembly_number = None
                                                                                        self.manufacturer_assembly_revision = None
                                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                                        self.manufacturer_firmware_identifier = None
                                                                                        self.manufacturer_software_identifier = None
                                                                                        self.original_equipment_manufacturer_string = None
                                                                                        self.part_number = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.manufacturer_assembly_number is not None:
                                                                                            return True

                                                                                        if self.manufacturer_assembly_revision is not None:
                                                                                            return True

                                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                            return True

                                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                                            return True

                                                                                        if self.manufacturer_software_identifier is not None:
                                                                                            return True

                                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                                            return True

                                                                                        if self.part_number is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvAssetBag']['meta_info']


                                                                                class Threshold(object):
                                                                                    """
                                                                                    Threshold
                                                                                    
                                                                                    .. attribute:: critical_hi
                                                                                    
                                                                                    	Critical High
                                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi>`
                                                                                    
                                                                                    .. attribute:: critical_lo
                                                                                    
                                                                                    	Critical Low
                                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo>`
                                                                                    
                                                                                    .. attribute:: major_hi
                                                                                    
                                                                                    	Major High
                                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi>`
                                                                                    
                                                                                    .. attribute:: major_lo
                                                                                    
                                                                                    	Major Low
                                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo>`
                                                                                    
                                                                                    .. attribute:: minor_hi
                                                                                    
                                                                                    	Minor High
                                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi>`
                                                                                    
                                                                                    .. attribute:: minor_lo
                                                                                    
                                                                                    	Minor Low
                                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo>`
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi()
                                                                                        self.critical_hi.parent = self
                                                                                        self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo()
                                                                                        self.critical_lo.parent = self
                                                                                        self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi()
                                                                                        self.major_hi.parent = self
                                                                                        self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo()
                                                                                        self.major_lo.parent = self
                                                                                        self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi()
                                                                                        self.minor_hi.parent = self
                                                                                        self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo()
                                                                                        self.minor_lo.parent = self


                                                                                    class MajorLo(object):
                                                                                        """
                                                                                        Major Low
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo']['meta_info']


                                                                                    class CriticalHi(object):
                                                                                        """
                                                                                        Critical High
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                    class MinorHi(object):
                                                                                        """
                                                                                        Minor High
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi']['meta_info']


                                                                                    class MajorHi(object):
                                                                                        """
                                                                                        Major High
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi']['meta_info']


                                                                                    class CriticalLo(object):
                                                                                        """
                                                                                        Critical Low
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                    class MinorLo(object):
                                                                                        """
                                                                                        Minor Low
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                            return True

                                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                            return True

                                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                                            return True

                                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                                            return True

                                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                            return True

                                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold']['meta_info']


                                                                                class FruInfo(object):
                                                                                    """
                                                                                    Inventory EDM FRU info
                                                                                    
                                                                                    .. attribute:: card_administrative_state
                                                                                    
                                                                                    	card admin state\: shutdown or not
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: card_monitor_state
                                                                                    
                                                                                    	card is monitored by a manager or left unmonitored
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: card_operational_state
                                                                                    
                                                                                    	card operation state
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: card_reset_reason
                                                                                    
                                                                                    	card reset reason enum
                                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                    
                                                                                    .. attribute:: card_up_time
                                                                                    
                                                                                    	card up time
                                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.CardUpTime>`
                                                                                    
                                                                                    .. attribute:: last_operational_state_change
                                                                                    
                                                                                    	last card oper change state
                                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                    
                                                                                    .. attribute:: power_administrative_state
                                                                                    
                                                                                    	power admin state\: up or down
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_current_measurement
                                                                                    
                                                                                    	power current\: not implemented
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_operational_state
                                                                                    
                                                                                    	Power operation state
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.card_administrative_state = None
                                                                                        self.card_monitor_state = None
                                                                                        self.card_operational_state = None
                                                                                        self.card_reset_reason = None
                                                                                        self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.CardUpTime()
                                                                                        self.card_up_time.parent = self
                                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.LastOperationalStateChange()
                                                                                        self.last_operational_state_change.parent = self
                                                                                        self.power_administrative_state = None
                                                                                        self.power_current_measurement = None
                                                                                        self.power_operational_state = None


                                                                                    class LastOperationalStateChange(object):
                                                                                        """
                                                                                        last card oper change state
                                                                                        
                                                                                        .. attribute:: time_in_nano_seconds
                                                                                        
                                                                                        	Time Value in Nano\-seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: nanosecond
                                                                                        
                                                                                        .. attribute:: time_in_seconds
                                                                                        
                                                                                        	Time Value in Seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: second
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.time_in_nano_seconds = None
                                                                                            self.time_in_seconds = None

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                return True

                                                                                            if self.time_in_seconds is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                    class CardUpTime(object):
                                                                                        """
                                                                                        card up time
                                                                                        
                                                                                        .. attribute:: time_in_nano_seconds
                                                                                        
                                                                                        	Time Value in Nano\-seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: nanosecond
                                                                                        
                                                                                        .. attribute:: time_in_seconds
                                                                                        
                                                                                        	Time Value in Seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: second
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.time_in_nano_seconds = None
                                                                                            self.time_in_seconds = None

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                return True

                                                                                            if self.time_in_seconds is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.card_administrative_state is not None:
                                                                                            return True

                                                                                        if self.card_monitor_state is not None:
                                                                                            return True

                                                                                        if self.card_operational_state is not None:
                                                                                            return True

                                                                                        if self.card_reset_reason is not None:
                                                                                            return True

                                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                            return True

                                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                            return True

                                                                                        if self.power_administrative_state is not None:
                                                                                            return True

                                                                                        if self.power_current_measurement is not None:
                                                                                            return True

                                                                                        if self.power_operational_state is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo']['meta_info']


                                                                                class InvBasicBag(object):
                                                                                    """
                                                                                    Inventory Basic Bag
                                                                                    
                                                                                    .. attribute:: alias
                                                                                    
                                                                                    	useful for storing an entity alias 
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: asset_id_str
                                                                                    
                                                                                    	asset Identification string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: asset_identification
                                                                                    
                                                                                    	asset Identification
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: ceport
                                                                                    
                                                                                    	1 if ce port found, 0 if not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: chip_hardware_revision
                                                                                    
                                                                                    	chip module hw revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: composite_class_code
                                                                                    
                                                                                    	Major&minor class of the entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: description
                                                                                    
                                                                                    	describes in user\-readable terms       what the entity in question does
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: environmental_monitor_path
                                                                                    
                                                                                    	sysdb name of sensor in the envmon EDM
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: firmware_revision
                                                                                    
                                                                                    	firmware revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: group_flag
                                                                                    
                                                                                    	indicates if this entity is group       or not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: hardware_revision
                                                                                    
                                                                                    	hw revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: is_field_replaceable_unit
                                                                                    
                                                                                    	1 if Field Replaceable Unit 0, if not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: manufacturer_asset_tags
                                                                                    
                                                                                    	Manufacture Asset Tags
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: manufacturer_name
                                                                                    
                                                                                    	manufacturer's name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: memory_size
                                                                                    
                                                                                    	Size of memory associated with       the entity where applicable
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: model_name
                                                                                    
                                                                                    	model name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: name
                                                                                    
                                                                                    	name string for the entity
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: new_deviation_number
                                                                                    
                                                                                    	integer value for New Deviation Number 0x88
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: physical_layer_interface_module_type
                                                                                    
                                                                                    	integer value for plim type if     applicable to this entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: redundancystate
                                                                                    
                                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: serial_number
                                                                                    
                                                                                    	serial number
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: software_revision
                                                                                    
                                                                                    	software revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: unique_id
                                                                                    
                                                                                    	Unique id for an entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: unrecognized_fru
                                                                                    
                                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: vendor_type
                                                                                    
                                                                                    	maps to the vendor OID string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: xr_scoped
                                                                                    
                                                                                    	1 if xr scoped, 0 if not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.alias = None
                                                                                        self.asset_id_str = None
                                                                                        self.asset_identification = None
                                                                                        self.ceport = None
                                                                                        self.chip_hardware_revision = None
                                                                                        self.composite_class_code = None
                                                                                        self.description = None
                                                                                        self.environmental_monitor_path = None
                                                                                        self.firmware_revision = None
                                                                                        self.group_flag = None
                                                                                        self.hardware_revision = None
                                                                                        self.is_field_replaceable_unit = None
                                                                                        self.manufacturer_asset_tags = None
                                                                                        self.manufacturer_name = None
                                                                                        self.memory_size = None
                                                                                        self.model_name = None
                                                                                        self.name = None
                                                                                        self.new_deviation_number = None
                                                                                        self.physical_layer_interface_module_type = None
                                                                                        self.redundancystate = None
                                                                                        self.serial_number = None
                                                                                        self.software_revision = None
                                                                                        self.unique_id = None
                                                                                        self.unrecognized_fru = None
                                                                                        self.vendor_type = None
                                                                                        self.xr_scoped = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.alias is not None:
                                                                                            return True

                                                                                        if self.asset_id_str is not None:
                                                                                            return True

                                                                                        if self.asset_identification is not None:
                                                                                            return True

                                                                                        if self.ceport is not None:
                                                                                            return True

                                                                                        if self.chip_hardware_revision is not None:
                                                                                            return True

                                                                                        if self.composite_class_code is not None:
                                                                                            return True

                                                                                        if self.description is not None:
                                                                                            return True

                                                                                        if self.environmental_monitor_path is not None:
                                                                                            return True

                                                                                        if self.firmware_revision is not None:
                                                                                            return True

                                                                                        if self.group_flag is not None:
                                                                                            return True

                                                                                        if self.hardware_revision is not None:
                                                                                            return True

                                                                                        if self.is_field_replaceable_unit is not None:
                                                                                            return True

                                                                                        if self.manufacturer_asset_tags is not None:
                                                                                            return True

                                                                                        if self.manufacturer_name is not None:
                                                                                            return True

                                                                                        if self.memory_size is not None:
                                                                                            return True

                                                                                        if self.model_name is not None:
                                                                                            return True

                                                                                        if self.name is not None:
                                                                                            return True

                                                                                        if self.new_deviation_number is not None:
                                                                                            return True

                                                                                        if self.physical_layer_interface_module_type is not None:
                                                                                            return True

                                                                                        if self.redundancystate is not None:
                                                                                            return True

                                                                                        if self.serial_number is not None:
                                                                                            return True

                                                                                        if self.software_revision is not None:
                                                                                            return True

                                                                                        if self.unique_id is not None:
                                                                                            return True

                                                                                        if self.unrecognized_fru is not None:
                                                                                            return True

                                                                                        if self.vendor_type is not None:
                                                                                            return True

                                                                                        if self.xr_scoped is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvBasicBag']['meta_info']


                                                                                class InvEepromInfo(object):
                                                                                    """
                                                                                    Inventory EDM EEPROM Information Bag
                                                                                    
                                                                                    .. attribute:: description
                                                                                    
                                                                                    	A textual description of physical entity
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: eeprom
                                                                                    
                                                                                    	EEPROM data not from hex data
                                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom>`
                                                                                    
                                                                                    .. attribute:: has_eeprom
                                                                                    
                                                                                    	use eeprom instead of opaque data
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: inv_card_type
                                                                                    
                                                                                    	Inventory card type
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..255
                                                                                    
                                                                                    .. attribute:: opaque_data
                                                                                    
                                                                                    	EEPROM hex data
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                    
                                                                                    .. attribute:: opaque_data_size
                                                                                    
                                                                                    	size of the EEPROM hex data
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.description = None
                                                                                        self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom()
                                                                                        self.eeprom.parent = self
                                                                                        self.has_eeprom = None
                                                                                        self.inv_card_type = None
                                                                                        self.opaque_data = None
                                                                                        self.opaque_data_size = None


                                                                                    class Eeprom(object):
                                                                                        """
                                                                                        EEPROM data not from hex data
                                                                                        
                                                                                        .. attribute:: asset_alias
                                                                                        
                                                                                        	Asset Alias
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: asset_id
                                                                                        
                                                                                        	Asset ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address1
                                                                                        
                                                                                        	Base Mac Address #1
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address2
                                                                                        
                                                                                        	Base Mac Address #2
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address3
                                                                                        
                                                                                        	Base Mac Address #3
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address4
                                                                                        
                                                                                        	Base Mac Address #4
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_checksum
                                                                                        
                                                                                        	Block Checksum
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_count
                                                                                        
                                                                                        	Block Count
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_length
                                                                                        
                                                                                        	Block Length
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_signature
                                                                                        
                                                                                        	Block Signature
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_version
                                                                                        
                                                                                        	Block Version
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: chassis_sid
                                                                                        
                                                                                        	Chassis serial number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: clei
                                                                                        
                                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: controller_family
                                                                                        
                                                                                        	Controller family
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: controller_type
                                                                                        
                                                                                        	Controller type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: description
                                                                                        
                                                                                        	A textual description of physical entity
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num1
                                                                                        
                                                                                        	Deviation Number # 1
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num2
                                                                                        
                                                                                        	Deviation Number # 2
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num3
                                                                                        
                                                                                        	Deviation Number # 3
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num4
                                                                                        
                                                                                        	Deviation Number # 4
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num5
                                                                                        
                                                                                        	Deviation Number # 5
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num6
                                                                                        
                                                                                        	Deviation Number # 6
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num7
                                                                                        
                                                                                        	Deviation Number # 7
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: eci
                                                                                        
                                                                                        	Equipment Catalog Item (ECI) number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: eeprom_size
                                                                                        
                                                                                        	EEPROM Size
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: engineer_use
                                                                                        
                                                                                        	Engineer Use
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: fru_major_type
                                                                                        
                                                                                        	FRU Major Type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: fru_minor_type
                                                                                        
                                                                                        	FRU Minor Type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: hw_version
                                                                                        
                                                                                        	Hardware Version
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: hwid
                                                                                        
                                                                                        	Hardware Revision
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: idprom_format_rev
                                                                                        
                                                                                        	IDPROM Format Revision
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size1
                                                                                        
                                                                                        	Mac Address Block Size #1
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size2
                                                                                        
                                                                                        	Mac Address Block Size #2
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size3
                                                                                        
                                                                                        	Mac Address Block Size #3
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size4
                                                                                        
                                                                                        	Mac Address Block Size #4
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: manu_test_data
                                                                                        
                                                                                        	Manufacturing Test Data
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mfg_bits
                                                                                        
                                                                                        	MFG Bits
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mfg_deviation
                                                                                        
                                                                                        	MFG Deviation
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: oem_string
                                                                                        
                                                                                        	OEM String
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: part_number
                                                                                        
                                                                                        	Part Number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: part_revision
                                                                                        
                                                                                        	Part Revision
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pca_num
                                                                                        
                                                                                        	PCA number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pcavid
                                                                                        
                                                                                        	PCA revision ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pcb_serial_num
                                                                                        
                                                                                        	PCB Serial Number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pid
                                                                                        
                                                                                        	Product ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: power_consumption
                                                                                        
                                                                                        	Power Consumption
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: power_supply_type
                                                                                        
                                                                                        	Power Supply Type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: product_id
                                                                                        
                                                                                        	Product ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: rma
                                                                                        
                                                                                        	RMA Data
                                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                        
                                                                                        .. attribute:: rma_code
                                                                                        
                                                                                        	RMA Code
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: serial_number
                                                                                        
                                                                                        	Serial Number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: snmpoid
                                                                                        
                                                                                        	SNMP OID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: top_assem_part_num
                                                                                        
                                                                                        	Top assembly part number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: top_assem_vid
                                                                                        
                                                                                        	Top assembly revision number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: udi_description
                                                                                        
                                                                                        	UDI description
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: udi_name
                                                                                        
                                                                                        	UDI name
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: vid
                                                                                        
                                                                                        	Version ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.asset_alias = None
                                                                                            self.asset_id = None
                                                                                            self.base_mac_address1 = None
                                                                                            self.base_mac_address2 = None
                                                                                            self.base_mac_address3 = None
                                                                                            self.base_mac_address4 = None
                                                                                            self.block_checksum = None
                                                                                            self.block_count = None
                                                                                            self.block_length = None
                                                                                            self.block_signature = None
                                                                                            self.block_version = None
                                                                                            self.chassis_sid = None
                                                                                            self.clei = None
                                                                                            self.controller_family = None
                                                                                            self.controller_type = None
                                                                                            self.description = None
                                                                                            self.dev_num1 = None
                                                                                            self.dev_num2 = None
                                                                                            self.dev_num3 = None
                                                                                            self.dev_num4 = None
                                                                                            self.dev_num5 = None
                                                                                            self.dev_num6 = None
                                                                                            self.dev_num7 = None
                                                                                            self.eci = None
                                                                                            self.eeprom_size = None
                                                                                            self.engineer_use = None
                                                                                            self.fru_major_type = None
                                                                                            self.fru_minor_type = None
                                                                                            self.hw_version = None
                                                                                            self.hwid = None
                                                                                            self.idprom_format_rev = None
                                                                                            self.mac_add_blk_size1 = None
                                                                                            self.mac_add_blk_size2 = None
                                                                                            self.mac_add_blk_size3 = None
                                                                                            self.mac_add_blk_size4 = None
                                                                                            self.manu_test_data = None
                                                                                            self.mfg_bits = None
                                                                                            self.mfg_deviation = None
                                                                                            self.oem_string = None
                                                                                            self.part_number = None
                                                                                            self.part_revision = None
                                                                                            self.pca_num = None
                                                                                            self.pcavid = None
                                                                                            self.pcb_serial_num = None
                                                                                            self.pid = None
                                                                                            self.power_consumption = None
                                                                                            self.power_supply_type = None
                                                                                            self.product_id = None
                                                                                            self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                            self.rma.parent = self
                                                                                            self.rma_code = None
                                                                                            self.serial_number = None
                                                                                            self.snmpoid = None
                                                                                            self.top_assem_part_num = None
                                                                                            self.top_assem_vid = None
                                                                                            self.udi_description = None
                                                                                            self.udi_name = None
                                                                                            self.vid = None


                                                                                        class Rma(object):
                                                                                            """
                                                                                            RMA Data
                                                                                            
                                                                                            .. attribute:: rma_history
                                                                                            
                                                                                            	RMA history
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: rma_number
                                                                                            
                                                                                            	RMA tracking number format is N\-N\-N
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: test_history
                                                                                            
                                                                                            	Test history
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.rma_history = None
                                                                                                self.rma_number = None
                                                                                                self.test_history = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.rma_history is not None:
                                                                                                    return True

                                                                                                if self.rma_number is not None:
                                                                                                    return True

                                                                                                if self.test_history is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.asset_alias is not None:
                                                                                                return True

                                                                                            if self.asset_id is not None:
                                                                                                return True

                                                                                            if self.base_mac_address1 is not None:
                                                                                                return True

                                                                                            if self.base_mac_address2 is not None:
                                                                                                return True

                                                                                            if self.base_mac_address3 is not None:
                                                                                                return True

                                                                                            if self.base_mac_address4 is not None:
                                                                                                return True

                                                                                            if self.block_checksum is not None:
                                                                                                return True

                                                                                            if self.block_count is not None:
                                                                                                return True

                                                                                            if self.block_length is not None:
                                                                                                return True

                                                                                            if self.block_signature is not None:
                                                                                                return True

                                                                                            if self.block_version is not None:
                                                                                                return True

                                                                                            if self.chassis_sid is not None:
                                                                                                return True

                                                                                            if self.clei is not None:
                                                                                                return True

                                                                                            if self.controller_family is not None:
                                                                                                return True

                                                                                            if self.controller_type is not None:
                                                                                                return True

                                                                                            if self.description is not None:
                                                                                                return True

                                                                                            if self.dev_num1 is not None:
                                                                                                return True

                                                                                            if self.dev_num2 is not None:
                                                                                                return True

                                                                                            if self.dev_num3 is not None:
                                                                                                return True

                                                                                            if self.dev_num4 is not None:
                                                                                                return True

                                                                                            if self.dev_num5 is not None:
                                                                                                return True

                                                                                            if self.dev_num6 is not None:
                                                                                                return True

                                                                                            if self.dev_num7 is not None:
                                                                                                return True

                                                                                            if self.eci is not None:
                                                                                                return True

                                                                                            if self.eeprom_size is not None:
                                                                                                return True

                                                                                            if self.engineer_use is not None:
                                                                                                return True

                                                                                            if self.fru_major_type is not None:
                                                                                                return True

                                                                                            if self.fru_minor_type is not None:
                                                                                                return True

                                                                                            if self.hw_version is not None:
                                                                                                return True

                                                                                            if self.hwid is not None:
                                                                                                return True

                                                                                            if self.idprom_format_rev is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size1 is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size2 is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size3 is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size4 is not None:
                                                                                                return True

                                                                                            if self.manu_test_data is not None:
                                                                                                return True

                                                                                            if self.mfg_bits is not None:
                                                                                                return True

                                                                                            if self.mfg_deviation is not None:
                                                                                                return True

                                                                                            if self.oem_string is not None:
                                                                                                return True

                                                                                            if self.part_number is not None:
                                                                                                return True

                                                                                            if self.part_revision is not None:
                                                                                                return True

                                                                                            if self.pca_num is not None:
                                                                                                return True

                                                                                            if self.pcavid is not None:
                                                                                                return True

                                                                                            if self.pcb_serial_num is not None:
                                                                                                return True

                                                                                            if self.pid is not None:
                                                                                                return True

                                                                                            if self.power_consumption is not None:
                                                                                                return True

                                                                                            if self.power_supply_type is not None:
                                                                                                return True

                                                                                            if self.product_id is not None:
                                                                                                return True

                                                                                            if self.rma is not None and self.rma._has_data():
                                                                                                return True

                                                                                            if self.rma_code is not None:
                                                                                                return True

                                                                                            if self.serial_number is not None:
                                                                                                return True

                                                                                            if self.snmpoid is not None:
                                                                                                return True

                                                                                            if self.top_assem_part_num is not None:
                                                                                                return True

                                                                                            if self.top_assem_vid is not None:
                                                                                                return True

                                                                                            if self.udi_description is not None:
                                                                                                return True

                                                                                            if self.udi_name is not None:
                                                                                                return True

                                                                                            if self.vid is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.description is not None:
                                                                                            return True

                                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                                            return True

                                                                                        if self.has_eeprom is not None:
                                                                                            return True

                                                                                        if self.inv_card_type is not None:
                                                                                            return True

                                                                                        if self.opaque_data is not None:
                                                                                            return True

                                                                                        if self.opaque_data_size is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                        return True

                                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                        return True

                                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                                        return True

                                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                        return True

                                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                        return True

                                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                        return True

                                                                                    if self.module_done is not None:
                                                                                        return True

                                                                                    if self.node_id is not None:
                                                                                        return True

                                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                        return True

                                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                                        return True

                                                                                    if self.vm_done is not None:
                                                                                        return True

                                                                                    if self.vm_node_id is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                if self.name is None:
                                                                                    raise YPYModelError('Key property name is None')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi7[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.name is not None:
                                                                                    return True

                                                                                if self.attributes is not None and self.attributes._has_data():
                                                                                    return True

                                                                                if self.tsi8s is not None and self.tsi8s._has_data():
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi7s'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.tsi7 is not None:
                                                                                for child_ref in self.tsi7:
                                                                                    if child_ref._has_data():
                                                                                        return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S']['meta_info']


                                                                    class Attributes(object):
                                                                        """
                                                                        Attributes
                                                                        
                                                                        .. attribute:: env_sensor_info
                                                                        
                                                                        	Environment sensor info
                                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfo>`
                                                                        
                                                                        .. attribute:: env_sensor_info_xml
                                                                        
                                                                        	Environment sensor info XML
                                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml>`
                                                                        
                                                                        .. attribute:: fru_info
                                                                        
                                                                        	Inventory EDM FRU info
                                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo>`
                                                                        
                                                                        .. attribute:: inv_asset_bag
                                                                        
                                                                        	Inventory Asset Bag
                                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvAssetBag>`
                                                                        
                                                                        .. attribute:: inv_basic_bag
                                                                        
                                                                        	Inventory Basic Bag
                                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvBasicBag>`
                                                                        
                                                                        .. attribute:: inv_eeprom_info
                                                                        
                                                                        	Inventory EDM EEPROM Information Bag
                                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo>`
                                                                        
                                                                        .. attribute:: module_done
                                                                        
                                                                        	Inventory EDM Module Done Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**default value**\: 1
                                                                        
                                                                        .. attribute:: node_id
                                                                        
                                                                        	Node ID Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: pwg_info
                                                                        
                                                                        	Inventory EDM PWG info
                                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.PwgInfo>`
                                                                        
                                                                        .. attribute:: threshold
                                                                        
                                                                        	Threshold
                                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold>`
                                                                        
                                                                        .. attribute:: vm_done
                                                                        
                                                                        	VM Done Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        .. attribute:: vm_node_id
                                                                        
                                                                        	VM Node ID Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfo()
                                                                            self.env_sensor_info.parent = self
                                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml()
                                                                            self.env_sensor_info_xml.parent = self
                                                                            self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo()
                                                                            self.fru_info.parent = self
                                                                            self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvAssetBag()
                                                                            self.inv_asset_bag.parent = self
                                                                            self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvBasicBag()
                                                                            self.inv_basic_bag.parent = self
                                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo()
                                                                            self.inv_eeprom_info.parent = self
                                                                            self.module_done = None
                                                                            self.node_id = None
                                                                            self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.PwgInfo()
                                                                            self.pwg_info.parent = self
                                                                            self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold()
                                                                            self.threshold.parent = self
                                                                            self.vm_done = None
                                                                            self.vm_node_id = None


                                                                        class EnvSensorInfo(object):
                                                                            """
                                                                            Environment sensor info
                                                                            
                                                                            .. attribute:: age_time_stamp
                                                                            
                                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: alarm_type
                                                                            
                                                                            	Indicates threshold violation
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: data_type
                                                                            
                                                                            	Sensor data type enums
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: device_description
                                                                            
                                                                            	Device Name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: device_id
                                                                            
                                                                            	Identifier for this device
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: field_validity_bitmap
                                                                            
                                                                            	Sensor valid bitmap
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: precision
                                                                            
                                                                            	Sensor precision range
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: scale
                                                                            
                                                                            	Sensor scale enums
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: status
                                                                            
                                                                            	Sensor operation state enums
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: units
                                                                            
                                                                            	Units of variable being read
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: update_rate
                                                                            
                                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	Current reading of sensor
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.age_time_stamp = None
                                                                                self.alarm_type = None
                                                                                self.data_type = None
                                                                                self.device_description = None
                                                                                self.device_id = None
                                                                                self.field_validity_bitmap = None
                                                                                self.precision = None
                                                                                self.scale = None
                                                                                self.status = None
                                                                                self.units = None
                                                                                self.update_rate = None
                                                                                self.value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.age_time_stamp is not None:
                                                                                    return True

                                                                                if self.alarm_type is not None:
                                                                                    return True

                                                                                if self.data_type is not None:
                                                                                    return True

                                                                                if self.device_description is not None:
                                                                                    return True

                                                                                if self.device_id is not None:
                                                                                    return True

                                                                                if self.field_validity_bitmap is not None:
                                                                                    return True

                                                                                if self.precision is not None:
                                                                                    return True

                                                                                if self.scale is not None:
                                                                                    return True

                                                                                if self.status is not None:
                                                                                    return True

                                                                                if self.units is not None:
                                                                                    return True

                                                                                if self.update_rate is not None:
                                                                                    return True

                                                                                if self.value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfo']['meta_info']


                                                                        class PwgInfo(object):
                                                                            """
                                                                            Inventory EDM PWG info
                                                                            
                                                                            .. attribute:: power_group_available_current
                                                                            
                                                                            	available current
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_group_drawn_current
                                                                            
                                                                            	drawn current
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_group_power_units
                                                                            
                                                                            	power units
                                                                            	**type**\:  str
                                                                            
                                                                            .. attribute:: power_group_redundancy_mode
                                                                            
                                                                            	redundancy mode
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.power_group_available_current = None
                                                                                self.power_group_drawn_current = None
                                                                                self.power_group_power_units = None
                                                                                self.power_group_redundancy_mode = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.power_group_available_current is not None:
                                                                                    return True

                                                                                if self.power_group_drawn_current is not None:
                                                                                    return True

                                                                                if self.power_group_power_units is not None:
                                                                                    return True

                                                                                if self.power_group_redundancy_mode is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.PwgInfo']['meta_info']


                                                                        class EnvSensorInfoXml(object):
                                                                            """
                                                                            Environment sensor info XML
                                                                            
                                                                            .. attribute:: data_type
                                                                            
                                                                            	Sensor data type
                                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                            
                                                                            .. attribute:: description
                                                                            
                                                                            	Device Name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: status
                                                                            
                                                                            	Sensor operation state
                                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                            
                                                                            .. attribute:: threshold
                                                                            
                                                                            	Threshold information
                                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold>`
                                                                            
                                                                            .. attribute:: units
                                                                            
                                                                            	Units of variable being read
                                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                            
                                                                            .. attribute:: update_rate
                                                                            
                                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.data_type = None
                                                                                self.description = None
                                                                                self.status = None
                                                                                self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold()
                                                                                self.threshold.parent = self
                                                                                self.units = None
                                                                                self.update_rate = None
                                                                                self.value = None


                                                                            class Threshold(object):
                                                                                """
                                                                                Threshold information
                                                                                
                                                                                .. attribute:: threshold_array
                                                                                
                                                                                	Array of threshold
                                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.threshold_array = YList()
                                                                                    self.threshold_array.parent = self
                                                                                    self.threshold_array.name = 'threshold_array'


                                                                                class ThresholdArray(object):
                                                                                    """
                                                                                    Array of threshold
                                                                                    
                                                                                    .. attribute:: threshold_name
                                                                                    
                                                                                    	Threshold name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_name = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_name is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.threshold_array is not None:
                                                                                        for child_ref in self.threshold_array:
                                                                                            if child_ref._has_data():
                                                                                                return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.data_type is not None:
                                                                                    return True

                                                                                if self.description is not None:
                                                                                    return True

                                                                                if self.status is not None:
                                                                                    return True

                                                                                if self.threshold is not None and self.threshold._has_data():
                                                                                    return True

                                                                                if self.units is not None:
                                                                                    return True

                                                                                if self.update_rate is not None:
                                                                                    return True

                                                                                if self.value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml']['meta_info']


                                                                        class InvAssetBag(object):
                                                                            """
                                                                            Inventory Asset Bag
                                                                            
                                                                            .. attribute:: manufacturer_assembly_number
                                                                            
                                                                            	Manufacture Assembly number
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_assembly_revision
                                                                            
                                                                            	Manufacture assembly revision
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                                            
                                                                            	Common Language Equipment           Identifier number
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_firmware_identifier
                                                                            
                                                                            	
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_software_identifier
                                                                            
                                                                            	
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: original_equipment_manufacturer_string
                                                                            
                                                                            	String containing OEM information           if applicable
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: part_number
                                                                            
                                                                            	
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.manufacturer_assembly_number = None
                                                                                self.manufacturer_assembly_revision = None
                                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                                self.manufacturer_firmware_identifier = None
                                                                                self.manufacturer_software_identifier = None
                                                                                self.original_equipment_manufacturer_string = None
                                                                                self.part_number = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.manufacturer_assembly_number is not None:
                                                                                    return True

                                                                                if self.manufacturer_assembly_revision is not None:
                                                                                    return True

                                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                    return True

                                                                                if self.manufacturer_firmware_identifier is not None:
                                                                                    return True

                                                                                if self.manufacturer_software_identifier is not None:
                                                                                    return True

                                                                                if self.original_equipment_manufacturer_string is not None:
                                                                                    return True

                                                                                if self.part_number is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvAssetBag']['meta_info']


                                                                        class Threshold(object):
                                                                            """
                                                                            Threshold
                                                                            
                                                                            .. attribute:: critical_hi
                                                                            
                                                                            	Critical High
                                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi>`
                                                                            
                                                                            .. attribute:: critical_lo
                                                                            
                                                                            	Critical Low
                                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo>`
                                                                            
                                                                            .. attribute:: major_hi
                                                                            
                                                                            	Major High
                                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi>`
                                                                            
                                                                            .. attribute:: major_lo
                                                                            
                                                                            	Major Low
                                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo>`
                                                                            
                                                                            .. attribute:: minor_hi
                                                                            
                                                                            	Minor High
                                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi>`
                                                                            
                                                                            .. attribute:: minor_lo
                                                                            
                                                                            	Minor Low
                                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi()
                                                                                self.critical_hi.parent = self
                                                                                self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo()
                                                                                self.critical_lo.parent = self
                                                                                self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi()
                                                                                self.major_hi.parent = self
                                                                                self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo()
                                                                                self.major_lo.parent = self
                                                                                self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi()
                                                                                self.minor_hi.parent = self
                                                                                self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo()
                                                                                self.minor_lo.parent = self


                                                                            class MajorLo(object):
                                                                                """
                                                                                Major Low
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo']['meta_info']


                                                                            class CriticalHi(object):
                                                                                """
                                                                                Critical High
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi']['meta_info']


                                                                            class MinorHi(object):
                                                                                """
                                                                                Minor High
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi']['meta_info']


                                                                            class MajorHi(object):
                                                                                """
                                                                                Major High
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi']['meta_info']


                                                                            class CriticalLo(object):
                                                                                """
                                                                                Critical Low
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo']['meta_info']


                                                                            class MinorLo(object):
                                                                                """
                                                                                Minor Low
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                    return True

                                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                    return True

                                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                                    return True

                                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                                    return True

                                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                    return True

                                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold']['meta_info']


                                                                        class FruInfo(object):
                                                                            """
                                                                            Inventory EDM FRU info
                                                                            
                                                                            .. attribute:: card_administrative_state
                                                                            
                                                                            	card admin state\: shutdown or not
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: card_monitor_state
                                                                            
                                                                            	card is monitored by a manager or left unmonitored
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: card_operational_state
                                                                            
                                                                            	card operation state
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: card_reset_reason
                                                                            
                                                                            	card reset reason enum
                                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                            
                                                                            .. attribute:: card_up_time
                                                                            
                                                                            	card up time
                                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.CardUpTime>`
                                                                            
                                                                            .. attribute:: last_operational_state_change
                                                                            
                                                                            	last card oper change state
                                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.LastOperationalStateChange>`
                                                                            
                                                                            .. attribute:: power_administrative_state
                                                                            
                                                                            	power admin state\: up or down
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_current_measurement
                                                                            
                                                                            	power current\: not implemented
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_operational_state
                                                                            
                                                                            	Power operation state
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.card_administrative_state = None
                                                                                self.card_monitor_state = None
                                                                                self.card_operational_state = None
                                                                                self.card_reset_reason = None
                                                                                self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.CardUpTime()
                                                                                self.card_up_time.parent = self
                                                                                self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.LastOperationalStateChange()
                                                                                self.last_operational_state_change.parent = self
                                                                                self.power_administrative_state = None
                                                                                self.power_current_measurement = None
                                                                                self.power_operational_state = None


                                                                            class LastOperationalStateChange(object):
                                                                                """
                                                                                last card oper change state
                                                                                
                                                                                .. attribute:: time_in_nano_seconds
                                                                                
                                                                                	Time Value in Nano\-seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: nanosecond
                                                                                
                                                                                .. attribute:: time_in_seconds
                                                                                
                                                                                	Time Value in Seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: second
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.time_in_nano_seconds = None
                                                                                    self.time_in_seconds = None

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.time_in_nano_seconds is not None:
                                                                                        return True

                                                                                    if self.time_in_seconds is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                            class CardUpTime(object):
                                                                                """
                                                                                card up time
                                                                                
                                                                                .. attribute:: time_in_nano_seconds
                                                                                
                                                                                	Time Value in Nano\-seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: nanosecond
                                                                                
                                                                                .. attribute:: time_in_seconds
                                                                                
                                                                                	Time Value in Seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: second
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.time_in_nano_seconds = None
                                                                                    self.time_in_seconds = None

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.time_in_nano_seconds is not None:
                                                                                        return True

                                                                                    if self.time_in_seconds is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.card_administrative_state is not None:
                                                                                    return True

                                                                                if self.card_monitor_state is not None:
                                                                                    return True

                                                                                if self.card_operational_state is not None:
                                                                                    return True

                                                                                if self.card_reset_reason is not None:
                                                                                    return True

                                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                    return True

                                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                    return True

                                                                                if self.power_administrative_state is not None:
                                                                                    return True

                                                                                if self.power_current_measurement is not None:
                                                                                    return True

                                                                                if self.power_operational_state is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo']['meta_info']


                                                                        class InvBasicBag(object):
                                                                            """
                                                                            Inventory Basic Bag
                                                                            
                                                                            .. attribute:: alias
                                                                            
                                                                            	useful for storing an entity alias 
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: asset_id_str
                                                                            
                                                                            	asset Identification string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: asset_identification
                                                                            
                                                                            	asset Identification
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: ceport
                                                                            
                                                                            	1 if ce port found, 0 if not
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: chip_hardware_revision
                                                                            
                                                                            	chip module hw revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: composite_class_code
                                                                            
                                                                            	Major&minor class of the entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: description
                                                                            
                                                                            	describes in user\-readable terms       what the entity in question does
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: environmental_monitor_path
                                                                            
                                                                            	sysdb name of sensor in the envmon EDM
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: firmware_revision
                                                                            
                                                                            	firmware revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: group_flag
                                                                            
                                                                            	indicates if this entity is group       or not
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: hardware_revision
                                                                            
                                                                            	hw revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: is_field_replaceable_unit
                                                                            
                                                                            	1 if Field Replaceable Unit 0, if not
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: manufacturer_asset_tags
                                                                            
                                                                            	Manufacture Asset Tags
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: manufacturer_name
                                                                            
                                                                            	manufacturer's name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: memory_size
                                                                            
                                                                            	Size of memory associated with       the entity where applicable
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: model_name
                                                                            
                                                                            	model name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: name
                                                                            
                                                                            	name string for the entity
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: new_deviation_number
                                                                            
                                                                            	integer value for New Deviation Number 0x88
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: physical_layer_interface_module_type
                                                                            
                                                                            	integer value for plim type if     applicable to this entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: redundancystate
                                                                            
                                                                            	integer value for Redundancy State if     applicable to this entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: serial_number
                                                                            
                                                                            	serial number
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: software_revision
                                                                            
                                                                            	software revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: unique_id
                                                                            
                                                                            	Unique id for an entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: unrecognized_fru
                                                                            
                                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: vendor_type
                                                                            
                                                                            	maps to the vendor OID string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: xr_scoped
                                                                            
                                                                            	1 if xr scoped, 0 if not
                                                                            	**type**\:  bool
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.alias = None
                                                                                self.asset_id_str = None
                                                                                self.asset_identification = None
                                                                                self.ceport = None
                                                                                self.chip_hardware_revision = None
                                                                                self.composite_class_code = None
                                                                                self.description = None
                                                                                self.environmental_monitor_path = None
                                                                                self.firmware_revision = None
                                                                                self.group_flag = None
                                                                                self.hardware_revision = None
                                                                                self.is_field_replaceable_unit = None
                                                                                self.manufacturer_asset_tags = None
                                                                                self.manufacturer_name = None
                                                                                self.memory_size = None
                                                                                self.model_name = None
                                                                                self.name = None
                                                                                self.new_deviation_number = None
                                                                                self.physical_layer_interface_module_type = None
                                                                                self.redundancystate = None
                                                                                self.serial_number = None
                                                                                self.software_revision = None
                                                                                self.unique_id = None
                                                                                self.unrecognized_fru = None
                                                                                self.vendor_type = None
                                                                                self.xr_scoped = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.alias is not None:
                                                                                    return True

                                                                                if self.asset_id_str is not None:
                                                                                    return True

                                                                                if self.asset_identification is not None:
                                                                                    return True

                                                                                if self.ceport is not None:
                                                                                    return True

                                                                                if self.chip_hardware_revision is not None:
                                                                                    return True

                                                                                if self.composite_class_code is not None:
                                                                                    return True

                                                                                if self.description is not None:
                                                                                    return True

                                                                                if self.environmental_monitor_path is not None:
                                                                                    return True

                                                                                if self.firmware_revision is not None:
                                                                                    return True

                                                                                if self.group_flag is not None:
                                                                                    return True

                                                                                if self.hardware_revision is not None:
                                                                                    return True

                                                                                if self.is_field_replaceable_unit is not None:
                                                                                    return True

                                                                                if self.manufacturer_asset_tags is not None:
                                                                                    return True

                                                                                if self.manufacturer_name is not None:
                                                                                    return True

                                                                                if self.memory_size is not None:
                                                                                    return True

                                                                                if self.model_name is not None:
                                                                                    return True

                                                                                if self.name is not None:
                                                                                    return True

                                                                                if self.new_deviation_number is not None:
                                                                                    return True

                                                                                if self.physical_layer_interface_module_type is not None:
                                                                                    return True

                                                                                if self.redundancystate is not None:
                                                                                    return True

                                                                                if self.serial_number is not None:
                                                                                    return True

                                                                                if self.software_revision is not None:
                                                                                    return True

                                                                                if self.unique_id is not None:
                                                                                    return True

                                                                                if self.unrecognized_fru is not None:
                                                                                    return True

                                                                                if self.vendor_type is not None:
                                                                                    return True

                                                                                if self.xr_scoped is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvBasicBag']['meta_info']


                                                                        class InvEepromInfo(object):
                                                                            """
                                                                            Inventory EDM EEPROM Information Bag
                                                                            
                                                                            .. attribute:: description
                                                                            
                                                                            	A textual description of physical entity
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: eeprom
                                                                            
                                                                            	EEPROM data not from hex data
                                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom>`
                                                                            
                                                                            .. attribute:: has_eeprom
                                                                            
                                                                            	use eeprom instead of opaque data
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: inv_card_type
                                                                            
                                                                            	Inventory card type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: opaque_data
                                                                            
                                                                            	EEPROM hex data
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: opaque_data_size
                                                                            
                                                                            	size of the EEPROM hex data
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.description = None
                                                                                self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom()
                                                                                self.eeprom.parent = self
                                                                                self.has_eeprom = None
                                                                                self.inv_card_type = None
                                                                                self.opaque_data = None
                                                                                self.opaque_data_size = None


                                                                            class Eeprom(object):
                                                                                """
                                                                                EEPROM data not from hex data
                                                                                
                                                                                .. attribute:: asset_alias
                                                                                
                                                                                	Asset Alias
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: asset_id
                                                                                
                                                                                	Asset ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address1
                                                                                
                                                                                	Base Mac Address #1
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address2
                                                                                
                                                                                	Base Mac Address #2
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address3
                                                                                
                                                                                	Base Mac Address #3
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address4
                                                                                
                                                                                	Base Mac Address #4
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_checksum
                                                                                
                                                                                	Block Checksum
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_count
                                                                                
                                                                                	Block Count
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_length
                                                                                
                                                                                	Block Length
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_signature
                                                                                
                                                                                	Block Signature
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_version
                                                                                
                                                                                	Block Version
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: chassis_sid
                                                                                
                                                                                	Chassis serial number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: clei
                                                                                
                                                                                	Common Language Equipment Identifier (CLEI) code
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: controller_family
                                                                                
                                                                                	Controller family
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: controller_type
                                                                                
                                                                                	Controller type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: description
                                                                                
                                                                                	A textual description of physical entity
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num1
                                                                                
                                                                                	Deviation Number # 1
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num2
                                                                                
                                                                                	Deviation Number # 2
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num3
                                                                                
                                                                                	Deviation Number # 3
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num4
                                                                                
                                                                                	Deviation Number # 4
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num5
                                                                                
                                                                                	Deviation Number # 5
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num6
                                                                                
                                                                                	Deviation Number # 6
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num7
                                                                                
                                                                                	Deviation Number # 7
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: eci
                                                                                
                                                                                	Equipment Catalog Item (ECI) number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: eeprom_size
                                                                                
                                                                                	EEPROM Size
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: engineer_use
                                                                                
                                                                                	Engineer Use
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: fru_major_type
                                                                                
                                                                                	FRU Major Type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: fru_minor_type
                                                                                
                                                                                	FRU Minor Type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: hw_version
                                                                                
                                                                                	Hardware Version
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: hwid
                                                                                
                                                                                	Hardware Revision
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: idprom_format_rev
                                                                                
                                                                                	IDPROM Format Revision
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size1
                                                                                
                                                                                	Mac Address Block Size #1
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size2
                                                                                
                                                                                	Mac Address Block Size #2
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size3
                                                                                
                                                                                	Mac Address Block Size #3
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size4
                                                                                
                                                                                	Mac Address Block Size #4
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: manu_test_data
                                                                                
                                                                                	Manufacturing Test Data
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mfg_bits
                                                                                
                                                                                	MFG Bits
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mfg_deviation
                                                                                
                                                                                	MFG Deviation
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: oem_string
                                                                                
                                                                                	OEM String
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: part_number
                                                                                
                                                                                	Part Number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: part_revision
                                                                                
                                                                                	Part Revision
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pca_num
                                                                                
                                                                                	PCA number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pcavid
                                                                                
                                                                                	PCA revision ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pcb_serial_num
                                                                                
                                                                                	PCB Serial Number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pid
                                                                                
                                                                                	Product ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: power_consumption
                                                                                
                                                                                	Power Consumption
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: power_supply_type
                                                                                
                                                                                	Power Supply Type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: product_id
                                                                                
                                                                                	Product ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: rma
                                                                                
                                                                                	RMA Data
                                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                
                                                                                .. attribute:: rma_code
                                                                                
                                                                                	RMA Code
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: serial_number
                                                                                
                                                                                	Serial Number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: snmpoid
                                                                                
                                                                                	SNMP OID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: top_assem_part_num
                                                                                
                                                                                	Top assembly part number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: top_assem_vid
                                                                                
                                                                                	Top assembly revision number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: udi_description
                                                                                
                                                                                	UDI description
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: udi_name
                                                                                
                                                                                	UDI name
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: vid
                                                                                
                                                                                	Version ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.asset_alias = None
                                                                                    self.asset_id = None
                                                                                    self.base_mac_address1 = None
                                                                                    self.base_mac_address2 = None
                                                                                    self.base_mac_address3 = None
                                                                                    self.base_mac_address4 = None
                                                                                    self.block_checksum = None
                                                                                    self.block_count = None
                                                                                    self.block_length = None
                                                                                    self.block_signature = None
                                                                                    self.block_version = None
                                                                                    self.chassis_sid = None
                                                                                    self.clei = None
                                                                                    self.controller_family = None
                                                                                    self.controller_type = None
                                                                                    self.description = None
                                                                                    self.dev_num1 = None
                                                                                    self.dev_num2 = None
                                                                                    self.dev_num3 = None
                                                                                    self.dev_num4 = None
                                                                                    self.dev_num5 = None
                                                                                    self.dev_num6 = None
                                                                                    self.dev_num7 = None
                                                                                    self.eci = None
                                                                                    self.eeprom_size = None
                                                                                    self.engineer_use = None
                                                                                    self.fru_major_type = None
                                                                                    self.fru_minor_type = None
                                                                                    self.hw_version = None
                                                                                    self.hwid = None
                                                                                    self.idprom_format_rev = None
                                                                                    self.mac_add_blk_size1 = None
                                                                                    self.mac_add_blk_size2 = None
                                                                                    self.mac_add_blk_size3 = None
                                                                                    self.mac_add_blk_size4 = None
                                                                                    self.manu_test_data = None
                                                                                    self.mfg_bits = None
                                                                                    self.mfg_deviation = None
                                                                                    self.oem_string = None
                                                                                    self.part_number = None
                                                                                    self.part_revision = None
                                                                                    self.pca_num = None
                                                                                    self.pcavid = None
                                                                                    self.pcb_serial_num = None
                                                                                    self.pid = None
                                                                                    self.power_consumption = None
                                                                                    self.power_supply_type = None
                                                                                    self.product_id = None
                                                                                    self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                    self.rma.parent = self
                                                                                    self.rma_code = None
                                                                                    self.serial_number = None
                                                                                    self.snmpoid = None
                                                                                    self.top_assem_part_num = None
                                                                                    self.top_assem_vid = None
                                                                                    self.udi_description = None
                                                                                    self.udi_name = None
                                                                                    self.vid = None


                                                                                class Rma(object):
                                                                                    """
                                                                                    RMA Data
                                                                                    
                                                                                    .. attribute:: rma_history
                                                                                    
                                                                                    	RMA history
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: rma_number
                                                                                    
                                                                                    	RMA tracking number format is N\-N\-N
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: test_history
                                                                                    
                                                                                    	Test history
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.rma_history = None
                                                                                        self.rma_number = None
                                                                                        self.test_history = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.rma_history is not None:
                                                                                            return True

                                                                                        if self.rma_number is not None:
                                                                                            return True

                                                                                        if self.test_history is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.asset_alias is not None:
                                                                                        return True

                                                                                    if self.asset_id is not None:
                                                                                        return True

                                                                                    if self.base_mac_address1 is not None:
                                                                                        return True

                                                                                    if self.base_mac_address2 is not None:
                                                                                        return True

                                                                                    if self.base_mac_address3 is not None:
                                                                                        return True

                                                                                    if self.base_mac_address4 is not None:
                                                                                        return True

                                                                                    if self.block_checksum is not None:
                                                                                        return True

                                                                                    if self.block_count is not None:
                                                                                        return True

                                                                                    if self.block_length is not None:
                                                                                        return True

                                                                                    if self.block_signature is not None:
                                                                                        return True

                                                                                    if self.block_version is not None:
                                                                                        return True

                                                                                    if self.chassis_sid is not None:
                                                                                        return True

                                                                                    if self.clei is not None:
                                                                                        return True

                                                                                    if self.controller_family is not None:
                                                                                        return True

                                                                                    if self.controller_type is not None:
                                                                                        return True

                                                                                    if self.description is not None:
                                                                                        return True

                                                                                    if self.dev_num1 is not None:
                                                                                        return True

                                                                                    if self.dev_num2 is not None:
                                                                                        return True

                                                                                    if self.dev_num3 is not None:
                                                                                        return True

                                                                                    if self.dev_num4 is not None:
                                                                                        return True

                                                                                    if self.dev_num5 is not None:
                                                                                        return True

                                                                                    if self.dev_num6 is not None:
                                                                                        return True

                                                                                    if self.dev_num7 is not None:
                                                                                        return True

                                                                                    if self.eci is not None:
                                                                                        return True

                                                                                    if self.eeprom_size is not None:
                                                                                        return True

                                                                                    if self.engineer_use is not None:
                                                                                        return True

                                                                                    if self.fru_major_type is not None:
                                                                                        return True

                                                                                    if self.fru_minor_type is not None:
                                                                                        return True

                                                                                    if self.hw_version is not None:
                                                                                        return True

                                                                                    if self.hwid is not None:
                                                                                        return True

                                                                                    if self.idprom_format_rev is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size1 is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size2 is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size3 is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size4 is not None:
                                                                                        return True

                                                                                    if self.manu_test_data is not None:
                                                                                        return True

                                                                                    if self.mfg_bits is not None:
                                                                                        return True

                                                                                    if self.mfg_deviation is not None:
                                                                                        return True

                                                                                    if self.oem_string is not None:
                                                                                        return True

                                                                                    if self.part_number is not None:
                                                                                        return True

                                                                                    if self.part_revision is not None:
                                                                                        return True

                                                                                    if self.pca_num is not None:
                                                                                        return True

                                                                                    if self.pcavid is not None:
                                                                                        return True

                                                                                    if self.pcb_serial_num is not None:
                                                                                        return True

                                                                                    if self.pid is not None:
                                                                                        return True

                                                                                    if self.power_consumption is not None:
                                                                                        return True

                                                                                    if self.power_supply_type is not None:
                                                                                        return True

                                                                                    if self.product_id is not None:
                                                                                        return True

                                                                                    if self.rma is not None and self.rma._has_data():
                                                                                        return True

                                                                                    if self.rma_code is not None:
                                                                                        return True

                                                                                    if self.serial_number is not None:
                                                                                        return True

                                                                                    if self.snmpoid is not None:
                                                                                        return True

                                                                                    if self.top_assem_part_num is not None:
                                                                                        return True

                                                                                    if self.top_assem_vid is not None:
                                                                                        return True

                                                                                    if self.udi_description is not None:
                                                                                        return True

                                                                                    if self.udi_name is not None:
                                                                                        return True

                                                                                    if self.vid is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.description is not None:
                                                                                    return True

                                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                                    return True

                                                                                if self.has_eeprom is not None:
                                                                                    return True

                                                                                if self.inv_card_type is not None:
                                                                                    return True

                                                                                if self.opaque_data is not None:
                                                                                    return True

                                                                                if self.opaque_data_size is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                return True

                                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                return True

                                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                                return True

                                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                return True

                                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                return True

                                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                return True

                                                                            if self.module_done is not None:
                                                                                return True

                                                                            if self.node_id is not None:
                                                                                return True

                                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                return True

                                                                            if self.threshold is not None and self.threshold._has_data():
                                                                                return True

                                                                            if self.vm_done is not None:
                                                                                return True

                                                                            if self.vm_node_id is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                                        if self.name is None:
                                                                            raise YPYModelError('Key property name is None')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi6[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.name is not None:
                                                                            return True

                                                                        if self.attributes is not None and self.attributes._has_data():
                                                                            return True

                                                                        if self.tsi7s is not None and self.tsi7s._has_data():
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi6s'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.tsi6 is not None:
                                                                        for child_ref in self.tsi6:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S']['meta_info']


                                                            class Attributes(object):
                                                                """
                                                                Attributes
                                                                
                                                                .. attribute:: env_sensor_info
                                                                
                                                                	Environment sensor info
                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfo>`
                                                                
                                                                .. attribute:: env_sensor_info_xml
                                                                
                                                                	Environment sensor info XML
                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml>`
                                                                
                                                                .. attribute:: fru_info
                                                                
                                                                	Inventory EDM FRU info
                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo>`
                                                                
                                                                .. attribute:: inv_asset_bag
                                                                
                                                                	Inventory Asset Bag
                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvAssetBag>`
                                                                
                                                                .. attribute:: inv_basic_bag
                                                                
                                                                	Inventory Basic Bag
                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvBasicBag>`
                                                                
                                                                .. attribute:: inv_eeprom_info
                                                                
                                                                	Inventory EDM EEPROM Information Bag
                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo>`
                                                                
                                                                .. attribute:: module_done
                                                                
                                                                	Inventory EDM Module Done Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**default value**\: 1
                                                                
                                                                .. attribute:: node_id
                                                                
                                                                	Node ID Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pwg_info
                                                                
                                                                	Inventory EDM PWG info
                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.PwgInfo>`
                                                                
                                                                .. attribute:: threshold
                                                                
                                                                	Threshold
                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold>`
                                                                
                                                                .. attribute:: vm_done
                                                                
                                                                	VM Done Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                .. attribute:: vm_node_id
                                                                
                                                                	VM Node ID Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfo()
                                                                    self.env_sensor_info.parent = self
                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml()
                                                                    self.env_sensor_info_xml.parent = self
                                                                    self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo()
                                                                    self.fru_info.parent = self
                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvAssetBag()
                                                                    self.inv_asset_bag.parent = self
                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvBasicBag()
                                                                    self.inv_basic_bag.parent = self
                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo()
                                                                    self.inv_eeprom_info.parent = self
                                                                    self.module_done = None
                                                                    self.node_id = None
                                                                    self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.PwgInfo()
                                                                    self.pwg_info.parent = self
                                                                    self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold()
                                                                    self.threshold.parent = self
                                                                    self.vm_done = None
                                                                    self.vm_node_id = None


                                                                class EnvSensorInfo(object):
                                                                    """
                                                                    Environment sensor info
                                                                    
                                                                    .. attribute:: age_time_stamp
                                                                    
                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: alarm_type
                                                                    
                                                                    	Indicates threshold violation
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: data_type
                                                                    
                                                                    	Sensor data type enums
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: device_description
                                                                    
                                                                    	Device Name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: device_id
                                                                    
                                                                    	Identifier for this device
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: field_validity_bitmap
                                                                    
                                                                    	Sensor valid bitmap
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: precision
                                                                    
                                                                    	Sensor precision range
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: scale
                                                                    
                                                                    	Sensor scale enums
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: status
                                                                    
                                                                    	Sensor operation state enums
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: units
                                                                    
                                                                    	Units of variable being read
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: update_rate
                                                                    
                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	Current reading of sensor
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.age_time_stamp = None
                                                                        self.alarm_type = None
                                                                        self.data_type = None
                                                                        self.device_description = None
                                                                        self.device_id = None
                                                                        self.field_validity_bitmap = None
                                                                        self.precision = None
                                                                        self.scale = None
                                                                        self.status = None
                                                                        self.units = None
                                                                        self.update_rate = None
                                                                        self.value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.age_time_stamp is not None:
                                                                            return True

                                                                        if self.alarm_type is not None:
                                                                            return True

                                                                        if self.data_type is not None:
                                                                            return True

                                                                        if self.device_description is not None:
                                                                            return True

                                                                        if self.device_id is not None:
                                                                            return True

                                                                        if self.field_validity_bitmap is not None:
                                                                            return True

                                                                        if self.precision is not None:
                                                                            return True

                                                                        if self.scale is not None:
                                                                            return True

                                                                        if self.status is not None:
                                                                            return True

                                                                        if self.units is not None:
                                                                            return True

                                                                        if self.update_rate is not None:
                                                                            return True

                                                                        if self.value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfo']['meta_info']


                                                                class PwgInfo(object):
                                                                    """
                                                                    Inventory EDM PWG info
                                                                    
                                                                    .. attribute:: power_group_available_current
                                                                    
                                                                    	available current
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_group_drawn_current
                                                                    
                                                                    	drawn current
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_group_power_units
                                                                    
                                                                    	power units
                                                                    	**type**\:  str
                                                                    
                                                                    .. attribute:: power_group_redundancy_mode
                                                                    
                                                                    	redundancy mode
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.power_group_available_current = None
                                                                        self.power_group_drawn_current = None
                                                                        self.power_group_power_units = None
                                                                        self.power_group_redundancy_mode = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.power_group_available_current is not None:
                                                                            return True

                                                                        if self.power_group_drawn_current is not None:
                                                                            return True

                                                                        if self.power_group_power_units is not None:
                                                                            return True

                                                                        if self.power_group_redundancy_mode is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.PwgInfo']['meta_info']


                                                                class EnvSensorInfoXml(object):
                                                                    """
                                                                    Environment sensor info XML
                                                                    
                                                                    .. attribute:: data_type
                                                                    
                                                                    	Sensor data type
                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                    
                                                                    .. attribute:: description
                                                                    
                                                                    	Device Name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: status
                                                                    
                                                                    	Sensor operation state
                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                    
                                                                    .. attribute:: threshold
                                                                    
                                                                    	Threshold information
                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold>`
                                                                    
                                                                    .. attribute:: units
                                                                    
                                                                    	Units of variable being read
                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                    
                                                                    .. attribute:: update_rate
                                                                    
                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.data_type = None
                                                                        self.description = None
                                                                        self.status = None
                                                                        self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold()
                                                                        self.threshold.parent = self
                                                                        self.units = None
                                                                        self.update_rate = None
                                                                        self.value = None


                                                                    class Threshold(object):
                                                                        """
                                                                        Threshold information
                                                                        
                                                                        .. attribute:: threshold_array
                                                                        
                                                                        	Array of threshold
                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.threshold_array = YList()
                                                                            self.threshold_array.parent = self
                                                                            self.threshold_array.name = 'threshold_array'


                                                                        class ThresholdArray(object):
                                                                            """
                                                                            Array of threshold
                                                                            
                                                                            .. attribute:: threshold_name
                                                                            
                                                                            	Threshold name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_name = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_name is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.threshold_array is not None:
                                                                                for child_ref in self.threshold_array:
                                                                                    if child_ref._has_data():
                                                                                        return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.data_type is not None:
                                                                            return True

                                                                        if self.description is not None:
                                                                            return True

                                                                        if self.status is not None:
                                                                            return True

                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                            return True

                                                                        if self.units is not None:
                                                                            return True

                                                                        if self.update_rate is not None:
                                                                            return True

                                                                        if self.value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml']['meta_info']


                                                                class InvAssetBag(object):
                                                                    """
                                                                    Inventory Asset Bag
                                                                    
                                                                    .. attribute:: manufacturer_assembly_number
                                                                    
                                                                    	Manufacture Assembly number
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_assembly_revision
                                                                    
                                                                    	Manufacture assembly revision
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                    
                                                                    	Common Language Equipment           Identifier number
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_software_identifier
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                    
                                                                    	String containing OEM information           if applicable
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: part_number
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.manufacturer_assembly_number = None
                                                                        self.manufacturer_assembly_revision = None
                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                        self.manufacturer_firmware_identifier = None
                                                                        self.manufacturer_software_identifier = None
                                                                        self.original_equipment_manufacturer_string = None
                                                                        self.part_number = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.manufacturer_assembly_number is not None:
                                                                            return True

                                                                        if self.manufacturer_assembly_revision is not None:
                                                                            return True

                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                            return True

                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                            return True

                                                                        if self.manufacturer_software_identifier is not None:
                                                                            return True

                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                            return True

                                                                        if self.part_number is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvAssetBag']['meta_info']


                                                                class Threshold(object):
                                                                    """
                                                                    Threshold
                                                                    
                                                                    .. attribute:: critical_hi
                                                                    
                                                                    	Critical High
                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi>`
                                                                    
                                                                    .. attribute:: critical_lo
                                                                    
                                                                    	Critical Low
                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo>`
                                                                    
                                                                    .. attribute:: major_hi
                                                                    
                                                                    	Major High
                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi>`
                                                                    
                                                                    .. attribute:: major_lo
                                                                    
                                                                    	Major Low
                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo>`
                                                                    
                                                                    .. attribute:: minor_hi
                                                                    
                                                                    	Minor High
                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi>`
                                                                    
                                                                    .. attribute:: minor_lo
                                                                    
                                                                    	Minor Low
                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi()
                                                                        self.critical_hi.parent = self
                                                                        self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo()
                                                                        self.critical_lo.parent = self
                                                                        self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi()
                                                                        self.major_hi.parent = self
                                                                        self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo()
                                                                        self.major_lo.parent = self
                                                                        self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi()
                                                                        self.minor_hi.parent = self
                                                                        self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo()
                                                                        self.minor_lo.parent = self


                                                                    class MajorLo(object):
                                                                        """
                                                                        Major Low
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo']['meta_info']


                                                                    class CriticalHi(object):
                                                                        """
                                                                        Critical High
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi']['meta_info']


                                                                    class MinorHi(object):
                                                                        """
                                                                        Minor High
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi']['meta_info']


                                                                    class MajorHi(object):
                                                                        """
                                                                        Major High
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi']['meta_info']


                                                                    class CriticalLo(object):
                                                                        """
                                                                        Critical Low
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo']['meta_info']


                                                                    class MinorLo(object):
                                                                        """
                                                                        Minor Low
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                            return True

                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                            return True

                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                            return True

                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                            return True

                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                            return True

                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold']['meta_info']


                                                                class FruInfo(object):
                                                                    """
                                                                    Inventory EDM FRU info
                                                                    
                                                                    .. attribute:: card_administrative_state
                                                                    
                                                                    	card admin state\: shutdown or not
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: card_monitor_state
                                                                    
                                                                    	card is monitored by a manager or left unmonitored
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: card_operational_state
                                                                    
                                                                    	card operation state
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: card_reset_reason
                                                                    
                                                                    	card reset reason enum
                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                    
                                                                    .. attribute:: card_up_time
                                                                    
                                                                    	card up time
                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.CardUpTime>`
                                                                    
                                                                    .. attribute:: last_operational_state_change
                                                                    
                                                                    	last card oper change state
                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.LastOperationalStateChange>`
                                                                    
                                                                    .. attribute:: power_administrative_state
                                                                    
                                                                    	power admin state\: up or down
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_current_measurement
                                                                    
                                                                    	power current\: not implemented
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_operational_state
                                                                    
                                                                    	Power operation state
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.card_administrative_state = None
                                                                        self.card_monitor_state = None
                                                                        self.card_operational_state = None
                                                                        self.card_reset_reason = None
                                                                        self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.CardUpTime()
                                                                        self.card_up_time.parent = self
                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.LastOperationalStateChange()
                                                                        self.last_operational_state_change.parent = self
                                                                        self.power_administrative_state = None
                                                                        self.power_current_measurement = None
                                                                        self.power_operational_state = None


                                                                    class LastOperationalStateChange(object):
                                                                        """
                                                                        last card oper change state
                                                                        
                                                                        .. attribute:: time_in_nano_seconds
                                                                        
                                                                        	Time Value in Nano\-seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: nanosecond
                                                                        
                                                                        .. attribute:: time_in_seconds
                                                                        
                                                                        	Time Value in Seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.time_in_nano_seconds = None
                                                                            self.time_in_seconds = None

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.time_in_nano_seconds is not None:
                                                                                return True

                                                                            if self.time_in_seconds is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                    class CardUpTime(object):
                                                                        """
                                                                        card up time
                                                                        
                                                                        .. attribute:: time_in_nano_seconds
                                                                        
                                                                        	Time Value in Nano\-seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: nanosecond
                                                                        
                                                                        .. attribute:: time_in_seconds
                                                                        
                                                                        	Time Value in Seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.time_in_nano_seconds = None
                                                                            self.time_in_seconds = None

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.time_in_nano_seconds is not None:
                                                                                return True

                                                                            if self.time_in_seconds is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.card_administrative_state is not None:
                                                                            return True

                                                                        if self.card_monitor_state is not None:
                                                                            return True

                                                                        if self.card_operational_state is not None:
                                                                            return True

                                                                        if self.card_reset_reason is not None:
                                                                            return True

                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                            return True

                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                            return True

                                                                        if self.power_administrative_state is not None:
                                                                            return True

                                                                        if self.power_current_measurement is not None:
                                                                            return True

                                                                        if self.power_operational_state is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo']['meta_info']


                                                                class InvBasicBag(object):
                                                                    """
                                                                    Inventory Basic Bag
                                                                    
                                                                    .. attribute:: alias
                                                                    
                                                                    	useful for storing an entity alias 
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: asset_id_str
                                                                    
                                                                    	asset Identification string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: asset_identification
                                                                    
                                                                    	asset Identification
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: ceport
                                                                    
                                                                    	1 if ce port found, 0 if not
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: chip_hardware_revision
                                                                    
                                                                    	chip module hw revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: composite_class_code
                                                                    
                                                                    	Major&minor class of the entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: description
                                                                    
                                                                    	describes in user\-readable terms       what the entity in question does
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: environmental_monitor_path
                                                                    
                                                                    	sysdb name of sensor in the envmon EDM
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: firmware_revision
                                                                    
                                                                    	firmware revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: group_flag
                                                                    
                                                                    	indicates if this entity is group       or not
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: hardware_revision
                                                                    
                                                                    	hw revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: is_field_replaceable_unit
                                                                    
                                                                    	1 if Field Replaceable Unit 0, if not
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: manufacturer_asset_tags
                                                                    
                                                                    	Manufacture Asset Tags
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: manufacturer_name
                                                                    
                                                                    	manufacturer's name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: memory_size
                                                                    
                                                                    	Size of memory associated with       the entity where applicable
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: model_name
                                                                    
                                                                    	model name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: name
                                                                    
                                                                    	name string for the entity
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: new_deviation_number
                                                                    
                                                                    	integer value for New Deviation Number 0x88
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: physical_layer_interface_module_type
                                                                    
                                                                    	integer value for plim type if     applicable to this entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: redundancystate
                                                                    
                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: serial_number
                                                                    
                                                                    	serial number
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: software_revision
                                                                    
                                                                    	software revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: unique_id
                                                                    
                                                                    	Unique id for an entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: unrecognized_fru
                                                                    
                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: vendor_type
                                                                    
                                                                    	maps to the vendor OID string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: xr_scoped
                                                                    
                                                                    	1 if xr scoped, 0 if not
                                                                    	**type**\:  bool
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.alias = None
                                                                        self.asset_id_str = None
                                                                        self.asset_identification = None
                                                                        self.ceport = None
                                                                        self.chip_hardware_revision = None
                                                                        self.composite_class_code = None
                                                                        self.description = None
                                                                        self.environmental_monitor_path = None
                                                                        self.firmware_revision = None
                                                                        self.group_flag = None
                                                                        self.hardware_revision = None
                                                                        self.is_field_replaceable_unit = None
                                                                        self.manufacturer_asset_tags = None
                                                                        self.manufacturer_name = None
                                                                        self.memory_size = None
                                                                        self.model_name = None
                                                                        self.name = None
                                                                        self.new_deviation_number = None
                                                                        self.physical_layer_interface_module_type = None
                                                                        self.redundancystate = None
                                                                        self.serial_number = None
                                                                        self.software_revision = None
                                                                        self.unique_id = None
                                                                        self.unrecognized_fru = None
                                                                        self.vendor_type = None
                                                                        self.xr_scoped = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.alias is not None:
                                                                            return True

                                                                        if self.asset_id_str is not None:
                                                                            return True

                                                                        if self.asset_identification is not None:
                                                                            return True

                                                                        if self.ceport is not None:
                                                                            return True

                                                                        if self.chip_hardware_revision is not None:
                                                                            return True

                                                                        if self.composite_class_code is not None:
                                                                            return True

                                                                        if self.description is not None:
                                                                            return True

                                                                        if self.environmental_monitor_path is not None:
                                                                            return True

                                                                        if self.firmware_revision is not None:
                                                                            return True

                                                                        if self.group_flag is not None:
                                                                            return True

                                                                        if self.hardware_revision is not None:
                                                                            return True

                                                                        if self.is_field_replaceable_unit is not None:
                                                                            return True

                                                                        if self.manufacturer_asset_tags is not None:
                                                                            return True

                                                                        if self.manufacturer_name is not None:
                                                                            return True

                                                                        if self.memory_size is not None:
                                                                            return True

                                                                        if self.model_name is not None:
                                                                            return True

                                                                        if self.name is not None:
                                                                            return True

                                                                        if self.new_deviation_number is not None:
                                                                            return True

                                                                        if self.physical_layer_interface_module_type is not None:
                                                                            return True

                                                                        if self.redundancystate is not None:
                                                                            return True

                                                                        if self.serial_number is not None:
                                                                            return True

                                                                        if self.software_revision is not None:
                                                                            return True

                                                                        if self.unique_id is not None:
                                                                            return True

                                                                        if self.unrecognized_fru is not None:
                                                                            return True

                                                                        if self.vendor_type is not None:
                                                                            return True

                                                                        if self.xr_scoped is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvBasicBag']['meta_info']


                                                                class InvEepromInfo(object):
                                                                    """
                                                                    Inventory EDM EEPROM Information Bag
                                                                    
                                                                    .. attribute:: description
                                                                    
                                                                    	A textual description of physical entity
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: eeprom
                                                                    
                                                                    	EEPROM data not from hex data
                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom>`
                                                                    
                                                                    .. attribute:: has_eeprom
                                                                    
                                                                    	use eeprom instead of opaque data
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: inv_card_type
                                                                    
                                                                    	Inventory card type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: opaque_data
                                                                    
                                                                    	EEPROM hex data
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: opaque_data_size
                                                                    
                                                                    	size of the EEPROM hex data
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.description = None
                                                                        self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom()
                                                                        self.eeprom.parent = self
                                                                        self.has_eeprom = None
                                                                        self.inv_card_type = None
                                                                        self.opaque_data = None
                                                                        self.opaque_data_size = None


                                                                    class Eeprom(object):
                                                                        """
                                                                        EEPROM data not from hex data
                                                                        
                                                                        .. attribute:: asset_alias
                                                                        
                                                                        	Asset Alias
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: asset_id
                                                                        
                                                                        	Asset ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address1
                                                                        
                                                                        	Base Mac Address #1
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address2
                                                                        
                                                                        	Base Mac Address #2
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address3
                                                                        
                                                                        	Base Mac Address #3
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address4
                                                                        
                                                                        	Base Mac Address #4
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_checksum
                                                                        
                                                                        	Block Checksum
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_count
                                                                        
                                                                        	Block Count
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_length
                                                                        
                                                                        	Block Length
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_signature
                                                                        
                                                                        	Block Signature
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_version
                                                                        
                                                                        	Block Version
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: chassis_sid
                                                                        
                                                                        	Chassis serial number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: clei
                                                                        
                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: controller_family
                                                                        
                                                                        	Controller family
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: controller_type
                                                                        
                                                                        	Controller type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: description
                                                                        
                                                                        	A textual description of physical entity
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num1
                                                                        
                                                                        	Deviation Number # 1
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num2
                                                                        
                                                                        	Deviation Number # 2
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num3
                                                                        
                                                                        	Deviation Number # 3
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num4
                                                                        
                                                                        	Deviation Number # 4
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num5
                                                                        
                                                                        	Deviation Number # 5
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num6
                                                                        
                                                                        	Deviation Number # 6
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num7
                                                                        
                                                                        	Deviation Number # 7
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: eci
                                                                        
                                                                        	Equipment Catalog Item (ECI) number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: eeprom_size
                                                                        
                                                                        	EEPROM Size
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: engineer_use
                                                                        
                                                                        	Engineer Use
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: fru_major_type
                                                                        
                                                                        	FRU Major Type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: fru_minor_type
                                                                        
                                                                        	FRU Minor Type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: hw_version
                                                                        
                                                                        	Hardware Version
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: hwid
                                                                        
                                                                        	Hardware Revision
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: idprom_format_rev
                                                                        
                                                                        	IDPROM Format Revision
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size1
                                                                        
                                                                        	Mac Address Block Size #1
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size2
                                                                        
                                                                        	Mac Address Block Size #2
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size3
                                                                        
                                                                        	Mac Address Block Size #3
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size4
                                                                        
                                                                        	Mac Address Block Size #4
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: manu_test_data
                                                                        
                                                                        	Manufacturing Test Data
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mfg_bits
                                                                        
                                                                        	MFG Bits
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mfg_deviation
                                                                        
                                                                        	MFG Deviation
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: oem_string
                                                                        
                                                                        	OEM String
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: part_number
                                                                        
                                                                        	Part Number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: part_revision
                                                                        
                                                                        	Part Revision
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pca_num
                                                                        
                                                                        	PCA number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pcavid
                                                                        
                                                                        	PCA revision ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pcb_serial_num
                                                                        
                                                                        	PCB Serial Number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pid
                                                                        
                                                                        	Product ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: power_consumption
                                                                        
                                                                        	Power Consumption
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: power_supply_type
                                                                        
                                                                        	Power Supply Type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: product_id
                                                                        
                                                                        	Product ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: rma
                                                                        
                                                                        	RMA Data
                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                        
                                                                        .. attribute:: rma_code
                                                                        
                                                                        	RMA Code
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: serial_number
                                                                        
                                                                        	Serial Number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: snmpoid
                                                                        
                                                                        	SNMP OID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: top_assem_part_num
                                                                        
                                                                        	Top assembly part number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: top_assem_vid
                                                                        
                                                                        	Top assembly revision number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: udi_description
                                                                        
                                                                        	UDI description
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: udi_name
                                                                        
                                                                        	UDI name
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: vid
                                                                        
                                                                        	Version ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.asset_alias = None
                                                                            self.asset_id = None
                                                                            self.base_mac_address1 = None
                                                                            self.base_mac_address2 = None
                                                                            self.base_mac_address3 = None
                                                                            self.base_mac_address4 = None
                                                                            self.block_checksum = None
                                                                            self.block_count = None
                                                                            self.block_length = None
                                                                            self.block_signature = None
                                                                            self.block_version = None
                                                                            self.chassis_sid = None
                                                                            self.clei = None
                                                                            self.controller_family = None
                                                                            self.controller_type = None
                                                                            self.description = None
                                                                            self.dev_num1 = None
                                                                            self.dev_num2 = None
                                                                            self.dev_num3 = None
                                                                            self.dev_num4 = None
                                                                            self.dev_num5 = None
                                                                            self.dev_num6 = None
                                                                            self.dev_num7 = None
                                                                            self.eci = None
                                                                            self.eeprom_size = None
                                                                            self.engineer_use = None
                                                                            self.fru_major_type = None
                                                                            self.fru_minor_type = None
                                                                            self.hw_version = None
                                                                            self.hwid = None
                                                                            self.idprom_format_rev = None
                                                                            self.mac_add_blk_size1 = None
                                                                            self.mac_add_blk_size2 = None
                                                                            self.mac_add_blk_size3 = None
                                                                            self.mac_add_blk_size4 = None
                                                                            self.manu_test_data = None
                                                                            self.mfg_bits = None
                                                                            self.mfg_deviation = None
                                                                            self.oem_string = None
                                                                            self.part_number = None
                                                                            self.part_revision = None
                                                                            self.pca_num = None
                                                                            self.pcavid = None
                                                                            self.pcb_serial_num = None
                                                                            self.pid = None
                                                                            self.power_consumption = None
                                                                            self.power_supply_type = None
                                                                            self.product_id = None
                                                                            self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                            self.rma.parent = self
                                                                            self.rma_code = None
                                                                            self.serial_number = None
                                                                            self.snmpoid = None
                                                                            self.top_assem_part_num = None
                                                                            self.top_assem_vid = None
                                                                            self.udi_description = None
                                                                            self.udi_name = None
                                                                            self.vid = None


                                                                        class Rma(object):
                                                                            """
                                                                            RMA Data
                                                                            
                                                                            .. attribute:: rma_history
                                                                            
                                                                            	RMA history
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: rma_number
                                                                            
                                                                            	RMA tracking number format is N\-N\-N
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: test_history
                                                                            
                                                                            	Test history
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.rma_history = None
                                                                                self.rma_number = None
                                                                                self.test_history = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.rma_history is not None:
                                                                                    return True

                                                                                if self.rma_number is not None:
                                                                                    return True

                                                                                if self.test_history is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.asset_alias is not None:
                                                                                return True

                                                                            if self.asset_id is not None:
                                                                                return True

                                                                            if self.base_mac_address1 is not None:
                                                                                return True

                                                                            if self.base_mac_address2 is not None:
                                                                                return True

                                                                            if self.base_mac_address3 is not None:
                                                                                return True

                                                                            if self.base_mac_address4 is not None:
                                                                                return True

                                                                            if self.block_checksum is not None:
                                                                                return True

                                                                            if self.block_count is not None:
                                                                                return True

                                                                            if self.block_length is not None:
                                                                                return True

                                                                            if self.block_signature is not None:
                                                                                return True

                                                                            if self.block_version is not None:
                                                                                return True

                                                                            if self.chassis_sid is not None:
                                                                                return True

                                                                            if self.clei is not None:
                                                                                return True

                                                                            if self.controller_family is not None:
                                                                                return True

                                                                            if self.controller_type is not None:
                                                                                return True

                                                                            if self.description is not None:
                                                                                return True

                                                                            if self.dev_num1 is not None:
                                                                                return True

                                                                            if self.dev_num2 is not None:
                                                                                return True

                                                                            if self.dev_num3 is not None:
                                                                                return True

                                                                            if self.dev_num4 is not None:
                                                                                return True

                                                                            if self.dev_num5 is not None:
                                                                                return True

                                                                            if self.dev_num6 is not None:
                                                                                return True

                                                                            if self.dev_num7 is not None:
                                                                                return True

                                                                            if self.eci is not None:
                                                                                return True

                                                                            if self.eeprom_size is not None:
                                                                                return True

                                                                            if self.engineer_use is not None:
                                                                                return True

                                                                            if self.fru_major_type is not None:
                                                                                return True

                                                                            if self.fru_minor_type is not None:
                                                                                return True

                                                                            if self.hw_version is not None:
                                                                                return True

                                                                            if self.hwid is not None:
                                                                                return True

                                                                            if self.idprom_format_rev is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size1 is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size2 is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size3 is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size4 is not None:
                                                                                return True

                                                                            if self.manu_test_data is not None:
                                                                                return True

                                                                            if self.mfg_bits is not None:
                                                                                return True

                                                                            if self.mfg_deviation is not None:
                                                                                return True

                                                                            if self.oem_string is not None:
                                                                                return True

                                                                            if self.part_number is not None:
                                                                                return True

                                                                            if self.part_revision is not None:
                                                                                return True

                                                                            if self.pca_num is not None:
                                                                                return True

                                                                            if self.pcavid is not None:
                                                                                return True

                                                                            if self.pcb_serial_num is not None:
                                                                                return True

                                                                            if self.pid is not None:
                                                                                return True

                                                                            if self.power_consumption is not None:
                                                                                return True

                                                                            if self.power_supply_type is not None:
                                                                                return True

                                                                            if self.product_id is not None:
                                                                                return True

                                                                            if self.rma is not None and self.rma._has_data():
                                                                                return True

                                                                            if self.rma_code is not None:
                                                                                return True

                                                                            if self.serial_number is not None:
                                                                                return True

                                                                            if self.snmpoid is not None:
                                                                                return True

                                                                            if self.top_assem_part_num is not None:
                                                                                return True

                                                                            if self.top_assem_vid is not None:
                                                                                return True

                                                                            if self.udi_description is not None:
                                                                                return True

                                                                            if self.udi_name is not None:
                                                                                return True

                                                                            if self.vid is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.description is not None:
                                                                            return True

                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                            return True

                                                                        if self.has_eeprom is not None:
                                                                            return True

                                                                        if self.inv_card_type is not None:
                                                                            return True

                                                                        if self.opaque_data is not None:
                                                                            return True

                                                                        if self.opaque_data_size is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                        return True

                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                        return True

                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                        return True

                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                        return True

                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                        return True

                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                        return True

                                                                    if self.module_done is not None:
                                                                        return True

                                                                    if self.node_id is not None:
                                                                        return True

                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                        return True

                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                        return True

                                                                    if self.vm_done is not None:
                                                                        return True

                                                                    if self.vm_node_id is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                if self.name is None:
                                                                    raise YPYModelError('Key property name is None')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi5[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.name is not None:
                                                                    return True

                                                                if self.attributes is not None and self.attributes._has_data():
                                                                    return True

                                                                if self.tsi6s is not None and self.tsi6s._has_data():
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi5s'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.tsi5 is not None:
                                                                for child_ref in self.tsi5:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S']['meta_info']


                                                    class Attributes(object):
                                                        """
                                                        Attributes
                                                        
                                                        .. attribute:: env_sensor_info
                                                        
                                                        	Environment sensor info
                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfo>`
                                                        
                                                        .. attribute:: env_sensor_info_xml
                                                        
                                                        	Environment sensor info XML
                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml>`
                                                        
                                                        .. attribute:: fru_info
                                                        
                                                        	Inventory EDM FRU info
                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo>`
                                                        
                                                        .. attribute:: inv_asset_bag
                                                        
                                                        	Inventory Asset Bag
                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvAssetBag>`
                                                        
                                                        .. attribute:: inv_basic_bag
                                                        
                                                        	Inventory Basic Bag
                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvBasicBag>`
                                                        
                                                        .. attribute:: inv_eeprom_info
                                                        
                                                        	Inventory EDM EEPROM Information Bag
                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo>`
                                                        
                                                        .. attribute:: module_done
                                                        
                                                        	Inventory EDM Module Done Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: node_id
                                                        
                                                        	Node ID Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pwg_info
                                                        
                                                        	Inventory EDM PWG info
                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.PwgInfo>`
                                                        
                                                        .. attribute:: threshold
                                                        
                                                        	Threshold
                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold>`
                                                        
                                                        .. attribute:: vm_done
                                                        
                                                        	VM Done Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        .. attribute:: vm_node_id
                                                        
                                                        	VM Node ID Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfo()
                                                            self.env_sensor_info.parent = self
                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml()
                                                            self.env_sensor_info_xml.parent = self
                                                            self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo()
                                                            self.fru_info.parent = self
                                                            self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvAssetBag()
                                                            self.inv_asset_bag.parent = self
                                                            self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvBasicBag()
                                                            self.inv_basic_bag.parent = self
                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo()
                                                            self.inv_eeprom_info.parent = self
                                                            self.module_done = None
                                                            self.node_id = None
                                                            self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.PwgInfo()
                                                            self.pwg_info.parent = self
                                                            self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold()
                                                            self.threshold.parent = self
                                                            self.vm_done = None
                                                            self.vm_node_id = None


                                                        class EnvSensorInfo(object):
                                                            """
                                                            Environment sensor info
                                                            
                                                            .. attribute:: age_time_stamp
                                                            
                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: alarm_type
                                                            
                                                            	Indicates threshold violation
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: data_type
                                                            
                                                            	Sensor data type enums
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: device_description
                                                            
                                                            	Device Name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: device_id
                                                            
                                                            	Identifier for this device
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: field_validity_bitmap
                                                            
                                                            	Sensor valid bitmap
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: precision
                                                            
                                                            	Sensor precision range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: scale
                                                            
                                                            	Sensor scale enums
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: status
                                                            
                                                            	Sensor operation state enums
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: units
                                                            
                                                            	Units of variable being read
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: update_rate
                                                            
                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: value
                                                            
                                                            	Current reading of sensor
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.age_time_stamp = None
                                                                self.alarm_type = None
                                                                self.data_type = None
                                                                self.device_description = None
                                                                self.device_id = None
                                                                self.field_validity_bitmap = None
                                                                self.precision = None
                                                                self.scale = None
                                                                self.status = None
                                                                self.units = None
                                                                self.update_rate = None
                                                                self.value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.age_time_stamp is not None:
                                                                    return True

                                                                if self.alarm_type is not None:
                                                                    return True

                                                                if self.data_type is not None:
                                                                    return True

                                                                if self.device_description is not None:
                                                                    return True

                                                                if self.device_id is not None:
                                                                    return True

                                                                if self.field_validity_bitmap is not None:
                                                                    return True

                                                                if self.precision is not None:
                                                                    return True

                                                                if self.scale is not None:
                                                                    return True

                                                                if self.status is not None:
                                                                    return True

                                                                if self.units is not None:
                                                                    return True

                                                                if self.update_rate is not None:
                                                                    return True

                                                                if self.value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfo']['meta_info']


                                                        class PwgInfo(object):
                                                            """
                                                            Inventory EDM PWG info
                                                            
                                                            .. attribute:: power_group_available_current
                                                            
                                                            	available current
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_group_drawn_current
                                                            
                                                            	drawn current
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_group_power_units
                                                            
                                                            	power units
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: power_group_redundancy_mode
                                                            
                                                            	redundancy mode
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.power_group_available_current = None
                                                                self.power_group_drawn_current = None
                                                                self.power_group_power_units = None
                                                                self.power_group_redundancy_mode = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.power_group_available_current is not None:
                                                                    return True

                                                                if self.power_group_drawn_current is not None:
                                                                    return True

                                                                if self.power_group_power_units is not None:
                                                                    return True

                                                                if self.power_group_redundancy_mode is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.PwgInfo']['meta_info']


                                                        class EnvSensorInfoXml(object):
                                                            """
                                                            Environment sensor info XML
                                                            
                                                            .. attribute:: data_type
                                                            
                                                            	Sensor data type
                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                            
                                                            .. attribute:: description
                                                            
                                                            	Device Name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: status
                                                            
                                                            	Sensor operation state
                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                            
                                                            .. attribute:: threshold
                                                            
                                                            	Threshold information
                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold>`
                                                            
                                                            .. attribute:: units
                                                            
                                                            	Units of variable being read
                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                            
                                                            .. attribute:: update_rate
                                                            
                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: value
                                                            
                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.data_type = None
                                                                self.description = None
                                                                self.status = None
                                                                self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold()
                                                                self.threshold.parent = self
                                                                self.units = None
                                                                self.update_rate = None
                                                                self.value = None


                                                            class Threshold(object):
                                                                """
                                                                Threshold information
                                                                
                                                                .. attribute:: threshold_array
                                                                
                                                                	Array of threshold
                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.threshold_array = YList()
                                                                    self.threshold_array.parent = self
                                                                    self.threshold_array.name = 'threshold_array'


                                                                class ThresholdArray(object):
                                                                    """
                                                                    Array of threshold
                                                                    
                                                                    .. attribute:: threshold_name
                                                                    
                                                                    	Threshold name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_name = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_name is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.threshold_array is not None:
                                                                        for child_ref in self.threshold_array:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.data_type is not None:
                                                                    return True

                                                                if self.description is not None:
                                                                    return True

                                                                if self.status is not None:
                                                                    return True

                                                                if self.threshold is not None and self.threshold._has_data():
                                                                    return True

                                                                if self.units is not None:
                                                                    return True

                                                                if self.update_rate is not None:
                                                                    return True

                                                                if self.value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml']['meta_info']


                                                        class InvAssetBag(object):
                                                            """
                                                            Inventory Asset Bag
                                                            
                                                            .. attribute:: manufacturer_assembly_number
                                                            
                                                            	Manufacture Assembly number
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_assembly_revision
                                                            
                                                            	Manufacture assembly revision
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                            
                                                            	Common Language Equipment           Identifier number
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_firmware_identifier
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_software_identifier
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: original_equipment_manufacturer_string
                                                            
                                                            	String containing OEM information           if applicable
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: part_number
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.manufacturer_assembly_number = None
                                                                self.manufacturer_assembly_revision = None
                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                self.manufacturer_firmware_identifier = None
                                                                self.manufacturer_software_identifier = None
                                                                self.original_equipment_manufacturer_string = None
                                                                self.part_number = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.manufacturer_assembly_number is not None:
                                                                    return True

                                                                if self.manufacturer_assembly_revision is not None:
                                                                    return True

                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                    return True

                                                                if self.manufacturer_firmware_identifier is not None:
                                                                    return True

                                                                if self.manufacturer_software_identifier is not None:
                                                                    return True

                                                                if self.original_equipment_manufacturer_string is not None:
                                                                    return True

                                                                if self.part_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvAssetBag']['meta_info']


                                                        class Threshold(object):
                                                            """
                                                            Threshold
                                                            
                                                            .. attribute:: critical_hi
                                                            
                                                            	Critical High
                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi>`
                                                            
                                                            .. attribute:: critical_lo
                                                            
                                                            	Critical Low
                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo>`
                                                            
                                                            .. attribute:: major_hi
                                                            
                                                            	Major High
                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi>`
                                                            
                                                            .. attribute:: major_lo
                                                            
                                                            	Major Low
                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo>`
                                                            
                                                            .. attribute:: minor_hi
                                                            
                                                            	Minor High
                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi>`
                                                            
                                                            .. attribute:: minor_lo
                                                            
                                                            	Minor Low
                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi()
                                                                self.critical_hi.parent = self
                                                                self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo()
                                                                self.critical_lo.parent = self
                                                                self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi()
                                                                self.major_hi.parent = self
                                                                self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo()
                                                                self.major_lo.parent = self
                                                                self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi()
                                                                self.minor_hi.parent = self
                                                                self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo()
                                                                self.minor_lo.parent = self


                                                            class MajorLo(object):
                                                                """
                                                                Major Low
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo']['meta_info']


                                                            class CriticalHi(object):
                                                                """
                                                                Critical High
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi']['meta_info']


                                                            class MinorHi(object):
                                                                """
                                                                Minor High
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi']['meta_info']


                                                            class MajorHi(object):
                                                                """
                                                                Major High
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi']['meta_info']


                                                            class CriticalLo(object):
                                                                """
                                                                Critical Low
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo']['meta_info']


                                                            class MinorLo(object):
                                                                """
                                                                Minor Low
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                    return True

                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                    return True

                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                    return True

                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                    return True

                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                    return True

                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold']['meta_info']


                                                        class FruInfo(object):
                                                            """
                                                            Inventory EDM FRU info
                                                            
                                                            .. attribute:: card_administrative_state
                                                            
                                                            	card admin state\: shutdown or not
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: card_monitor_state
                                                            
                                                            	card is monitored by a manager or left unmonitored
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: card_operational_state
                                                            
                                                            	card operation state
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: card_reset_reason
                                                            
                                                            	card reset reason enum
                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                            
                                                            .. attribute:: card_up_time
                                                            
                                                            	card up time
                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.CardUpTime>`
                                                            
                                                            .. attribute:: last_operational_state_change
                                                            
                                                            	last card oper change state
                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.LastOperationalStateChange>`
                                                            
                                                            .. attribute:: power_administrative_state
                                                            
                                                            	power admin state\: up or down
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_current_measurement
                                                            
                                                            	power current\: not implemented
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_operational_state
                                                            
                                                            	Power operation state
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.card_administrative_state = None
                                                                self.card_monitor_state = None
                                                                self.card_operational_state = None
                                                                self.card_reset_reason = None
                                                                self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.CardUpTime()
                                                                self.card_up_time.parent = self
                                                                self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.LastOperationalStateChange()
                                                                self.last_operational_state_change.parent = self
                                                                self.power_administrative_state = None
                                                                self.power_current_measurement = None
                                                                self.power_operational_state = None


                                                            class LastOperationalStateChange(object):
                                                                """
                                                                last card oper change state
                                                                
                                                                .. attribute:: time_in_nano_seconds
                                                                
                                                                	Time Value in Nano\-seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: nanosecond
                                                                
                                                                .. attribute:: time_in_seconds
                                                                
                                                                	Time Value in Seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: second
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.time_in_nano_seconds = None
                                                                    self.time_in_seconds = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.time_in_nano_seconds is not None:
                                                                        return True

                                                                    if self.time_in_seconds is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                            class CardUpTime(object):
                                                                """
                                                                card up time
                                                                
                                                                .. attribute:: time_in_nano_seconds
                                                                
                                                                	Time Value in Nano\-seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: nanosecond
                                                                
                                                                .. attribute:: time_in_seconds
                                                                
                                                                	Time Value in Seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: second
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.time_in_nano_seconds = None
                                                                    self.time_in_seconds = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.time_in_nano_seconds is not None:
                                                                        return True

                                                                    if self.time_in_seconds is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.CardUpTime']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.card_administrative_state is not None:
                                                                    return True

                                                                if self.card_monitor_state is not None:
                                                                    return True

                                                                if self.card_operational_state is not None:
                                                                    return True

                                                                if self.card_reset_reason is not None:
                                                                    return True

                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                    return True

                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                    return True

                                                                if self.power_administrative_state is not None:
                                                                    return True

                                                                if self.power_current_measurement is not None:
                                                                    return True

                                                                if self.power_operational_state is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo']['meta_info']


                                                        class InvBasicBag(object):
                                                            """
                                                            Inventory Basic Bag
                                                            
                                                            .. attribute:: alias
                                                            
                                                            	useful for storing an entity alias 
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: asset_id_str
                                                            
                                                            	asset Identification string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: asset_identification
                                                            
                                                            	asset Identification
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: ceport
                                                            
                                                            	1 if ce port found, 0 if not
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: chip_hardware_revision
                                                            
                                                            	chip module hw revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: composite_class_code
                                                            
                                                            	Major&minor class of the entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: description
                                                            
                                                            	describes in user\-readable terms       what the entity in question does
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: environmental_monitor_path
                                                            
                                                            	sysdb name of sensor in the envmon EDM
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: firmware_revision
                                                            
                                                            	firmware revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: group_flag
                                                            
                                                            	indicates if this entity is group       or not
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: hardware_revision
                                                            
                                                            	hw revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: is_field_replaceable_unit
                                                            
                                                            	1 if Field Replaceable Unit 0, if not
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: manufacturer_asset_tags
                                                            
                                                            	Manufacture Asset Tags
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: manufacturer_name
                                                            
                                                            	manufacturer's name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: memory_size
                                                            
                                                            	Size of memory associated with       the entity where applicable
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: model_name
                                                            
                                                            	model name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: name
                                                            
                                                            	name string for the entity
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: new_deviation_number
                                                            
                                                            	integer value for New Deviation Number 0x88
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: physical_layer_interface_module_type
                                                            
                                                            	integer value for plim type if     applicable to this entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: redundancystate
                                                            
                                                            	integer value for Redundancy State if     applicable to this entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: serial_number
                                                            
                                                            	serial number
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: software_revision
                                                            
                                                            	software revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: unique_id
                                                            
                                                            	Unique id for an entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: unrecognized_fru
                                                            
                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: vendor_type
                                                            
                                                            	maps to the vendor OID string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: xr_scoped
                                                            
                                                            	1 if xr scoped, 0 if not
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.alias = None
                                                                self.asset_id_str = None
                                                                self.asset_identification = None
                                                                self.ceport = None
                                                                self.chip_hardware_revision = None
                                                                self.composite_class_code = None
                                                                self.description = None
                                                                self.environmental_monitor_path = None
                                                                self.firmware_revision = None
                                                                self.group_flag = None
                                                                self.hardware_revision = None
                                                                self.is_field_replaceable_unit = None
                                                                self.manufacturer_asset_tags = None
                                                                self.manufacturer_name = None
                                                                self.memory_size = None
                                                                self.model_name = None
                                                                self.name = None
                                                                self.new_deviation_number = None
                                                                self.physical_layer_interface_module_type = None
                                                                self.redundancystate = None
                                                                self.serial_number = None
                                                                self.software_revision = None
                                                                self.unique_id = None
                                                                self.unrecognized_fru = None
                                                                self.vendor_type = None
                                                                self.xr_scoped = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.alias is not None:
                                                                    return True

                                                                if self.asset_id_str is not None:
                                                                    return True

                                                                if self.asset_identification is not None:
                                                                    return True

                                                                if self.ceport is not None:
                                                                    return True

                                                                if self.chip_hardware_revision is not None:
                                                                    return True

                                                                if self.composite_class_code is not None:
                                                                    return True

                                                                if self.description is not None:
                                                                    return True

                                                                if self.environmental_monitor_path is not None:
                                                                    return True

                                                                if self.firmware_revision is not None:
                                                                    return True

                                                                if self.group_flag is not None:
                                                                    return True

                                                                if self.hardware_revision is not None:
                                                                    return True

                                                                if self.is_field_replaceable_unit is not None:
                                                                    return True

                                                                if self.manufacturer_asset_tags is not None:
                                                                    return True

                                                                if self.manufacturer_name is not None:
                                                                    return True

                                                                if self.memory_size is not None:
                                                                    return True

                                                                if self.model_name is not None:
                                                                    return True

                                                                if self.name is not None:
                                                                    return True

                                                                if self.new_deviation_number is not None:
                                                                    return True

                                                                if self.physical_layer_interface_module_type is not None:
                                                                    return True

                                                                if self.redundancystate is not None:
                                                                    return True

                                                                if self.serial_number is not None:
                                                                    return True

                                                                if self.software_revision is not None:
                                                                    return True

                                                                if self.unique_id is not None:
                                                                    return True

                                                                if self.unrecognized_fru is not None:
                                                                    return True

                                                                if self.vendor_type is not None:
                                                                    return True

                                                                if self.xr_scoped is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvBasicBag']['meta_info']


                                                        class InvEepromInfo(object):
                                                            """
                                                            Inventory EDM EEPROM Information Bag
                                                            
                                                            .. attribute:: description
                                                            
                                                            	A textual description of physical entity
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: eeprom
                                                            
                                                            	EEPROM data not from hex data
                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom>`
                                                            
                                                            .. attribute:: has_eeprom
                                                            
                                                            	use eeprom instead of opaque data
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: inv_card_type
                                                            
                                                            	Inventory card type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: opaque_data
                                                            
                                                            	EEPROM hex data
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: opaque_data_size
                                                            
                                                            	size of the EEPROM hex data
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.description = None
                                                                self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom()
                                                                self.eeprom.parent = self
                                                                self.has_eeprom = None
                                                                self.inv_card_type = None
                                                                self.opaque_data = None
                                                                self.opaque_data_size = None


                                                            class Eeprom(object):
                                                                """
                                                                EEPROM data not from hex data
                                                                
                                                                .. attribute:: asset_alias
                                                                
                                                                	Asset Alias
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: asset_id
                                                                
                                                                	Asset ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address1
                                                                
                                                                	Base Mac Address #1
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address2
                                                                
                                                                	Base Mac Address #2
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address3
                                                                
                                                                	Base Mac Address #3
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address4
                                                                
                                                                	Base Mac Address #4
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_checksum
                                                                
                                                                	Block Checksum
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_count
                                                                
                                                                	Block Count
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_length
                                                                
                                                                	Block Length
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_signature
                                                                
                                                                	Block Signature
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_version
                                                                
                                                                	Block Version
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: chassis_sid
                                                                
                                                                	Chassis serial number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: clei
                                                                
                                                                	Common Language Equipment Identifier (CLEI) code
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: controller_family
                                                                
                                                                	Controller family
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: controller_type
                                                                
                                                                	Controller type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: description
                                                                
                                                                	A textual description of physical entity
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num1
                                                                
                                                                	Deviation Number # 1
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num2
                                                                
                                                                	Deviation Number # 2
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num3
                                                                
                                                                	Deviation Number # 3
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num4
                                                                
                                                                	Deviation Number # 4
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num5
                                                                
                                                                	Deviation Number # 5
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num6
                                                                
                                                                	Deviation Number # 6
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num7
                                                                
                                                                	Deviation Number # 7
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: eci
                                                                
                                                                	Equipment Catalog Item (ECI) number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: eeprom_size
                                                                
                                                                	EEPROM Size
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: engineer_use
                                                                
                                                                	Engineer Use
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: fru_major_type
                                                                
                                                                	FRU Major Type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: fru_minor_type
                                                                
                                                                	FRU Minor Type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: hw_version
                                                                
                                                                	Hardware Version
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: hwid
                                                                
                                                                	Hardware Revision
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: idprom_format_rev
                                                                
                                                                	IDPROM Format Revision
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size1
                                                                
                                                                	Mac Address Block Size #1
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size2
                                                                
                                                                	Mac Address Block Size #2
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size3
                                                                
                                                                	Mac Address Block Size #3
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size4
                                                                
                                                                	Mac Address Block Size #4
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: manu_test_data
                                                                
                                                                	Manufacturing Test Data
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mfg_bits
                                                                
                                                                	MFG Bits
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mfg_deviation
                                                                
                                                                	MFG Deviation
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: oem_string
                                                                
                                                                	OEM String
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: part_number
                                                                
                                                                	Part Number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: part_revision
                                                                
                                                                	Part Revision
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pca_num
                                                                
                                                                	PCA number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pcavid
                                                                
                                                                	PCA revision ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pcb_serial_num
                                                                
                                                                	PCB Serial Number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pid
                                                                
                                                                	Product ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: power_consumption
                                                                
                                                                	Power Consumption
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: power_supply_type
                                                                
                                                                	Power Supply Type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: product_id
                                                                
                                                                	Product ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: rma
                                                                
                                                                	RMA Data
                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                
                                                                .. attribute:: rma_code
                                                                
                                                                	RMA Code
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: serial_number
                                                                
                                                                	Serial Number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: snmpoid
                                                                
                                                                	SNMP OID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: top_assem_part_num
                                                                
                                                                	Top assembly part number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: top_assem_vid
                                                                
                                                                	Top assembly revision number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: udi_description
                                                                
                                                                	UDI description
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: udi_name
                                                                
                                                                	UDI name
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: vid
                                                                
                                                                	Version ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.asset_alias = None
                                                                    self.asset_id = None
                                                                    self.base_mac_address1 = None
                                                                    self.base_mac_address2 = None
                                                                    self.base_mac_address3 = None
                                                                    self.base_mac_address4 = None
                                                                    self.block_checksum = None
                                                                    self.block_count = None
                                                                    self.block_length = None
                                                                    self.block_signature = None
                                                                    self.block_version = None
                                                                    self.chassis_sid = None
                                                                    self.clei = None
                                                                    self.controller_family = None
                                                                    self.controller_type = None
                                                                    self.description = None
                                                                    self.dev_num1 = None
                                                                    self.dev_num2 = None
                                                                    self.dev_num3 = None
                                                                    self.dev_num4 = None
                                                                    self.dev_num5 = None
                                                                    self.dev_num6 = None
                                                                    self.dev_num7 = None
                                                                    self.eci = None
                                                                    self.eeprom_size = None
                                                                    self.engineer_use = None
                                                                    self.fru_major_type = None
                                                                    self.fru_minor_type = None
                                                                    self.hw_version = None
                                                                    self.hwid = None
                                                                    self.idprom_format_rev = None
                                                                    self.mac_add_blk_size1 = None
                                                                    self.mac_add_blk_size2 = None
                                                                    self.mac_add_blk_size3 = None
                                                                    self.mac_add_blk_size4 = None
                                                                    self.manu_test_data = None
                                                                    self.mfg_bits = None
                                                                    self.mfg_deviation = None
                                                                    self.oem_string = None
                                                                    self.part_number = None
                                                                    self.part_revision = None
                                                                    self.pca_num = None
                                                                    self.pcavid = None
                                                                    self.pcb_serial_num = None
                                                                    self.pid = None
                                                                    self.power_consumption = None
                                                                    self.power_supply_type = None
                                                                    self.product_id = None
                                                                    self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                    self.rma.parent = self
                                                                    self.rma_code = None
                                                                    self.serial_number = None
                                                                    self.snmpoid = None
                                                                    self.top_assem_part_num = None
                                                                    self.top_assem_vid = None
                                                                    self.udi_description = None
                                                                    self.udi_name = None
                                                                    self.vid = None


                                                                class Rma(object):
                                                                    """
                                                                    RMA Data
                                                                    
                                                                    .. attribute:: rma_history
                                                                    
                                                                    	RMA history
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: rma_number
                                                                    
                                                                    	RMA tracking number format is N\-N\-N
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: test_history
                                                                    
                                                                    	Test history
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.rma_history = None
                                                                        self.rma_number = None
                                                                        self.test_history = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.rma_history is not None:
                                                                            return True

                                                                        if self.rma_number is not None:
                                                                            return True

                                                                        if self.test_history is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.asset_alias is not None:
                                                                        return True

                                                                    if self.asset_id is not None:
                                                                        return True

                                                                    if self.base_mac_address1 is not None:
                                                                        return True

                                                                    if self.base_mac_address2 is not None:
                                                                        return True

                                                                    if self.base_mac_address3 is not None:
                                                                        return True

                                                                    if self.base_mac_address4 is not None:
                                                                        return True

                                                                    if self.block_checksum is not None:
                                                                        return True

                                                                    if self.block_count is not None:
                                                                        return True

                                                                    if self.block_length is not None:
                                                                        return True

                                                                    if self.block_signature is not None:
                                                                        return True

                                                                    if self.block_version is not None:
                                                                        return True

                                                                    if self.chassis_sid is not None:
                                                                        return True

                                                                    if self.clei is not None:
                                                                        return True

                                                                    if self.controller_family is not None:
                                                                        return True

                                                                    if self.controller_type is not None:
                                                                        return True

                                                                    if self.description is not None:
                                                                        return True

                                                                    if self.dev_num1 is not None:
                                                                        return True

                                                                    if self.dev_num2 is not None:
                                                                        return True

                                                                    if self.dev_num3 is not None:
                                                                        return True

                                                                    if self.dev_num4 is not None:
                                                                        return True

                                                                    if self.dev_num5 is not None:
                                                                        return True

                                                                    if self.dev_num6 is not None:
                                                                        return True

                                                                    if self.dev_num7 is not None:
                                                                        return True

                                                                    if self.eci is not None:
                                                                        return True

                                                                    if self.eeprom_size is not None:
                                                                        return True

                                                                    if self.engineer_use is not None:
                                                                        return True

                                                                    if self.fru_major_type is not None:
                                                                        return True

                                                                    if self.fru_minor_type is not None:
                                                                        return True

                                                                    if self.hw_version is not None:
                                                                        return True

                                                                    if self.hwid is not None:
                                                                        return True

                                                                    if self.idprom_format_rev is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size1 is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size2 is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size3 is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size4 is not None:
                                                                        return True

                                                                    if self.manu_test_data is not None:
                                                                        return True

                                                                    if self.mfg_bits is not None:
                                                                        return True

                                                                    if self.mfg_deviation is not None:
                                                                        return True

                                                                    if self.oem_string is not None:
                                                                        return True

                                                                    if self.part_number is not None:
                                                                        return True

                                                                    if self.part_revision is not None:
                                                                        return True

                                                                    if self.pca_num is not None:
                                                                        return True

                                                                    if self.pcavid is not None:
                                                                        return True

                                                                    if self.pcb_serial_num is not None:
                                                                        return True

                                                                    if self.pid is not None:
                                                                        return True

                                                                    if self.power_consumption is not None:
                                                                        return True

                                                                    if self.power_supply_type is not None:
                                                                        return True

                                                                    if self.product_id is not None:
                                                                        return True

                                                                    if self.rma is not None and self.rma._has_data():
                                                                        return True

                                                                    if self.rma_code is not None:
                                                                        return True

                                                                    if self.serial_number is not None:
                                                                        return True

                                                                    if self.snmpoid is not None:
                                                                        return True

                                                                    if self.top_assem_part_num is not None:
                                                                        return True

                                                                    if self.top_assem_vid is not None:
                                                                        return True

                                                                    if self.udi_description is not None:
                                                                        return True

                                                                    if self.udi_name is not None:
                                                                        return True

                                                                    if self.vid is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.description is not None:
                                                                    return True

                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                    return True

                                                                if self.has_eeprom is not None:
                                                                    return True

                                                                if self.inv_card_type is not None:
                                                                    return True

                                                                if self.opaque_data is not None:
                                                                    return True

                                                                if self.opaque_data_size is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                return True

                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                return True

                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                return True

                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                return True

                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                return True

                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                return True

                                                            if self.module_done is not None:
                                                                return True

                                                            if self.node_id is not None:
                                                                return True

                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                return True

                                                            if self.threshold is not None and self.threshold._has_data():
                                                                return True

                                                            if self.vm_done is not None:
                                                                return True

                                                            if self.vm_node_id is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.name is None:
                                                            raise YPYModelError('Key property name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi4[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.name is not None:
                                                            return True

                                                        if self.attributes is not None and self.attributes._has_data():
                                                            return True

                                                        if self.tsi5s is not None and self.tsi5s._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi4s'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.tsi4 is not None:
                                                        for child_ref in self.tsi4:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S']['meta_info']


                                            class Attributes(object):
                                                """
                                                Attributes
                                                
                                                .. attribute:: env_sensor_info
                                                
                                                	Environment sensor info
                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfo>`
                                                
                                                .. attribute:: env_sensor_info_xml
                                                
                                                	Environment sensor info XML
                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml>`
                                                
                                                .. attribute:: fru_info
                                                
                                                	Inventory EDM FRU info
                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo>`
                                                
                                                .. attribute:: inv_asset_bag
                                                
                                                	Inventory Asset Bag
                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvAssetBag>`
                                                
                                                .. attribute:: inv_basic_bag
                                                
                                                	Inventory Basic Bag
                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvBasicBag>`
                                                
                                                .. attribute:: inv_eeprom_info
                                                
                                                	Inventory EDM EEPROM Information Bag
                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo>`
                                                
                                                .. attribute:: module_done
                                                
                                                	Inventory EDM Module Done Tuple
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: node_id
                                                
                                                	Node ID Tuple
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pwg_info
                                                
                                                	Inventory EDM PWG info
                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.PwgInfo>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold
                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold>`
                                                
                                                .. attribute:: vm_done
                                                
                                                	VM Done Tuple
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: vm_node_id
                                                
                                                	VM Node ID Tuple
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfo()
                                                    self.env_sensor_info.parent = self
                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml()
                                                    self.env_sensor_info_xml.parent = self
                                                    self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo()
                                                    self.fru_info.parent = self
                                                    self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvAssetBag()
                                                    self.inv_asset_bag.parent = self
                                                    self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvBasicBag()
                                                    self.inv_basic_bag.parent = self
                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo()
                                                    self.inv_eeprom_info.parent = self
                                                    self.module_done = None
                                                    self.node_id = None
                                                    self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.PwgInfo()
                                                    self.pwg_info.parent = self
                                                    self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold()
                                                    self.threshold.parent = self
                                                    self.vm_done = None
                                                    self.vm_node_id = None


                                                class EnvSensorInfo(object):
                                                    """
                                                    Environment sensor info
                                                    
                                                    .. attribute:: age_time_stamp
                                                    
                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: alarm_type
                                                    
                                                    	Indicates threshold violation
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: data_type
                                                    
                                                    	Sensor data type enums
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: device_description
                                                    
                                                    	Device Name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: device_id
                                                    
                                                    	Identifier for this device
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: field_validity_bitmap
                                                    
                                                    	Sensor valid bitmap
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: precision
                                                    
                                                    	Sensor precision range
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: scale
                                                    
                                                    	Sensor scale enums
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: status
                                                    
                                                    	Sensor operation state enums
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: units
                                                    
                                                    	Units of variable being read
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: update_rate
                                                    
                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Current reading of sensor
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.age_time_stamp = None
                                                        self.alarm_type = None
                                                        self.data_type = None
                                                        self.device_description = None
                                                        self.device_id = None
                                                        self.field_validity_bitmap = None
                                                        self.precision = None
                                                        self.scale = None
                                                        self.status = None
                                                        self.units = None
                                                        self.update_rate = None
                                                        self.value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.age_time_stamp is not None:
                                                            return True

                                                        if self.alarm_type is not None:
                                                            return True

                                                        if self.data_type is not None:
                                                            return True

                                                        if self.device_description is not None:
                                                            return True

                                                        if self.device_id is not None:
                                                            return True

                                                        if self.field_validity_bitmap is not None:
                                                            return True

                                                        if self.precision is not None:
                                                            return True

                                                        if self.scale is not None:
                                                            return True

                                                        if self.status is not None:
                                                            return True

                                                        if self.units is not None:
                                                            return True

                                                        if self.update_rate is not None:
                                                            return True

                                                        if self.value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfo']['meta_info']


                                                class PwgInfo(object):
                                                    """
                                                    Inventory EDM PWG info
                                                    
                                                    .. attribute:: power_group_available_current
                                                    
                                                    	available current
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_group_drawn_current
                                                    
                                                    	drawn current
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_group_power_units
                                                    
                                                    	power units
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: power_group_redundancy_mode
                                                    
                                                    	redundancy mode
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.power_group_available_current = None
                                                        self.power_group_drawn_current = None
                                                        self.power_group_power_units = None
                                                        self.power_group_redundancy_mode = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.power_group_available_current is not None:
                                                            return True

                                                        if self.power_group_drawn_current is not None:
                                                            return True

                                                        if self.power_group_power_units is not None:
                                                            return True

                                                        if self.power_group_redundancy_mode is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.PwgInfo']['meta_info']


                                                class EnvSensorInfoXml(object):
                                                    """
                                                    Environment sensor info XML
                                                    
                                                    .. attribute:: data_type
                                                    
                                                    	Sensor data type
                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Device Name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: status
                                                    
                                                    	Sensor operation state
                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold information
                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold>`
                                                    
                                                    .. attribute:: units
                                                    
                                                    	Units of variable being read
                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                    
                                                    .. attribute:: update_rate
                                                    
                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data_type = None
                                                        self.description = None
                                                        self.status = None
                                                        self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold()
                                                        self.threshold.parent = self
                                                        self.units = None
                                                        self.update_rate = None
                                                        self.value = None


                                                    class Threshold(object):
                                                        """
                                                        Threshold information
                                                        
                                                        .. attribute:: threshold_array
                                                        
                                                        	Array of threshold
                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.threshold_array = YList()
                                                            self.threshold_array.parent = self
                                                            self.threshold_array.name = 'threshold_array'


                                                        class ThresholdArray(object):
                                                            """
                                                            Array of threshold
                                                            
                                                            .. attribute:: threshold_name
                                                            
                                                            	Threshold name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_name = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_name is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.threshold_array is not None:
                                                                for child_ref in self.threshold_array:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data_type is not None:
                                                            return True

                                                        if self.description is not None:
                                                            return True

                                                        if self.status is not None:
                                                            return True

                                                        if self.threshold is not None and self.threshold._has_data():
                                                            return True

                                                        if self.units is not None:
                                                            return True

                                                        if self.update_rate is not None:
                                                            return True

                                                        if self.value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml']['meta_info']


                                                class InvAssetBag(object):
                                                    """
                                                    Inventory Asset Bag
                                                    
                                                    .. attribute:: manufacturer_assembly_number
                                                    
                                                    	Manufacture Assembly number
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_assembly_revision
                                                    
                                                    	Manufacture assembly revision
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                    
                                                    	Common Language Equipment           Identifier number
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_firmware_identifier
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_software_identifier
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: original_equipment_manufacturer_string
                                                    
                                                    	String containing OEM information           if applicable
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: part_number
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.manufacturer_assembly_number = None
                                                        self.manufacturer_assembly_revision = None
                                                        self.manufacturer_common_language_equipment_identifier = None
                                                        self.manufacturer_firmware_identifier = None
                                                        self.manufacturer_software_identifier = None
                                                        self.original_equipment_manufacturer_string = None
                                                        self.part_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.manufacturer_assembly_number is not None:
                                                            return True

                                                        if self.manufacturer_assembly_revision is not None:
                                                            return True

                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                            return True

                                                        if self.manufacturer_firmware_identifier is not None:
                                                            return True

                                                        if self.manufacturer_software_identifier is not None:
                                                            return True

                                                        if self.original_equipment_manufacturer_string is not None:
                                                            return True

                                                        if self.part_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvAssetBag']['meta_info']


                                                class Threshold(object):
                                                    """
                                                    Threshold
                                                    
                                                    .. attribute:: critical_hi
                                                    
                                                    	Critical High
                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi>`
                                                    
                                                    .. attribute:: critical_lo
                                                    
                                                    	Critical Low
                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo>`
                                                    
                                                    .. attribute:: major_hi
                                                    
                                                    	Major High
                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi>`
                                                    
                                                    .. attribute:: major_lo
                                                    
                                                    	Major Low
                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo>`
                                                    
                                                    .. attribute:: minor_hi
                                                    
                                                    	Minor High
                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi>`
                                                    
                                                    .. attribute:: minor_lo
                                                    
                                                    	Minor Low
                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi()
                                                        self.critical_hi.parent = self
                                                        self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo()
                                                        self.critical_lo.parent = self
                                                        self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi()
                                                        self.major_hi.parent = self
                                                        self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo()
                                                        self.major_lo.parent = self
                                                        self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi()
                                                        self.minor_hi.parent = self
                                                        self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo()
                                                        self.minor_lo.parent = self


                                                    class MajorLo(object):
                                                        """
                                                        Major Low
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo']['meta_info']


                                                    class CriticalHi(object):
                                                        """
                                                        Critical High
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi']['meta_info']


                                                    class MinorHi(object):
                                                        """
                                                        Minor High
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi']['meta_info']


                                                    class MajorHi(object):
                                                        """
                                                        Major High
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi']['meta_info']


                                                    class CriticalLo(object):
                                                        """
                                                        Critical Low
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo']['meta_info']


                                                    class MinorLo(object):
                                                        """
                                                        Minor Low
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                            return True

                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                            return True

                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                            return True

                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                            return True

                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                            return True

                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold']['meta_info']


                                                class FruInfo(object):
                                                    """
                                                    Inventory EDM FRU info
                                                    
                                                    .. attribute:: card_administrative_state
                                                    
                                                    	card admin state\: shutdown or not
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: card_monitor_state
                                                    
                                                    	card is monitored by a manager or left unmonitored
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: card_operational_state
                                                    
                                                    	card operation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: card_reset_reason
                                                    
                                                    	card reset reason enum
                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                    
                                                    .. attribute:: card_up_time
                                                    
                                                    	card up time
                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.CardUpTime>`
                                                    
                                                    .. attribute:: last_operational_state_change
                                                    
                                                    	last card oper change state
                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.LastOperationalStateChange>`
                                                    
                                                    .. attribute:: power_administrative_state
                                                    
                                                    	power admin state\: up or down
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_current_measurement
                                                    
                                                    	power current\: not implemented
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_operational_state
                                                    
                                                    	Power operation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.card_administrative_state = None
                                                        self.card_monitor_state = None
                                                        self.card_operational_state = None
                                                        self.card_reset_reason = None
                                                        self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.CardUpTime()
                                                        self.card_up_time.parent = self
                                                        self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.LastOperationalStateChange()
                                                        self.last_operational_state_change.parent = self
                                                        self.power_administrative_state = None
                                                        self.power_current_measurement = None
                                                        self.power_operational_state = None


                                                    class LastOperationalStateChange(object):
                                                        """
                                                        last card oper change state
                                                        
                                                        .. attribute:: time_in_nano_seconds
                                                        
                                                        	Time Value in Nano\-seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: time_in_seconds
                                                        
                                                        	Time Value in Seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.time_in_nano_seconds = None
                                                            self.time_in_seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.time_in_nano_seconds is not None:
                                                                return True

                                                            if self.time_in_seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                    class CardUpTime(object):
                                                        """
                                                        card up time
                                                        
                                                        .. attribute:: time_in_nano_seconds
                                                        
                                                        	Time Value in Nano\-seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: time_in_seconds
                                                        
                                                        	Time Value in Seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.time_in_nano_seconds = None
                                                            self.time_in_seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.time_in_nano_seconds is not None:
                                                                return True

                                                            if self.time_in_seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.CardUpTime']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.card_administrative_state is not None:
                                                            return True

                                                        if self.card_monitor_state is not None:
                                                            return True

                                                        if self.card_operational_state is not None:
                                                            return True

                                                        if self.card_reset_reason is not None:
                                                            return True

                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                            return True

                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                            return True

                                                        if self.power_administrative_state is not None:
                                                            return True

                                                        if self.power_current_measurement is not None:
                                                            return True

                                                        if self.power_operational_state is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo']['meta_info']


                                                class InvBasicBag(object):
                                                    """
                                                    Inventory Basic Bag
                                                    
                                                    .. attribute:: alias
                                                    
                                                    	useful for storing an entity alias 
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: asset_id_str
                                                    
                                                    	asset Identification string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: asset_identification
                                                    
                                                    	asset Identification
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: ceport
                                                    
                                                    	1 if ce port found, 0 if not
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: chip_hardware_revision
                                                    
                                                    	chip module hw revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: composite_class_code
                                                    
                                                    	Major&minor class of the entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: description
                                                    
                                                    	describes in user\-readable terms       what the entity in question does
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: environmental_monitor_path
                                                    
                                                    	sysdb name of sensor in the envmon EDM
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: firmware_revision
                                                    
                                                    	firmware revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: group_flag
                                                    
                                                    	indicates if this entity is group       or not
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: hardware_revision
                                                    
                                                    	hw revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: is_field_replaceable_unit
                                                    
                                                    	1 if Field Replaceable Unit 0, if not
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: manufacturer_asset_tags
                                                    
                                                    	Manufacture Asset Tags
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: manufacturer_name
                                                    
                                                    	manufacturer's name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: memory_size
                                                    
                                                    	Size of memory associated with       the entity where applicable
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: model_name
                                                    
                                                    	model name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: name
                                                    
                                                    	name string for the entity
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: new_deviation_number
                                                    
                                                    	integer value for New Deviation Number 0x88
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: physical_layer_interface_module_type
                                                    
                                                    	integer value for plim type if     applicable to this entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: redundancystate
                                                    
                                                    	integer value for Redundancy State if     applicable to this entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: serial_number
                                                    
                                                    	serial number
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: software_revision
                                                    
                                                    	software revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: unique_id
                                                    
                                                    	Unique id for an entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: unrecognized_fru
                                                    
                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vendor_type
                                                    
                                                    	maps to the vendor OID string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: xr_scoped
                                                    
                                                    	1 if xr scoped, 0 if not
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.alias = None
                                                        self.asset_id_str = None
                                                        self.asset_identification = None
                                                        self.ceport = None
                                                        self.chip_hardware_revision = None
                                                        self.composite_class_code = None
                                                        self.description = None
                                                        self.environmental_monitor_path = None
                                                        self.firmware_revision = None
                                                        self.group_flag = None
                                                        self.hardware_revision = None
                                                        self.is_field_replaceable_unit = None
                                                        self.manufacturer_asset_tags = None
                                                        self.manufacturer_name = None
                                                        self.memory_size = None
                                                        self.model_name = None
                                                        self.name = None
                                                        self.new_deviation_number = None
                                                        self.physical_layer_interface_module_type = None
                                                        self.redundancystate = None
                                                        self.serial_number = None
                                                        self.software_revision = None
                                                        self.unique_id = None
                                                        self.unrecognized_fru = None
                                                        self.vendor_type = None
                                                        self.xr_scoped = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.alias is not None:
                                                            return True

                                                        if self.asset_id_str is not None:
                                                            return True

                                                        if self.asset_identification is not None:
                                                            return True

                                                        if self.ceport is not None:
                                                            return True

                                                        if self.chip_hardware_revision is not None:
                                                            return True

                                                        if self.composite_class_code is not None:
                                                            return True

                                                        if self.description is not None:
                                                            return True

                                                        if self.environmental_monitor_path is not None:
                                                            return True

                                                        if self.firmware_revision is not None:
                                                            return True

                                                        if self.group_flag is not None:
                                                            return True

                                                        if self.hardware_revision is not None:
                                                            return True

                                                        if self.is_field_replaceable_unit is not None:
                                                            return True

                                                        if self.manufacturer_asset_tags is not None:
                                                            return True

                                                        if self.manufacturer_name is not None:
                                                            return True

                                                        if self.memory_size is not None:
                                                            return True

                                                        if self.model_name is not None:
                                                            return True

                                                        if self.name is not None:
                                                            return True

                                                        if self.new_deviation_number is not None:
                                                            return True

                                                        if self.physical_layer_interface_module_type is not None:
                                                            return True

                                                        if self.redundancystate is not None:
                                                            return True

                                                        if self.serial_number is not None:
                                                            return True

                                                        if self.software_revision is not None:
                                                            return True

                                                        if self.unique_id is not None:
                                                            return True

                                                        if self.unrecognized_fru is not None:
                                                            return True

                                                        if self.vendor_type is not None:
                                                            return True

                                                        if self.xr_scoped is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvBasicBag']['meta_info']


                                                class InvEepromInfo(object):
                                                    """
                                                    Inventory EDM EEPROM Information Bag
                                                    
                                                    .. attribute:: description
                                                    
                                                    	A textual description of physical entity
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: eeprom
                                                    
                                                    	EEPROM data not from hex data
                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom>`
                                                    
                                                    .. attribute:: has_eeprom
                                                    
                                                    	use eeprom instead of opaque data
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: inv_card_type
                                                    
                                                    	Inventory card type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: opaque_data
                                                    
                                                    	EEPROM hex data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: opaque_data_size
                                                    
                                                    	size of the EEPROM hex data
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.description = None
                                                        self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom()
                                                        self.eeprom.parent = self
                                                        self.has_eeprom = None
                                                        self.inv_card_type = None
                                                        self.opaque_data = None
                                                        self.opaque_data_size = None


                                                    class Eeprom(object):
                                                        """
                                                        EEPROM data not from hex data
                                                        
                                                        .. attribute:: asset_alias
                                                        
                                                        	Asset Alias
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: asset_id
                                                        
                                                        	Asset ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address1
                                                        
                                                        	Base Mac Address #1
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address2
                                                        
                                                        	Base Mac Address #2
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address3
                                                        
                                                        	Base Mac Address #3
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address4
                                                        
                                                        	Base Mac Address #4
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_checksum
                                                        
                                                        	Block Checksum
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_count
                                                        
                                                        	Block Count
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_length
                                                        
                                                        	Block Length
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_signature
                                                        
                                                        	Block Signature
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_version
                                                        
                                                        	Block Version
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: chassis_sid
                                                        
                                                        	Chassis serial number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: clei
                                                        
                                                        	Common Language Equipment Identifier (CLEI) code
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: controller_family
                                                        
                                                        	Controller family
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: controller_type
                                                        
                                                        	Controller type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: description
                                                        
                                                        	A textual description of physical entity
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num1
                                                        
                                                        	Deviation Number # 1
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num2
                                                        
                                                        	Deviation Number # 2
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num3
                                                        
                                                        	Deviation Number # 3
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num4
                                                        
                                                        	Deviation Number # 4
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num5
                                                        
                                                        	Deviation Number # 5
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num6
                                                        
                                                        	Deviation Number # 6
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num7
                                                        
                                                        	Deviation Number # 7
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: eci
                                                        
                                                        	Equipment Catalog Item (ECI) number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: eeprom_size
                                                        
                                                        	EEPROM Size
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: engineer_use
                                                        
                                                        	Engineer Use
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: fru_major_type
                                                        
                                                        	FRU Major Type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: fru_minor_type
                                                        
                                                        	FRU Minor Type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: hw_version
                                                        
                                                        	Hardware Version
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: hwid
                                                        
                                                        	Hardware Revision
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: idprom_format_rev
                                                        
                                                        	IDPROM Format Revision
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size1
                                                        
                                                        	Mac Address Block Size #1
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size2
                                                        
                                                        	Mac Address Block Size #2
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size3
                                                        
                                                        	Mac Address Block Size #3
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size4
                                                        
                                                        	Mac Address Block Size #4
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: manu_test_data
                                                        
                                                        	Manufacturing Test Data
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mfg_bits
                                                        
                                                        	MFG Bits
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mfg_deviation
                                                        
                                                        	MFG Deviation
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: oem_string
                                                        
                                                        	OEM String
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: part_number
                                                        
                                                        	Part Number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: part_revision
                                                        
                                                        	Part Revision
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pca_num
                                                        
                                                        	PCA number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pcavid
                                                        
                                                        	PCA revision ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pcb_serial_num
                                                        
                                                        	PCB Serial Number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pid
                                                        
                                                        	Product ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: power_consumption
                                                        
                                                        	Power Consumption
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: power_supply_type
                                                        
                                                        	Power Supply Type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: product_id
                                                        
                                                        	Product ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: rma
                                                        
                                                        	RMA Data
                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                        
                                                        .. attribute:: rma_code
                                                        
                                                        	RMA Code
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: serial_number
                                                        
                                                        	Serial Number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: snmpoid
                                                        
                                                        	SNMP OID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: top_assem_part_num
                                                        
                                                        	Top assembly part number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: top_assem_vid
                                                        
                                                        	Top assembly revision number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: udi_description
                                                        
                                                        	UDI description
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: udi_name
                                                        
                                                        	UDI name
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: vid
                                                        
                                                        	Version ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.asset_alias = None
                                                            self.asset_id = None
                                                            self.base_mac_address1 = None
                                                            self.base_mac_address2 = None
                                                            self.base_mac_address3 = None
                                                            self.base_mac_address4 = None
                                                            self.block_checksum = None
                                                            self.block_count = None
                                                            self.block_length = None
                                                            self.block_signature = None
                                                            self.block_version = None
                                                            self.chassis_sid = None
                                                            self.clei = None
                                                            self.controller_family = None
                                                            self.controller_type = None
                                                            self.description = None
                                                            self.dev_num1 = None
                                                            self.dev_num2 = None
                                                            self.dev_num3 = None
                                                            self.dev_num4 = None
                                                            self.dev_num5 = None
                                                            self.dev_num6 = None
                                                            self.dev_num7 = None
                                                            self.eci = None
                                                            self.eeprom_size = None
                                                            self.engineer_use = None
                                                            self.fru_major_type = None
                                                            self.fru_minor_type = None
                                                            self.hw_version = None
                                                            self.hwid = None
                                                            self.idprom_format_rev = None
                                                            self.mac_add_blk_size1 = None
                                                            self.mac_add_blk_size2 = None
                                                            self.mac_add_blk_size3 = None
                                                            self.mac_add_blk_size4 = None
                                                            self.manu_test_data = None
                                                            self.mfg_bits = None
                                                            self.mfg_deviation = None
                                                            self.oem_string = None
                                                            self.part_number = None
                                                            self.part_revision = None
                                                            self.pca_num = None
                                                            self.pcavid = None
                                                            self.pcb_serial_num = None
                                                            self.pid = None
                                                            self.power_consumption = None
                                                            self.power_supply_type = None
                                                            self.product_id = None
                                                            self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom.Rma()
                                                            self.rma.parent = self
                                                            self.rma_code = None
                                                            self.serial_number = None
                                                            self.snmpoid = None
                                                            self.top_assem_part_num = None
                                                            self.top_assem_vid = None
                                                            self.udi_description = None
                                                            self.udi_name = None
                                                            self.vid = None


                                                        class Rma(object):
                                                            """
                                                            RMA Data
                                                            
                                                            .. attribute:: rma_history
                                                            
                                                            	RMA history
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: rma_number
                                                            
                                                            	RMA tracking number format is N\-N\-N
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: test_history
                                                            
                                                            	Test history
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.rma_history = None
                                                                self.rma_number = None
                                                                self.test_history = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.rma_history is not None:
                                                                    return True

                                                                if self.rma_number is not None:
                                                                    return True

                                                                if self.test_history is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.asset_alias is not None:
                                                                return True

                                                            if self.asset_id is not None:
                                                                return True

                                                            if self.base_mac_address1 is not None:
                                                                return True

                                                            if self.base_mac_address2 is not None:
                                                                return True

                                                            if self.base_mac_address3 is not None:
                                                                return True

                                                            if self.base_mac_address4 is not None:
                                                                return True

                                                            if self.block_checksum is not None:
                                                                return True

                                                            if self.block_count is not None:
                                                                return True

                                                            if self.block_length is not None:
                                                                return True

                                                            if self.block_signature is not None:
                                                                return True

                                                            if self.block_version is not None:
                                                                return True

                                                            if self.chassis_sid is not None:
                                                                return True

                                                            if self.clei is not None:
                                                                return True

                                                            if self.controller_family is not None:
                                                                return True

                                                            if self.controller_type is not None:
                                                                return True

                                                            if self.description is not None:
                                                                return True

                                                            if self.dev_num1 is not None:
                                                                return True

                                                            if self.dev_num2 is not None:
                                                                return True

                                                            if self.dev_num3 is not None:
                                                                return True

                                                            if self.dev_num4 is not None:
                                                                return True

                                                            if self.dev_num5 is not None:
                                                                return True

                                                            if self.dev_num6 is not None:
                                                                return True

                                                            if self.dev_num7 is not None:
                                                                return True

                                                            if self.eci is not None:
                                                                return True

                                                            if self.eeprom_size is not None:
                                                                return True

                                                            if self.engineer_use is not None:
                                                                return True

                                                            if self.fru_major_type is not None:
                                                                return True

                                                            if self.fru_minor_type is not None:
                                                                return True

                                                            if self.hw_version is not None:
                                                                return True

                                                            if self.hwid is not None:
                                                                return True

                                                            if self.idprom_format_rev is not None:
                                                                return True

                                                            if self.mac_add_blk_size1 is not None:
                                                                return True

                                                            if self.mac_add_blk_size2 is not None:
                                                                return True

                                                            if self.mac_add_blk_size3 is not None:
                                                                return True

                                                            if self.mac_add_blk_size4 is not None:
                                                                return True

                                                            if self.manu_test_data is not None:
                                                                return True

                                                            if self.mfg_bits is not None:
                                                                return True

                                                            if self.mfg_deviation is not None:
                                                                return True

                                                            if self.oem_string is not None:
                                                                return True

                                                            if self.part_number is not None:
                                                                return True

                                                            if self.part_revision is not None:
                                                                return True

                                                            if self.pca_num is not None:
                                                                return True

                                                            if self.pcavid is not None:
                                                                return True

                                                            if self.pcb_serial_num is not None:
                                                                return True

                                                            if self.pid is not None:
                                                                return True

                                                            if self.power_consumption is not None:
                                                                return True

                                                            if self.power_supply_type is not None:
                                                                return True

                                                            if self.product_id is not None:
                                                                return True

                                                            if self.rma is not None and self.rma._has_data():
                                                                return True

                                                            if self.rma_code is not None:
                                                                return True

                                                            if self.serial_number is not None:
                                                                return True

                                                            if self.snmpoid is not None:
                                                                return True

                                                            if self.top_assem_part_num is not None:
                                                                return True

                                                            if self.top_assem_vid is not None:
                                                                return True

                                                            if self.udi_description is not None:
                                                                return True

                                                            if self.udi_name is not None:
                                                                return True

                                                            if self.vid is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.description is not None:
                                                            return True

                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                            return True

                                                        if self.has_eeprom is not None:
                                                            return True

                                                        if self.inv_card_type is not None:
                                                            return True

                                                        if self.opaque_data is not None:
                                                            return True

                                                        if self.opaque_data_size is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                        return True

                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                        return True

                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                        return True

                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                        return True

                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                        return True

                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                        return True

                                                    if self.module_done is not None:
                                                        return True

                                                    if self.node_id is not None:
                                                        return True

                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                        return True

                                                    if self.threshold is not None and self.threshold._has_data():
                                                        return True

                                                    if self.vm_done is not None:
                                                        return True

                                                    if self.vm_node_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.name is None:
                                                    raise YPYModelError('Key property name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi3[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.name is not None:
                                                    return True

                                                if self.attributes is not None and self.attributes._has_data():
                                                    return True

                                                if self.tsi4s is not None and self.tsi4s._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi3s'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tsi3 is not None:
                                                for child_ref in self.tsi3:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S']['meta_info']


                                    class Attributes(object):
                                        """
                                        Attributes
                                        
                                        .. attribute:: env_sensor_info
                                        
                                        	Environment sensor info
                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfo>`
                                        
                                        .. attribute:: env_sensor_info_xml
                                        
                                        	Environment sensor info XML
                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml>`
                                        
                                        .. attribute:: fru_info
                                        
                                        	Inventory EDM FRU info
                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo>`
                                        
                                        .. attribute:: inv_asset_bag
                                        
                                        	Inventory Asset Bag
                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvAssetBag>`
                                        
                                        .. attribute:: inv_basic_bag
                                        
                                        	Inventory Basic Bag
                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvBasicBag>`
                                        
                                        .. attribute:: inv_eeprom_info
                                        
                                        	Inventory EDM EEPROM Information Bag
                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo>`
                                        
                                        .. attribute:: module_done
                                        
                                        	Inventory EDM Module Done Tuple
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: node_id
                                        
                                        	Node ID Tuple
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pwg_info
                                        
                                        	Inventory EDM PWG info
                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.PwgInfo>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold
                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold>`
                                        
                                        .. attribute:: vm_done
                                        
                                        	VM Done Tuple
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: vm_node_id
                                        
                                        	VM Node ID Tuple
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfo()
                                            self.env_sensor_info.parent = self
                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml()
                                            self.env_sensor_info_xml.parent = self
                                            self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo()
                                            self.fru_info.parent = self
                                            self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvAssetBag()
                                            self.inv_asset_bag.parent = self
                                            self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvBasicBag()
                                            self.inv_basic_bag.parent = self
                                            self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo()
                                            self.inv_eeprom_info.parent = self
                                            self.module_done = None
                                            self.node_id = None
                                            self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.PwgInfo()
                                            self.pwg_info.parent = self
                                            self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold()
                                            self.threshold.parent = self
                                            self.vm_done = None
                                            self.vm_node_id = None


                                        class EnvSensorInfo(object):
                                            """
                                            Environment sensor info
                                            
                                            .. attribute:: age_time_stamp
                                            
                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: alarm_type
                                            
                                            	Indicates threshold violation
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_type
                                            
                                            	Sensor data type enums
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: device_description
                                            
                                            	Device Name
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: device_id
                                            
                                            	Identifier for this device
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: field_validity_bitmap
                                            
                                            	Sensor valid bitmap
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: precision
                                            
                                            	Sensor precision range
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scale
                                            
                                            	Sensor scale enums
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: status
                                            
                                            	Sensor operation state enums
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: units
                                            
                                            	Units of variable being read
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: update_rate
                                            
                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: value
                                            
                                            	Current reading of sensor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.age_time_stamp = None
                                                self.alarm_type = None
                                                self.data_type = None
                                                self.device_description = None
                                                self.device_id = None
                                                self.field_validity_bitmap = None
                                                self.precision = None
                                                self.scale = None
                                                self.status = None
                                                self.units = None
                                                self.update_rate = None
                                                self.value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.age_time_stamp is not None:
                                                    return True

                                                if self.alarm_type is not None:
                                                    return True

                                                if self.data_type is not None:
                                                    return True

                                                if self.device_description is not None:
                                                    return True

                                                if self.device_id is not None:
                                                    return True

                                                if self.field_validity_bitmap is not None:
                                                    return True

                                                if self.precision is not None:
                                                    return True

                                                if self.scale is not None:
                                                    return True

                                                if self.status is not None:
                                                    return True

                                                if self.units is not None:
                                                    return True

                                                if self.update_rate is not None:
                                                    return True

                                                if self.value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfo']['meta_info']


                                        class PwgInfo(object):
                                            """
                                            Inventory EDM PWG info
                                            
                                            .. attribute:: power_group_available_current
                                            
                                            	available current
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_group_drawn_current
                                            
                                            	drawn current
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_group_power_units
                                            
                                            	power units
                                            	**type**\:  str
                                            
                                            .. attribute:: power_group_redundancy_mode
                                            
                                            	redundancy mode
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.power_group_available_current = None
                                                self.power_group_drawn_current = None
                                                self.power_group_power_units = None
                                                self.power_group_redundancy_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.power_group_available_current is not None:
                                                    return True

                                                if self.power_group_drawn_current is not None:
                                                    return True

                                                if self.power_group_power_units is not None:
                                                    return True

                                                if self.power_group_redundancy_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.PwgInfo']['meta_info']


                                        class EnvSensorInfoXml(object):
                                            """
                                            Environment sensor info XML
                                            
                                            .. attribute:: data_type
                                            
                                            	Sensor data type
                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                            
                                            .. attribute:: description
                                            
                                            	Device Name
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: status
                                            
                                            	Sensor operation state
                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold information
                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold>`
                                            
                                            .. attribute:: units
                                            
                                            	Units of variable being read
                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                            
                                            .. attribute:: update_rate
                                            
                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: value
                                            
                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.data_type = None
                                                self.description = None
                                                self.status = None
                                                self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold()
                                                self.threshold.parent = self
                                                self.units = None
                                                self.update_rate = None
                                                self.value = None


                                            class Threshold(object):
                                                """
                                                Threshold information
                                                
                                                .. attribute:: threshold_array
                                                
                                                	Array of threshold
                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.threshold_array = YList()
                                                    self.threshold_array.parent = self
                                                    self.threshold_array.name = 'threshold_array'


                                                class ThresholdArray(object):
                                                    """
                                                    Array of threshold
                                                    
                                                    .. attribute:: threshold_name
                                                    
                                                    	Threshold name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_name = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_name is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.threshold_array is not None:
                                                        for child_ref in self.threshold_array:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.data_type is not None:
                                                    return True

                                                if self.description is not None:
                                                    return True

                                                if self.status is not None:
                                                    return True

                                                if self.threshold is not None and self.threshold._has_data():
                                                    return True

                                                if self.units is not None:
                                                    return True

                                                if self.update_rate is not None:
                                                    return True

                                                if self.value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml']['meta_info']


                                        class InvAssetBag(object):
                                            """
                                            Inventory Asset Bag
                                            
                                            .. attribute:: manufacturer_assembly_number
                                            
                                            	Manufacture Assembly number
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_assembly_revision
                                            
                                            	Manufacture assembly revision
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                            
                                            	Common Language Equipment           Identifier number
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_firmware_identifier
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_software_identifier
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: original_equipment_manufacturer_string
                                            
                                            	String containing OEM information           if applicable
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: part_number
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.manufacturer_assembly_number = None
                                                self.manufacturer_assembly_revision = None
                                                self.manufacturer_common_language_equipment_identifier = None
                                                self.manufacturer_firmware_identifier = None
                                                self.manufacturer_software_identifier = None
                                                self.original_equipment_manufacturer_string = None
                                                self.part_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.manufacturer_assembly_number is not None:
                                                    return True

                                                if self.manufacturer_assembly_revision is not None:
                                                    return True

                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                    return True

                                                if self.manufacturer_firmware_identifier is not None:
                                                    return True

                                                if self.manufacturer_software_identifier is not None:
                                                    return True

                                                if self.original_equipment_manufacturer_string is not None:
                                                    return True

                                                if self.part_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvAssetBag']['meta_info']


                                        class Threshold(object):
                                            """
                                            Threshold
                                            
                                            .. attribute:: critical_hi
                                            
                                            	Critical High
                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi>`
                                            
                                            .. attribute:: critical_lo
                                            
                                            	Critical Low
                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo>`
                                            
                                            .. attribute:: major_hi
                                            
                                            	Major High
                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi>`
                                            
                                            .. attribute:: major_lo
                                            
                                            	Major Low
                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo>`
                                            
                                            .. attribute:: minor_hi
                                            
                                            	Minor High
                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi>`
                                            
                                            .. attribute:: minor_lo
                                            
                                            	Minor Low
                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo>`
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi()
                                                self.critical_hi.parent = self
                                                self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo()
                                                self.critical_lo.parent = self
                                                self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi()
                                                self.major_hi.parent = self
                                                self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo()
                                                self.major_lo.parent = self
                                                self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi()
                                                self.minor_hi.parent = self
                                                self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo()
                                                self.minor_lo.parent = self


                                            class MajorLo(object):
                                                """
                                                Major Low
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo']['meta_info']


                                            class CriticalHi(object):
                                                """
                                                Critical High
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi']['meta_info']


                                            class MinorHi(object):
                                                """
                                                Minor High
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi']['meta_info']


                                            class MajorHi(object):
                                                """
                                                Major High
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi']['meta_info']


                                            class CriticalLo(object):
                                                """
                                                Critical Low
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo']['meta_info']


                                            class MinorLo(object):
                                                """
                                                Minor Low
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                    return True

                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                    return True

                                                if self.major_hi is not None and self.major_hi._has_data():
                                                    return True

                                                if self.major_lo is not None and self.major_lo._has_data():
                                                    return True

                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                    return True

                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold']['meta_info']


                                        class FruInfo(object):
                                            """
                                            Inventory EDM FRU info
                                            
                                            .. attribute:: card_administrative_state
                                            
                                            	card admin state\: shutdown or not
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: card_monitor_state
                                            
                                            	card is monitored by a manager or left unmonitored
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: card_operational_state
                                            
                                            	card operation state
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: card_reset_reason
                                            
                                            	card reset reason enum
                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                            
                                            .. attribute:: card_up_time
                                            
                                            	card up time
                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.CardUpTime>`
                                            
                                            .. attribute:: last_operational_state_change
                                            
                                            	last card oper change state
                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.LastOperationalStateChange>`
                                            
                                            .. attribute:: power_administrative_state
                                            
                                            	power admin state\: up or down
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_current_measurement
                                            
                                            	power current\: not implemented
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_operational_state
                                            
                                            	Power operation state
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.card_administrative_state = None
                                                self.card_monitor_state = None
                                                self.card_operational_state = None
                                                self.card_reset_reason = None
                                                self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.CardUpTime()
                                                self.card_up_time.parent = self
                                                self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.LastOperationalStateChange()
                                                self.last_operational_state_change.parent = self
                                                self.power_administrative_state = None
                                                self.power_current_measurement = None
                                                self.power_operational_state = None


                                            class LastOperationalStateChange(object):
                                                """
                                                last card oper change state
                                                
                                                .. attribute:: time_in_nano_seconds
                                                
                                                	Time Value in Nano\-seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: time_in_seconds
                                                
                                                	Time Value in Seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.time_in_nano_seconds = None
                                                    self.time_in_seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.time_in_nano_seconds is not None:
                                                        return True

                                                    if self.time_in_seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                            class CardUpTime(object):
                                                """
                                                card up time
                                                
                                                .. attribute:: time_in_nano_seconds
                                                
                                                	Time Value in Nano\-seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: time_in_seconds
                                                
                                                	Time Value in Seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.time_in_nano_seconds = None
                                                    self.time_in_seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.time_in_nano_seconds is not None:
                                                        return True

                                                    if self.time_in_seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.CardUpTime']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.card_administrative_state is not None:
                                                    return True

                                                if self.card_monitor_state is not None:
                                                    return True

                                                if self.card_operational_state is not None:
                                                    return True

                                                if self.card_reset_reason is not None:
                                                    return True

                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                    return True

                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                    return True

                                                if self.power_administrative_state is not None:
                                                    return True

                                                if self.power_current_measurement is not None:
                                                    return True

                                                if self.power_operational_state is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo']['meta_info']


                                        class InvBasicBag(object):
                                            """
                                            Inventory Basic Bag
                                            
                                            .. attribute:: alias
                                            
                                            	useful for storing an entity alias 
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: asset_id_str
                                            
                                            	asset Identification string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: asset_identification
                                            
                                            	asset Identification
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ceport
                                            
                                            	1 if ce port found, 0 if not
                                            	**type**\:  bool
                                            
                                            .. attribute:: chip_hardware_revision
                                            
                                            	chip module hw revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: composite_class_code
                                            
                                            	Major&minor class of the entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: description
                                            
                                            	describes in user\-readable terms       what the entity in question does
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: environmental_monitor_path
                                            
                                            	sysdb name of sensor in the envmon EDM
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: firmware_revision
                                            
                                            	firmware revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: group_flag
                                            
                                            	indicates if this entity is group       or not
                                            	**type**\:  bool
                                            
                                            .. attribute:: hardware_revision
                                            
                                            	hw revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: is_field_replaceable_unit
                                            
                                            	1 if Field Replaceable Unit 0, if not
                                            	**type**\:  bool
                                            
                                            .. attribute:: manufacturer_asset_tags
                                            
                                            	Manufacture Asset Tags
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: manufacturer_name
                                            
                                            	manufacturer's name
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: memory_size
                                            
                                            	Size of memory associated with       the entity where applicable
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: model_name
                                            
                                            	model name
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: name
                                            
                                            	name string for the entity
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: new_deviation_number
                                            
                                            	integer value for New Deviation Number 0x88
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: physical_layer_interface_module_type
                                            
                                            	integer value for plim type if     applicable to this entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: redundancystate
                                            
                                            	integer value for Redundancy State if     applicable to this entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: serial_number
                                            
                                            	serial number
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: software_revision
                                            
                                            	software revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: unique_id
                                            
                                            	Unique id for an entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: unrecognized_fru
                                            
                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                            	**type**\:  bool
                                            
                                            .. attribute:: vendor_type
                                            
                                            	maps to the vendor OID string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: xr_scoped
                                            
                                            	1 if xr scoped, 0 if not
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.alias = None
                                                self.asset_id_str = None
                                                self.asset_identification = None
                                                self.ceport = None
                                                self.chip_hardware_revision = None
                                                self.composite_class_code = None
                                                self.description = None
                                                self.environmental_monitor_path = None
                                                self.firmware_revision = None
                                                self.group_flag = None
                                                self.hardware_revision = None
                                                self.is_field_replaceable_unit = None
                                                self.manufacturer_asset_tags = None
                                                self.manufacturer_name = None
                                                self.memory_size = None
                                                self.model_name = None
                                                self.name = None
                                                self.new_deviation_number = None
                                                self.physical_layer_interface_module_type = None
                                                self.redundancystate = None
                                                self.serial_number = None
                                                self.software_revision = None
                                                self.unique_id = None
                                                self.unrecognized_fru = None
                                                self.vendor_type = None
                                                self.xr_scoped = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.alias is not None:
                                                    return True

                                                if self.asset_id_str is not None:
                                                    return True

                                                if self.asset_identification is not None:
                                                    return True

                                                if self.ceport is not None:
                                                    return True

                                                if self.chip_hardware_revision is not None:
                                                    return True

                                                if self.composite_class_code is not None:
                                                    return True

                                                if self.description is not None:
                                                    return True

                                                if self.environmental_monitor_path is not None:
                                                    return True

                                                if self.firmware_revision is not None:
                                                    return True

                                                if self.group_flag is not None:
                                                    return True

                                                if self.hardware_revision is not None:
                                                    return True

                                                if self.is_field_replaceable_unit is not None:
                                                    return True

                                                if self.manufacturer_asset_tags is not None:
                                                    return True

                                                if self.manufacturer_name is not None:
                                                    return True

                                                if self.memory_size is not None:
                                                    return True

                                                if self.model_name is not None:
                                                    return True

                                                if self.name is not None:
                                                    return True

                                                if self.new_deviation_number is not None:
                                                    return True

                                                if self.physical_layer_interface_module_type is not None:
                                                    return True

                                                if self.redundancystate is not None:
                                                    return True

                                                if self.serial_number is not None:
                                                    return True

                                                if self.software_revision is not None:
                                                    return True

                                                if self.unique_id is not None:
                                                    return True

                                                if self.unrecognized_fru is not None:
                                                    return True

                                                if self.vendor_type is not None:
                                                    return True

                                                if self.xr_scoped is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvBasicBag']['meta_info']


                                        class InvEepromInfo(object):
                                            """
                                            Inventory EDM EEPROM Information Bag
                                            
                                            .. attribute:: description
                                            
                                            	A textual description of physical entity
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: eeprom
                                            
                                            	EEPROM data not from hex data
                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom>`
                                            
                                            .. attribute:: has_eeprom
                                            
                                            	use eeprom instead of opaque data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inv_card_type
                                            
                                            	Inventory card type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: opaque_data
                                            
                                            	EEPROM hex data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: opaque_data_size
                                            
                                            	size of the EEPROM hex data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom()
                                                self.eeprom.parent = self
                                                self.has_eeprom = None
                                                self.inv_card_type = None
                                                self.opaque_data = None
                                                self.opaque_data_size = None


                                            class Eeprom(object):
                                                """
                                                EEPROM data not from hex data
                                                
                                                .. attribute:: asset_alias
                                                
                                                	Asset Alias
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: asset_id
                                                
                                                	Asset ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address1
                                                
                                                	Base Mac Address #1
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address2
                                                
                                                	Base Mac Address #2
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address3
                                                
                                                	Base Mac Address #3
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address4
                                                
                                                	Base Mac Address #4
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_checksum
                                                
                                                	Block Checksum
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_count
                                                
                                                	Block Count
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_length
                                                
                                                	Block Length
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_signature
                                                
                                                	Block Signature
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_version
                                                
                                                	Block Version
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: chassis_sid
                                                
                                                	Chassis serial number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: clei
                                                
                                                	Common Language Equipment Identifier (CLEI) code
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: controller_family
                                                
                                                	Controller family
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: controller_type
                                                
                                                	Controller type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: description
                                                
                                                	A textual description of physical entity
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num1
                                                
                                                	Deviation Number # 1
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num2
                                                
                                                	Deviation Number # 2
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num3
                                                
                                                	Deviation Number # 3
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num4
                                                
                                                	Deviation Number # 4
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num5
                                                
                                                	Deviation Number # 5
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num6
                                                
                                                	Deviation Number # 6
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num7
                                                
                                                	Deviation Number # 7
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: eci
                                                
                                                	Equipment Catalog Item (ECI) number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: eeprom_size
                                                
                                                	EEPROM Size
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: engineer_use
                                                
                                                	Engineer Use
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: fru_major_type
                                                
                                                	FRU Major Type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: fru_minor_type
                                                
                                                	FRU Minor Type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: hw_version
                                                
                                                	Hardware Version
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: hwid
                                                
                                                	Hardware Revision
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: idprom_format_rev
                                                
                                                	IDPROM Format Revision
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size1
                                                
                                                	Mac Address Block Size #1
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size2
                                                
                                                	Mac Address Block Size #2
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size3
                                                
                                                	Mac Address Block Size #3
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size4
                                                
                                                	Mac Address Block Size #4
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: manu_test_data
                                                
                                                	Manufacturing Test Data
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mfg_bits
                                                
                                                	MFG Bits
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mfg_deviation
                                                
                                                	MFG Deviation
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: oem_string
                                                
                                                	OEM String
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: part_number
                                                
                                                	Part Number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: part_revision
                                                
                                                	Part Revision
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pca_num
                                                
                                                	PCA number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pcavid
                                                
                                                	PCA revision ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pcb_serial_num
                                                
                                                	PCB Serial Number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pid
                                                
                                                	Product ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: power_consumption
                                                
                                                	Power Consumption
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: power_supply_type
                                                
                                                	Power Supply Type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: product_id
                                                
                                                	Product ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: rma
                                                
                                                	RMA Data
                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                
                                                .. attribute:: rma_code
                                                
                                                	RMA Code
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: serial_number
                                                
                                                	Serial Number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: snmpoid
                                                
                                                	SNMP OID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: top_assem_part_num
                                                
                                                	Top assembly part number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: top_assem_vid
                                                
                                                	Top assembly revision number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: udi_description
                                                
                                                	UDI description
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: udi_name
                                                
                                                	UDI name
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: vid
                                                
                                                	Version ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asset_alias = None
                                                    self.asset_id = None
                                                    self.base_mac_address1 = None
                                                    self.base_mac_address2 = None
                                                    self.base_mac_address3 = None
                                                    self.base_mac_address4 = None
                                                    self.block_checksum = None
                                                    self.block_count = None
                                                    self.block_length = None
                                                    self.block_signature = None
                                                    self.block_version = None
                                                    self.chassis_sid = None
                                                    self.clei = None
                                                    self.controller_family = None
                                                    self.controller_type = None
                                                    self.description = None
                                                    self.dev_num1 = None
                                                    self.dev_num2 = None
                                                    self.dev_num3 = None
                                                    self.dev_num4 = None
                                                    self.dev_num5 = None
                                                    self.dev_num6 = None
                                                    self.dev_num7 = None
                                                    self.eci = None
                                                    self.eeprom_size = None
                                                    self.engineer_use = None
                                                    self.fru_major_type = None
                                                    self.fru_minor_type = None
                                                    self.hw_version = None
                                                    self.hwid = None
                                                    self.idprom_format_rev = None
                                                    self.mac_add_blk_size1 = None
                                                    self.mac_add_blk_size2 = None
                                                    self.mac_add_blk_size3 = None
                                                    self.mac_add_blk_size4 = None
                                                    self.manu_test_data = None
                                                    self.mfg_bits = None
                                                    self.mfg_deviation = None
                                                    self.oem_string = None
                                                    self.part_number = None
                                                    self.part_revision = None
                                                    self.pca_num = None
                                                    self.pcavid = None
                                                    self.pcb_serial_num = None
                                                    self.pid = None
                                                    self.power_consumption = None
                                                    self.power_supply_type = None
                                                    self.product_id = None
                                                    self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom.Rma()
                                                    self.rma.parent = self
                                                    self.rma_code = None
                                                    self.serial_number = None
                                                    self.snmpoid = None
                                                    self.top_assem_part_num = None
                                                    self.top_assem_vid = None
                                                    self.udi_description = None
                                                    self.udi_name = None
                                                    self.vid = None


                                                class Rma(object):
                                                    """
                                                    RMA Data
                                                    
                                                    .. attribute:: rma_history
                                                    
                                                    	RMA history
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: rma_number
                                                    
                                                    	RMA tracking number format is N\-N\-N
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: test_history
                                                    
                                                    	Test history
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.rma_history = None
                                                        self.rma_number = None
                                                        self.test_history = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.rma_history is not None:
                                                            return True

                                                        if self.rma_number is not None:
                                                            return True

                                                        if self.test_history is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asset_alias is not None:
                                                        return True

                                                    if self.asset_id is not None:
                                                        return True

                                                    if self.base_mac_address1 is not None:
                                                        return True

                                                    if self.base_mac_address2 is not None:
                                                        return True

                                                    if self.base_mac_address3 is not None:
                                                        return True

                                                    if self.base_mac_address4 is not None:
                                                        return True

                                                    if self.block_checksum is not None:
                                                        return True

                                                    if self.block_count is not None:
                                                        return True

                                                    if self.block_length is not None:
                                                        return True

                                                    if self.block_signature is not None:
                                                        return True

                                                    if self.block_version is not None:
                                                        return True

                                                    if self.chassis_sid is not None:
                                                        return True

                                                    if self.clei is not None:
                                                        return True

                                                    if self.controller_family is not None:
                                                        return True

                                                    if self.controller_type is not None:
                                                        return True

                                                    if self.description is not None:
                                                        return True

                                                    if self.dev_num1 is not None:
                                                        return True

                                                    if self.dev_num2 is not None:
                                                        return True

                                                    if self.dev_num3 is not None:
                                                        return True

                                                    if self.dev_num4 is not None:
                                                        return True

                                                    if self.dev_num5 is not None:
                                                        return True

                                                    if self.dev_num6 is not None:
                                                        return True

                                                    if self.dev_num7 is not None:
                                                        return True

                                                    if self.eci is not None:
                                                        return True

                                                    if self.eeprom_size is not None:
                                                        return True

                                                    if self.engineer_use is not None:
                                                        return True

                                                    if self.fru_major_type is not None:
                                                        return True

                                                    if self.fru_minor_type is not None:
                                                        return True

                                                    if self.hw_version is not None:
                                                        return True

                                                    if self.hwid is not None:
                                                        return True

                                                    if self.idprom_format_rev is not None:
                                                        return True

                                                    if self.mac_add_blk_size1 is not None:
                                                        return True

                                                    if self.mac_add_blk_size2 is not None:
                                                        return True

                                                    if self.mac_add_blk_size3 is not None:
                                                        return True

                                                    if self.mac_add_blk_size4 is not None:
                                                        return True

                                                    if self.manu_test_data is not None:
                                                        return True

                                                    if self.mfg_bits is not None:
                                                        return True

                                                    if self.mfg_deviation is not None:
                                                        return True

                                                    if self.oem_string is not None:
                                                        return True

                                                    if self.part_number is not None:
                                                        return True

                                                    if self.part_revision is not None:
                                                        return True

                                                    if self.pca_num is not None:
                                                        return True

                                                    if self.pcavid is not None:
                                                        return True

                                                    if self.pcb_serial_num is not None:
                                                        return True

                                                    if self.pid is not None:
                                                        return True

                                                    if self.power_consumption is not None:
                                                        return True

                                                    if self.power_supply_type is not None:
                                                        return True

                                                    if self.product_id is not None:
                                                        return True

                                                    if self.rma is not None and self.rma._has_data():
                                                        return True

                                                    if self.rma_code is not None:
                                                        return True

                                                    if self.serial_number is not None:
                                                        return True

                                                    if self.snmpoid is not None:
                                                        return True

                                                    if self.top_assem_part_num is not None:
                                                        return True

                                                    if self.top_assem_vid is not None:
                                                        return True

                                                    if self.udi_description is not None:
                                                        return True

                                                    if self.udi_name is not None:
                                                        return True

                                                    if self.vid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.eeprom is not None and self.eeprom._has_data():
                                                    return True

                                                if self.has_eeprom is not None:
                                                    return True

                                                if self.inv_card_type is not None:
                                                    return True

                                                if self.opaque_data is not None:
                                                    return True

                                                if self.opaque_data_size is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                return True

                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                return True

                                            if self.fru_info is not None and self.fru_info._has_data():
                                                return True

                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                return True

                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                return True

                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                return True

                                            if self.module_done is not None:
                                                return True

                                            if self.node_id is not None:
                                                return True

                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                return True

                                            if self.threshold is not None and self.threshold._has_data():
                                                return True

                                            if self.vm_done is not None:
                                                return True

                                            if self.vm_node_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.name is None:
                                            raise YPYModelError('Key property name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi2[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.name is not None:
                                            return True

                                        if self.attributes is not None and self.attributes._has_data():
                                            return True

                                        if self.tsi3s is not None and self.tsi3s._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi2s'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tsi2 is not None:
                                        for child_ref in self.tsi2:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Tsi2S']['meta_info']


                            class Attributes(object):
                                """
                                Attributes
                                
                                .. attribute:: env_sensor_info
                                
                                	Environment sensor info
                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfo>`
                                
                                .. attribute:: env_sensor_info_xml
                                
                                	Environment sensor info XML
                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml>`
                                
                                .. attribute:: fru_info
                                
                                	Inventory EDM FRU info
                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.FruInfo>`
                                
                                .. attribute:: inv_asset_bag
                                
                                	Inventory Asset Bag
                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvAssetBag>`
                                
                                .. attribute:: inv_basic_bag
                                
                                	Inventory Basic Bag
                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvBasicBag>`
                                
                                .. attribute:: inv_eeprom_info
                                
                                	Inventory EDM EEPROM Information Bag
                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo>`
                                
                                .. attribute:: module_done
                                
                                	Inventory EDM Module Done Tuple
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**default value**\: 1
                                
                                .. attribute:: node_id
                                
                                	Node ID Tuple
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pwg_info
                                
                                	Inventory EDM PWG info
                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.PwgInfo>`
                                
                                .. attribute:: threshold
                                
                                	Threshold
                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold>`
                                
                                .. attribute:: vm_done
                                
                                	VM Done Tuple
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: vm_node_id
                                
                                	VM Node ID Tuple
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfo()
                                    self.env_sensor_info.parent = self
                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml()
                                    self.env_sensor_info_xml.parent = self
                                    self.fru_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.FruInfo()
                                    self.fru_info.parent = self
                                    self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvAssetBag()
                                    self.inv_asset_bag.parent = self
                                    self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvBasicBag()
                                    self.inv_basic_bag.parent = self
                                    self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo()
                                    self.inv_eeprom_info.parent = self
                                    self.module_done = None
                                    self.node_id = None
                                    self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.PwgInfo()
                                    self.pwg_info.parent = self
                                    self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold()
                                    self.threshold.parent = self
                                    self.vm_done = None
                                    self.vm_node_id = None


                                class EnvSensorInfo(object):
                                    """
                                    Environment sensor info
                                    
                                    .. attribute:: age_time_stamp
                                    
                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: alarm_type
                                    
                                    	Indicates threshold violation
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_type
                                    
                                    	Sensor data type enums
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: device_description
                                    
                                    	Device Name
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: device_id
                                    
                                    	Identifier for this device
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: field_validity_bitmap
                                    
                                    	Sensor valid bitmap
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: precision
                                    
                                    	Sensor precision range
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scale
                                    
                                    	Sensor scale enums
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status
                                    
                                    	Sensor operation state enums
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: units
                                    
                                    	Units of variable being read
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: update_rate
                                    
                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: value
                                    
                                    	Current reading of sensor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.age_time_stamp = None
                                        self.alarm_type = None
                                        self.data_type = None
                                        self.device_description = None
                                        self.device_id = None
                                        self.field_validity_bitmap = None
                                        self.precision = None
                                        self.scale = None
                                        self.status = None
                                        self.units = None
                                        self.update_rate = None
                                        self.value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.age_time_stamp is not None:
                                            return True

                                        if self.alarm_type is not None:
                                            return True

                                        if self.data_type is not None:
                                            return True

                                        if self.device_description is not None:
                                            return True

                                        if self.device_id is not None:
                                            return True

                                        if self.field_validity_bitmap is not None:
                                            return True

                                        if self.precision is not None:
                                            return True

                                        if self.scale is not None:
                                            return True

                                        if self.status is not None:
                                            return True

                                        if self.units is not None:
                                            return True

                                        if self.update_rate is not None:
                                            return True

                                        if self.value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfo']['meta_info']


                                class PwgInfo(object):
                                    """
                                    Inventory EDM PWG info
                                    
                                    .. attribute:: power_group_available_current
                                    
                                    	available current
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_group_drawn_current
                                    
                                    	drawn current
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_group_power_units
                                    
                                    	power units
                                    	**type**\:  str
                                    
                                    .. attribute:: power_group_redundancy_mode
                                    
                                    	redundancy mode
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.power_group_available_current = None
                                        self.power_group_drawn_current = None
                                        self.power_group_power_units = None
                                        self.power_group_redundancy_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.power_group_available_current is not None:
                                            return True

                                        if self.power_group_drawn_current is not None:
                                            return True

                                        if self.power_group_power_units is not None:
                                            return True

                                        if self.power_group_redundancy_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.PwgInfo']['meta_info']


                                class EnvSensorInfoXml(object):
                                    """
                                    Environment sensor info XML
                                    
                                    .. attribute:: data_type
                                    
                                    	Sensor data type
                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                    
                                    .. attribute:: description
                                    
                                    	Device Name
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: status
                                    
                                    	Sensor operation state
                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold information
                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold>`
                                    
                                    .. attribute:: units
                                    
                                    	Units of variable being read
                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                    
                                    .. attribute:: update_rate
                                    
                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: value
                                    
                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data_type = None
                                        self.description = None
                                        self.status = None
                                        self.threshold = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold()
                                        self.threshold.parent = self
                                        self.units = None
                                        self.update_rate = None
                                        self.value = None


                                    class Threshold(object):
                                        """
                                        Threshold information
                                        
                                        .. attribute:: threshold_array
                                        
                                        	Array of threshold
                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.threshold_array = YList()
                                            self.threshold_array.parent = self
                                            self.threshold_array.name = 'threshold_array'


                                        class ThresholdArray(object):
                                            """
                                            Array of threshold
                                            
                                            .. attribute:: threshold_name
                                            
                                            	Threshold name
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_name = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_name is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.threshold_array is not None:
                                                for child_ref in self.threshold_array:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data_type is not None:
                                            return True

                                        if self.description is not None:
                                            return True

                                        if self.status is not None:
                                            return True

                                        if self.threshold is not None and self.threshold._has_data():
                                            return True

                                        if self.units is not None:
                                            return True

                                        if self.update_rate is not None:
                                            return True

                                        if self.value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml']['meta_info']


                                class InvAssetBag(object):
                                    """
                                    Inventory Asset Bag
                                    
                                    .. attribute:: manufacturer_assembly_number
                                    
                                    	Manufacture Assembly number
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_assembly_revision
                                    
                                    	Manufacture assembly revision
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                    
                                    	Common Language Equipment           Identifier number
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_firmware_identifier
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_software_identifier
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: original_equipment_manufacturer_string
                                    
                                    	String containing OEM information           if applicable
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: part_number
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.manufacturer_assembly_number = None
                                        self.manufacturer_assembly_revision = None
                                        self.manufacturer_common_language_equipment_identifier = None
                                        self.manufacturer_firmware_identifier = None
                                        self.manufacturer_software_identifier = None
                                        self.original_equipment_manufacturer_string = None
                                        self.part_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.manufacturer_assembly_number is not None:
                                            return True

                                        if self.manufacturer_assembly_revision is not None:
                                            return True

                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                            return True

                                        if self.manufacturer_firmware_identifier is not None:
                                            return True

                                        if self.manufacturer_software_identifier is not None:
                                            return True

                                        if self.original_equipment_manufacturer_string is not None:
                                            return True

                                        if self.part_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvAssetBag']['meta_info']


                                class Threshold(object):
                                    """
                                    Threshold
                                    
                                    .. attribute:: critical_hi
                                    
                                    	Critical High
                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi>`
                                    
                                    .. attribute:: critical_lo
                                    
                                    	Critical Low
                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo>`
                                    
                                    .. attribute:: major_hi
                                    
                                    	Major High
                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi>`
                                    
                                    .. attribute:: major_lo
                                    
                                    	Major Low
                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo>`
                                    
                                    .. attribute:: minor_hi
                                    
                                    	Minor High
                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi>`
                                    
                                    .. attribute:: minor_lo
                                    
                                    	Minor Low
                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo>`
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi()
                                        self.critical_hi.parent = self
                                        self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo()
                                        self.critical_lo.parent = self
                                        self.major_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi()
                                        self.major_hi.parent = self
                                        self.major_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo()
                                        self.major_lo.parent = self
                                        self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi()
                                        self.minor_hi.parent = self
                                        self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo()
                                        self.minor_lo.parent = self


                                    class MajorLo(object):
                                        """
                                        Major Low
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo']['meta_info']


                                    class CriticalHi(object):
                                        """
                                        Critical High
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi']['meta_info']


                                    class MinorHi(object):
                                        """
                                        Minor High
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi']['meta_info']


                                    class MajorHi(object):
                                        """
                                        Major High
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi']['meta_info']


                                    class CriticalLo(object):
                                        """
                                        Critical Low
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo']['meta_info']


                                    class MinorLo(object):
                                        """
                                        Minor Low
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                            return True

                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                            return True

                                        if self.major_hi is not None and self.major_hi._has_data():
                                            return True

                                        if self.major_lo is not None and self.major_lo._has_data():
                                            return True

                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                            return True

                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.Threshold']['meta_info']


                                class FruInfo(object):
                                    """
                                    Inventory EDM FRU info
                                    
                                    .. attribute:: card_administrative_state
                                    
                                    	card admin state\: shutdown or not
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: card_monitor_state
                                    
                                    	card is monitored by a manager or left unmonitored
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: card_operational_state
                                    
                                    	card operation state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: card_reset_reason
                                    
                                    	card reset reason enum
                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                    
                                    .. attribute:: card_up_time
                                    
                                    	card up time
                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.FruInfo.CardUpTime>`
                                    
                                    .. attribute:: last_operational_state_change
                                    
                                    	last card oper change state
                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.FruInfo.LastOperationalStateChange>`
                                    
                                    .. attribute:: power_administrative_state
                                    
                                    	power admin state\: up or down
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_current_measurement
                                    
                                    	power current\: not implemented
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_operational_state
                                    
                                    	Power operation state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.card_administrative_state = None
                                        self.card_monitor_state = None
                                        self.card_operational_state = None
                                        self.card_reset_reason = None
                                        self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.FruInfo.CardUpTime()
                                        self.card_up_time.parent = self
                                        self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.FruInfo.LastOperationalStateChange()
                                        self.last_operational_state_change.parent = self
                                        self.power_administrative_state = None
                                        self.power_current_measurement = None
                                        self.power_operational_state = None


                                    class LastOperationalStateChange(object):
                                        """
                                        last card oper change state
                                        
                                        .. attribute:: time_in_nano_seconds
                                        
                                        	Time Value in Nano\-seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: time_in_seconds
                                        
                                        	Time Value in Seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.time_in_nano_seconds = None
                                            self.time_in_seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.time_in_nano_seconds is not None:
                                                return True

                                            if self.time_in_seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                    class CardUpTime(object):
                                        """
                                        card up time
                                        
                                        .. attribute:: time_in_nano_seconds
                                        
                                        	Time Value in Nano\-seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: time_in_seconds
                                        
                                        	Time Value in Seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.time_in_nano_seconds = None
                                            self.time_in_seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.time_in_nano_seconds is not None:
                                                return True

                                            if self.time_in_seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.FruInfo.CardUpTime']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.card_administrative_state is not None:
                                            return True

                                        if self.card_monitor_state is not None:
                                            return True

                                        if self.card_operational_state is not None:
                                            return True

                                        if self.card_reset_reason is not None:
                                            return True

                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                            return True

                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                            return True

                                        if self.power_administrative_state is not None:
                                            return True

                                        if self.power_current_measurement is not None:
                                            return True

                                        if self.power_operational_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.FruInfo']['meta_info']


                                class InvBasicBag(object):
                                    """
                                    Inventory Basic Bag
                                    
                                    .. attribute:: alias
                                    
                                    	useful for storing an entity alias 
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: asset_id_str
                                    
                                    	asset Identification string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: asset_identification
                                    
                                    	asset Identification
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ceport
                                    
                                    	1 if ce port found, 0 if not
                                    	**type**\:  bool
                                    
                                    .. attribute:: chip_hardware_revision
                                    
                                    	chip module hw revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: composite_class_code
                                    
                                    	Major&minor class of the entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: description
                                    
                                    	describes in user\-readable terms       what the entity in question does
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: environmental_monitor_path
                                    
                                    	sysdb name of sensor in the envmon EDM
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: firmware_revision
                                    
                                    	firmware revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: group_flag
                                    
                                    	indicates if this entity is group       or not
                                    	**type**\:  bool
                                    
                                    .. attribute:: hardware_revision
                                    
                                    	hw revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: is_field_replaceable_unit
                                    
                                    	1 if Field Replaceable Unit 0, if not
                                    	**type**\:  bool
                                    
                                    .. attribute:: manufacturer_asset_tags
                                    
                                    	Manufacture Asset Tags
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: manufacturer_name
                                    
                                    	manufacturer's name
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: memory_size
                                    
                                    	Size of memory associated with       the entity where applicable
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: model_name
                                    
                                    	model name
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: name
                                    
                                    	name string for the entity
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: new_deviation_number
                                    
                                    	integer value for New Deviation Number 0x88
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: physical_layer_interface_module_type
                                    
                                    	integer value for plim type if     applicable to this entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: redundancystate
                                    
                                    	integer value for Redundancy State if     applicable to this entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: serial_number
                                    
                                    	serial number
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: software_revision
                                    
                                    	software revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: unique_id
                                    
                                    	Unique id for an entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: unrecognized_fru
                                    
                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                    	**type**\:  bool
                                    
                                    .. attribute:: vendor_type
                                    
                                    	maps to the vendor OID string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: xr_scoped
                                    
                                    	1 if xr scoped, 0 if not
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.alias = None
                                        self.asset_id_str = None
                                        self.asset_identification = None
                                        self.ceport = None
                                        self.chip_hardware_revision = None
                                        self.composite_class_code = None
                                        self.description = None
                                        self.environmental_monitor_path = None
                                        self.firmware_revision = None
                                        self.group_flag = None
                                        self.hardware_revision = None
                                        self.is_field_replaceable_unit = None
                                        self.manufacturer_asset_tags = None
                                        self.manufacturer_name = None
                                        self.memory_size = None
                                        self.model_name = None
                                        self.name = None
                                        self.new_deviation_number = None
                                        self.physical_layer_interface_module_type = None
                                        self.redundancystate = None
                                        self.serial_number = None
                                        self.software_revision = None
                                        self.unique_id = None
                                        self.unrecognized_fru = None
                                        self.vendor_type = None
                                        self.xr_scoped = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.alias is not None:
                                            return True

                                        if self.asset_id_str is not None:
                                            return True

                                        if self.asset_identification is not None:
                                            return True

                                        if self.ceport is not None:
                                            return True

                                        if self.chip_hardware_revision is not None:
                                            return True

                                        if self.composite_class_code is not None:
                                            return True

                                        if self.description is not None:
                                            return True

                                        if self.environmental_monitor_path is not None:
                                            return True

                                        if self.firmware_revision is not None:
                                            return True

                                        if self.group_flag is not None:
                                            return True

                                        if self.hardware_revision is not None:
                                            return True

                                        if self.is_field_replaceable_unit is not None:
                                            return True

                                        if self.manufacturer_asset_tags is not None:
                                            return True

                                        if self.manufacturer_name is not None:
                                            return True

                                        if self.memory_size is not None:
                                            return True

                                        if self.model_name is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.new_deviation_number is not None:
                                            return True

                                        if self.physical_layer_interface_module_type is not None:
                                            return True

                                        if self.redundancystate is not None:
                                            return True

                                        if self.serial_number is not None:
                                            return True

                                        if self.software_revision is not None:
                                            return True

                                        if self.unique_id is not None:
                                            return True

                                        if self.unrecognized_fru is not None:
                                            return True

                                        if self.vendor_type is not None:
                                            return True

                                        if self.xr_scoped is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvBasicBag']['meta_info']


                                class InvEepromInfo(object):
                                    """
                                    Inventory EDM EEPROM Information Bag
                                    
                                    .. attribute:: description
                                    
                                    	A textual description of physical entity
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: eeprom
                                    
                                    	EEPROM data not from hex data
                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom>`
                                    
                                    .. attribute:: has_eeprom
                                    
                                    	use eeprom instead of opaque data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inv_card_type
                                    
                                    	Inventory card type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: opaque_data
                                    
                                    	EEPROM hex data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: opaque_data_size
                                    
                                    	size of the EEPROM hex data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.eeprom = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom()
                                        self.eeprom.parent = self
                                        self.has_eeprom = None
                                        self.inv_card_type = None
                                        self.opaque_data = None
                                        self.opaque_data_size = None


                                    class Eeprom(object):
                                        """
                                        EEPROM data not from hex data
                                        
                                        .. attribute:: asset_alias
                                        
                                        	Asset Alias
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: asset_id
                                        
                                        	Asset ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address1
                                        
                                        	Base Mac Address #1
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address2
                                        
                                        	Base Mac Address #2
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address3
                                        
                                        	Base Mac Address #3
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address4
                                        
                                        	Base Mac Address #4
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_checksum
                                        
                                        	Block Checksum
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_count
                                        
                                        	Block Count
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_length
                                        
                                        	Block Length
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_signature
                                        
                                        	Block Signature
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_version
                                        
                                        	Block Version
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: chassis_sid
                                        
                                        	Chassis serial number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: clei
                                        
                                        	Common Language Equipment Identifier (CLEI) code
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: controller_family
                                        
                                        	Controller family
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: controller_type
                                        
                                        	Controller type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: description
                                        
                                        	A textual description of physical entity
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num1
                                        
                                        	Deviation Number # 1
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num2
                                        
                                        	Deviation Number # 2
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num3
                                        
                                        	Deviation Number # 3
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num4
                                        
                                        	Deviation Number # 4
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num5
                                        
                                        	Deviation Number # 5
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num6
                                        
                                        	Deviation Number # 6
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num7
                                        
                                        	Deviation Number # 7
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: eci
                                        
                                        	Equipment Catalog Item (ECI) number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: eeprom_size
                                        
                                        	EEPROM Size
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: engineer_use
                                        
                                        	Engineer Use
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: fru_major_type
                                        
                                        	FRU Major Type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: fru_minor_type
                                        
                                        	FRU Minor Type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: hw_version
                                        
                                        	Hardware Version
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: hwid
                                        
                                        	Hardware Revision
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: idprom_format_rev
                                        
                                        	IDPROM Format Revision
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size1
                                        
                                        	Mac Address Block Size #1
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size2
                                        
                                        	Mac Address Block Size #2
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size3
                                        
                                        	Mac Address Block Size #3
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size4
                                        
                                        	Mac Address Block Size #4
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: manu_test_data
                                        
                                        	Manufacturing Test Data
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mfg_bits
                                        
                                        	MFG Bits
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mfg_deviation
                                        
                                        	MFG Deviation
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: oem_string
                                        
                                        	OEM String
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: part_number
                                        
                                        	Part Number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: part_revision
                                        
                                        	Part Revision
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pca_num
                                        
                                        	PCA number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pcavid
                                        
                                        	PCA revision ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pcb_serial_num
                                        
                                        	PCB Serial Number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pid
                                        
                                        	Product ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: power_consumption
                                        
                                        	Power Consumption
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: power_supply_type
                                        
                                        	Power Supply Type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: product_id
                                        
                                        	Product ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: rma
                                        
                                        	RMA Data
                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom.Rma>`
                                        
                                        .. attribute:: rma_code
                                        
                                        	RMA Code
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: serial_number
                                        
                                        	Serial Number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: snmpoid
                                        
                                        	SNMP OID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: top_assem_part_num
                                        
                                        	Top assembly part number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: top_assem_vid
                                        
                                        	Top assembly revision number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: udi_description
                                        
                                        	UDI description
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: udi_name
                                        
                                        	UDI name
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: vid
                                        
                                        	Version ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asset_alias = None
                                            self.asset_id = None
                                            self.base_mac_address1 = None
                                            self.base_mac_address2 = None
                                            self.base_mac_address3 = None
                                            self.base_mac_address4 = None
                                            self.block_checksum = None
                                            self.block_count = None
                                            self.block_length = None
                                            self.block_signature = None
                                            self.block_version = None
                                            self.chassis_sid = None
                                            self.clei = None
                                            self.controller_family = None
                                            self.controller_type = None
                                            self.description = None
                                            self.dev_num1 = None
                                            self.dev_num2 = None
                                            self.dev_num3 = None
                                            self.dev_num4 = None
                                            self.dev_num5 = None
                                            self.dev_num6 = None
                                            self.dev_num7 = None
                                            self.eci = None
                                            self.eeprom_size = None
                                            self.engineer_use = None
                                            self.fru_major_type = None
                                            self.fru_minor_type = None
                                            self.hw_version = None
                                            self.hwid = None
                                            self.idprom_format_rev = None
                                            self.mac_add_blk_size1 = None
                                            self.mac_add_blk_size2 = None
                                            self.mac_add_blk_size3 = None
                                            self.mac_add_blk_size4 = None
                                            self.manu_test_data = None
                                            self.mfg_bits = None
                                            self.mfg_deviation = None
                                            self.oem_string = None
                                            self.part_number = None
                                            self.part_revision = None
                                            self.pca_num = None
                                            self.pcavid = None
                                            self.pcb_serial_num = None
                                            self.pid = None
                                            self.power_consumption = None
                                            self.power_supply_type = None
                                            self.product_id = None
                                            self.rma = Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom.Rma()
                                            self.rma.parent = self
                                            self.rma_code = None
                                            self.serial_number = None
                                            self.snmpoid = None
                                            self.top_assem_part_num = None
                                            self.top_assem_vid = None
                                            self.udi_description = None
                                            self.udi_name = None
                                            self.vid = None


                                        class Rma(object):
                                            """
                                            RMA Data
                                            
                                            .. attribute:: rma_history
                                            
                                            	RMA history
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: rma_number
                                            
                                            	RMA tracking number format is N\-N\-N
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: test_history
                                            
                                            	Test history
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.rma_history = None
                                                self.rma_number = None
                                                self.test_history = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rma_history is not None:
                                                    return True

                                                if self.rma_number is not None:
                                                    return True

                                                if self.test_history is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asset_alias is not None:
                                                return True

                                            if self.asset_id is not None:
                                                return True

                                            if self.base_mac_address1 is not None:
                                                return True

                                            if self.base_mac_address2 is not None:
                                                return True

                                            if self.base_mac_address3 is not None:
                                                return True

                                            if self.base_mac_address4 is not None:
                                                return True

                                            if self.block_checksum is not None:
                                                return True

                                            if self.block_count is not None:
                                                return True

                                            if self.block_length is not None:
                                                return True

                                            if self.block_signature is not None:
                                                return True

                                            if self.block_version is not None:
                                                return True

                                            if self.chassis_sid is not None:
                                                return True

                                            if self.clei is not None:
                                                return True

                                            if self.controller_family is not None:
                                                return True

                                            if self.controller_type is not None:
                                                return True

                                            if self.description is not None:
                                                return True

                                            if self.dev_num1 is not None:
                                                return True

                                            if self.dev_num2 is not None:
                                                return True

                                            if self.dev_num3 is not None:
                                                return True

                                            if self.dev_num4 is not None:
                                                return True

                                            if self.dev_num5 is not None:
                                                return True

                                            if self.dev_num6 is not None:
                                                return True

                                            if self.dev_num7 is not None:
                                                return True

                                            if self.eci is not None:
                                                return True

                                            if self.eeprom_size is not None:
                                                return True

                                            if self.engineer_use is not None:
                                                return True

                                            if self.fru_major_type is not None:
                                                return True

                                            if self.fru_minor_type is not None:
                                                return True

                                            if self.hw_version is not None:
                                                return True

                                            if self.hwid is not None:
                                                return True

                                            if self.idprom_format_rev is not None:
                                                return True

                                            if self.mac_add_blk_size1 is not None:
                                                return True

                                            if self.mac_add_blk_size2 is not None:
                                                return True

                                            if self.mac_add_blk_size3 is not None:
                                                return True

                                            if self.mac_add_blk_size4 is not None:
                                                return True

                                            if self.manu_test_data is not None:
                                                return True

                                            if self.mfg_bits is not None:
                                                return True

                                            if self.mfg_deviation is not None:
                                                return True

                                            if self.oem_string is not None:
                                                return True

                                            if self.part_number is not None:
                                                return True

                                            if self.part_revision is not None:
                                                return True

                                            if self.pca_num is not None:
                                                return True

                                            if self.pcavid is not None:
                                                return True

                                            if self.pcb_serial_num is not None:
                                                return True

                                            if self.pid is not None:
                                                return True

                                            if self.power_consumption is not None:
                                                return True

                                            if self.power_supply_type is not None:
                                                return True

                                            if self.product_id is not None:
                                                return True

                                            if self.rma is not None and self.rma._has_data():
                                                return True

                                            if self.rma_code is not None:
                                                return True

                                            if self.serial_number is not None:
                                                return True

                                            if self.snmpoid is not None:
                                                return True

                                            if self.top_assem_part_num is not None:
                                                return True

                                            if self.top_assem_vid is not None:
                                                return True

                                            if self.udi_description is not None:
                                                return True

                                            if self.udi_name is not None:
                                                return True

                                            if self.vid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.eeprom is not None and self.eeprom._has_data():
                                            return True

                                        if self.has_eeprom is not None:
                                            return True

                                        if self.inv_card_type is not None:
                                            return True

                                        if self.opaque_data is not None:
                                            return True

                                        if self.opaque_data_size is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                        return True

                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                        return True

                                    if self.fru_info is not None and self.fru_info._has_data():
                                        return True

                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                        return True

                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                        return True

                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                        return True

                                    if self.module_done is not None:
                                        return True

                                    if self.node_id is not None:
                                        return True

                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                        return True

                                    if self.threshold is not None and self.threshold._has_data():
                                        return True

                                    if self.vm_done is not None:
                                        return True

                                    if self.vm_node_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1.Attributes']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.name is None:
                                    raise YPYModelError('Key property name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi1[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.name is not None:
                                    return True

                                if self.attributes is not None and self.attributes._has_data():
                                    return True

                                if self.tsi2s is not None and self.tsi2s._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S.Tsi1']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi1s'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tsi1 is not None:
                                for child_ref in self.tsi1:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Tsi1S']['meta_info']


                    class Attributes(object):
                        """
                        Attributes
                        
                        .. attribute:: env_sensor_info
                        
                        	Environment sensor info
                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfo>`
                        
                        .. attribute:: env_sensor_info_xml
                        
                        	Environment sensor info XML
                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfoXml>`
                        
                        .. attribute:: fru_info
                        
                        	Inventory EDM FRU info
                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.FruInfo>`
                        
                        .. attribute:: inv_asset_bag
                        
                        	Inventory Asset Bag
                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.InvAssetBag>`
                        
                        .. attribute:: inv_basic_bag
                        
                        	Inventory Basic Bag
                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.InvBasicBag>`
                        
                        .. attribute:: inv_eeprom_info
                        
                        	Inventory EDM EEPROM Information Bag
                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.InvEepromInfo>`
                        
                        .. attribute:: module_done
                        
                        	Inventory EDM Module Done Tuple
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**default value**\: 1
                        
                        .. attribute:: node_id
                        
                        	Node ID Tuple
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwg_info
                        
                        	Inventory EDM PWG info
                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.PwgInfo>`
                        
                        .. attribute:: threshold
                        
                        	Threshold
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold>`
                        
                        .. attribute:: vm_done
                        
                        	VM Done Tuple
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: vm_node_id
                        
                        	VM Node ID Tuple
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.env_sensor_info = Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfo()
                            self.env_sensor_info.parent = self
                            self.env_sensor_info_xml = Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfoXml()
                            self.env_sensor_info_xml.parent = self
                            self.fru_info = Inventory.Racks.Rack.Entity.Slot.Attributes.FruInfo()
                            self.fru_info.parent = self
                            self.inv_asset_bag = Inventory.Racks.Rack.Entity.Slot.Attributes.InvAssetBag()
                            self.inv_asset_bag.parent = self
                            self.inv_basic_bag = Inventory.Racks.Rack.Entity.Slot.Attributes.InvBasicBag()
                            self.inv_basic_bag.parent = self
                            self.inv_eeprom_info = Inventory.Racks.Rack.Entity.Slot.Attributes.InvEepromInfo()
                            self.inv_eeprom_info.parent = self
                            self.module_done = None
                            self.node_id = None
                            self.pwg_info = Inventory.Racks.Rack.Entity.Slot.Attributes.PwgInfo()
                            self.pwg_info.parent = self
                            self.threshold = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold()
                            self.threshold.parent = self
                            self.vm_done = None
                            self.vm_node_id = None


                        class EnvSensorInfo(object):
                            """
                            Environment sensor info
                            
                            .. attribute:: age_time_stamp
                            
                            	Age of the sensor value; set to the current time if directly access the value from sensor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: alarm_type
                            
                            	Indicates threshold violation
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: data_type
                            
                            	Sensor data type enums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: device_description
                            
                            	Device Name
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: device_id
                            
                            	Identifier for this device
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: field_validity_bitmap
                            
                            	Sensor valid bitmap
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: precision
                            
                            	Sensor precision range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: scale
                            
                            	Sensor scale enums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status
                            
                            	Sensor operation state enums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: units
                            
                            	Units of variable being read
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: update_rate
                            
                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: value
                            
                            	Current reading of sensor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.age_time_stamp = None
                                self.alarm_type = None
                                self.data_type = None
                                self.device_description = None
                                self.device_id = None
                                self.field_validity_bitmap = None
                                self.precision = None
                                self.scale = None
                                self.status = None
                                self.units = None
                                self.update_rate = None
                                self.value = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.age_time_stamp is not None:
                                    return True

                                if self.alarm_type is not None:
                                    return True

                                if self.data_type is not None:
                                    return True

                                if self.device_description is not None:
                                    return True

                                if self.device_id is not None:
                                    return True

                                if self.field_validity_bitmap is not None:
                                    return True

                                if self.precision is not None:
                                    return True

                                if self.scale is not None:
                                    return True

                                if self.status is not None:
                                    return True

                                if self.units is not None:
                                    return True

                                if self.update_rate is not None:
                                    return True

                                if self.value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfo']['meta_info']


                        class PwgInfo(object):
                            """
                            Inventory EDM PWG info
                            
                            .. attribute:: power_group_available_current
                            
                            	available current
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_group_drawn_current
                            
                            	drawn current
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_group_power_units
                            
                            	power units
                            	**type**\:  str
                            
                            .. attribute:: power_group_redundancy_mode
                            
                            	redundancy mode
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.power_group_available_current = None
                                self.power_group_drawn_current = None
                                self.power_group_power_units = None
                                self.power_group_redundancy_mode = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.power_group_available_current is not None:
                                    return True

                                if self.power_group_drawn_current is not None:
                                    return True

                                if self.power_group_power_units is not None:
                                    return True

                                if self.power_group_redundancy_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.PwgInfo']['meta_info']


                        class EnvSensorInfoXml(object):
                            """
                            Environment sensor info XML
                            
                            .. attribute:: data_type
                            
                            	Sensor data type
                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                            
                            .. attribute:: description
                            
                            	Device Name
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: status
                            
                            	Sensor operation state
                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                            
                            .. attribute:: threshold
                            
                            	Threshold information
                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfoXml.Threshold>`
                            
                            .. attribute:: units
                            
                            	Units of variable being read
                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                            
                            .. attribute:: update_rate
                            
                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: value
                            
                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.data_type = None
                                self.description = None
                                self.status = None
                                self.threshold = Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfoXml.Threshold()
                                self.threshold.parent = self
                                self.units = None
                                self.update_rate = None
                                self.value = None


                            class Threshold(object):
                                """
                                Threshold information
                                
                                .. attribute:: threshold_array
                                
                                	Array of threshold
                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.threshold_array = YList()
                                    self.threshold_array.parent = self
                                    self.threshold_array.name = 'threshold_array'


                                class ThresholdArray(object):
                                    """
                                    Array of threshold
                                    
                                    .. attribute:: threshold_name
                                    
                                    	Threshold name
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_name = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_name is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.threshold_array is not None:
                                        for child_ref in self.threshold_array:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.data_type is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.status is not None:
                                    return True

                                if self.threshold is not None and self.threshold._has_data():
                                    return True

                                if self.units is not None:
                                    return True

                                if self.update_rate is not None:
                                    return True

                                if self.value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.EnvSensorInfoXml']['meta_info']


                        class InvAssetBag(object):
                            """
                            Inventory Asset Bag
                            
                            .. attribute:: manufacturer_assembly_number
                            
                            	Manufacture Assembly number
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_assembly_revision
                            
                            	Manufacture assembly revision
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_common_language_equipment_identifier
                            
                            	Common Language Equipment           Identifier number
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_firmware_identifier
                            
                            	
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_software_identifier
                            
                            	
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: original_equipment_manufacturer_string
                            
                            	String containing OEM information           if applicable
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: part_number
                            
                            	
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.manufacturer_assembly_number = None
                                self.manufacturer_assembly_revision = None
                                self.manufacturer_common_language_equipment_identifier = None
                                self.manufacturer_firmware_identifier = None
                                self.manufacturer_software_identifier = None
                                self.original_equipment_manufacturer_string = None
                                self.part_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.manufacturer_assembly_number is not None:
                                    return True

                                if self.manufacturer_assembly_revision is not None:
                                    return True

                                if self.manufacturer_common_language_equipment_identifier is not None:
                                    return True

                                if self.manufacturer_firmware_identifier is not None:
                                    return True

                                if self.manufacturer_software_identifier is not None:
                                    return True

                                if self.original_equipment_manufacturer_string is not None:
                                    return True

                                if self.part_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.InvAssetBag']['meta_info']


                        class Threshold(object):
                            """
                            Threshold
                            
                            .. attribute:: critical_hi
                            
                            	Critical High
                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalHi>`
                            
                            .. attribute:: critical_lo
                            
                            	Critical Low
                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalLo>`
                            
                            .. attribute:: major_hi
                            
                            	Major High
                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorHi>`
                            
                            .. attribute:: major_lo
                            
                            	Major Low
                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorLo>`
                            
                            .. attribute:: minor_hi
                            
                            	Minor High
                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorHi>`
                            
                            .. attribute:: minor_lo
                            
                            	Minor Low
                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorLo>`
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.critical_hi = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalHi()
                                self.critical_hi.parent = self
                                self.critical_lo = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalLo()
                                self.critical_lo.parent = self
                                self.major_hi = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorHi()
                                self.major_hi.parent = self
                                self.major_lo = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorLo()
                                self.major_lo.parent = self
                                self.minor_hi = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorHi()
                                self.minor_hi.parent = self
                                self.minor_lo = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorLo()
                                self.minor_lo.parent = self


                            class MajorLo(object):
                                """
                                Major Low
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorLo.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorLo.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorLo']['meta_info']


                            class CriticalHi(object):
                                """
                                Critical High
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalHi.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalHi.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalHi']['meta_info']


                            class MinorHi(object):
                                """
                                Minor High
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorHi.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorHi.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorHi']['meta_info']


                            class MajorHi(object):
                                """
                                Major High
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorHi.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorHi.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MajorHi']['meta_info']


                            class CriticalLo(object):
                                """
                                Critical Low
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalLo.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalLo.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.CriticalLo']['meta_info']


                            class MinorLo(object):
                                """
                                Minor Low
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorLo.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorLo.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold.MinorLo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.critical_hi is not None and self.critical_hi._has_data():
                                    return True

                                if self.critical_lo is not None and self.critical_lo._has_data():
                                    return True

                                if self.major_hi is not None and self.major_hi._has_data():
                                    return True

                                if self.major_lo is not None and self.major_lo._has_data():
                                    return True

                                if self.minor_hi is not None and self.minor_hi._has_data():
                                    return True

                                if self.minor_lo is not None and self.minor_lo._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.Threshold']['meta_info']


                        class FruInfo(object):
                            """
                            Inventory EDM FRU info
                            
                            .. attribute:: card_administrative_state
                            
                            	card admin state\: shutdown or not
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: card_monitor_state
                            
                            	card is monitored by a manager or left unmonitored
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: card_operational_state
                            
                            	card operation state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: card_reset_reason
                            
                            	card reset reason enum
                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                            
                            .. attribute:: card_up_time
                            
                            	card up time
                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.FruInfo.CardUpTime>`
                            
                            .. attribute:: last_operational_state_change
                            
                            	last card oper change state
                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.FruInfo.LastOperationalStateChange>`
                            
                            .. attribute:: power_administrative_state
                            
                            	power admin state\: up or down
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_current_measurement
                            
                            	power current\: not implemented
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_operational_state
                            
                            	Power operation state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.card_administrative_state = None
                                self.card_monitor_state = None
                                self.card_operational_state = None
                                self.card_reset_reason = None
                                self.card_up_time = Inventory.Racks.Rack.Entity.Slot.Attributes.FruInfo.CardUpTime()
                                self.card_up_time.parent = self
                                self.last_operational_state_change = Inventory.Racks.Rack.Entity.Slot.Attributes.FruInfo.LastOperationalStateChange()
                                self.last_operational_state_change.parent = self
                                self.power_administrative_state = None
                                self.power_current_measurement = None
                                self.power_operational_state = None


                            class LastOperationalStateChange(object):
                                """
                                last card oper change state
                                
                                .. attribute:: time_in_nano_seconds
                                
                                	Time Value in Nano\-seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: time_in_seconds
                                
                                	Time Value in Seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.time_in_nano_seconds = None
                                    self.time_in_seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.time_in_nano_seconds is not None:
                                        return True

                                    if self.time_in_seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                            class CardUpTime(object):
                                """
                                card up time
                                
                                .. attribute:: time_in_nano_seconds
                                
                                	Time Value in Nano\-seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: time_in_seconds
                                
                                	Time Value in Seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.time_in_nano_seconds = None
                                    self.time_in_seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.time_in_nano_seconds is not None:
                                        return True

                                    if self.time_in_seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.FruInfo.CardUpTime']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.card_administrative_state is not None:
                                    return True

                                if self.card_monitor_state is not None:
                                    return True

                                if self.card_operational_state is not None:
                                    return True

                                if self.card_reset_reason is not None:
                                    return True

                                if self.card_up_time is not None and self.card_up_time._has_data():
                                    return True

                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                    return True

                                if self.power_administrative_state is not None:
                                    return True

                                if self.power_current_measurement is not None:
                                    return True

                                if self.power_operational_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.FruInfo']['meta_info']


                        class InvBasicBag(object):
                            """
                            Inventory Basic Bag
                            
                            .. attribute:: alias
                            
                            	useful for storing an entity alias 
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: asset_id_str
                            
                            	asset Identification string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: asset_identification
                            
                            	asset Identification
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ceport
                            
                            	1 if ce port found, 0 if not
                            	**type**\:  bool
                            
                            .. attribute:: chip_hardware_revision
                            
                            	chip module hw revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: composite_class_code
                            
                            	Major&minor class of the entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: description
                            
                            	describes in user\-readable terms       what the entity in question does
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: environmental_monitor_path
                            
                            	sysdb name of sensor in the envmon EDM
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: firmware_revision
                            
                            	firmware revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: group_flag
                            
                            	indicates if this entity is group       or not
                            	**type**\:  bool
                            
                            .. attribute:: hardware_revision
                            
                            	hw revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: is_field_replaceable_unit
                            
                            	1 if Field Replaceable Unit 0, if not
                            	**type**\:  bool
                            
                            .. attribute:: manufacturer_asset_tags
                            
                            	Manufacture Asset Tags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: manufacturer_name
                            
                            	manufacturer's name
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: memory_size
                            
                            	Size of memory associated with       the entity where applicable
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: model_name
                            
                            	model name
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: name
                            
                            	name string for the entity
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: new_deviation_number
                            
                            	integer value for New Deviation Number 0x88
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: physical_layer_interface_module_type
                            
                            	integer value for plim type if     applicable to this entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: redundancystate
                            
                            	integer value for Redundancy State if     applicable to this entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: serial_number
                            
                            	serial number
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: software_revision
                            
                            	software revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: unique_id
                            
                            	Unique id for an entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: unrecognized_fru
                            
                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                            	**type**\:  bool
                            
                            .. attribute:: vendor_type
                            
                            	maps to the vendor OID string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: xr_scoped
                            
                            	1 if xr scoped, 0 if not
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.alias = None
                                self.asset_id_str = None
                                self.asset_identification = None
                                self.ceport = None
                                self.chip_hardware_revision = None
                                self.composite_class_code = None
                                self.description = None
                                self.environmental_monitor_path = None
                                self.firmware_revision = None
                                self.group_flag = None
                                self.hardware_revision = None
                                self.is_field_replaceable_unit = None
                                self.manufacturer_asset_tags = None
                                self.manufacturer_name = None
                                self.memory_size = None
                                self.model_name = None
                                self.name = None
                                self.new_deviation_number = None
                                self.physical_layer_interface_module_type = None
                                self.redundancystate = None
                                self.serial_number = None
                                self.software_revision = None
                                self.unique_id = None
                                self.unrecognized_fru = None
                                self.vendor_type = None
                                self.xr_scoped = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.alias is not None:
                                    return True

                                if self.asset_id_str is not None:
                                    return True

                                if self.asset_identification is not None:
                                    return True

                                if self.ceport is not None:
                                    return True

                                if self.chip_hardware_revision is not None:
                                    return True

                                if self.composite_class_code is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.environmental_monitor_path is not None:
                                    return True

                                if self.firmware_revision is not None:
                                    return True

                                if self.group_flag is not None:
                                    return True

                                if self.hardware_revision is not None:
                                    return True

                                if self.is_field_replaceable_unit is not None:
                                    return True

                                if self.manufacturer_asset_tags is not None:
                                    return True

                                if self.manufacturer_name is not None:
                                    return True

                                if self.memory_size is not None:
                                    return True

                                if self.model_name is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.new_deviation_number is not None:
                                    return True

                                if self.physical_layer_interface_module_type is not None:
                                    return True

                                if self.redundancystate is not None:
                                    return True

                                if self.serial_number is not None:
                                    return True

                                if self.software_revision is not None:
                                    return True

                                if self.unique_id is not None:
                                    return True

                                if self.unrecognized_fru is not None:
                                    return True

                                if self.vendor_type is not None:
                                    return True

                                if self.xr_scoped is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.InvBasicBag']['meta_info']


                        class InvEepromInfo(object):
                            """
                            Inventory EDM EEPROM Information Bag
                            
                            .. attribute:: description
                            
                            	A textual description of physical entity
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: eeprom
                            
                            	EEPROM data not from hex data
                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.InvEepromInfo.Eeprom>`
                            
                            .. attribute:: has_eeprom
                            
                            	use eeprom instead of opaque data
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inv_card_type
                            
                            	Inventory card type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: opaque_data
                            
                            	EEPROM hex data
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: opaque_data_size
                            
                            	size of the EEPROM hex data
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.eeprom = Inventory.Racks.Rack.Entity.Slot.Attributes.InvEepromInfo.Eeprom()
                                self.eeprom.parent = self
                                self.has_eeprom = None
                                self.inv_card_type = None
                                self.opaque_data = None
                                self.opaque_data_size = None


                            class Eeprom(object):
                                """
                                EEPROM data not from hex data
                                
                                .. attribute:: asset_alias
                                
                                	Asset Alias
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: asset_id
                                
                                	Asset ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address1
                                
                                	Base Mac Address #1
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address2
                                
                                	Base Mac Address #2
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address3
                                
                                	Base Mac Address #3
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address4
                                
                                	Base Mac Address #4
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_checksum
                                
                                	Block Checksum
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_count
                                
                                	Block Count
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_length
                                
                                	Block Length
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_signature
                                
                                	Block Signature
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_version
                                
                                	Block Version
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: chassis_sid
                                
                                	Chassis serial number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: clei
                                
                                	Common Language Equipment Identifier (CLEI) code
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: controller_family
                                
                                	Controller family
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: controller_type
                                
                                	Controller type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: description
                                
                                	A textual description of physical entity
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num1
                                
                                	Deviation Number # 1
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num2
                                
                                	Deviation Number # 2
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num3
                                
                                	Deviation Number # 3
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num4
                                
                                	Deviation Number # 4
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num5
                                
                                	Deviation Number # 5
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num6
                                
                                	Deviation Number # 6
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num7
                                
                                	Deviation Number # 7
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: eci
                                
                                	Equipment Catalog Item (ECI) number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: eeprom_size
                                
                                	EEPROM Size
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: engineer_use
                                
                                	Engineer Use
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: fru_major_type
                                
                                	FRU Major Type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: fru_minor_type
                                
                                	FRU Minor Type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: hw_version
                                
                                	Hardware Version
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: hwid
                                
                                	Hardware Revision
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: idprom_format_rev
                                
                                	IDPROM Format Revision
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size1
                                
                                	Mac Address Block Size #1
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size2
                                
                                	Mac Address Block Size #2
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size3
                                
                                	Mac Address Block Size #3
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size4
                                
                                	Mac Address Block Size #4
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: manu_test_data
                                
                                	Manufacturing Test Data
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mfg_bits
                                
                                	MFG Bits
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mfg_deviation
                                
                                	MFG Deviation
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: oem_string
                                
                                	OEM String
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: part_number
                                
                                	Part Number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: part_revision
                                
                                	Part Revision
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pca_num
                                
                                	PCA number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pcavid
                                
                                	PCA revision ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pcb_serial_num
                                
                                	PCB Serial Number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pid
                                
                                	Product ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: power_consumption
                                
                                	Power Consumption
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: power_supply_type
                                
                                	Power Supply Type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: product_id
                                
                                	Product ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: rma
                                
                                	RMA Data
                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Entity.Slot.Attributes.InvEepromInfo.Eeprom.Rma>`
                                
                                .. attribute:: rma_code
                                
                                	RMA Code
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: serial_number
                                
                                	Serial Number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: snmpoid
                                
                                	SNMP OID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: top_assem_part_num
                                
                                	Top assembly part number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: top_assem_vid
                                
                                	Top assembly revision number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: udi_description
                                
                                	UDI description
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: udi_name
                                
                                	UDI name
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: vid
                                
                                	Version ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.asset_alias = None
                                    self.asset_id = None
                                    self.base_mac_address1 = None
                                    self.base_mac_address2 = None
                                    self.base_mac_address3 = None
                                    self.base_mac_address4 = None
                                    self.block_checksum = None
                                    self.block_count = None
                                    self.block_length = None
                                    self.block_signature = None
                                    self.block_version = None
                                    self.chassis_sid = None
                                    self.clei = None
                                    self.controller_family = None
                                    self.controller_type = None
                                    self.description = None
                                    self.dev_num1 = None
                                    self.dev_num2 = None
                                    self.dev_num3 = None
                                    self.dev_num4 = None
                                    self.dev_num5 = None
                                    self.dev_num6 = None
                                    self.dev_num7 = None
                                    self.eci = None
                                    self.eeprom_size = None
                                    self.engineer_use = None
                                    self.fru_major_type = None
                                    self.fru_minor_type = None
                                    self.hw_version = None
                                    self.hwid = None
                                    self.idprom_format_rev = None
                                    self.mac_add_blk_size1 = None
                                    self.mac_add_blk_size2 = None
                                    self.mac_add_blk_size3 = None
                                    self.mac_add_blk_size4 = None
                                    self.manu_test_data = None
                                    self.mfg_bits = None
                                    self.mfg_deviation = None
                                    self.oem_string = None
                                    self.part_number = None
                                    self.part_revision = None
                                    self.pca_num = None
                                    self.pcavid = None
                                    self.pcb_serial_num = None
                                    self.pid = None
                                    self.power_consumption = None
                                    self.power_supply_type = None
                                    self.product_id = None
                                    self.rma = Inventory.Racks.Rack.Entity.Slot.Attributes.InvEepromInfo.Eeprom.Rma()
                                    self.rma.parent = self
                                    self.rma_code = None
                                    self.serial_number = None
                                    self.snmpoid = None
                                    self.top_assem_part_num = None
                                    self.top_assem_vid = None
                                    self.udi_description = None
                                    self.udi_name = None
                                    self.vid = None


                                class Rma(object):
                                    """
                                    RMA Data
                                    
                                    .. attribute:: rma_history
                                    
                                    	RMA history
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: rma_number
                                    
                                    	RMA tracking number format is N\-N\-N
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: test_history
                                    
                                    	Test history
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.rma_history = None
                                        self.rma_number = None
                                        self.test_history = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rma_history is not None:
                                            return True

                                        if self.rma_number is not None:
                                            return True

                                        if self.test_history is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.asset_alias is not None:
                                        return True

                                    if self.asset_id is not None:
                                        return True

                                    if self.base_mac_address1 is not None:
                                        return True

                                    if self.base_mac_address2 is not None:
                                        return True

                                    if self.base_mac_address3 is not None:
                                        return True

                                    if self.base_mac_address4 is not None:
                                        return True

                                    if self.block_checksum is not None:
                                        return True

                                    if self.block_count is not None:
                                        return True

                                    if self.block_length is not None:
                                        return True

                                    if self.block_signature is not None:
                                        return True

                                    if self.block_version is not None:
                                        return True

                                    if self.chassis_sid is not None:
                                        return True

                                    if self.clei is not None:
                                        return True

                                    if self.controller_family is not None:
                                        return True

                                    if self.controller_type is not None:
                                        return True

                                    if self.description is not None:
                                        return True

                                    if self.dev_num1 is not None:
                                        return True

                                    if self.dev_num2 is not None:
                                        return True

                                    if self.dev_num3 is not None:
                                        return True

                                    if self.dev_num4 is not None:
                                        return True

                                    if self.dev_num5 is not None:
                                        return True

                                    if self.dev_num6 is not None:
                                        return True

                                    if self.dev_num7 is not None:
                                        return True

                                    if self.eci is not None:
                                        return True

                                    if self.eeprom_size is not None:
                                        return True

                                    if self.engineer_use is not None:
                                        return True

                                    if self.fru_major_type is not None:
                                        return True

                                    if self.fru_minor_type is not None:
                                        return True

                                    if self.hw_version is not None:
                                        return True

                                    if self.hwid is not None:
                                        return True

                                    if self.idprom_format_rev is not None:
                                        return True

                                    if self.mac_add_blk_size1 is not None:
                                        return True

                                    if self.mac_add_blk_size2 is not None:
                                        return True

                                    if self.mac_add_blk_size3 is not None:
                                        return True

                                    if self.mac_add_blk_size4 is not None:
                                        return True

                                    if self.manu_test_data is not None:
                                        return True

                                    if self.mfg_bits is not None:
                                        return True

                                    if self.mfg_deviation is not None:
                                        return True

                                    if self.oem_string is not None:
                                        return True

                                    if self.part_number is not None:
                                        return True

                                    if self.part_revision is not None:
                                        return True

                                    if self.pca_num is not None:
                                        return True

                                    if self.pcavid is not None:
                                        return True

                                    if self.pcb_serial_num is not None:
                                        return True

                                    if self.pid is not None:
                                        return True

                                    if self.power_consumption is not None:
                                        return True

                                    if self.power_supply_type is not None:
                                        return True

                                    if self.product_id is not None:
                                        return True

                                    if self.rma is not None and self.rma._has_data():
                                        return True

                                    if self.rma_code is not None:
                                        return True

                                    if self.serial_number is not None:
                                        return True

                                    if self.snmpoid is not None:
                                        return True

                                    if self.top_assem_part_num is not None:
                                        return True

                                    if self.top_assem_vid is not None:
                                        return True

                                    if self.udi_description is not None:
                                        return True

                                    if self.udi_name is not None:
                                        return True

                                    if self.vid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.InvEepromInfo.Eeprom']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.eeprom is not None and self.eeprom._has_data():
                                    return True

                                if self.has_eeprom is not None:
                                    return True

                                if self.inv_card_type is not None:
                                    return True

                                if self.opaque_data is not None:
                                    return True

                                if self.opaque_data_size is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes.InvEepromInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                return True

                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                return True

                            if self.fru_info is not None and self.fru_info._has_data():
                                return True

                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                return True

                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                return True

                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                return True

                            if self.module_done is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.pwg_info is not None and self.pwg_info._has_data():
                                return True

                            if self.threshold is not None and self.threshold._has_data():
                                return True

                            if self.vm_done is not None:
                                return True

                            if self.vm_node_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Entity.Slot.Attributes']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.name is None:
                            raise YPYModelError('Key property name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:slot[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.name is not None:
                            return True

                        if self.attributes is not None and self.attributes._has_data():
                            return True

                        if self.tsi1s is not None and self.tsi1s._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Entity.Slot']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:entity'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.slot is not None:
                        for child_ref in self.slot:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                    return meta._meta_table['Inventory.Racks.Rack.Entity']['meta_info']


            class Powershelf(object):
                """
                Powershelf information
                
                .. attribute:: slot
                
                	Slot number
                	**type**\: list of    :py:class:`Slot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot>`
                
                

                """

                _prefix = 'invmgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.slot = YList()
                    self.slot.parent = self
                    self.slot.name = 'slot'


                class Slot(object):
                    """
                    Slot number
                    
                    .. attribute:: name  <key>
                    
                    	Slot name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: attributes
                    
                    	Attributes
                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes>`
                    
                    .. attribute:: tsi1s
                    
                    	Entity Level 1
                    	**type**\:   :py:class:`Tsi1S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S>`
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.name = None
                        self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Attributes()
                        self.attributes.parent = self
                        self.tsi1s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S()
                        self.tsi1s.parent = self


                    class Tsi1S(object):
                        """
                        Entity Level 1
                        
                        .. attribute:: tsi1
                        
                        	TSI1
                        	**type**\: list of    :py:class:`Tsi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1>`
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tsi1 = YList()
                            self.tsi1.parent = self
                            self.tsi1.name = 'tsi1'


                        class Tsi1(object):
                            """
                            TSI1
                            
                            .. attribute:: name  <key>
                            
                            	TSI1
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: attributes
                            
                            	Attributes
                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes>`
                            
                            .. attribute:: tsi2s
                            
                            	Entity Level 2
                            	**type**\:   :py:class:`Tsi2S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S>`
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.name = None
                                self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes()
                                self.attributes.parent = self
                                self.tsi2s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S()
                                self.tsi2s.parent = self


                            class Tsi2S(object):
                                """
                                Entity Level 2
                                
                                .. attribute:: tsi2
                                
                                	TSI2
                                	**type**\: list of    :py:class:`Tsi2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tsi2 = YList()
                                    self.tsi2.parent = self
                                    self.tsi2.name = 'tsi2'


                                class Tsi2(object):
                                    """
                                    TSI2
                                    
                                    .. attribute:: name  <key>
                                    
                                    	TSI2
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: attributes
                                    
                                    	Attributes
                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes>`
                                    
                                    .. attribute:: tsi3s
                                    
                                    	Entity Level 3
                                    	**type**\:   :py:class:`Tsi3S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S>`
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.name = None
                                        self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes()
                                        self.attributes.parent = self
                                        self.tsi3s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S()
                                        self.tsi3s.parent = self


                                    class Tsi3S(object):
                                        """
                                        Entity Level 3
                                        
                                        .. attribute:: tsi3
                                        
                                        	TSI3
                                        	**type**\: list of    :py:class:`Tsi3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tsi3 = YList()
                                            self.tsi3.parent = self
                                            self.tsi3.name = 'tsi3'


                                        class Tsi3(object):
                                            """
                                            TSI3
                                            
                                            .. attribute:: name  <key>
                                            
                                            	TSI3
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: attributes
                                            
                                            	Attributes
                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes>`
                                            
                                            .. attribute:: tsi4s
                                            
                                            	Entity Level 4
                                            	**type**\:   :py:class:`Tsi4S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S>`
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.name = None
                                                self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes()
                                                self.attributes.parent = self
                                                self.tsi4s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S()
                                                self.tsi4s.parent = self


                                            class Tsi4S(object):
                                                """
                                                Entity Level 4
                                                
                                                .. attribute:: tsi4
                                                
                                                	TSI4
                                                	**type**\: list of    :py:class:`Tsi4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.tsi4 = YList()
                                                    self.tsi4.parent = self
                                                    self.tsi4.name = 'tsi4'


                                                class Tsi4(object):
                                                    """
                                                    TSI4
                                                    
                                                    .. attribute:: name  <key>
                                                    
                                                    	TSI4
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: attributes
                                                    
                                                    	Attributes
                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes>`
                                                    
                                                    .. attribute:: tsi5s
                                                    
                                                    	Entity Level 5
                                                    	**type**\:   :py:class:`Tsi5S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.name = None
                                                        self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes()
                                                        self.attributes.parent = self
                                                        self.tsi5s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S()
                                                        self.tsi5s.parent = self


                                                    class Tsi5S(object):
                                                        """
                                                        Entity Level 5
                                                        
                                                        .. attribute:: tsi5
                                                        
                                                        	TSI5
                                                        	**type**\: list of    :py:class:`Tsi5 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.tsi5 = YList()
                                                            self.tsi5.parent = self
                                                            self.tsi5.name = 'tsi5'


                                                        class Tsi5(object):
                                                            """
                                                            TSI5
                                                            
                                                            .. attribute:: name  <key>
                                                            
                                                            	TSI5
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                            
                                                            .. attribute:: attributes
                                                            
                                                            	Attributes
                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes>`
                                                            
                                                            .. attribute:: tsi6s
                                                            
                                                            	Entity Level 6
                                                            	**type**\:   :py:class:`Tsi6S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.name = None
                                                                self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes()
                                                                self.attributes.parent = self
                                                                self.tsi6s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S()
                                                                self.tsi6s.parent = self


                                                            class Tsi6S(object):
                                                                """
                                                                Entity Level 6
                                                                
                                                                .. attribute:: tsi6
                                                                
                                                                	TSI6
                                                                	**type**\: list of    :py:class:`Tsi6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.tsi6 = YList()
                                                                    self.tsi6.parent = self
                                                                    self.tsi6.name = 'tsi6'


                                                                class Tsi6(object):
                                                                    """
                                                                    TSI6
                                                                    
                                                                    .. attribute:: name  <key>
                                                                    
                                                                    	TSI6
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                    
                                                                    .. attribute:: attributes
                                                                    
                                                                    	Attributes
                                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes>`
                                                                    
                                                                    .. attribute:: tsi7s
                                                                    
                                                                    	Entity Level 7
                                                                    	**type**\:   :py:class:`Tsi7S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.name = None
                                                                        self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes()
                                                                        self.attributes.parent = self
                                                                        self.tsi7s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S()
                                                                        self.tsi7s.parent = self


                                                                    class Tsi7S(object):
                                                                        """
                                                                        Entity Level 7
                                                                        
                                                                        .. attribute:: tsi7
                                                                        
                                                                        	TSI7
                                                                        	**type**\: list of    :py:class:`Tsi7 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.tsi7 = YList()
                                                                            self.tsi7.parent = self
                                                                            self.tsi7.name = 'tsi7'


                                                                        class Tsi7(object):
                                                                            """
                                                                            TSI7
                                                                            
                                                                            .. attribute:: name  <key>
                                                                            
                                                                            	TSI7
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                            
                                                                            .. attribute:: attributes
                                                                            
                                                                            	Attributes
                                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes>`
                                                                            
                                                                            .. attribute:: tsi8s
                                                                            
                                                                            	Entity Level 8
                                                                            	**type**\:   :py:class:`Tsi8S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.name = None
                                                                                self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes()
                                                                                self.attributes.parent = self
                                                                                self.tsi8s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S()
                                                                                self.tsi8s.parent = self


                                                                            class Tsi8S(object):
                                                                                """
                                                                                Entity Level 8
                                                                                
                                                                                .. attribute:: tsi8
                                                                                
                                                                                	TSI8
                                                                                	**type**\: list of    :py:class:`Tsi8 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.tsi8 = YList()
                                                                                    self.tsi8.parent = self
                                                                                    self.tsi8.name = 'tsi8'


                                                                                class Tsi8(object):
                                                                                    """
                                                                                    TSI8
                                                                                    
                                                                                    .. attribute:: name  <key>
                                                                                    
                                                                                    	TSI8
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                    
                                                                                    .. attribute:: attributes
                                                                                    
                                                                                    	Attributes
                                                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes>`
                                                                                    
                                                                                    .. attribute:: tsi9s
                                                                                    
                                                                                    	Entity Level 9
                                                                                    	**type**\:   :py:class:`Tsi9S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S>`
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.name = None
                                                                                        self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes()
                                                                                        self.attributes.parent = self
                                                                                        self.tsi9s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S()
                                                                                        self.tsi9s.parent = self


                                                                                    class Tsi9S(object):
                                                                                        """
                                                                                        Entity Level 9
                                                                                        
                                                                                        .. attribute:: tsi9
                                                                                        
                                                                                        	TSI9
                                                                                        	**type**\: list of    :py:class:`Tsi9 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.tsi9 = YList()
                                                                                            self.tsi9.parent = self
                                                                                            self.tsi9.name = 'tsi9'


                                                                                        class Tsi9(object):
                                                                                            """
                                                                                            TSI9
                                                                                            
                                                                                            .. attribute:: name  <key>
                                                                                            
                                                                                            	TSI9
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                            
                                                                                            .. attribute:: attributes
                                                                                            
                                                                                            	Attributes
                                                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes>`
                                                                                            
                                                                                            .. attribute:: tsi10s
                                                                                            
                                                                                            	Entity Level 10
                                                                                            	**type**\:   :py:class:`Tsi10S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S>`
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.name = None
                                                                                                self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes()
                                                                                                self.attributes.parent = self
                                                                                                self.tsi10s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S()
                                                                                                self.tsi10s.parent = self


                                                                                            class Tsi10S(object):
                                                                                                """
                                                                                                Entity Level 10
                                                                                                
                                                                                                .. attribute:: tsi10
                                                                                                
                                                                                                	TSI10
                                                                                                	**type**\: list of    :py:class:`Tsi10 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.tsi10 = YList()
                                                                                                    self.tsi10.parent = self
                                                                                                    self.tsi10.name = 'tsi10'


                                                                                                class Tsi10(object):
                                                                                                    """
                                                                                                    TSI10
                                                                                                    
                                                                                                    .. attribute:: name  <key>
                                                                                                    
                                                                                                    	TSI10
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                                    
                                                                                                    .. attribute:: attributes
                                                                                                    
                                                                                                    	Attributes
                                                                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes>`
                                                                                                    
                                                                                                    .. attribute:: tsi11s
                                                                                                    
                                                                                                    	Entity Level 11
                                                                                                    	**type**\:   :py:class:`Tsi11S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S>`
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.name = None
                                                                                                        self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes()
                                                                                                        self.attributes.parent = self
                                                                                                        self.tsi11s = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S()
                                                                                                        self.tsi11s.parent = self


                                                                                                    class Tsi11S(object):
                                                                                                        """
                                                                                                        Entity Level 11
                                                                                                        
                                                                                                        .. attribute:: tsi11
                                                                                                        
                                                                                                        	TSI11
                                                                                                        	**type**\: list of    :py:class:`Tsi11 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.tsi11 = YList()
                                                                                                            self.tsi11.parent = self
                                                                                                            self.tsi11.name = 'tsi11'


                                                                                                        class Tsi11(object):
                                                                                                            """
                                                                                                            TSI11
                                                                                                            
                                                                                                            .. attribute:: name  <key>
                                                                                                            
                                                                                                            	TSI11
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                                            
                                                                                                            .. attribute:: attributes
                                                                                                            
                                                                                                            	Attributes
                                                                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes>`
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.name = None
                                                                                                                self.attributes = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes()
                                                                                                                self.attributes.parent = self


                                                                                                            class Attributes(object):
                                                                                                                """
                                                                                                                Attributes
                                                                                                                
                                                                                                                .. attribute:: env_sensor_info
                                                                                                                
                                                                                                                	Environment sensor info
                                                                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfo>`
                                                                                                                
                                                                                                                .. attribute:: env_sensor_info_xml
                                                                                                                
                                                                                                                	Environment sensor info XML
                                                                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml>`
                                                                                                                
                                                                                                                .. attribute:: fru_info
                                                                                                                
                                                                                                                	Inventory EDM FRU info
                                                                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo>`
                                                                                                                
                                                                                                                .. attribute:: inv_asset_bag
                                                                                                                
                                                                                                                	Inventory Asset Bag
                                                                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvAssetBag>`
                                                                                                                
                                                                                                                .. attribute:: inv_basic_bag
                                                                                                                
                                                                                                                	Inventory Basic Bag
                                                                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvBasicBag>`
                                                                                                                
                                                                                                                .. attribute:: inv_eeprom_info
                                                                                                                
                                                                                                                	Inventory EDM EEPROM Information Bag
                                                                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo>`
                                                                                                                
                                                                                                                .. attribute:: module_done
                                                                                                                
                                                                                                                	Inventory EDM Module Done Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**default value**\: 1
                                                                                                                
                                                                                                                .. attribute:: node_id
                                                                                                                
                                                                                                                	Node ID Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** 0..4294967295
                                                                                                                
                                                                                                                .. attribute:: pwg_info
                                                                                                                
                                                                                                                	Inventory EDM PWG info
                                                                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.PwgInfo>`
                                                                                                                
                                                                                                                .. attribute:: threshold
                                                                                                                
                                                                                                                	Threshold
                                                                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold>`
                                                                                                                
                                                                                                                .. attribute:: vm_done
                                                                                                                
                                                                                                                	VM Done Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                .. attribute:: vm_node_id
                                                                                                                
                                                                                                                	VM Node ID Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** 0..4294967295
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfo()
                                                                                                                    self.env_sensor_info.parent = self
                                                                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml()
                                                                                                                    self.env_sensor_info_xml.parent = self
                                                                                                                    self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo()
                                                                                                                    self.fru_info.parent = self
                                                                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvAssetBag()
                                                                                                                    self.inv_asset_bag.parent = self
                                                                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvBasicBag()
                                                                                                                    self.inv_basic_bag.parent = self
                                                                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo()
                                                                                                                    self.inv_eeprom_info.parent = self
                                                                                                                    self.module_done = None
                                                                                                                    self.node_id = None
                                                                                                                    self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.PwgInfo()
                                                                                                                    self.pwg_info.parent = self
                                                                                                                    self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold()
                                                                                                                    self.threshold.parent = self
                                                                                                                    self.vm_done = None
                                                                                                                    self.vm_node_id = None


                                                                                                                class EnvSensorInfo(object):
                                                                                                                    """
                                                                                                                    Environment sensor info
                                                                                                                    
                                                                                                                    .. attribute:: age_time_stamp
                                                                                                                    
                                                                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: alarm_type
                                                                                                                    
                                                                                                                    	Indicates threshold violation
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: data_type
                                                                                                                    
                                                                                                                    	Sensor data type enums
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: device_description
                                                                                                                    
                                                                                                                    	Device Name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: device_id
                                                                                                                    
                                                                                                                    	Identifier for this device
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: field_validity_bitmap
                                                                                                                    
                                                                                                                    	Sensor valid bitmap
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: precision
                                                                                                                    
                                                                                                                    	Sensor precision range
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: scale
                                                                                                                    
                                                                                                                    	Sensor scale enums
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: status
                                                                                                                    
                                                                                                                    	Sensor operation state enums
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: units
                                                                                                                    
                                                                                                                    	Units of variable being read
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: update_rate
                                                                                                                    
                                                                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: value
                                                                                                                    
                                                                                                                    	Current reading of sensor
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.age_time_stamp = None
                                                                                                                        self.alarm_type = None
                                                                                                                        self.data_type = None
                                                                                                                        self.device_description = None
                                                                                                                        self.device_id = None
                                                                                                                        self.field_validity_bitmap = None
                                                                                                                        self.precision = None
                                                                                                                        self.scale = None
                                                                                                                        self.status = None
                                                                                                                        self.units = None
                                                                                                                        self.update_rate = None
                                                                                                                        self.value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.age_time_stamp is not None:
                                                                                                                            return True

                                                                                                                        if self.alarm_type is not None:
                                                                                                                            return True

                                                                                                                        if self.data_type is not None:
                                                                                                                            return True

                                                                                                                        if self.device_description is not None:
                                                                                                                            return True

                                                                                                                        if self.device_id is not None:
                                                                                                                            return True

                                                                                                                        if self.field_validity_bitmap is not None:
                                                                                                                            return True

                                                                                                                        if self.precision is not None:
                                                                                                                            return True

                                                                                                                        if self.scale is not None:
                                                                                                                            return True

                                                                                                                        if self.status is not None:
                                                                                                                            return True

                                                                                                                        if self.units is not None:
                                                                                                                            return True

                                                                                                                        if self.update_rate is not None:
                                                                                                                            return True

                                                                                                                        if self.value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfo']['meta_info']


                                                                                                                class PwgInfo(object):
                                                                                                                    """
                                                                                                                    Inventory EDM PWG info
                                                                                                                    
                                                                                                                    .. attribute:: power_group_available_current
                                                                                                                    
                                                                                                                    	available current
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_group_drawn_current
                                                                                                                    
                                                                                                                    	drawn current
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_group_power_units
                                                                                                                    
                                                                                                                    	power units
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    .. attribute:: power_group_redundancy_mode
                                                                                                                    
                                                                                                                    	redundancy mode
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.power_group_available_current = None
                                                                                                                        self.power_group_drawn_current = None
                                                                                                                        self.power_group_power_units = None
                                                                                                                        self.power_group_redundancy_mode = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.power_group_available_current is not None:
                                                                                                                            return True

                                                                                                                        if self.power_group_drawn_current is not None:
                                                                                                                            return True

                                                                                                                        if self.power_group_power_units is not None:
                                                                                                                            return True

                                                                                                                        if self.power_group_redundancy_mode is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.PwgInfo']['meta_info']


                                                                                                                class EnvSensorInfoXml(object):
                                                                                                                    """
                                                                                                                    Environment sensor info XML
                                                                                                                    
                                                                                                                    .. attribute:: data_type
                                                                                                                    
                                                                                                                    	Sensor data type
                                                                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: description
                                                                                                                    
                                                                                                                    	Device Name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: status
                                                                                                                    
                                                                                                                    	Sensor operation state
                                                                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: threshold
                                                                                                                    
                                                                                                                    	Threshold information
                                                                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                                                    
                                                                                                                    .. attribute:: units
                                                                                                                    
                                                                                                                    	Units of variable being read
                                                                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: update_rate
                                                                                                                    
                                                                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: value
                                                                                                                    
                                                                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.data_type = None
                                                                                                                        self.description = None
                                                                                                                        self.status = None
                                                                                                                        self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                                        self.threshold.parent = self
                                                                                                                        self.units = None
                                                                                                                        self.update_rate = None
                                                                                                                        self.value = None


                                                                                                                    class Threshold(object):
                                                                                                                        """
                                                                                                                        Threshold information
                                                                                                                        
                                                                                                                        .. attribute:: threshold_array
                                                                                                                        
                                                                                                                        	Array of threshold
                                                                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.threshold_array = YList()
                                                                                                                            self.threshold_array.parent = self
                                                                                                                            self.threshold_array.name = 'threshold_array'


                                                                                                                        class ThresholdArray(object):
                                                                                                                            """
                                                                                                                            Array of threshold
                                                                                                                            
                                                                                                                            .. attribute:: threshold_name
                                                                                                                            
                                                                                                                            	Threshold name
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..50
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_name = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_name is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.threshold_array is not None:
                                                                                                                                for child_ref in self.threshold_array:
                                                                                                                                    if child_ref._has_data():
                                                                                                                                        return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.data_type is not None:
                                                                                                                            return True

                                                                                                                        if self.description is not None:
                                                                                                                            return True

                                                                                                                        if self.status is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                                                                            return True

                                                                                                                        if self.units is not None:
                                                                                                                            return True

                                                                                                                        if self.update_rate is not None:
                                                                                                                            return True

                                                                                                                        if self.value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                                                class InvAssetBag(object):
                                                                                                                    """
                                                                                                                    Inventory Asset Bag
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_assembly_number
                                                                                                                    
                                                                                                                    	Manufacture Assembly number
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_assembly_revision
                                                                                                                    
                                                                                                                    	Manufacture assembly revision
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                                                    
                                                                                                                    	Common Language Equipment           Identifier number
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                                                                    
                                                                                                                    	
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_software_identifier
                                                                                                                    
                                                                                                                    	
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                                                                    
                                                                                                                    	String containing OEM information           if applicable
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: part_number
                                                                                                                    
                                                                                                                    	
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.manufacturer_assembly_number = None
                                                                                                                        self.manufacturer_assembly_revision = None
                                                                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                                                                        self.manufacturer_firmware_identifier = None
                                                                                                                        self.manufacturer_software_identifier = None
                                                                                                                        self.original_equipment_manufacturer_string = None
                                                                                                                        self.part_number = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.manufacturer_assembly_number is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_assembly_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_software_identifier is not None:
                                                                                                                            return True

                                                                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                                                                            return True

                                                                                                                        if self.part_number is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvAssetBag']['meta_info']


                                                                                                                class Threshold(object):
                                                                                                                    """
                                                                                                                    Threshold
                                                                                                                    
                                                                                                                    .. attribute:: critical_hi
                                                                                                                    
                                                                                                                    	Critical High
                                                                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi>`
                                                                                                                    
                                                                                                                    .. attribute:: critical_lo
                                                                                                                    
                                                                                                                    	Critical Low
                                                                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo>`
                                                                                                                    
                                                                                                                    .. attribute:: major_hi
                                                                                                                    
                                                                                                                    	Major High
                                                                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi>`
                                                                                                                    
                                                                                                                    .. attribute:: major_lo
                                                                                                                    
                                                                                                                    	Major Low
                                                                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo>`
                                                                                                                    
                                                                                                                    .. attribute:: minor_hi
                                                                                                                    
                                                                                                                    	Minor High
                                                                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi>`
                                                                                                                    
                                                                                                                    .. attribute:: minor_lo
                                                                                                                    
                                                                                                                    	Minor Low
                                                                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo>`
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi()
                                                                                                                        self.critical_hi.parent = self
                                                                                                                        self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo()
                                                                                                                        self.critical_lo.parent = self
                                                                                                                        self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi()
                                                                                                                        self.major_hi.parent = self
                                                                                                                        self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo()
                                                                                                                        self.major_lo.parent = self
                                                                                                                        self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi()
                                                                                                                        self.minor_hi.parent = self
                                                                                                                        self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo()
                                                                                                                        self.minor_lo.parent = self


                                                                                                                    class MajorLo(object):
                                                                                                                        """
                                                                                                                        Major Low
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo']['meta_info']


                                                                                                                    class CriticalHi(object):
                                                                                                                        """
                                                                                                                        Critical High
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                                                    class MinorHi(object):
                                                                                                                        """
                                                                                                                        Minor High
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi']['meta_info']


                                                                                                                    class MajorHi(object):
                                                                                                                        """
                                                                                                                        Major High
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi']['meta_info']


                                                                                                                    class CriticalLo(object):
                                                                                                                        """
                                                                                                                        Critical Low
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                                                    class MinorLo(object):
                                                                                                                        """
                                                                                                                        Minor Low
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                                            return True

                                                                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                                            return True

                                                                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                                                                            return True

                                                                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                                                                            return True

                                                                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                                            return True

                                                                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold']['meta_info']


                                                                                                                class FruInfo(object):
                                                                                                                    """
                                                                                                                    Inventory EDM FRU info
                                                                                                                    
                                                                                                                    .. attribute:: card_administrative_state
                                                                                                                    
                                                                                                                    	card admin state\: shutdown or not
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: card_monitor_state
                                                                                                                    
                                                                                                                    	card is monitored by a manager or left unmonitored
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: card_operational_state
                                                                                                                    
                                                                                                                    	card operation state
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: card_reset_reason
                                                                                                                    
                                                                                                                    	card reset reason enum
                                                                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: card_up_time
                                                                                                                    
                                                                                                                    	card up time
                                                                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.CardUpTime>`
                                                                                                                    
                                                                                                                    .. attribute:: last_operational_state_change
                                                                                                                    
                                                                                                                    	last card oper change state
                                                                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                                                    
                                                                                                                    .. attribute:: power_administrative_state
                                                                                                                    
                                                                                                                    	power admin state\: up or down
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_current_measurement
                                                                                                                    
                                                                                                                    	power current\: not implemented
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_operational_state
                                                                                                                    
                                                                                                                    	Power operation state
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.card_administrative_state = None
                                                                                                                        self.card_monitor_state = None
                                                                                                                        self.card_operational_state = None
                                                                                                                        self.card_reset_reason = None
                                                                                                                        self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.CardUpTime()
                                                                                                                        self.card_up_time.parent = self
                                                                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                                        self.last_operational_state_change.parent = self
                                                                                                                        self.power_administrative_state = None
                                                                                                                        self.power_current_measurement = None
                                                                                                                        self.power_operational_state = None


                                                                                                                    class LastOperationalStateChange(object):
                                                                                                                        """
                                                                                                                        last card oper change state
                                                                                                                        
                                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                                        
                                                                                                                        	Time Value in Nano\-seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: nanosecond
                                                                                                                        
                                                                                                                        .. attribute:: time_in_seconds
                                                                                                                        
                                                                                                                        	Time Value in Seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: second
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.time_in_nano_seconds = None
                                                                                                                            self.time_in_seconds = None

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                                return True

                                                                                                                            if self.time_in_seconds is not None:
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                                                    class CardUpTime(object):
                                                                                                                        """
                                                                                                                        card up time
                                                                                                                        
                                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                                        
                                                                                                                        	Time Value in Nano\-seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: nanosecond
                                                                                                                        
                                                                                                                        .. attribute:: time_in_seconds
                                                                                                                        
                                                                                                                        	Time Value in Seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: second
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.time_in_nano_seconds = None
                                                                                                                            self.time_in_seconds = None

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                                return True

                                                                                                                            if self.time_in_seconds is not None:
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.card_administrative_state is not None:
                                                                                                                            return True

                                                                                                                        if self.card_monitor_state is not None:
                                                                                                                            return True

                                                                                                                        if self.card_operational_state is not None:
                                                                                                                            return True

                                                                                                                        if self.card_reset_reason is not None:
                                                                                                                            return True

                                                                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                                            return True

                                                                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                                            return True

                                                                                                                        if self.power_administrative_state is not None:
                                                                                                                            return True

                                                                                                                        if self.power_current_measurement is not None:
                                                                                                                            return True

                                                                                                                        if self.power_operational_state is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo']['meta_info']


                                                                                                                class InvBasicBag(object):
                                                                                                                    """
                                                                                                                    Inventory Basic Bag
                                                                                                                    
                                                                                                                    .. attribute:: alias
                                                                                                                    
                                                                                                                    	useful for storing an entity alias 
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: asset_id_str
                                                                                                                    
                                                                                                                    	asset Identification string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: asset_identification
                                                                                                                    
                                                                                                                    	asset Identification
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: ceport
                                                                                                                    
                                                                                                                    	1 if ce port found, 0 if not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: chip_hardware_revision
                                                                                                                    
                                                                                                                    	chip module hw revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: composite_class_code
                                                                                                                    
                                                                                                                    	Major&minor class of the entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: description
                                                                                                                    
                                                                                                                    	describes in user\-readable terms       what the entity in question does
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: environmental_monitor_path
                                                                                                                    
                                                                                                                    	sysdb name of sensor in the envmon EDM
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: firmware_revision
                                                                                                                    
                                                                                                                    	firmware revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: group_flag
                                                                                                                    
                                                                                                                    	indicates if this entity is group       or not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: hardware_revision
                                                                                                                    
                                                                                                                    	hw revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: is_field_replaceable_unit
                                                                                                                    
                                                                                                                    	1 if Field Replaceable Unit 0, if not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_asset_tags
                                                                                                                    
                                                                                                                    	Manufacture Asset Tags
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_name
                                                                                                                    
                                                                                                                    	manufacturer's name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: memory_size
                                                                                                                    
                                                                                                                    	Size of memory associated with       the entity where applicable
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: model_name
                                                                                                                    
                                                                                                                    	model name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: name
                                                                                                                    
                                                                                                                    	name string for the entity
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: new_deviation_number
                                                                                                                    
                                                                                                                    	integer value for New Deviation Number 0x88
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: physical_layer_interface_module_type
                                                                                                                    
                                                                                                                    	integer value for plim type if     applicable to this entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: redundancystate
                                                                                                                    
                                                                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: serial_number
                                                                                                                    
                                                                                                                    	serial number
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: software_revision
                                                                                                                    
                                                                                                                    	software revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: unique_id
                                                                                                                    
                                                                                                                    	Unique id for an entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: unrecognized_fru
                                                                                                                    
                                                                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: vendor_type
                                                                                                                    
                                                                                                                    	maps to the vendor OID string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: xr_scoped
                                                                                                                    
                                                                                                                    	1 if xr scoped, 0 if not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.alias = None
                                                                                                                        self.asset_id_str = None
                                                                                                                        self.asset_identification = None
                                                                                                                        self.ceport = None
                                                                                                                        self.chip_hardware_revision = None
                                                                                                                        self.composite_class_code = None
                                                                                                                        self.description = None
                                                                                                                        self.environmental_monitor_path = None
                                                                                                                        self.firmware_revision = None
                                                                                                                        self.group_flag = None
                                                                                                                        self.hardware_revision = None
                                                                                                                        self.is_field_replaceable_unit = None
                                                                                                                        self.manufacturer_asset_tags = None
                                                                                                                        self.manufacturer_name = None
                                                                                                                        self.memory_size = None
                                                                                                                        self.model_name = None
                                                                                                                        self.name = None
                                                                                                                        self.new_deviation_number = None
                                                                                                                        self.physical_layer_interface_module_type = None
                                                                                                                        self.redundancystate = None
                                                                                                                        self.serial_number = None
                                                                                                                        self.software_revision = None
                                                                                                                        self.unique_id = None
                                                                                                                        self.unrecognized_fru = None
                                                                                                                        self.vendor_type = None
                                                                                                                        self.xr_scoped = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.alias is not None:
                                                                                                                            return True

                                                                                                                        if self.asset_id_str is not None:
                                                                                                                            return True

                                                                                                                        if self.asset_identification is not None:
                                                                                                                            return True

                                                                                                                        if self.ceport is not None:
                                                                                                                            return True

                                                                                                                        if self.chip_hardware_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.composite_class_code is not None:
                                                                                                                            return True

                                                                                                                        if self.description is not None:
                                                                                                                            return True

                                                                                                                        if self.environmental_monitor_path is not None:
                                                                                                                            return True

                                                                                                                        if self.firmware_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.group_flag is not None:
                                                                                                                            return True

                                                                                                                        if self.hardware_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.is_field_replaceable_unit is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_asset_tags is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_name is not None:
                                                                                                                            return True

                                                                                                                        if self.memory_size is not None:
                                                                                                                            return True

                                                                                                                        if self.model_name is not None:
                                                                                                                            return True

                                                                                                                        if self.name is not None:
                                                                                                                            return True

                                                                                                                        if self.new_deviation_number is not None:
                                                                                                                            return True

                                                                                                                        if self.physical_layer_interface_module_type is not None:
                                                                                                                            return True

                                                                                                                        if self.redundancystate is not None:
                                                                                                                            return True

                                                                                                                        if self.serial_number is not None:
                                                                                                                            return True

                                                                                                                        if self.software_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.unique_id is not None:
                                                                                                                            return True

                                                                                                                        if self.unrecognized_fru is not None:
                                                                                                                            return True

                                                                                                                        if self.vendor_type is not None:
                                                                                                                            return True

                                                                                                                        if self.xr_scoped is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvBasicBag']['meta_info']


                                                                                                                class InvEepromInfo(object):
                                                                                                                    """
                                                                                                                    Inventory EDM EEPROM Information Bag
                                                                                                                    
                                                                                                                    .. attribute:: description
                                                                                                                    
                                                                                                                    	A textual description of physical entity
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: eeprom
                                                                                                                    
                                                                                                                    	EEPROM data not from hex data
                                                                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom>`
                                                                                                                    
                                                                                                                    .. attribute:: has_eeprom
                                                                                                                    
                                                                                                                    	use eeprom instead of opaque data
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: inv_card_type
                                                                                                                    
                                                                                                                    	Inventory card type
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: opaque_data
                                                                                                                    
                                                                                                                    	EEPROM hex data
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                                                    
                                                                                                                    .. attribute:: opaque_data_size
                                                                                                                    
                                                                                                                    	size of the EEPROM hex data
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.description = None
                                                                                                                        self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom()
                                                                                                                        self.eeprom.parent = self
                                                                                                                        self.has_eeprom = None
                                                                                                                        self.inv_card_type = None
                                                                                                                        self.opaque_data = None
                                                                                                                        self.opaque_data_size = None


                                                                                                                    class Eeprom(object):
                                                                                                                        """
                                                                                                                        EEPROM data not from hex data
                                                                                                                        
                                                                                                                        .. attribute:: asset_alias
                                                                                                                        
                                                                                                                        	Asset Alias
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: asset_id
                                                                                                                        
                                                                                                                        	Asset ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address1
                                                                                                                        
                                                                                                                        	Base Mac Address #1
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address2
                                                                                                                        
                                                                                                                        	Base Mac Address #2
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address3
                                                                                                                        
                                                                                                                        	Base Mac Address #3
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address4
                                                                                                                        
                                                                                                                        	Base Mac Address #4
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_checksum
                                                                                                                        
                                                                                                                        	Block Checksum
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_count
                                                                                                                        
                                                                                                                        	Block Count
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_length
                                                                                                                        
                                                                                                                        	Block Length
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_signature
                                                                                                                        
                                                                                                                        	Block Signature
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_version
                                                                                                                        
                                                                                                                        	Block Version
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: chassis_sid
                                                                                                                        
                                                                                                                        	Chassis serial number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: clei
                                                                                                                        
                                                                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: controller_family
                                                                                                                        
                                                                                                                        	Controller family
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: controller_type
                                                                                                                        
                                                                                                                        	Controller type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: description
                                                                                                                        
                                                                                                                        	A textual description of physical entity
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num1
                                                                                                                        
                                                                                                                        	Deviation Number # 1
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num2
                                                                                                                        
                                                                                                                        	Deviation Number # 2
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num3
                                                                                                                        
                                                                                                                        	Deviation Number # 3
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num4
                                                                                                                        
                                                                                                                        	Deviation Number # 4
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num5
                                                                                                                        
                                                                                                                        	Deviation Number # 5
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num6
                                                                                                                        
                                                                                                                        	Deviation Number # 6
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num7
                                                                                                                        
                                                                                                                        	Deviation Number # 7
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: eci
                                                                                                                        
                                                                                                                        	Equipment Catalog Item (ECI) number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: eeprom_size
                                                                                                                        
                                                                                                                        	EEPROM Size
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: engineer_use
                                                                                                                        
                                                                                                                        	Engineer Use
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: fru_major_type
                                                                                                                        
                                                                                                                        	FRU Major Type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: fru_minor_type
                                                                                                                        
                                                                                                                        	FRU Minor Type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: hw_version
                                                                                                                        
                                                                                                                        	Hardware Version
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: hwid
                                                                                                                        
                                                                                                                        	Hardware Revision
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: idprom_format_rev
                                                                                                                        
                                                                                                                        	IDPROM Format Revision
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size1
                                                                                                                        
                                                                                                                        	Mac Address Block Size #1
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size2
                                                                                                                        
                                                                                                                        	Mac Address Block Size #2
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size3
                                                                                                                        
                                                                                                                        	Mac Address Block Size #3
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size4
                                                                                                                        
                                                                                                                        	Mac Address Block Size #4
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: manu_test_data
                                                                                                                        
                                                                                                                        	Manufacturing Test Data
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mfg_bits
                                                                                                                        
                                                                                                                        	MFG Bits
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mfg_deviation
                                                                                                                        
                                                                                                                        	MFG Deviation
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: oem_string
                                                                                                                        
                                                                                                                        	OEM String
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: part_number
                                                                                                                        
                                                                                                                        	Part Number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: part_revision
                                                                                                                        
                                                                                                                        	Part Revision
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pca_num
                                                                                                                        
                                                                                                                        	PCA number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pcavid
                                                                                                                        
                                                                                                                        	PCA revision ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pcb_serial_num
                                                                                                                        
                                                                                                                        	PCB Serial Number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pid
                                                                                                                        
                                                                                                                        	Product ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: power_consumption
                                                                                                                        
                                                                                                                        	Power Consumption
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: power_supply_type
                                                                                                                        
                                                                                                                        	Power Supply Type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: product_id
                                                                                                                        
                                                                                                                        	Product ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: rma
                                                                                                                        
                                                                                                                        	RMA Data
                                                                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                                        
                                                                                                                        .. attribute:: rma_code
                                                                                                                        
                                                                                                                        	RMA Code
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: serial_number
                                                                                                                        
                                                                                                                        	Serial Number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: snmpoid
                                                                                                                        
                                                                                                                        	SNMP OID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: top_assem_part_num
                                                                                                                        
                                                                                                                        	Top assembly part number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: top_assem_vid
                                                                                                                        
                                                                                                                        	Top assembly revision number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: udi_description
                                                                                                                        
                                                                                                                        	UDI description
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: udi_name
                                                                                                                        
                                                                                                                        	UDI name
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: vid
                                                                                                                        
                                                                                                                        	Version ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.asset_alias = None
                                                                                                                            self.asset_id = None
                                                                                                                            self.base_mac_address1 = None
                                                                                                                            self.base_mac_address2 = None
                                                                                                                            self.base_mac_address3 = None
                                                                                                                            self.base_mac_address4 = None
                                                                                                                            self.block_checksum = None
                                                                                                                            self.block_count = None
                                                                                                                            self.block_length = None
                                                                                                                            self.block_signature = None
                                                                                                                            self.block_version = None
                                                                                                                            self.chassis_sid = None
                                                                                                                            self.clei = None
                                                                                                                            self.controller_family = None
                                                                                                                            self.controller_type = None
                                                                                                                            self.description = None
                                                                                                                            self.dev_num1 = None
                                                                                                                            self.dev_num2 = None
                                                                                                                            self.dev_num3 = None
                                                                                                                            self.dev_num4 = None
                                                                                                                            self.dev_num5 = None
                                                                                                                            self.dev_num6 = None
                                                                                                                            self.dev_num7 = None
                                                                                                                            self.eci = None
                                                                                                                            self.eeprom_size = None
                                                                                                                            self.engineer_use = None
                                                                                                                            self.fru_major_type = None
                                                                                                                            self.fru_minor_type = None
                                                                                                                            self.hw_version = None
                                                                                                                            self.hwid = None
                                                                                                                            self.idprom_format_rev = None
                                                                                                                            self.mac_add_blk_size1 = None
                                                                                                                            self.mac_add_blk_size2 = None
                                                                                                                            self.mac_add_blk_size3 = None
                                                                                                                            self.mac_add_blk_size4 = None
                                                                                                                            self.manu_test_data = None
                                                                                                                            self.mfg_bits = None
                                                                                                                            self.mfg_deviation = None
                                                                                                                            self.oem_string = None
                                                                                                                            self.part_number = None
                                                                                                                            self.part_revision = None
                                                                                                                            self.pca_num = None
                                                                                                                            self.pcavid = None
                                                                                                                            self.pcb_serial_num = None
                                                                                                                            self.pid = None
                                                                                                                            self.power_consumption = None
                                                                                                                            self.power_supply_type = None
                                                                                                                            self.product_id = None
                                                                                                                            self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                                            self.rma.parent = self
                                                                                                                            self.rma_code = None
                                                                                                                            self.serial_number = None
                                                                                                                            self.snmpoid = None
                                                                                                                            self.top_assem_part_num = None
                                                                                                                            self.top_assem_vid = None
                                                                                                                            self.udi_description = None
                                                                                                                            self.udi_name = None
                                                                                                                            self.vid = None


                                                                                                                        class Rma(object):
                                                                                                                            """
                                                                                                                            RMA Data
                                                                                                                            
                                                                                                                            .. attribute:: rma_history
                                                                                                                            
                                                                                                                            	RMA history
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..255
                                                                                                                            
                                                                                                                            .. attribute:: rma_number
                                                                                                                            
                                                                                                                            	RMA tracking number format is N\-N\-N
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..255
                                                                                                                            
                                                                                                                            .. attribute:: test_history
                                                                                                                            
                                                                                                                            	Test history
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..255
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.rma_history = None
                                                                                                                                self.rma_number = None
                                                                                                                                self.test_history = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.rma_history is not None:
                                                                                                                                    return True

                                                                                                                                if self.rma_number is not None:
                                                                                                                                    return True

                                                                                                                                if self.test_history is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.asset_alias is not None:
                                                                                                                                return True

                                                                                                                            if self.asset_id is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address1 is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address2 is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address3 is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address4 is not None:
                                                                                                                                return True

                                                                                                                            if self.block_checksum is not None:
                                                                                                                                return True

                                                                                                                            if self.block_count is not None:
                                                                                                                                return True

                                                                                                                            if self.block_length is not None:
                                                                                                                                return True

                                                                                                                            if self.block_signature is not None:
                                                                                                                                return True

                                                                                                                            if self.block_version is not None:
                                                                                                                                return True

                                                                                                                            if self.chassis_sid is not None:
                                                                                                                                return True

                                                                                                                            if self.clei is not None:
                                                                                                                                return True

                                                                                                                            if self.controller_family is not None:
                                                                                                                                return True

                                                                                                                            if self.controller_type is not None:
                                                                                                                                return True

                                                                                                                            if self.description is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num1 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num2 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num3 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num4 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num5 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num6 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num7 is not None:
                                                                                                                                return True

                                                                                                                            if self.eci is not None:
                                                                                                                                return True

                                                                                                                            if self.eeprom_size is not None:
                                                                                                                                return True

                                                                                                                            if self.engineer_use is not None:
                                                                                                                                return True

                                                                                                                            if self.fru_major_type is not None:
                                                                                                                                return True

                                                                                                                            if self.fru_minor_type is not None:
                                                                                                                                return True

                                                                                                                            if self.hw_version is not None:
                                                                                                                                return True

                                                                                                                            if self.hwid is not None:
                                                                                                                                return True

                                                                                                                            if self.idprom_format_rev is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size1 is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size2 is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size3 is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size4 is not None:
                                                                                                                                return True

                                                                                                                            if self.manu_test_data is not None:
                                                                                                                                return True

                                                                                                                            if self.mfg_bits is not None:
                                                                                                                                return True

                                                                                                                            if self.mfg_deviation is not None:
                                                                                                                                return True

                                                                                                                            if self.oem_string is not None:
                                                                                                                                return True

                                                                                                                            if self.part_number is not None:
                                                                                                                                return True

                                                                                                                            if self.part_revision is not None:
                                                                                                                                return True

                                                                                                                            if self.pca_num is not None:
                                                                                                                                return True

                                                                                                                            if self.pcavid is not None:
                                                                                                                                return True

                                                                                                                            if self.pcb_serial_num is not None:
                                                                                                                                return True

                                                                                                                            if self.pid is not None:
                                                                                                                                return True

                                                                                                                            if self.power_consumption is not None:
                                                                                                                                return True

                                                                                                                            if self.power_supply_type is not None:
                                                                                                                                return True

                                                                                                                            if self.product_id is not None:
                                                                                                                                return True

                                                                                                                            if self.rma is not None and self.rma._has_data():
                                                                                                                                return True

                                                                                                                            if self.rma_code is not None:
                                                                                                                                return True

                                                                                                                            if self.serial_number is not None:
                                                                                                                                return True

                                                                                                                            if self.snmpoid is not None:
                                                                                                                                return True

                                                                                                                            if self.top_assem_part_num is not None:
                                                                                                                                return True

                                                                                                                            if self.top_assem_vid is not None:
                                                                                                                                return True

                                                                                                                            if self.udi_description is not None:
                                                                                                                                return True

                                                                                                                            if self.udi_name is not None:
                                                                                                                                return True

                                                                                                                            if self.vid is not None:
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.description is not None:
                                                                                                                            return True

                                                                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                                                                            return True

                                                                                                                        if self.has_eeprom is not None:
                                                                                                                            return True

                                                                                                                        if self.inv_card_type is not None:
                                                                                                                            return True

                                                                                                                        if self.opaque_data is not None:
                                                                                                                            return True

                                                                                                                        if self.opaque_data_size is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                                        return True

                                                                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                                        return True

                                                                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                                        return True

                                                                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.module_done is not None:
                                                                                                                        return True

                                                                                                                    if self.node_id is not None:
                                                                                                                        return True

                                                                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                                                                        return True

                                                                                                                    if self.vm_done is not None:
                                                                                                                        return True

                                                                                                                    if self.vm_node_id is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                                                if self.name is None:
                                                                                                                    raise YPYModelError('Key property name is None')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi11[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.name is not None:
                                                                                                                    return True

                                                                                                                if self.attributes is not None and self.attributes._has_data():
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi11s'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.tsi11 is not None:
                                                                                                                for child_ref in self.tsi11:
                                                                                                                    if child_ref._has_data():
                                                                                                                        return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S']['meta_info']


                                                                                                    class Attributes(object):
                                                                                                        """
                                                                                                        Attributes
                                                                                                        
                                                                                                        .. attribute:: env_sensor_info
                                                                                                        
                                                                                                        	Environment sensor info
                                                                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfo>`
                                                                                                        
                                                                                                        .. attribute:: env_sensor_info_xml
                                                                                                        
                                                                                                        	Environment sensor info XML
                                                                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml>`
                                                                                                        
                                                                                                        .. attribute:: fru_info
                                                                                                        
                                                                                                        	Inventory EDM FRU info
                                                                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo>`
                                                                                                        
                                                                                                        .. attribute:: inv_asset_bag
                                                                                                        
                                                                                                        	Inventory Asset Bag
                                                                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvAssetBag>`
                                                                                                        
                                                                                                        .. attribute:: inv_basic_bag
                                                                                                        
                                                                                                        	Inventory Basic Bag
                                                                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvBasicBag>`
                                                                                                        
                                                                                                        .. attribute:: inv_eeprom_info
                                                                                                        
                                                                                                        	Inventory EDM EEPROM Information Bag
                                                                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo>`
                                                                                                        
                                                                                                        .. attribute:: module_done
                                                                                                        
                                                                                                        	Inventory EDM Module Done Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**default value**\: 1
                                                                                                        
                                                                                                        .. attribute:: node_id
                                                                                                        
                                                                                                        	Node ID Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** 0..4294967295
                                                                                                        
                                                                                                        .. attribute:: pwg_info
                                                                                                        
                                                                                                        	Inventory EDM PWG info
                                                                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.PwgInfo>`
                                                                                                        
                                                                                                        .. attribute:: threshold
                                                                                                        
                                                                                                        	Threshold
                                                                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold>`
                                                                                                        
                                                                                                        .. attribute:: vm_done
                                                                                                        
                                                                                                        	VM Done Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        .. attribute:: vm_node_id
                                                                                                        
                                                                                                        	VM Node ID Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** 0..4294967295
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfo()
                                                                                                            self.env_sensor_info.parent = self
                                                                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml()
                                                                                                            self.env_sensor_info_xml.parent = self
                                                                                                            self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo()
                                                                                                            self.fru_info.parent = self
                                                                                                            self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvAssetBag()
                                                                                                            self.inv_asset_bag.parent = self
                                                                                                            self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvBasicBag()
                                                                                                            self.inv_basic_bag.parent = self
                                                                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo()
                                                                                                            self.inv_eeprom_info.parent = self
                                                                                                            self.module_done = None
                                                                                                            self.node_id = None
                                                                                                            self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.PwgInfo()
                                                                                                            self.pwg_info.parent = self
                                                                                                            self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold()
                                                                                                            self.threshold.parent = self
                                                                                                            self.vm_done = None
                                                                                                            self.vm_node_id = None


                                                                                                        class EnvSensorInfo(object):
                                                                                                            """
                                                                                                            Environment sensor info
                                                                                                            
                                                                                                            .. attribute:: age_time_stamp
                                                                                                            
                                                                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: alarm_type
                                                                                                            
                                                                                                            	Indicates threshold violation
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: data_type
                                                                                                            
                                                                                                            	Sensor data type enums
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: device_description
                                                                                                            
                                                                                                            	Device Name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: device_id
                                                                                                            
                                                                                                            	Identifier for this device
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: field_validity_bitmap
                                                                                                            
                                                                                                            	Sensor valid bitmap
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: precision
                                                                                                            
                                                                                                            	Sensor precision range
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: scale
                                                                                                            
                                                                                                            	Sensor scale enums
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: status
                                                                                                            
                                                                                                            	Sensor operation state enums
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: units
                                                                                                            
                                                                                                            	Units of variable being read
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: update_rate
                                                                                                            
                                                                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: value
                                                                                                            
                                                                                                            	Current reading of sensor
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.age_time_stamp = None
                                                                                                                self.alarm_type = None
                                                                                                                self.data_type = None
                                                                                                                self.device_description = None
                                                                                                                self.device_id = None
                                                                                                                self.field_validity_bitmap = None
                                                                                                                self.precision = None
                                                                                                                self.scale = None
                                                                                                                self.status = None
                                                                                                                self.units = None
                                                                                                                self.update_rate = None
                                                                                                                self.value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.age_time_stamp is not None:
                                                                                                                    return True

                                                                                                                if self.alarm_type is not None:
                                                                                                                    return True

                                                                                                                if self.data_type is not None:
                                                                                                                    return True

                                                                                                                if self.device_description is not None:
                                                                                                                    return True

                                                                                                                if self.device_id is not None:
                                                                                                                    return True

                                                                                                                if self.field_validity_bitmap is not None:
                                                                                                                    return True

                                                                                                                if self.precision is not None:
                                                                                                                    return True

                                                                                                                if self.scale is not None:
                                                                                                                    return True

                                                                                                                if self.status is not None:
                                                                                                                    return True

                                                                                                                if self.units is not None:
                                                                                                                    return True

                                                                                                                if self.update_rate is not None:
                                                                                                                    return True

                                                                                                                if self.value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfo']['meta_info']


                                                                                                        class PwgInfo(object):
                                                                                                            """
                                                                                                            Inventory EDM PWG info
                                                                                                            
                                                                                                            .. attribute:: power_group_available_current
                                                                                                            
                                                                                                            	available current
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_group_drawn_current
                                                                                                            
                                                                                                            	drawn current
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_group_power_units
                                                                                                            
                                                                                                            	power units
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            .. attribute:: power_group_redundancy_mode
                                                                                                            
                                                                                                            	redundancy mode
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.power_group_available_current = None
                                                                                                                self.power_group_drawn_current = None
                                                                                                                self.power_group_power_units = None
                                                                                                                self.power_group_redundancy_mode = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.power_group_available_current is not None:
                                                                                                                    return True

                                                                                                                if self.power_group_drawn_current is not None:
                                                                                                                    return True

                                                                                                                if self.power_group_power_units is not None:
                                                                                                                    return True

                                                                                                                if self.power_group_redundancy_mode is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.PwgInfo']['meta_info']


                                                                                                        class EnvSensorInfoXml(object):
                                                                                                            """
                                                                                                            Environment sensor info XML
                                                                                                            
                                                                                                            .. attribute:: data_type
                                                                                                            
                                                                                                            	Sensor data type
                                                                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                                            
                                                                                                            .. attribute:: description
                                                                                                            
                                                                                                            	Device Name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: status
                                                                                                            
                                                                                                            	Sensor operation state
                                                                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                                            
                                                                                                            .. attribute:: threshold
                                                                                                            
                                                                                                            	Threshold information
                                                                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                                            
                                                                                                            .. attribute:: units
                                                                                                            
                                                                                                            	Units of variable being read
                                                                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                                            
                                                                                                            .. attribute:: update_rate
                                                                                                            
                                                                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: value
                                                                                                            
                                                                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.data_type = None
                                                                                                                self.description = None
                                                                                                                self.status = None
                                                                                                                self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                                self.threshold.parent = self
                                                                                                                self.units = None
                                                                                                                self.update_rate = None
                                                                                                                self.value = None


                                                                                                            class Threshold(object):
                                                                                                                """
                                                                                                                Threshold information
                                                                                                                
                                                                                                                .. attribute:: threshold_array
                                                                                                                
                                                                                                                	Array of threshold
                                                                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.threshold_array = YList()
                                                                                                                    self.threshold_array.parent = self
                                                                                                                    self.threshold_array.name = 'threshold_array'


                                                                                                                class ThresholdArray(object):
                                                                                                                    """
                                                                                                                    Array of threshold
                                                                                                                    
                                                                                                                    .. attribute:: threshold_name
                                                                                                                    
                                                                                                                    	Threshold name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_name = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_name is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.threshold_array is not None:
                                                                                                                        for child_ref in self.threshold_array:
                                                                                                                            if child_ref._has_data():
                                                                                                                                return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.data_type is not None:
                                                                                                                    return True

                                                                                                                if self.description is not None:
                                                                                                                    return True

                                                                                                                if self.status is not None:
                                                                                                                    return True

                                                                                                                if self.threshold is not None and self.threshold._has_data():
                                                                                                                    return True

                                                                                                                if self.units is not None:
                                                                                                                    return True

                                                                                                                if self.update_rate is not None:
                                                                                                                    return True

                                                                                                                if self.value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                                        class InvAssetBag(object):
                                                                                                            """
                                                                                                            Inventory Asset Bag
                                                                                                            
                                                                                                            .. attribute:: manufacturer_assembly_number
                                                                                                            
                                                                                                            	Manufacture Assembly number
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_assembly_revision
                                                                                                            
                                                                                                            	Manufacture assembly revision
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                                            
                                                                                                            	Common Language Equipment           Identifier number
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_firmware_identifier
                                                                                                            
                                                                                                            	
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_software_identifier
                                                                                                            
                                                                                                            	
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: original_equipment_manufacturer_string
                                                                                                            
                                                                                                            	String containing OEM information           if applicable
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: part_number
                                                                                                            
                                                                                                            	
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.manufacturer_assembly_number = None
                                                                                                                self.manufacturer_assembly_revision = None
                                                                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                                                                self.manufacturer_firmware_identifier = None
                                                                                                                self.manufacturer_software_identifier = None
                                                                                                                self.original_equipment_manufacturer_string = None
                                                                                                                self.part_number = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.manufacturer_assembly_number is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_assembly_revision is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_firmware_identifier is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_software_identifier is not None:
                                                                                                                    return True

                                                                                                                if self.original_equipment_manufacturer_string is not None:
                                                                                                                    return True

                                                                                                                if self.part_number is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvAssetBag']['meta_info']


                                                                                                        class Threshold(object):
                                                                                                            """
                                                                                                            Threshold
                                                                                                            
                                                                                                            .. attribute:: critical_hi
                                                                                                            
                                                                                                            	Critical High
                                                                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi>`
                                                                                                            
                                                                                                            .. attribute:: critical_lo
                                                                                                            
                                                                                                            	Critical Low
                                                                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo>`
                                                                                                            
                                                                                                            .. attribute:: major_hi
                                                                                                            
                                                                                                            	Major High
                                                                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi>`
                                                                                                            
                                                                                                            .. attribute:: major_lo
                                                                                                            
                                                                                                            	Major Low
                                                                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo>`
                                                                                                            
                                                                                                            .. attribute:: minor_hi
                                                                                                            
                                                                                                            	Minor High
                                                                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi>`
                                                                                                            
                                                                                                            .. attribute:: minor_lo
                                                                                                            
                                                                                                            	Minor Low
                                                                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo>`
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi()
                                                                                                                self.critical_hi.parent = self
                                                                                                                self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo()
                                                                                                                self.critical_lo.parent = self
                                                                                                                self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi()
                                                                                                                self.major_hi.parent = self
                                                                                                                self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo()
                                                                                                                self.major_lo.parent = self
                                                                                                                self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi()
                                                                                                                self.minor_hi.parent = self
                                                                                                                self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo()
                                                                                                                self.minor_lo.parent = self


                                                                                                            class MajorLo(object):
                                                                                                                """
                                                                                                                Major Low
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo']['meta_info']


                                                                                                            class CriticalHi(object):
                                                                                                                """
                                                                                                                Critical High
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                                            class MinorHi(object):
                                                                                                                """
                                                                                                                Minor High
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi']['meta_info']


                                                                                                            class MajorHi(object):
                                                                                                                """
                                                                                                                Major High
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi']['meta_info']


                                                                                                            class CriticalLo(object):
                                                                                                                """
                                                                                                                Critical Low
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                                            class MinorLo(object):
                                                                                                                """
                                                                                                                Minor Low
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                                    return True

                                                                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                                    return True

                                                                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                                                                    return True

                                                                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                                                                    return True

                                                                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                                    return True

                                                                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold']['meta_info']


                                                                                                        class FruInfo(object):
                                                                                                            """
                                                                                                            Inventory EDM FRU info
                                                                                                            
                                                                                                            .. attribute:: card_administrative_state
                                                                                                            
                                                                                                            	card admin state\: shutdown or not
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: card_monitor_state
                                                                                                            
                                                                                                            	card is monitored by a manager or left unmonitored
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: card_operational_state
                                                                                                            
                                                                                                            	card operation state
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: card_reset_reason
                                                                                                            
                                                                                                            	card reset reason enum
                                                                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                                            
                                                                                                            .. attribute:: card_up_time
                                                                                                            
                                                                                                            	card up time
                                                                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.CardUpTime>`
                                                                                                            
                                                                                                            .. attribute:: last_operational_state_change
                                                                                                            
                                                                                                            	last card oper change state
                                                                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                                            
                                                                                                            .. attribute:: power_administrative_state
                                                                                                            
                                                                                                            	power admin state\: up or down
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_current_measurement
                                                                                                            
                                                                                                            	power current\: not implemented
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_operational_state
                                                                                                            
                                                                                                            	Power operation state
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.card_administrative_state = None
                                                                                                                self.card_monitor_state = None
                                                                                                                self.card_operational_state = None
                                                                                                                self.card_reset_reason = None
                                                                                                                self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.CardUpTime()
                                                                                                                self.card_up_time.parent = self
                                                                                                                self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                                self.last_operational_state_change.parent = self
                                                                                                                self.power_administrative_state = None
                                                                                                                self.power_current_measurement = None
                                                                                                                self.power_operational_state = None


                                                                                                            class LastOperationalStateChange(object):
                                                                                                                """
                                                                                                                last card oper change state
                                                                                                                
                                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                                
                                                                                                                	Time Value in Nano\-seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: nanosecond
                                                                                                                
                                                                                                                .. attribute:: time_in_seconds
                                                                                                                
                                                                                                                	Time Value in Seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: second
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.time_in_nano_seconds = None
                                                                                                                    self.time_in_seconds = None

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                                        return True

                                                                                                                    if self.time_in_seconds is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                                            class CardUpTime(object):
                                                                                                                """
                                                                                                                card up time
                                                                                                                
                                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                                
                                                                                                                	Time Value in Nano\-seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: nanosecond
                                                                                                                
                                                                                                                .. attribute:: time_in_seconds
                                                                                                                
                                                                                                                	Time Value in Seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: second
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.time_in_nano_seconds = None
                                                                                                                    self.time_in_seconds = None

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                                        return True

                                                                                                                    if self.time_in_seconds is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.card_administrative_state is not None:
                                                                                                                    return True

                                                                                                                if self.card_monitor_state is not None:
                                                                                                                    return True

                                                                                                                if self.card_operational_state is not None:
                                                                                                                    return True

                                                                                                                if self.card_reset_reason is not None:
                                                                                                                    return True

                                                                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                                    return True

                                                                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                                    return True

                                                                                                                if self.power_administrative_state is not None:
                                                                                                                    return True

                                                                                                                if self.power_current_measurement is not None:
                                                                                                                    return True

                                                                                                                if self.power_operational_state is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo']['meta_info']


                                                                                                        class InvBasicBag(object):
                                                                                                            """
                                                                                                            Inventory Basic Bag
                                                                                                            
                                                                                                            .. attribute:: alias
                                                                                                            
                                                                                                            	useful for storing an entity alias 
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: asset_id_str
                                                                                                            
                                                                                                            	asset Identification string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: asset_identification
                                                                                                            
                                                                                                            	asset Identification
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: ceport
                                                                                                            
                                                                                                            	1 if ce port found, 0 if not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: chip_hardware_revision
                                                                                                            
                                                                                                            	chip module hw revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: composite_class_code
                                                                                                            
                                                                                                            	Major&minor class of the entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: description
                                                                                                            
                                                                                                            	describes in user\-readable terms       what the entity in question does
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: environmental_monitor_path
                                                                                                            
                                                                                                            	sysdb name of sensor in the envmon EDM
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: firmware_revision
                                                                                                            
                                                                                                            	firmware revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: group_flag
                                                                                                            
                                                                                                            	indicates if this entity is group       or not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: hardware_revision
                                                                                                            
                                                                                                            	hw revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: is_field_replaceable_unit
                                                                                                            
                                                                                                            	1 if Field Replaceable Unit 0, if not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: manufacturer_asset_tags
                                                                                                            
                                                                                                            	Manufacture Asset Tags
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: manufacturer_name
                                                                                                            
                                                                                                            	manufacturer's name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: memory_size
                                                                                                            
                                                                                                            	Size of memory associated with       the entity where applicable
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: model_name
                                                                                                            
                                                                                                            	model name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: name
                                                                                                            
                                                                                                            	name string for the entity
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: new_deviation_number
                                                                                                            
                                                                                                            	integer value for New Deviation Number 0x88
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: physical_layer_interface_module_type
                                                                                                            
                                                                                                            	integer value for plim type if     applicable to this entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: redundancystate
                                                                                                            
                                                                                                            	integer value for Redundancy State if     applicable to this entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: serial_number
                                                                                                            
                                                                                                            	serial number
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: software_revision
                                                                                                            
                                                                                                            	software revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: unique_id
                                                                                                            
                                                                                                            	Unique id for an entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: unrecognized_fru
                                                                                                            
                                                                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: vendor_type
                                                                                                            
                                                                                                            	maps to the vendor OID string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: xr_scoped
                                                                                                            
                                                                                                            	1 if xr scoped, 0 if not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.alias = None
                                                                                                                self.asset_id_str = None
                                                                                                                self.asset_identification = None
                                                                                                                self.ceport = None
                                                                                                                self.chip_hardware_revision = None
                                                                                                                self.composite_class_code = None
                                                                                                                self.description = None
                                                                                                                self.environmental_monitor_path = None
                                                                                                                self.firmware_revision = None
                                                                                                                self.group_flag = None
                                                                                                                self.hardware_revision = None
                                                                                                                self.is_field_replaceable_unit = None
                                                                                                                self.manufacturer_asset_tags = None
                                                                                                                self.manufacturer_name = None
                                                                                                                self.memory_size = None
                                                                                                                self.model_name = None
                                                                                                                self.name = None
                                                                                                                self.new_deviation_number = None
                                                                                                                self.physical_layer_interface_module_type = None
                                                                                                                self.redundancystate = None
                                                                                                                self.serial_number = None
                                                                                                                self.software_revision = None
                                                                                                                self.unique_id = None
                                                                                                                self.unrecognized_fru = None
                                                                                                                self.vendor_type = None
                                                                                                                self.xr_scoped = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.alias is not None:
                                                                                                                    return True

                                                                                                                if self.asset_id_str is not None:
                                                                                                                    return True

                                                                                                                if self.asset_identification is not None:
                                                                                                                    return True

                                                                                                                if self.ceport is not None:
                                                                                                                    return True

                                                                                                                if self.chip_hardware_revision is not None:
                                                                                                                    return True

                                                                                                                if self.composite_class_code is not None:
                                                                                                                    return True

                                                                                                                if self.description is not None:
                                                                                                                    return True

                                                                                                                if self.environmental_monitor_path is not None:
                                                                                                                    return True

                                                                                                                if self.firmware_revision is not None:
                                                                                                                    return True

                                                                                                                if self.group_flag is not None:
                                                                                                                    return True

                                                                                                                if self.hardware_revision is not None:
                                                                                                                    return True

                                                                                                                if self.is_field_replaceable_unit is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_asset_tags is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_name is not None:
                                                                                                                    return True

                                                                                                                if self.memory_size is not None:
                                                                                                                    return True

                                                                                                                if self.model_name is not None:
                                                                                                                    return True

                                                                                                                if self.name is not None:
                                                                                                                    return True

                                                                                                                if self.new_deviation_number is not None:
                                                                                                                    return True

                                                                                                                if self.physical_layer_interface_module_type is not None:
                                                                                                                    return True

                                                                                                                if self.redundancystate is not None:
                                                                                                                    return True

                                                                                                                if self.serial_number is not None:
                                                                                                                    return True

                                                                                                                if self.software_revision is not None:
                                                                                                                    return True

                                                                                                                if self.unique_id is not None:
                                                                                                                    return True

                                                                                                                if self.unrecognized_fru is not None:
                                                                                                                    return True

                                                                                                                if self.vendor_type is not None:
                                                                                                                    return True

                                                                                                                if self.xr_scoped is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvBasicBag']['meta_info']


                                                                                                        class InvEepromInfo(object):
                                                                                                            """
                                                                                                            Inventory EDM EEPROM Information Bag
                                                                                                            
                                                                                                            .. attribute:: description
                                                                                                            
                                                                                                            	A textual description of physical entity
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: eeprom
                                                                                                            
                                                                                                            	EEPROM data not from hex data
                                                                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom>`
                                                                                                            
                                                                                                            .. attribute:: has_eeprom
                                                                                                            
                                                                                                            	use eeprom instead of opaque data
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: inv_card_type
                                                                                                            
                                                                                                            	Inventory card type
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..255
                                                                                                            
                                                                                                            .. attribute:: opaque_data
                                                                                                            
                                                                                                            	EEPROM hex data
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                                            
                                                                                                            .. attribute:: opaque_data_size
                                                                                                            
                                                                                                            	size of the EEPROM hex data
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.description = None
                                                                                                                self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom()
                                                                                                                self.eeprom.parent = self
                                                                                                                self.has_eeprom = None
                                                                                                                self.inv_card_type = None
                                                                                                                self.opaque_data = None
                                                                                                                self.opaque_data_size = None


                                                                                                            class Eeprom(object):
                                                                                                                """
                                                                                                                EEPROM data not from hex data
                                                                                                                
                                                                                                                .. attribute:: asset_alias
                                                                                                                
                                                                                                                	Asset Alias
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: asset_id
                                                                                                                
                                                                                                                	Asset ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address1
                                                                                                                
                                                                                                                	Base Mac Address #1
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address2
                                                                                                                
                                                                                                                	Base Mac Address #2
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address3
                                                                                                                
                                                                                                                	Base Mac Address #3
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address4
                                                                                                                
                                                                                                                	Base Mac Address #4
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_checksum
                                                                                                                
                                                                                                                	Block Checksum
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_count
                                                                                                                
                                                                                                                	Block Count
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_length
                                                                                                                
                                                                                                                	Block Length
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_signature
                                                                                                                
                                                                                                                	Block Signature
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_version
                                                                                                                
                                                                                                                	Block Version
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: chassis_sid
                                                                                                                
                                                                                                                	Chassis serial number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: clei
                                                                                                                
                                                                                                                	Common Language Equipment Identifier (CLEI) code
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: controller_family
                                                                                                                
                                                                                                                	Controller family
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: controller_type
                                                                                                                
                                                                                                                	Controller type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: description
                                                                                                                
                                                                                                                	A textual description of physical entity
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num1
                                                                                                                
                                                                                                                	Deviation Number # 1
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num2
                                                                                                                
                                                                                                                	Deviation Number # 2
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num3
                                                                                                                
                                                                                                                	Deviation Number # 3
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num4
                                                                                                                
                                                                                                                	Deviation Number # 4
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num5
                                                                                                                
                                                                                                                	Deviation Number # 5
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num6
                                                                                                                
                                                                                                                	Deviation Number # 6
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num7
                                                                                                                
                                                                                                                	Deviation Number # 7
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: eci
                                                                                                                
                                                                                                                	Equipment Catalog Item (ECI) number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: eeprom_size
                                                                                                                
                                                                                                                	EEPROM Size
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: engineer_use
                                                                                                                
                                                                                                                	Engineer Use
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: fru_major_type
                                                                                                                
                                                                                                                	FRU Major Type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: fru_minor_type
                                                                                                                
                                                                                                                	FRU Minor Type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: hw_version
                                                                                                                
                                                                                                                	Hardware Version
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: hwid
                                                                                                                
                                                                                                                	Hardware Revision
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: idprom_format_rev
                                                                                                                
                                                                                                                	IDPROM Format Revision
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size1
                                                                                                                
                                                                                                                	Mac Address Block Size #1
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size2
                                                                                                                
                                                                                                                	Mac Address Block Size #2
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size3
                                                                                                                
                                                                                                                	Mac Address Block Size #3
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size4
                                                                                                                
                                                                                                                	Mac Address Block Size #4
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: manu_test_data
                                                                                                                
                                                                                                                	Manufacturing Test Data
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mfg_bits
                                                                                                                
                                                                                                                	MFG Bits
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mfg_deviation
                                                                                                                
                                                                                                                	MFG Deviation
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: oem_string
                                                                                                                
                                                                                                                	OEM String
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: part_number
                                                                                                                
                                                                                                                	Part Number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: part_revision
                                                                                                                
                                                                                                                	Part Revision
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pca_num
                                                                                                                
                                                                                                                	PCA number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pcavid
                                                                                                                
                                                                                                                	PCA revision ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pcb_serial_num
                                                                                                                
                                                                                                                	PCB Serial Number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pid
                                                                                                                
                                                                                                                	Product ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: power_consumption
                                                                                                                
                                                                                                                	Power Consumption
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: power_supply_type
                                                                                                                
                                                                                                                	Power Supply Type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: product_id
                                                                                                                
                                                                                                                	Product ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: rma
                                                                                                                
                                                                                                                	RMA Data
                                                                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                                
                                                                                                                .. attribute:: rma_code
                                                                                                                
                                                                                                                	RMA Code
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: serial_number
                                                                                                                
                                                                                                                	Serial Number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: snmpoid
                                                                                                                
                                                                                                                	SNMP OID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: top_assem_part_num
                                                                                                                
                                                                                                                	Top assembly part number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: top_assem_vid
                                                                                                                
                                                                                                                	Top assembly revision number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: udi_description
                                                                                                                
                                                                                                                	UDI description
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: udi_name
                                                                                                                
                                                                                                                	UDI name
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: vid
                                                                                                                
                                                                                                                	Version ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.asset_alias = None
                                                                                                                    self.asset_id = None
                                                                                                                    self.base_mac_address1 = None
                                                                                                                    self.base_mac_address2 = None
                                                                                                                    self.base_mac_address3 = None
                                                                                                                    self.base_mac_address4 = None
                                                                                                                    self.block_checksum = None
                                                                                                                    self.block_count = None
                                                                                                                    self.block_length = None
                                                                                                                    self.block_signature = None
                                                                                                                    self.block_version = None
                                                                                                                    self.chassis_sid = None
                                                                                                                    self.clei = None
                                                                                                                    self.controller_family = None
                                                                                                                    self.controller_type = None
                                                                                                                    self.description = None
                                                                                                                    self.dev_num1 = None
                                                                                                                    self.dev_num2 = None
                                                                                                                    self.dev_num3 = None
                                                                                                                    self.dev_num4 = None
                                                                                                                    self.dev_num5 = None
                                                                                                                    self.dev_num6 = None
                                                                                                                    self.dev_num7 = None
                                                                                                                    self.eci = None
                                                                                                                    self.eeprom_size = None
                                                                                                                    self.engineer_use = None
                                                                                                                    self.fru_major_type = None
                                                                                                                    self.fru_minor_type = None
                                                                                                                    self.hw_version = None
                                                                                                                    self.hwid = None
                                                                                                                    self.idprom_format_rev = None
                                                                                                                    self.mac_add_blk_size1 = None
                                                                                                                    self.mac_add_blk_size2 = None
                                                                                                                    self.mac_add_blk_size3 = None
                                                                                                                    self.mac_add_blk_size4 = None
                                                                                                                    self.manu_test_data = None
                                                                                                                    self.mfg_bits = None
                                                                                                                    self.mfg_deviation = None
                                                                                                                    self.oem_string = None
                                                                                                                    self.part_number = None
                                                                                                                    self.part_revision = None
                                                                                                                    self.pca_num = None
                                                                                                                    self.pcavid = None
                                                                                                                    self.pcb_serial_num = None
                                                                                                                    self.pid = None
                                                                                                                    self.power_consumption = None
                                                                                                                    self.power_supply_type = None
                                                                                                                    self.product_id = None
                                                                                                                    self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                                    self.rma.parent = self
                                                                                                                    self.rma_code = None
                                                                                                                    self.serial_number = None
                                                                                                                    self.snmpoid = None
                                                                                                                    self.top_assem_part_num = None
                                                                                                                    self.top_assem_vid = None
                                                                                                                    self.udi_description = None
                                                                                                                    self.udi_name = None
                                                                                                                    self.vid = None


                                                                                                                class Rma(object):
                                                                                                                    """
                                                                                                                    RMA Data
                                                                                                                    
                                                                                                                    .. attribute:: rma_history
                                                                                                                    
                                                                                                                    	RMA history
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: rma_number
                                                                                                                    
                                                                                                                    	RMA tracking number format is N\-N\-N
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: test_history
                                                                                                                    
                                                                                                                    	Test history
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.rma_history = None
                                                                                                                        self.rma_number = None
                                                                                                                        self.test_history = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.rma_history is not None:
                                                                                                                            return True

                                                                                                                        if self.rma_number is not None:
                                                                                                                            return True

                                                                                                                        if self.test_history is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.asset_alias is not None:
                                                                                                                        return True

                                                                                                                    if self.asset_id is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address1 is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address2 is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address3 is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address4 is not None:
                                                                                                                        return True

                                                                                                                    if self.block_checksum is not None:
                                                                                                                        return True

                                                                                                                    if self.block_count is not None:
                                                                                                                        return True

                                                                                                                    if self.block_length is not None:
                                                                                                                        return True

                                                                                                                    if self.block_signature is not None:
                                                                                                                        return True

                                                                                                                    if self.block_version is not None:
                                                                                                                        return True

                                                                                                                    if self.chassis_sid is not None:
                                                                                                                        return True

                                                                                                                    if self.clei is not None:
                                                                                                                        return True

                                                                                                                    if self.controller_family is not None:
                                                                                                                        return True

                                                                                                                    if self.controller_type is not None:
                                                                                                                        return True

                                                                                                                    if self.description is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num1 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num2 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num3 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num4 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num5 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num6 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num7 is not None:
                                                                                                                        return True

                                                                                                                    if self.eci is not None:
                                                                                                                        return True

                                                                                                                    if self.eeprom_size is not None:
                                                                                                                        return True

                                                                                                                    if self.engineer_use is not None:
                                                                                                                        return True

                                                                                                                    if self.fru_major_type is not None:
                                                                                                                        return True

                                                                                                                    if self.fru_minor_type is not None:
                                                                                                                        return True

                                                                                                                    if self.hw_version is not None:
                                                                                                                        return True

                                                                                                                    if self.hwid is not None:
                                                                                                                        return True

                                                                                                                    if self.idprom_format_rev is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size1 is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size2 is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size3 is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size4 is not None:
                                                                                                                        return True

                                                                                                                    if self.manu_test_data is not None:
                                                                                                                        return True

                                                                                                                    if self.mfg_bits is not None:
                                                                                                                        return True

                                                                                                                    if self.mfg_deviation is not None:
                                                                                                                        return True

                                                                                                                    if self.oem_string is not None:
                                                                                                                        return True

                                                                                                                    if self.part_number is not None:
                                                                                                                        return True

                                                                                                                    if self.part_revision is not None:
                                                                                                                        return True

                                                                                                                    if self.pca_num is not None:
                                                                                                                        return True

                                                                                                                    if self.pcavid is not None:
                                                                                                                        return True

                                                                                                                    if self.pcb_serial_num is not None:
                                                                                                                        return True

                                                                                                                    if self.pid is not None:
                                                                                                                        return True

                                                                                                                    if self.power_consumption is not None:
                                                                                                                        return True

                                                                                                                    if self.power_supply_type is not None:
                                                                                                                        return True

                                                                                                                    if self.product_id is not None:
                                                                                                                        return True

                                                                                                                    if self.rma is not None and self.rma._has_data():
                                                                                                                        return True

                                                                                                                    if self.rma_code is not None:
                                                                                                                        return True

                                                                                                                    if self.serial_number is not None:
                                                                                                                        return True

                                                                                                                    if self.snmpoid is not None:
                                                                                                                        return True

                                                                                                                    if self.top_assem_part_num is not None:
                                                                                                                        return True

                                                                                                                    if self.top_assem_vid is not None:
                                                                                                                        return True

                                                                                                                    if self.udi_description is not None:
                                                                                                                        return True

                                                                                                                    if self.udi_name is not None:
                                                                                                                        return True

                                                                                                                    if self.vid is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.description is not None:
                                                                                                                    return True

                                                                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                                                                    return True

                                                                                                                if self.has_eeprom is not None:
                                                                                                                    return True

                                                                                                                if self.inv_card_type is not None:
                                                                                                                    return True

                                                                                                                if self.opaque_data is not None:
                                                                                                                    return True

                                                                                                                if self.opaque_data_size is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                                return True

                                                                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                                return True

                                                                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                                                                return True

                                                                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                                return True

                                                                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                                return True

                                                                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                                return True

                                                                                                            if self.module_done is not None:
                                                                                                                return True

                                                                                                            if self.node_id is not None:
                                                                                                                return True

                                                                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                                return True

                                                                                                            if self.threshold is not None and self.threshold._has_data():
                                                                                                                return True

                                                                                                            if self.vm_done is not None:
                                                                                                                return True

                                                                                                            if self.vm_node_id is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                                        if self.name is None:
                                                                                                            raise YPYModelError('Key property name is None')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi10[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.name is not None:
                                                                                                            return True

                                                                                                        if self.attributes is not None and self.attributes._has_data():
                                                                                                            return True

                                                                                                        if self.tsi11s is not None and self.tsi11s._has_data():
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi10s'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.tsi10 is not None:
                                                                                                        for child_ref in self.tsi10:
                                                                                                            if child_ref._has_data():
                                                                                                                return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S']['meta_info']


                                                                                            class Attributes(object):
                                                                                                """
                                                                                                Attributes
                                                                                                
                                                                                                .. attribute:: env_sensor_info
                                                                                                
                                                                                                	Environment sensor info
                                                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfo>`
                                                                                                
                                                                                                .. attribute:: env_sensor_info_xml
                                                                                                
                                                                                                	Environment sensor info XML
                                                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml>`
                                                                                                
                                                                                                .. attribute:: fru_info
                                                                                                
                                                                                                	Inventory EDM FRU info
                                                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo>`
                                                                                                
                                                                                                .. attribute:: inv_asset_bag
                                                                                                
                                                                                                	Inventory Asset Bag
                                                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvAssetBag>`
                                                                                                
                                                                                                .. attribute:: inv_basic_bag
                                                                                                
                                                                                                	Inventory Basic Bag
                                                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvBasicBag>`
                                                                                                
                                                                                                .. attribute:: inv_eeprom_info
                                                                                                
                                                                                                	Inventory EDM EEPROM Information Bag
                                                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo>`
                                                                                                
                                                                                                .. attribute:: module_done
                                                                                                
                                                                                                	Inventory EDM Module Done Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**default value**\: 1
                                                                                                
                                                                                                .. attribute:: node_id
                                                                                                
                                                                                                	Node ID Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** 0..4294967295
                                                                                                
                                                                                                .. attribute:: pwg_info
                                                                                                
                                                                                                	Inventory EDM PWG info
                                                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.PwgInfo>`
                                                                                                
                                                                                                .. attribute:: threshold
                                                                                                
                                                                                                	Threshold
                                                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold>`
                                                                                                
                                                                                                .. attribute:: vm_done
                                                                                                
                                                                                                	VM Done Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                .. attribute:: vm_node_id
                                                                                                
                                                                                                	VM Node ID Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** 0..4294967295
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfo()
                                                                                                    self.env_sensor_info.parent = self
                                                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml()
                                                                                                    self.env_sensor_info_xml.parent = self
                                                                                                    self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo()
                                                                                                    self.fru_info.parent = self
                                                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvAssetBag()
                                                                                                    self.inv_asset_bag.parent = self
                                                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvBasicBag()
                                                                                                    self.inv_basic_bag.parent = self
                                                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo()
                                                                                                    self.inv_eeprom_info.parent = self
                                                                                                    self.module_done = None
                                                                                                    self.node_id = None
                                                                                                    self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.PwgInfo()
                                                                                                    self.pwg_info.parent = self
                                                                                                    self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold()
                                                                                                    self.threshold.parent = self
                                                                                                    self.vm_done = None
                                                                                                    self.vm_node_id = None


                                                                                                class EnvSensorInfo(object):
                                                                                                    """
                                                                                                    Environment sensor info
                                                                                                    
                                                                                                    .. attribute:: age_time_stamp
                                                                                                    
                                                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: alarm_type
                                                                                                    
                                                                                                    	Indicates threshold violation
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: data_type
                                                                                                    
                                                                                                    	Sensor data type enums
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: device_description
                                                                                                    
                                                                                                    	Device Name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: device_id
                                                                                                    
                                                                                                    	Identifier for this device
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: field_validity_bitmap
                                                                                                    
                                                                                                    	Sensor valid bitmap
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: precision
                                                                                                    
                                                                                                    	Sensor precision range
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: scale
                                                                                                    
                                                                                                    	Sensor scale enums
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: status
                                                                                                    
                                                                                                    	Sensor operation state enums
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: units
                                                                                                    
                                                                                                    	Units of variable being read
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: update_rate
                                                                                                    
                                                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: value
                                                                                                    
                                                                                                    	Current reading of sensor
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.age_time_stamp = None
                                                                                                        self.alarm_type = None
                                                                                                        self.data_type = None
                                                                                                        self.device_description = None
                                                                                                        self.device_id = None
                                                                                                        self.field_validity_bitmap = None
                                                                                                        self.precision = None
                                                                                                        self.scale = None
                                                                                                        self.status = None
                                                                                                        self.units = None
                                                                                                        self.update_rate = None
                                                                                                        self.value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.age_time_stamp is not None:
                                                                                                            return True

                                                                                                        if self.alarm_type is not None:
                                                                                                            return True

                                                                                                        if self.data_type is not None:
                                                                                                            return True

                                                                                                        if self.device_description is not None:
                                                                                                            return True

                                                                                                        if self.device_id is not None:
                                                                                                            return True

                                                                                                        if self.field_validity_bitmap is not None:
                                                                                                            return True

                                                                                                        if self.precision is not None:
                                                                                                            return True

                                                                                                        if self.scale is not None:
                                                                                                            return True

                                                                                                        if self.status is not None:
                                                                                                            return True

                                                                                                        if self.units is not None:
                                                                                                            return True

                                                                                                        if self.update_rate is not None:
                                                                                                            return True

                                                                                                        if self.value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfo']['meta_info']


                                                                                                class PwgInfo(object):
                                                                                                    """
                                                                                                    Inventory EDM PWG info
                                                                                                    
                                                                                                    .. attribute:: power_group_available_current
                                                                                                    
                                                                                                    	available current
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_group_drawn_current
                                                                                                    
                                                                                                    	drawn current
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_group_power_units
                                                                                                    
                                                                                                    	power units
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    .. attribute:: power_group_redundancy_mode
                                                                                                    
                                                                                                    	redundancy mode
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.power_group_available_current = None
                                                                                                        self.power_group_drawn_current = None
                                                                                                        self.power_group_power_units = None
                                                                                                        self.power_group_redundancy_mode = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.power_group_available_current is not None:
                                                                                                            return True

                                                                                                        if self.power_group_drawn_current is not None:
                                                                                                            return True

                                                                                                        if self.power_group_power_units is not None:
                                                                                                            return True

                                                                                                        if self.power_group_redundancy_mode is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.PwgInfo']['meta_info']


                                                                                                class EnvSensorInfoXml(object):
                                                                                                    """
                                                                                                    Environment sensor info XML
                                                                                                    
                                                                                                    .. attribute:: data_type
                                                                                                    
                                                                                                    	Sensor data type
                                                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                                    
                                                                                                    .. attribute:: description
                                                                                                    
                                                                                                    	Device Name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: status
                                                                                                    
                                                                                                    	Sensor operation state
                                                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                                    
                                                                                                    .. attribute:: threshold
                                                                                                    
                                                                                                    	Threshold information
                                                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                                    
                                                                                                    .. attribute:: units
                                                                                                    
                                                                                                    	Units of variable being read
                                                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                                    
                                                                                                    .. attribute:: update_rate
                                                                                                    
                                                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: value
                                                                                                    
                                                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.data_type = None
                                                                                                        self.description = None
                                                                                                        self.status = None
                                                                                                        self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                        self.threshold.parent = self
                                                                                                        self.units = None
                                                                                                        self.update_rate = None
                                                                                                        self.value = None


                                                                                                    class Threshold(object):
                                                                                                        """
                                                                                                        Threshold information
                                                                                                        
                                                                                                        .. attribute:: threshold_array
                                                                                                        
                                                                                                        	Array of threshold
                                                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.threshold_array = YList()
                                                                                                            self.threshold_array.parent = self
                                                                                                            self.threshold_array.name = 'threshold_array'


                                                                                                        class ThresholdArray(object):
                                                                                                            """
                                                                                                            Array of threshold
                                                                                                            
                                                                                                            .. attribute:: threshold_name
                                                                                                            
                                                                                                            	Threshold name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_name = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_name is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.threshold_array is not None:
                                                                                                                for child_ref in self.threshold_array:
                                                                                                                    if child_ref._has_data():
                                                                                                                        return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.data_type is not None:
                                                                                                            return True

                                                                                                        if self.description is not None:
                                                                                                            return True

                                                                                                        if self.status is not None:
                                                                                                            return True

                                                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                                                            return True

                                                                                                        if self.units is not None:
                                                                                                            return True

                                                                                                        if self.update_rate is not None:
                                                                                                            return True

                                                                                                        if self.value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                                class InvAssetBag(object):
                                                                                                    """
                                                                                                    Inventory Asset Bag
                                                                                                    
                                                                                                    .. attribute:: manufacturer_assembly_number
                                                                                                    
                                                                                                    	Manufacture Assembly number
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_assembly_revision
                                                                                                    
                                                                                                    	Manufacture assembly revision
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                                    
                                                                                                    	Common Language Equipment           Identifier number
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                                                    
                                                                                                    	
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_software_identifier
                                                                                                    
                                                                                                    	
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                                                    
                                                                                                    	String containing OEM information           if applicable
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: part_number
                                                                                                    
                                                                                                    	
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.manufacturer_assembly_number = None
                                                                                                        self.manufacturer_assembly_revision = None
                                                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                                                        self.manufacturer_firmware_identifier = None
                                                                                                        self.manufacturer_software_identifier = None
                                                                                                        self.original_equipment_manufacturer_string = None
                                                                                                        self.part_number = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.manufacturer_assembly_number is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_assembly_revision is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_software_identifier is not None:
                                                                                                            return True

                                                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                                                            return True

                                                                                                        if self.part_number is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvAssetBag']['meta_info']


                                                                                                class Threshold(object):
                                                                                                    """
                                                                                                    Threshold
                                                                                                    
                                                                                                    .. attribute:: critical_hi
                                                                                                    
                                                                                                    	Critical High
                                                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi>`
                                                                                                    
                                                                                                    .. attribute:: critical_lo
                                                                                                    
                                                                                                    	Critical Low
                                                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo>`
                                                                                                    
                                                                                                    .. attribute:: major_hi
                                                                                                    
                                                                                                    	Major High
                                                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi>`
                                                                                                    
                                                                                                    .. attribute:: major_lo
                                                                                                    
                                                                                                    	Major Low
                                                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo>`
                                                                                                    
                                                                                                    .. attribute:: minor_hi
                                                                                                    
                                                                                                    	Minor High
                                                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi>`
                                                                                                    
                                                                                                    .. attribute:: minor_lo
                                                                                                    
                                                                                                    	Minor Low
                                                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo>`
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi()
                                                                                                        self.critical_hi.parent = self
                                                                                                        self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo()
                                                                                                        self.critical_lo.parent = self
                                                                                                        self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi()
                                                                                                        self.major_hi.parent = self
                                                                                                        self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo()
                                                                                                        self.major_lo.parent = self
                                                                                                        self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi()
                                                                                                        self.minor_hi.parent = self
                                                                                                        self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo()
                                                                                                        self.minor_lo.parent = self


                                                                                                    class MajorLo(object):
                                                                                                        """
                                                                                                        Major Low
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo']['meta_info']


                                                                                                    class CriticalHi(object):
                                                                                                        """
                                                                                                        Critical High
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                                    class MinorHi(object):
                                                                                                        """
                                                                                                        Minor High
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi']['meta_info']


                                                                                                    class MajorHi(object):
                                                                                                        """
                                                                                                        Major High
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi']['meta_info']


                                                                                                    class CriticalLo(object):
                                                                                                        """
                                                                                                        Critical Low
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                                    class MinorLo(object):
                                                                                                        """
                                                                                                        Minor Low
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                            return True

                                                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                            return True

                                                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                                                            return True

                                                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                                                            return True

                                                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                            return True

                                                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold']['meta_info']


                                                                                                class FruInfo(object):
                                                                                                    """
                                                                                                    Inventory EDM FRU info
                                                                                                    
                                                                                                    .. attribute:: card_administrative_state
                                                                                                    
                                                                                                    	card admin state\: shutdown or not
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: card_monitor_state
                                                                                                    
                                                                                                    	card is monitored by a manager or left unmonitored
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: card_operational_state
                                                                                                    
                                                                                                    	card operation state
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: card_reset_reason
                                                                                                    
                                                                                                    	card reset reason enum
                                                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                                    
                                                                                                    .. attribute:: card_up_time
                                                                                                    
                                                                                                    	card up time
                                                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.CardUpTime>`
                                                                                                    
                                                                                                    .. attribute:: last_operational_state_change
                                                                                                    
                                                                                                    	last card oper change state
                                                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                                    
                                                                                                    .. attribute:: power_administrative_state
                                                                                                    
                                                                                                    	power admin state\: up or down
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_current_measurement
                                                                                                    
                                                                                                    	power current\: not implemented
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_operational_state
                                                                                                    
                                                                                                    	Power operation state
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.card_administrative_state = None
                                                                                                        self.card_monitor_state = None
                                                                                                        self.card_operational_state = None
                                                                                                        self.card_reset_reason = None
                                                                                                        self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.CardUpTime()
                                                                                                        self.card_up_time.parent = self
                                                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                        self.last_operational_state_change.parent = self
                                                                                                        self.power_administrative_state = None
                                                                                                        self.power_current_measurement = None
                                                                                                        self.power_operational_state = None


                                                                                                    class LastOperationalStateChange(object):
                                                                                                        """
                                                                                                        last card oper change state
                                                                                                        
                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                        
                                                                                                        	Time Value in Nano\-seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: nanosecond
                                                                                                        
                                                                                                        .. attribute:: time_in_seconds
                                                                                                        
                                                                                                        	Time Value in Seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: second
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.time_in_nano_seconds = None
                                                                                                            self.time_in_seconds = None

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                return True

                                                                                                            if self.time_in_seconds is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                                    class CardUpTime(object):
                                                                                                        """
                                                                                                        card up time
                                                                                                        
                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                        
                                                                                                        	Time Value in Nano\-seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: nanosecond
                                                                                                        
                                                                                                        .. attribute:: time_in_seconds
                                                                                                        
                                                                                                        	Time Value in Seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: second
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.time_in_nano_seconds = None
                                                                                                            self.time_in_seconds = None

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                return True

                                                                                                            if self.time_in_seconds is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.card_administrative_state is not None:
                                                                                                            return True

                                                                                                        if self.card_monitor_state is not None:
                                                                                                            return True

                                                                                                        if self.card_operational_state is not None:
                                                                                                            return True

                                                                                                        if self.card_reset_reason is not None:
                                                                                                            return True

                                                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                            return True

                                                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                            return True

                                                                                                        if self.power_administrative_state is not None:
                                                                                                            return True

                                                                                                        if self.power_current_measurement is not None:
                                                                                                            return True

                                                                                                        if self.power_operational_state is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo']['meta_info']


                                                                                                class InvBasicBag(object):
                                                                                                    """
                                                                                                    Inventory Basic Bag
                                                                                                    
                                                                                                    .. attribute:: alias
                                                                                                    
                                                                                                    	useful for storing an entity alias 
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: asset_id_str
                                                                                                    
                                                                                                    	asset Identification string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: asset_identification
                                                                                                    
                                                                                                    	asset Identification
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: ceport
                                                                                                    
                                                                                                    	1 if ce port found, 0 if not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: chip_hardware_revision
                                                                                                    
                                                                                                    	chip module hw revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: composite_class_code
                                                                                                    
                                                                                                    	Major&minor class of the entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: description
                                                                                                    
                                                                                                    	describes in user\-readable terms       what the entity in question does
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: environmental_monitor_path
                                                                                                    
                                                                                                    	sysdb name of sensor in the envmon EDM
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: firmware_revision
                                                                                                    
                                                                                                    	firmware revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: group_flag
                                                                                                    
                                                                                                    	indicates if this entity is group       or not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: hardware_revision
                                                                                                    
                                                                                                    	hw revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: is_field_replaceable_unit
                                                                                                    
                                                                                                    	1 if Field Replaceable Unit 0, if not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: manufacturer_asset_tags
                                                                                                    
                                                                                                    	Manufacture Asset Tags
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: manufacturer_name
                                                                                                    
                                                                                                    	manufacturer's name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: memory_size
                                                                                                    
                                                                                                    	Size of memory associated with       the entity where applicable
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: model_name
                                                                                                    
                                                                                                    	model name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: name
                                                                                                    
                                                                                                    	name string for the entity
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: new_deviation_number
                                                                                                    
                                                                                                    	integer value for New Deviation Number 0x88
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: physical_layer_interface_module_type
                                                                                                    
                                                                                                    	integer value for plim type if     applicable to this entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: redundancystate
                                                                                                    
                                                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: serial_number
                                                                                                    
                                                                                                    	serial number
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: software_revision
                                                                                                    
                                                                                                    	software revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: unique_id
                                                                                                    
                                                                                                    	Unique id for an entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: unrecognized_fru
                                                                                                    
                                                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: vendor_type
                                                                                                    
                                                                                                    	maps to the vendor OID string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: xr_scoped
                                                                                                    
                                                                                                    	1 if xr scoped, 0 if not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.alias = None
                                                                                                        self.asset_id_str = None
                                                                                                        self.asset_identification = None
                                                                                                        self.ceport = None
                                                                                                        self.chip_hardware_revision = None
                                                                                                        self.composite_class_code = None
                                                                                                        self.description = None
                                                                                                        self.environmental_monitor_path = None
                                                                                                        self.firmware_revision = None
                                                                                                        self.group_flag = None
                                                                                                        self.hardware_revision = None
                                                                                                        self.is_field_replaceable_unit = None
                                                                                                        self.manufacturer_asset_tags = None
                                                                                                        self.manufacturer_name = None
                                                                                                        self.memory_size = None
                                                                                                        self.model_name = None
                                                                                                        self.name = None
                                                                                                        self.new_deviation_number = None
                                                                                                        self.physical_layer_interface_module_type = None
                                                                                                        self.redundancystate = None
                                                                                                        self.serial_number = None
                                                                                                        self.software_revision = None
                                                                                                        self.unique_id = None
                                                                                                        self.unrecognized_fru = None
                                                                                                        self.vendor_type = None
                                                                                                        self.xr_scoped = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.alias is not None:
                                                                                                            return True

                                                                                                        if self.asset_id_str is not None:
                                                                                                            return True

                                                                                                        if self.asset_identification is not None:
                                                                                                            return True

                                                                                                        if self.ceport is not None:
                                                                                                            return True

                                                                                                        if self.chip_hardware_revision is not None:
                                                                                                            return True

                                                                                                        if self.composite_class_code is not None:
                                                                                                            return True

                                                                                                        if self.description is not None:
                                                                                                            return True

                                                                                                        if self.environmental_monitor_path is not None:
                                                                                                            return True

                                                                                                        if self.firmware_revision is not None:
                                                                                                            return True

                                                                                                        if self.group_flag is not None:
                                                                                                            return True

                                                                                                        if self.hardware_revision is not None:
                                                                                                            return True

                                                                                                        if self.is_field_replaceable_unit is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_asset_tags is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_name is not None:
                                                                                                            return True

                                                                                                        if self.memory_size is not None:
                                                                                                            return True

                                                                                                        if self.model_name is not None:
                                                                                                            return True

                                                                                                        if self.name is not None:
                                                                                                            return True

                                                                                                        if self.new_deviation_number is not None:
                                                                                                            return True

                                                                                                        if self.physical_layer_interface_module_type is not None:
                                                                                                            return True

                                                                                                        if self.redundancystate is not None:
                                                                                                            return True

                                                                                                        if self.serial_number is not None:
                                                                                                            return True

                                                                                                        if self.software_revision is not None:
                                                                                                            return True

                                                                                                        if self.unique_id is not None:
                                                                                                            return True

                                                                                                        if self.unrecognized_fru is not None:
                                                                                                            return True

                                                                                                        if self.vendor_type is not None:
                                                                                                            return True

                                                                                                        if self.xr_scoped is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvBasicBag']['meta_info']


                                                                                                class InvEepromInfo(object):
                                                                                                    """
                                                                                                    Inventory EDM EEPROM Information Bag
                                                                                                    
                                                                                                    .. attribute:: description
                                                                                                    
                                                                                                    	A textual description of physical entity
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: eeprom
                                                                                                    
                                                                                                    	EEPROM data not from hex data
                                                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom>`
                                                                                                    
                                                                                                    .. attribute:: has_eeprom
                                                                                                    
                                                                                                    	use eeprom instead of opaque data
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: inv_card_type
                                                                                                    
                                                                                                    	Inventory card type
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..255
                                                                                                    
                                                                                                    .. attribute:: opaque_data
                                                                                                    
                                                                                                    	EEPROM hex data
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                                    
                                                                                                    .. attribute:: opaque_data_size
                                                                                                    
                                                                                                    	size of the EEPROM hex data
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.description = None
                                                                                                        self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom()
                                                                                                        self.eeprom.parent = self
                                                                                                        self.has_eeprom = None
                                                                                                        self.inv_card_type = None
                                                                                                        self.opaque_data = None
                                                                                                        self.opaque_data_size = None


                                                                                                    class Eeprom(object):
                                                                                                        """
                                                                                                        EEPROM data not from hex data
                                                                                                        
                                                                                                        .. attribute:: asset_alias
                                                                                                        
                                                                                                        	Asset Alias
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: asset_id
                                                                                                        
                                                                                                        	Asset ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address1
                                                                                                        
                                                                                                        	Base Mac Address #1
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address2
                                                                                                        
                                                                                                        	Base Mac Address #2
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address3
                                                                                                        
                                                                                                        	Base Mac Address #3
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address4
                                                                                                        
                                                                                                        	Base Mac Address #4
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_checksum
                                                                                                        
                                                                                                        	Block Checksum
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_count
                                                                                                        
                                                                                                        	Block Count
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_length
                                                                                                        
                                                                                                        	Block Length
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_signature
                                                                                                        
                                                                                                        	Block Signature
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_version
                                                                                                        
                                                                                                        	Block Version
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: chassis_sid
                                                                                                        
                                                                                                        	Chassis serial number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: clei
                                                                                                        
                                                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: controller_family
                                                                                                        
                                                                                                        	Controller family
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: controller_type
                                                                                                        
                                                                                                        	Controller type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: description
                                                                                                        
                                                                                                        	A textual description of physical entity
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num1
                                                                                                        
                                                                                                        	Deviation Number # 1
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num2
                                                                                                        
                                                                                                        	Deviation Number # 2
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num3
                                                                                                        
                                                                                                        	Deviation Number # 3
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num4
                                                                                                        
                                                                                                        	Deviation Number # 4
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num5
                                                                                                        
                                                                                                        	Deviation Number # 5
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num6
                                                                                                        
                                                                                                        	Deviation Number # 6
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num7
                                                                                                        
                                                                                                        	Deviation Number # 7
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: eci
                                                                                                        
                                                                                                        	Equipment Catalog Item (ECI) number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: eeprom_size
                                                                                                        
                                                                                                        	EEPROM Size
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: engineer_use
                                                                                                        
                                                                                                        	Engineer Use
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: fru_major_type
                                                                                                        
                                                                                                        	FRU Major Type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: fru_minor_type
                                                                                                        
                                                                                                        	FRU Minor Type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: hw_version
                                                                                                        
                                                                                                        	Hardware Version
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: hwid
                                                                                                        
                                                                                                        	Hardware Revision
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: idprom_format_rev
                                                                                                        
                                                                                                        	IDPROM Format Revision
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size1
                                                                                                        
                                                                                                        	Mac Address Block Size #1
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size2
                                                                                                        
                                                                                                        	Mac Address Block Size #2
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size3
                                                                                                        
                                                                                                        	Mac Address Block Size #3
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size4
                                                                                                        
                                                                                                        	Mac Address Block Size #4
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: manu_test_data
                                                                                                        
                                                                                                        	Manufacturing Test Data
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mfg_bits
                                                                                                        
                                                                                                        	MFG Bits
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mfg_deviation
                                                                                                        
                                                                                                        	MFG Deviation
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: oem_string
                                                                                                        
                                                                                                        	OEM String
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: part_number
                                                                                                        
                                                                                                        	Part Number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: part_revision
                                                                                                        
                                                                                                        	Part Revision
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pca_num
                                                                                                        
                                                                                                        	PCA number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pcavid
                                                                                                        
                                                                                                        	PCA revision ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pcb_serial_num
                                                                                                        
                                                                                                        	PCB Serial Number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pid
                                                                                                        
                                                                                                        	Product ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: power_consumption
                                                                                                        
                                                                                                        	Power Consumption
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: power_supply_type
                                                                                                        
                                                                                                        	Power Supply Type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: product_id
                                                                                                        
                                                                                                        	Product ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: rma
                                                                                                        
                                                                                                        	RMA Data
                                                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                        
                                                                                                        .. attribute:: rma_code
                                                                                                        
                                                                                                        	RMA Code
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: serial_number
                                                                                                        
                                                                                                        	Serial Number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: snmpoid
                                                                                                        
                                                                                                        	SNMP OID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: top_assem_part_num
                                                                                                        
                                                                                                        	Top assembly part number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: top_assem_vid
                                                                                                        
                                                                                                        	Top assembly revision number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: udi_description
                                                                                                        
                                                                                                        	UDI description
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: udi_name
                                                                                                        
                                                                                                        	UDI name
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: vid
                                                                                                        
                                                                                                        	Version ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.asset_alias = None
                                                                                                            self.asset_id = None
                                                                                                            self.base_mac_address1 = None
                                                                                                            self.base_mac_address2 = None
                                                                                                            self.base_mac_address3 = None
                                                                                                            self.base_mac_address4 = None
                                                                                                            self.block_checksum = None
                                                                                                            self.block_count = None
                                                                                                            self.block_length = None
                                                                                                            self.block_signature = None
                                                                                                            self.block_version = None
                                                                                                            self.chassis_sid = None
                                                                                                            self.clei = None
                                                                                                            self.controller_family = None
                                                                                                            self.controller_type = None
                                                                                                            self.description = None
                                                                                                            self.dev_num1 = None
                                                                                                            self.dev_num2 = None
                                                                                                            self.dev_num3 = None
                                                                                                            self.dev_num4 = None
                                                                                                            self.dev_num5 = None
                                                                                                            self.dev_num6 = None
                                                                                                            self.dev_num7 = None
                                                                                                            self.eci = None
                                                                                                            self.eeprom_size = None
                                                                                                            self.engineer_use = None
                                                                                                            self.fru_major_type = None
                                                                                                            self.fru_minor_type = None
                                                                                                            self.hw_version = None
                                                                                                            self.hwid = None
                                                                                                            self.idprom_format_rev = None
                                                                                                            self.mac_add_blk_size1 = None
                                                                                                            self.mac_add_blk_size2 = None
                                                                                                            self.mac_add_blk_size3 = None
                                                                                                            self.mac_add_blk_size4 = None
                                                                                                            self.manu_test_data = None
                                                                                                            self.mfg_bits = None
                                                                                                            self.mfg_deviation = None
                                                                                                            self.oem_string = None
                                                                                                            self.part_number = None
                                                                                                            self.part_revision = None
                                                                                                            self.pca_num = None
                                                                                                            self.pcavid = None
                                                                                                            self.pcb_serial_num = None
                                                                                                            self.pid = None
                                                                                                            self.power_consumption = None
                                                                                                            self.power_supply_type = None
                                                                                                            self.product_id = None
                                                                                                            self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                            self.rma.parent = self
                                                                                                            self.rma_code = None
                                                                                                            self.serial_number = None
                                                                                                            self.snmpoid = None
                                                                                                            self.top_assem_part_num = None
                                                                                                            self.top_assem_vid = None
                                                                                                            self.udi_description = None
                                                                                                            self.udi_name = None
                                                                                                            self.vid = None


                                                                                                        class Rma(object):
                                                                                                            """
                                                                                                            RMA Data
                                                                                                            
                                                                                                            .. attribute:: rma_history
                                                                                                            
                                                                                                            	RMA history
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: rma_number
                                                                                                            
                                                                                                            	RMA tracking number format is N\-N\-N
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: test_history
                                                                                                            
                                                                                                            	Test history
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.rma_history = None
                                                                                                                self.rma_number = None
                                                                                                                self.test_history = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.rma_history is not None:
                                                                                                                    return True

                                                                                                                if self.rma_number is not None:
                                                                                                                    return True

                                                                                                                if self.test_history is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.asset_alias is not None:
                                                                                                                return True

                                                                                                            if self.asset_id is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address1 is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address2 is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address3 is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address4 is not None:
                                                                                                                return True

                                                                                                            if self.block_checksum is not None:
                                                                                                                return True

                                                                                                            if self.block_count is not None:
                                                                                                                return True

                                                                                                            if self.block_length is not None:
                                                                                                                return True

                                                                                                            if self.block_signature is not None:
                                                                                                                return True

                                                                                                            if self.block_version is not None:
                                                                                                                return True

                                                                                                            if self.chassis_sid is not None:
                                                                                                                return True

                                                                                                            if self.clei is not None:
                                                                                                                return True

                                                                                                            if self.controller_family is not None:
                                                                                                                return True

                                                                                                            if self.controller_type is not None:
                                                                                                                return True

                                                                                                            if self.description is not None:
                                                                                                                return True

                                                                                                            if self.dev_num1 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num2 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num3 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num4 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num5 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num6 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num7 is not None:
                                                                                                                return True

                                                                                                            if self.eci is not None:
                                                                                                                return True

                                                                                                            if self.eeprom_size is not None:
                                                                                                                return True

                                                                                                            if self.engineer_use is not None:
                                                                                                                return True

                                                                                                            if self.fru_major_type is not None:
                                                                                                                return True

                                                                                                            if self.fru_minor_type is not None:
                                                                                                                return True

                                                                                                            if self.hw_version is not None:
                                                                                                                return True

                                                                                                            if self.hwid is not None:
                                                                                                                return True

                                                                                                            if self.idprom_format_rev is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size1 is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size2 is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size3 is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size4 is not None:
                                                                                                                return True

                                                                                                            if self.manu_test_data is not None:
                                                                                                                return True

                                                                                                            if self.mfg_bits is not None:
                                                                                                                return True

                                                                                                            if self.mfg_deviation is not None:
                                                                                                                return True

                                                                                                            if self.oem_string is not None:
                                                                                                                return True

                                                                                                            if self.part_number is not None:
                                                                                                                return True

                                                                                                            if self.part_revision is not None:
                                                                                                                return True

                                                                                                            if self.pca_num is not None:
                                                                                                                return True

                                                                                                            if self.pcavid is not None:
                                                                                                                return True

                                                                                                            if self.pcb_serial_num is not None:
                                                                                                                return True

                                                                                                            if self.pid is not None:
                                                                                                                return True

                                                                                                            if self.power_consumption is not None:
                                                                                                                return True

                                                                                                            if self.power_supply_type is not None:
                                                                                                                return True

                                                                                                            if self.product_id is not None:
                                                                                                                return True

                                                                                                            if self.rma is not None and self.rma._has_data():
                                                                                                                return True

                                                                                                            if self.rma_code is not None:
                                                                                                                return True

                                                                                                            if self.serial_number is not None:
                                                                                                                return True

                                                                                                            if self.snmpoid is not None:
                                                                                                                return True

                                                                                                            if self.top_assem_part_num is not None:
                                                                                                                return True

                                                                                                            if self.top_assem_vid is not None:
                                                                                                                return True

                                                                                                            if self.udi_description is not None:
                                                                                                                return True

                                                                                                            if self.udi_name is not None:
                                                                                                                return True

                                                                                                            if self.vid is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.description is not None:
                                                                                                            return True

                                                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                                                            return True

                                                                                                        if self.has_eeprom is not None:
                                                                                                            return True

                                                                                                        if self.inv_card_type is not None:
                                                                                                            return True

                                                                                                        if self.opaque_data is not None:
                                                                                                            return True

                                                                                                        if self.opaque_data_size is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                        return True

                                                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                        return True

                                                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                                                        return True

                                                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                        return True

                                                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                        return True

                                                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                        return True

                                                                                                    if self.module_done is not None:
                                                                                                        return True

                                                                                                    if self.node_id is not None:
                                                                                                        return True

                                                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                        return True

                                                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                                                        return True

                                                                                                    if self.vm_done is not None:
                                                                                                        return True

                                                                                                    if self.vm_node_id is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                                if self.name is None:
                                                                                                    raise YPYModelError('Key property name is None')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi9[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.name is not None:
                                                                                                    return True

                                                                                                if self.attributes is not None and self.attributes._has_data():
                                                                                                    return True

                                                                                                if self.tsi10s is not None and self.tsi10s._has_data():
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi9s'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.tsi9 is not None:
                                                                                                for child_ref in self.tsi9:
                                                                                                    if child_ref._has_data():
                                                                                                        return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S']['meta_info']


                                                                                    class Attributes(object):
                                                                                        """
                                                                                        Attributes
                                                                                        
                                                                                        .. attribute:: env_sensor_info
                                                                                        
                                                                                        	Environment sensor info
                                                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfo>`
                                                                                        
                                                                                        .. attribute:: env_sensor_info_xml
                                                                                        
                                                                                        	Environment sensor info XML
                                                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml>`
                                                                                        
                                                                                        .. attribute:: fru_info
                                                                                        
                                                                                        	Inventory EDM FRU info
                                                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo>`
                                                                                        
                                                                                        .. attribute:: inv_asset_bag
                                                                                        
                                                                                        	Inventory Asset Bag
                                                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvAssetBag>`
                                                                                        
                                                                                        .. attribute:: inv_basic_bag
                                                                                        
                                                                                        	Inventory Basic Bag
                                                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvBasicBag>`
                                                                                        
                                                                                        .. attribute:: inv_eeprom_info
                                                                                        
                                                                                        	Inventory EDM EEPROM Information Bag
                                                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo>`
                                                                                        
                                                                                        .. attribute:: module_done
                                                                                        
                                                                                        	Inventory EDM Module Done Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**default value**\: 1
                                                                                        
                                                                                        .. attribute:: node_id
                                                                                        
                                                                                        	Node ID Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** 0..4294967295
                                                                                        
                                                                                        .. attribute:: pwg_info
                                                                                        
                                                                                        	Inventory EDM PWG info
                                                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.PwgInfo>`
                                                                                        
                                                                                        .. attribute:: threshold
                                                                                        
                                                                                        	Threshold
                                                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold>`
                                                                                        
                                                                                        .. attribute:: vm_done
                                                                                        
                                                                                        	VM Done Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        .. attribute:: vm_node_id
                                                                                        
                                                                                        	VM Node ID Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** 0..4294967295
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfo()
                                                                                            self.env_sensor_info.parent = self
                                                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml()
                                                                                            self.env_sensor_info_xml.parent = self
                                                                                            self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo()
                                                                                            self.fru_info.parent = self
                                                                                            self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvAssetBag()
                                                                                            self.inv_asset_bag.parent = self
                                                                                            self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvBasicBag()
                                                                                            self.inv_basic_bag.parent = self
                                                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo()
                                                                                            self.inv_eeprom_info.parent = self
                                                                                            self.module_done = None
                                                                                            self.node_id = None
                                                                                            self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.PwgInfo()
                                                                                            self.pwg_info.parent = self
                                                                                            self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold()
                                                                                            self.threshold.parent = self
                                                                                            self.vm_done = None
                                                                                            self.vm_node_id = None


                                                                                        class EnvSensorInfo(object):
                                                                                            """
                                                                                            Environment sensor info
                                                                                            
                                                                                            .. attribute:: age_time_stamp
                                                                                            
                                                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: alarm_type
                                                                                            
                                                                                            	Indicates threshold violation
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: data_type
                                                                                            
                                                                                            	Sensor data type enums
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: device_description
                                                                                            
                                                                                            	Device Name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: device_id
                                                                                            
                                                                                            	Identifier for this device
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: field_validity_bitmap
                                                                                            
                                                                                            	Sensor valid bitmap
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: precision
                                                                                            
                                                                                            	Sensor precision range
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: scale
                                                                                            
                                                                                            	Sensor scale enums
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: status
                                                                                            
                                                                                            	Sensor operation state enums
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: units
                                                                                            
                                                                                            	Units of variable being read
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: update_rate
                                                                                            
                                                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: value
                                                                                            
                                                                                            	Current reading of sensor
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.age_time_stamp = None
                                                                                                self.alarm_type = None
                                                                                                self.data_type = None
                                                                                                self.device_description = None
                                                                                                self.device_id = None
                                                                                                self.field_validity_bitmap = None
                                                                                                self.precision = None
                                                                                                self.scale = None
                                                                                                self.status = None
                                                                                                self.units = None
                                                                                                self.update_rate = None
                                                                                                self.value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.age_time_stamp is not None:
                                                                                                    return True

                                                                                                if self.alarm_type is not None:
                                                                                                    return True

                                                                                                if self.data_type is not None:
                                                                                                    return True

                                                                                                if self.device_description is not None:
                                                                                                    return True

                                                                                                if self.device_id is not None:
                                                                                                    return True

                                                                                                if self.field_validity_bitmap is not None:
                                                                                                    return True

                                                                                                if self.precision is not None:
                                                                                                    return True

                                                                                                if self.scale is not None:
                                                                                                    return True

                                                                                                if self.status is not None:
                                                                                                    return True

                                                                                                if self.units is not None:
                                                                                                    return True

                                                                                                if self.update_rate is not None:
                                                                                                    return True

                                                                                                if self.value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfo']['meta_info']


                                                                                        class PwgInfo(object):
                                                                                            """
                                                                                            Inventory EDM PWG info
                                                                                            
                                                                                            .. attribute:: power_group_available_current
                                                                                            
                                                                                            	available current
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_group_drawn_current
                                                                                            
                                                                                            	drawn current
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_group_power_units
                                                                                            
                                                                                            	power units
                                                                                            	**type**\:  str
                                                                                            
                                                                                            .. attribute:: power_group_redundancy_mode
                                                                                            
                                                                                            	redundancy mode
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.power_group_available_current = None
                                                                                                self.power_group_drawn_current = None
                                                                                                self.power_group_power_units = None
                                                                                                self.power_group_redundancy_mode = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.power_group_available_current is not None:
                                                                                                    return True

                                                                                                if self.power_group_drawn_current is not None:
                                                                                                    return True

                                                                                                if self.power_group_power_units is not None:
                                                                                                    return True

                                                                                                if self.power_group_redundancy_mode is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.PwgInfo']['meta_info']


                                                                                        class EnvSensorInfoXml(object):
                                                                                            """
                                                                                            Environment sensor info XML
                                                                                            
                                                                                            .. attribute:: data_type
                                                                                            
                                                                                            	Sensor data type
                                                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                            
                                                                                            .. attribute:: description
                                                                                            
                                                                                            	Device Name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: status
                                                                                            
                                                                                            	Sensor operation state
                                                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                            
                                                                                            .. attribute:: threshold
                                                                                            
                                                                                            	Threshold information
                                                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                            
                                                                                            .. attribute:: units
                                                                                            
                                                                                            	Units of variable being read
                                                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                            
                                                                                            .. attribute:: update_rate
                                                                                            
                                                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: value
                                                                                            
                                                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.data_type = None
                                                                                                self.description = None
                                                                                                self.status = None
                                                                                                self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                self.threshold.parent = self
                                                                                                self.units = None
                                                                                                self.update_rate = None
                                                                                                self.value = None


                                                                                            class Threshold(object):
                                                                                                """
                                                                                                Threshold information
                                                                                                
                                                                                                .. attribute:: threshold_array
                                                                                                
                                                                                                	Array of threshold
                                                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.threshold_array = YList()
                                                                                                    self.threshold_array.parent = self
                                                                                                    self.threshold_array.name = 'threshold_array'


                                                                                                class ThresholdArray(object):
                                                                                                    """
                                                                                                    Array of threshold
                                                                                                    
                                                                                                    .. attribute:: threshold_name
                                                                                                    
                                                                                                    	Threshold name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_name = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_name is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.threshold_array is not None:
                                                                                                        for child_ref in self.threshold_array:
                                                                                                            if child_ref._has_data():
                                                                                                                return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.data_type is not None:
                                                                                                    return True

                                                                                                if self.description is not None:
                                                                                                    return True

                                                                                                if self.status is not None:
                                                                                                    return True

                                                                                                if self.threshold is not None and self.threshold._has_data():
                                                                                                    return True

                                                                                                if self.units is not None:
                                                                                                    return True

                                                                                                if self.update_rate is not None:
                                                                                                    return True

                                                                                                if self.value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                        class InvAssetBag(object):
                                                                                            """
                                                                                            Inventory Asset Bag
                                                                                            
                                                                                            .. attribute:: manufacturer_assembly_number
                                                                                            
                                                                                            	Manufacture Assembly number
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_assembly_revision
                                                                                            
                                                                                            	Manufacture assembly revision
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                            
                                                                                            	Common Language Equipment           Identifier number
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_firmware_identifier
                                                                                            
                                                                                            	
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_software_identifier
                                                                                            
                                                                                            	
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: original_equipment_manufacturer_string
                                                                                            
                                                                                            	String containing OEM information           if applicable
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: part_number
                                                                                            
                                                                                            	
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.manufacturer_assembly_number = None
                                                                                                self.manufacturer_assembly_revision = None
                                                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                                                self.manufacturer_firmware_identifier = None
                                                                                                self.manufacturer_software_identifier = None
                                                                                                self.original_equipment_manufacturer_string = None
                                                                                                self.part_number = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.manufacturer_assembly_number is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_assembly_revision is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_firmware_identifier is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_software_identifier is not None:
                                                                                                    return True

                                                                                                if self.original_equipment_manufacturer_string is not None:
                                                                                                    return True

                                                                                                if self.part_number is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvAssetBag']['meta_info']


                                                                                        class Threshold(object):
                                                                                            """
                                                                                            Threshold
                                                                                            
                                                                                            .. attribute:: critical_hi
                                                                                            
                                                                                            	Critical High
                                                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi>`
                                                                                            
                                                                                            .. attribute:: critical_lo
                                                                                            
                                                                                            	Critical Low
                                                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo>`
                                                                                            
                                                                                            .. attribute:: major_hi
                                                                                            
                                                                                            	Major High
                                                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi>`
                                                                                            
                                                                                            .. attribute:: major_lo
                                                                                            
                                                                                            	Major Low
                                                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo>`
                                                                                            
                                                                                            .. attribute:: minor_hi
                                                                                            
                                                                                            	Minor High
                                                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi>`
                                                                                            
                                                                                            .. attribute:: minor_lo
                                                                                            
                                                                                            	Minor Low
                                                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo>`
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi()
                                                                                                self.critical_hi.parent = self
                                                                                                self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo()
                                                                                                self.critical_lo.parent = self
                                                                                                self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi()
                                                                                                self.major_hi.parent = self
                                                                                                self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo()
                                                                                                self.major_lo.parent = self
                                                                                                self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi()
                                                                                                self.minor_hi.parent = self
                                                                                                self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo()
                                                                                                self.minor_lo.parent = self


                                                                                            class MajorLo(object):
                                                                                                """
                                                                                                Major Low
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo']['meta_info']


                                                                                            class CriticalHi(object):
                                                                                                """
                                                                                                Critical High
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                            class MinorHi(object):
                                                                                                """
                                                                                                Minor High
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi']['meta_info']


                                                                                            class MajorHi(object):
                                                                                                """
                                                                                                Major High
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi']['meta_info']


                                                                                            class CriticalLo(object):
                                                                                                """
                                                                                                Critical Low
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                            class MinorLo(object):
                                                                                                """
                                                                                                Minor Low
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                    return True

                                                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                    return True

                                                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                                                    return True

                                                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                                                    return True

                                                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                    return True

                                                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold']['meta_info']


                                                                                        class FruInfo(object):
                                                                                            """
                                                                                            Inventory EDM FRU info
                                                                                            
                                                                                            .. attribute:: card_administrative_state
                                                                                            
                                                                                            	card admin state\: shutdown or not
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: card_monitor_state
                                                                                            
                                                                                            	card is monitored by a manager or left unmonitored
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: card_operational_state
                                                                                            
                                                                                            	card operation state
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: card_reset_reason
                                                                                            
                                                                                            	card reset reason enum
                                                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                            
                                                                                            .. attribute:: card_up_time
                                                                                            
                                                                                            	card up time
                                                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.CardUpTime>`
                                                                                            
                                                                                            .. attribute:: last_operational_state_change
                                                                                            
                                                                                            	last card oper change state
                                                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                            
                                                                                            .. attribute:: power_administrative_state
                                                                                            
                                                                                            	power admin state\: up or down
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_current_measurement
                                                                                            
                                                                                            	power current\: not implemented
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_operational_state
                                                                                            
                                                                                            	Power operation state
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.card_administrative_state = None
                                                                                                self.card_monitor_state = None
                                                                                                self.card_operational_state = None
                                                                                                self.card_reset_reason = None
                                                                                                self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.CardUpTime()
                                                                                                self.card_up_time.parent = self
                                                                                                self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                self.last_operational_state_change.parent = self
                                                                                                self.power_administrative_state = None
                                                                                                self.power_current_measurement = None
                                                                                                self.power_operational_state = None


                                                                                            class LastOperationalStateChange(object):
                                                                                                """
                                                                                                last card oper change state
                                                                                                
                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                
                                                                                                	Time Value in Nano\-seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: nanosecond
                                                                                                
                                                                                                .. attribute:: time_in_seconds
                                                                                                
                                                                                                	Time Value in Seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: second
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.time_in_nano_seconds = None
                                                                                                    self.time_in_seconds = None

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                        return True

                                                                                                    if self.time_in_seconds is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                            class CardUpTime(object):
                                                                                                """
                                                                                                card up time
                                                                                                
                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                
                                                                                                	Time Value in Nano\-seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: nanosecond
                                                                                                
                                                                                                .. attribute:: time_in_seconds
                                                                                                
                                                                                                	Time Value in Seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: second
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.time_in_nano_seconds = None
                                                                                                    self.time_in_seconds = None

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                        return True

                                                                                                    if self.time_in_seconds is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.card_administrative_state is not None:
                                                                                                    return True

                                                                                                if self.card_monitor_state is not None:
                                                                                                    return True

                                                                                                if self.card_operational_state is not None:
                                                                                                    return True

                                                                                                if self.card_reset_reason is not None:
                                                                                                    return True

                                                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                    return True

                                                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                    return True

                                                                                                if self.power_administrative_state is not None:
                                                                                                    return True

                                                                                                if self.power_current_measurement is not None:
                                                                                                    return True

                                                                                                if self.power_operational_state is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo']['meta_info']


                                                                                        class InvBasicBag(object):
                                                                                            """
                                                                                            Inventory Basic Bag
                                                                                            
                                                                                            .. attribute:: alias
                                                                                            
                                                                                            	useful for storing an entity alias 
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: asset_id_str
                                                                                            
                                                                                            	asset Identification string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: asset_identification
                                                                                            
                                                                                            	asset Identification
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: ceport
                                                                                            
                                                                                            	1 if ce port found, 0 if not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: chip_hardware_revision
                                                                                            
                                                                                            	chip module hw revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: composite_class_code
                                                                                            
                                                                                            	Major&minor class of the entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: description
                                                                                            
                                                                                            	describes in user\-readable terms       what the entity in question does
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: environmental_monitor_path
                                                                                            
                                                                                            	sysdb name of sensor in the envmon EDM
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: firmware_revision
                                                                                            
                                                                                            	firmware revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: group_flag
                                                                                            
                                                                                            	indicates if this entity is group       or not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: hardware_revision
                                                                                            
                                                                                            	hw revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: is_field_replaceable_unit
                                                                                            
                                                                                            	1 if Field Replaceable Unit 0, if not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: manufacturer_asset_tags
                                                                                            
                                                                                            	Manufacture Asset Tags
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: manufacturer_name
                                                                                            
                                                                                            	manufacturer's name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: memory_size
                                                                                            
                                                                                            	Size of memory associated with       the entity where applicable
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: model_name
                                                                                            
                                                                                            	model name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: name
                                                                                            
                                                                                            	name string for the entity
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: new_deviation_number
                                                                                            
                                                                                            	integer value for New Deviation Number 0x88
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: physical_layer_interface_module_type
                                                                                            
                                                                                            	integer value for plim type if     applicable to this entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: redundancystate
                                                                                            
                                                                                            	integer value for Redundancy State if     applicable to this entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: serial_number
                                                                                            
                                                                                            	serial number
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: software_revision
                                                                                            
                                                                                            	software revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: unique_id
                                                                                            
                                                                                            	Unique id for an entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: unrecognized_fru
                                                                                            
                                                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: vendor_type
                                                                                            
                                                                                            	maps to the vendor OID string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: xr_scoped
                                                                                            
                                                                                            	1 if xr scoped, 0 if not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.alias = None
                                                                                                self.asset_id_str = None
                                                                                                self.asset_identification = None
                                                                                                self.ceport = None
                                                                                                self.chip_hardware_revision = None
                                                                                                self.composite_class_code = None
                                                                                                self.description = None
                                                                                                self.environmental_monitor_path = None
                                                                                                self.firmware_revision = None
                                                                                                self.group_flag = None
                                                                                                self.hardware_revision = None
                                                                                                self.is_field_replaceable_unit = None
                                                                                                self.manufacturer_asset_tags = None
                                                                                                self.manufacturer_name = None
                                                                                                self.memory_size = None
                                                                                                self.model_name = None
                                                                                                self.name = None
                                                                                                self.new_deviation_number = None
                                                                                                self.physical_layer_interface_module_type = None
                                                                                                self.redundancystate = None
                                                                                                self.serial_number = None
                                                                                                self.software_revision = None
                                                                                                self.unique_id = None
                                                                                                self.unrecognized_fru = None
                                                                                                self.vendor_type = None
                                                                                                self.xr_scoped = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.alias is not None:
                                                                                                    return True

                                                                                                if self.asset_id_str is not None:
                                                                                                    return True

                                                                                                if self.asset_identification is not None:
                                                                                                    return True

                                                                                                if self.ceport is not None:
                                                                                                    return True

                                                                                                if self.chip_hardware_revision is not None:
                                                                                                    return True

                                                                                                if self.composite_class_code is not None:
                                                                                                    return True

                                                                                                if self.description is not None:
                                                                                                    return True

                                                                                                if self.environmental_monitor_path is not None:
                                                                                                    return True

                                                                                                if self.firmware_revision is not None:
                                                                                                    return True

                                                                                                if self.group_flag is not None:
                                                                                                    return True

                                                                                                if self.hardware_revision is not None:
                                                                                                    return True

                                                                                                if self.is_field_replaceable_unit is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_asset_tags is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_name is not None:
                                                                                                    return True

                                                                                                if self.memory_size is not None:
                                                                                                    return True

                                                                                                if self.model_name is not None:
                                                                                                    return True

                                                                                                if self.name is not None:
                                                                                                    return True

                                                                                                if self.new_deviation_number is not None:
                                                                                                    return True

                                                                                                if self.physical_layer_interface_module_type is not None:
                                                                                                    return True

                                                                                                if self.redundancystate is not None:
                                                                                                    return True

                                                                                                if self.serial_number is not None:
                                                                                                    return True

                                                                                                if self.software_revision is not None:
                                                                                                    return True

                                                                                                if self.unique_id is not None:
                                                                                                    return True

                                                                                                if self.unrecognized_fru is not None:
                                                                                                    return True

                                                                                                if self.vendor_type is not None:
                                                                                                    return True

                                                                                                if self.xr_scoped is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvBasicBag']['meta_info']


                                                                                        class InvEepromInfo(object):
                                                                                            """
                                                                                            Inventory EDM EEPROM Information Bag
                                                                                            
                                                                                            .. attribute:: description
                                                                                            
                                                                                            	A textual description of physical entity
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: eeprom
                                                                                            
                                                                                            	EEPROM data not from hex data
                                                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom>`
                                                                                            
                                                                                            .. attribute:: has_eeprom
                                                                                            
                                                                                            	use eeprom instead of opaque data
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: inv_card_type
                                                                                            
                                                                                            	Inventory card type
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..255
                                                                                            
                                                                                            .. attribute:: opaque_data
                                                                                            
                                                                                            	EEPROM hex data
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                            
                                                                                            .. attribute:: opaque_data_size
                                                                                            
                                                                                            	size of the EEPROM hex data
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.description = None
                                                                                                self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom()
                                                                                                self.eeprom.parent = self
                                                                                                self.has_eeprom = None
                                                                                                self.inv_card_type = None
                                                                                                self.opaque_data = None
                                                                                                self.opaque_data_size = None


                                                                                            class Eeprom(object):
                                                                                                """
                                                                                                EEPROM data not from hex data
                                                                                                
                                                                                                .. attribute:: asset_alias
                                                                                                
                                                                                                	Asset Alias
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: asset_id
                                                                                                
                                                                                                	Asset ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address1
                                                                                                
                                                                                                	Base Mac Address #1
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address2
                                                                                                
                                                                                                	Base Mac Address #2
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address3
                                                                                                
                                                                                                	Base Mac Address #3
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address4
                                                                                                
                                                                                                	Base Mac Address #4
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_checksum
                                                                                                
                                                                                                	Block Checksum
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_count
                                                                                                
                                                                                                	Block Count
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_length
                                                                                                
                                                                                                	Block Length
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_signature
                                                                                                
                                                                                                	Block Signature
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_version
                                                                                                
                                                                                                	Block Version
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: chassis_sid
                                                                                                
                                                                                                	Chassis serial number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: clei
                                                                                                
                                                                                                	Common Language Equipment Identifier (CLEI) code
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: controller_family
                                                                                                
                                                                                                	Controller family
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: controller_type
                                                                                                
                                                                                                	Controller type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: description
                                                                                                
                                                                                                	A textual description of physical entity
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num1
                                                                                                
                                                                                                	Deviation Number # 1
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num2
                                                                                                
                                                                                                	Deviation Number # 2
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num3
                                                                                                
                                                                                                	Deviation Number # 3
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num4
                                                                                                
                                                                                                	Deviation Number # 4
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num5
                                                                                                
                                                                                                	Deviation Number # 5
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num6
                                                                                                
                                                                                                	Deviation Number # 6
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num7
                                                                                                
                                                                                                	Deviation Number # 7
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: eci
                                                                                                
                                                                                                	Equipment Catalog Item (ECI) number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: eeprom_size
                                                                                                
                                                                                                	EEPROM Size
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: engineer_use
                                                                                                
                                                                                                	Engineer Use
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: fru_major_type
                                                                                                
                                                                                                	FRU Major Type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: fru_minor_type
                                                                                                
                                                                                                	FRU Minor Type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: hw_version
                                                                                                
                                                                                                	Hardware Version
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: hwid
                                                                                                
                                                                                                	Hardware Revision
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: idprom_format_rev
                                                                                                
                                                                                                	IDPROM Format Revision
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size1
                                                                                                
                                                                                                	Mac Address Block Size #1
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size2
                                                                                                
                                                                                                	Mac Address Block Size #2
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size3
                                                                                                
                                                                                                	Mac Address Block Size #3
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size4
                                                                                                
                                                                                                	Mac Address Block Size #4
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: manu_test_data
                                                                                                
                                                                                                	Manufacturing Test Data
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mfg_bits
                                                                                                
                                                                                                	MFG Bits
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mfg_deviation
                                                                                                
                                                                                                	MFG Deviation
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: oem_string
                                                                                                
                                                                                                	OEM String
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: part_number
                                                                                                
                                                                                                	Part Number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: part_revision
                                                                                                
                                                                                                	Part Revision
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pca_num
                                                                                                
                                                                                                	PCA number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pcavid
                                                                                                
                                                                                                	PCA revision ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pcb_serial_num
                                                                                                
                                                                                                	PCB Serial Number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pid
                                                                                                
                                                                                                	Product ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: power_consumption
                                                                                                
                                                                                                	Power Consumption
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: power_supply_type
                                                                                                
                                                                                                	Power Supply Type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: product_id
                                                                                                
                                                                                                	Product ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: rma
                                                                                                
                                                                                                	RMA Data
                                                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                
                                                                                                .. attribute:: rma_code
                                                                                                
                                                                                                	RMA Code
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: serial_number
                                                                                                
                                                                                                	Serial Number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: snmpoid
                                                                                                
                                                                                                	SNMP OID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: top_assem_part_num
                                                                                                
                                                                                                	Top assembly part number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: top_assem_vid
                                                                                                
                                                                                                	Top assembly revision number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: udi_description
                                                                                                
                                                                                                	UDI description
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: udi_name
                                                                                                
                                                                                                	UDI name
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: vid
                                                                                                
                                                                                                	Version ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.asset_alias = None
                                                                                                    self.asset_id = None
                                                                                                    self.base_mac_address1 = None
                                                                                                    self.base_mac_address2 = None
                                                                                                    self.base_mac_address3 = None
                                                                                                    self.base_mac_address4 = None
                                                                                                    self.block_checksum = None
                                                                                                    self.block_count = None
                                                                                                    self.block_length = None
                                                                                                    self.block_signature = None
                                                                                                    self.block_version = None
                                                                                                    self.chassis_sid = None
                                                                                                    self.clei = None
                                                                                                    self.controller_family = None
                                                                                                    self.controller_type = None
                                                                                                    self.description = None
                                                                                                    self.dev_num1 = None
                                                                                                    self.dev_num2 = None
                                                                                                    self.dev_num3 = None
                                                                                                    self.dev_num4 = None
                                                                                                    self.dev_num5 = None
                                                                                                    self.dev_num6 = None
                                                                                                    self.dev_num7 = None
                                                                                                    self.eci = None
                                                                                                    self.eeprom_size = None
                                                                                                    self.engineer_use = None
                                                                                                    self.fru_major_type = None
                                                                                                    self.fru_minor_type = None
                                                                                                    self.hw_version = None
                                                                                                    self.hwid = None
                                                                                                    self.idprom_format_rev = None
                                                                                                    self.mac_add_blk_size1 = None
                                                                                                    self.mac_add_blk_size2 = None
                                                                                                    self.mac_add_blk_size3 = None
                                                                                                    self.mac_add_blk_size4 = None
                                                                                                    self.manu_test_data = None
                                                                                                    self.mfg_bits = None
                                                                                                    self.mfg_deviation = None
                                                                                                    self.oem_string = None
                                                                                                    self.part_number = None
                                                                                                    self.part_revision = None
                                                                                                    self.pca_num = None
                                                                                                    self.pcavid = None
                                                                                                    self.pcb_serial_num = None
                                                                                                    self.pid = None
                                                                                                    self.power_consumption = None
                                                                                                    self.power_supply_type = None
                                                                                                    self.product_id = None
                                                                                                    self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                    self.rma.parent = self
                                                                                                    self.rma_code = None
                                                                                                    self.serial_number = None
                                                                                                    self.snmpoid = None
                                                                                                    self.top_assem_part_num = None
                                                                                                    self.top_assem_vid = None
                                                                                                    self.udi_description = None
                                                                                                    self.udi_name = None
                                                                                                    self.vid = None


                                                                                                class Rma(object):
                                                                                                    """
                                                                                                    RMA Data
                                                                                                    
                                                                                                    .. attribute:: rma_history
                                                                                                    
                                                                                                    	RMA history
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: rma_number
                                                                                                    
                                                                                                    	RMA tracking number format is N\-N\-N
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: test_history
                                                                                                    
                                                                                                    	Test history
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.rma_history = None
                                                                                                        self.rma_number = None
                                                                                                        self.test_history = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.rma_history is not None:
                                                                                                            return True

                                                                                                        if self.rma_number is not None:
                                                                                                            return True

                                                                                                        if self.test_history is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.asset_alias is not None:
                                                                                                        return True

                                                                                                    if self.asset_id is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address1 is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address2 is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address3 is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address4 is not None:
                                                                                                        return True

                                                                                                    if self.block_checksum is not None:
                                                                                                        return True

                                                                                                    if self.block_count is not None:
                                                                                                        return True

                                                                                                    if self.block_length is not None:
                                                                                                        return True

                                                                                                    if self.block_signature is not None:
                                                                                                        return True

                                                                                                    if self.block_version is not None:
                                                                                                        return True

                                                                                                    if self.chassis_sid is not None:
                                                                                                        return True

                                                                                                    if self.clei is not None:
                                                                                                        return True

                                                                                                    if self.controller_family is not None:
                                                                                                        return True

                                                                                                    if self.controller_type is not None:
                                                                                                        return True

                                                                                                    if self.description is not None:
                                                                                                        return True

                                                                                                    if self.dev_num1 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num2 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num3 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num4 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num5 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num6 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num7 is not None:
                                                                                                        return True

                                                                                                    if self.eci is not None:
                                                                                                        return True

                                                                                                    if self.eeprom_size is not None:
                                                                                                        return True

                                                                                                    if self.engineer_use is not None:
                                                                                                        return True

                                                                                                    if self.fru_major_type is not None:
                                                                                                        return True

                                                                                                    if self.fru_minor_type is not None:
                                                                                                        return True

                                                                                                    if self.hw_version is not None:
                                                                                                        return True

                                                                                                    if self.hwid is not None:
                                                                                                        return True

                                                                                                    if self.idprom_format_rev is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size1 is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size2 is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size3 is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size4 is not None:
                                                                                                        return True

                                                                                                    if self.manu_test_data is not None:
                                                                                                        return True

                                                                                                    if self.mfg_bits is not None:
                                                                                                        return True

                                                                                                    if self.mfg_deviation is not None:
                                                                                                        return True

                                                                                                    if self.oem_string is not None:
                                                                                                        return True

                                                                                                    if self.part_number is not None:
                                                                                                        return True

                                                                                                    if self.part_revision is not None:
                                                                                                        return True

                                                                                                    if self.pca_num is not None:
                                                                                                        return True

                                                                                                    if self.pcavid is not None:
                                                                                                        return True

                                                                                                    if self.pcb_serial_num is not None:
                                                                                                        return True

                                                                                                    if self.pid is not None:
                                                                                                        return True

                                                                                                    if self.power_consumption is not None:
                                                                                                        return True

                                                                                                    if self.power_supply_type is not None:
                                                                                                        return True

                                                                                                    if self.product_id is not None:
                                                                                                        return True

                                                                                                    if self.rma is not None and self.rma._has_data():
                                                                                                        return True

                                                                                                    if self.rma_code is not None:
                                                                                                        return True

                                                                                                    if self.serial_number is not None:
                                                                                                        return True

                                                                                                    if self.snmpoid is not None:
                                                                                                        return True

                                                                                                    if self.top_assem_part_num is not None:
                                                                                                        return True

                                                                                                    if self.top_assem_vid is not None:
                                                                                                        return True

                                                                                                    if self.udi_description is not None:
                                                                                                        return True

                                                                                                    if self.udi_name is not None:
                                                                                                        return True

                                                                                                    if self.vid is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.description is not None:
                                                                                                    return True

                                                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                                                    return True

                                                                                                if self.has_eeprom is not None:
                                                                                                    return True

                                                                                                if self.inv_card_type is not None:
                                                                                                    return True

                                                                                                if self.opaque_data is not None:
                                                                                                    return True

                                                                                                if self.opaque_data_size is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                return True

                                                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                return True

                                                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                                                return True

                                                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                return True

                                                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                return True

                                                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                return True

                                                                                            if self.module_done is not None:
                                                                                                return True

                                                                                            if self.node_id is not None:
                                                                                                return True

                                                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                return True

                                                                                            if self.threshold is not None and self.threshold._has_data():
                                                                                                return True

                                                                                            if self.vm_done is not None:
                                                                                                return True

                                                                                            if self.vm_node_id is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                        if self.name is None:
                                                                                            raise YPYModelError('Key property name is None')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi8[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.name is not None:
                                                                                            return True

                                                                                        if self.attributes is not None and self.attributes._has_data():
                                                                                            return True

                                                                                        if self.tsi9s is not None and self.tsi9s._has_data():
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi8s'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.tsi8 is not None:
                                                                                        for child_ref in self.tsi8:
                                                                                            if child_ref._has_data():
                                                                                                return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S']['meta_info']


                                                                            class Attributes(object):
                                                                                """
                                                                                Attributes
                                                                                
                                                                                .. attribute:: env_sensor_info
                                                                                
                                                                                	Environment sensor info
                                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfo>`
                                                                                
                                                                                .. attribute:: env_sensor_info_xml
                                                                                
                                                                                	Environment sensor info XML
                                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml>`
                                                                                
                                                                                .. attribute:: fru_info
                                                                                
                                                                                	Inventory EDM FRU info
                                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo>`
                                                                                
                                                                                .. attribute:: inv_asset_bag
                                                                                
                                                                                	Inventory Asset Bag
                                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvAssetBag>`
                                                                                
                                                                                .. attribute:: inv_basic_bag
                                                                                
                                                                                	Inventory Basic Bag
                                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvBasicBag>`
                                                                                
                                                                                .. attribute:: inv_eeprom_info
                                                                                
                                                                                	Inventory EDM EEPROM Information Bag
                                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo>`
                                                                                
                                                                                .. attribute:: module_done
                                                                                
                                                                                	Inventory EDM Module Done Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**default value**\: 1
                                                                                
                                                                                .. attribute:: node_id
                                                                                
                                                                                	Node ID Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: pwg_info
                                                                                
                                                                                	Inventory EDM PWG info
                                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.PwgInfo>`
                                                                                
                                                                                .. attribute:: threshold
                                                                                
                                                                                	Threshold
                                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold>`
                                                                                
                                                                                .. attribute:: vm_done
                                                                                
                                                                                	VM Done Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                .. attribute:: vm_node_id
                                                                                
                                                                                	VM Node ID Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfo()
                                                                                    self.env_sensor_info.parent = self
                                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml()
                                                                                    self.env_sensor_info_xml.parent = self
                                                                                    self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo()
                                                                                    self.fru_info.parent = self
                                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvAssetBag()
                                                                                    self.inv_asset_bag.parent = self
                                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvBasicBag()
                                                                                    self.inv_basic_bag.parent = self
                                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo()
                                                                                    self.inv_eeprom_info.parent = self
                                                                                    self.module_done = None
                                                                                    self.node_id = None
                                                                                    self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.PwgInfo()
                                                                                    self.pwg_info.parent = self
                                                                                    self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold()
                                                                                    self.threshold.parent = self
                                                                                    self.vm_done = None
                                                                                    self.vm_node_id = None


                                                                                class EnvSensorInfo(object):
                                                                                    """
                                                                                    Environment sensor info
                                                                                    
                                                                                    .. attribute:: age_time_stamp
                                                                                    
                                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: alarm_type
                                                                                    
                                                                                    	Indicates threshold violation
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: data_type
                                                                                    
                                                                                    	Sensor data type enums
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: device_description
                                                                                    
                                                                                    	Device Name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: device_id
                                                                                    
                                                                                    	Identifier for this device
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: field_validity_bitmap
                                                                                    
                                                                                    	Sensor valid bitmap
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: precision
                                                                                    
                                                                                    	Sensor precision range
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: scale
                                                                                    
                                                                                    	Sensor scale enums
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: status
                                                                                    
                                                                                    	Sensor operation state enums
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: units
                                                                                    
                                                                                    	Units of variable being read
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: update_rate
                                                                                    
                                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                    	Current reading of sensor
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.age_time_stamp = None
                                                                                        self.alarm_type = None
                                                                                        self.data_type = None
                                                                                        self.device_description = None
                                                                                        self.device_id = None
                                                                                        self.field_validity_bitmap = None
                                                                                        self.precision = None
                                                                                        self.scale = None
                                                                                        self.status = None
                                                                                        self.units = None
                                                                                        self.update_rate = None
                                                                                        self.value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.age_time_stamp is not None:
                                                                                            return True

                                                                                        if self.alarm_type is not None:
                                                                                            return True

                                                                                        if self.data_type is not None:
                                                                                            return True

                                                                                        if self.device_description is not None:
                                                                                            return True

                                                                                        if self.device_id is not None:
                                                                                            return True

                                                                                        if self.field_validity_bitmap is not None:
                                                                                            return True

                                                                                        if self.precision is not None:
                                                                                            return True

                                                                                        if self.scale is not None:
                                                                                            return True

                                                                                        if self.status is not None:
                                                                                            return True

                                                                                        if self.units is not None:
                                                                                            return True

                                                                                        if self.update_rate is not None:
                                                                                            return True

                                                                                        if self.value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfo']['meta_info']


                                                                                class PwgInfo(object):
                                                                                    """
                                                                                    Inventory EDM PWG info
                                                                                    
                                                                                    .. attribute:: power_group_available_current
                                                                                    
                                                                                    	available current
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_group_drawn_current
                                                                                    
                                                                                    	drawn current
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_group_power_units
                                                                                    
                                                                                    	power units
                                                                                    	**type**\:  str
                                                                                    
                                                                                    .. attribute:: power_group_redundancy_mode
                                                                                    
                                                                                    	redundancy mode
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.power_group_available_current = None
                                                                                        self.power_group_drawn_current = None
                                                                                        self.power_group_power_units = None
                                                                                        self.power_group_redundancy_mode = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.power_group_available_current is not None:
                                                                                            return True

                                                                                        if self.power_group_drawn_current is not None:
                                                                                            return True

                                                                                        if self.power_group_power_units is not None:
                                                                                            return True

                                                                                        if self.power_group_redundancy_mode is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.PwgInfo']['meta_info']


                                                                                class EnvSensorInfoXml(object):
                                                                                    """
                                                                                    Environment sensor info XML
                                                                                    
                                                                                    .. attribute:: data_type
                                                                                    
                                                                                    	Sensor data type
                                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                    
                                                                                    .. attribute:: description
                                                                                    
                                                                                    	Device Name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: status
                                                                                    
                                                                                    	Sensor operation state
                                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                    
                                                                                    .. attribute:: threshold
                                                                                    
                                                                                    	Threshold information
                                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                    
                                                                                    .. attribute:: units
                                                                                    
                                                                                    	Units of variable being read
                                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                    
                                                                                    .. attribute:: update_rate
                                                                                    
                                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.data_type = None
                                                                                        self.description = None
                                                                                        self.status = None
                                                                                        self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold()
                                                                                        self.threshold.parent = self
                                                                                        self.units = None
                                                                                        self.update_rate = None
                                                                                        self.value = None


                                                                                    class Threshold(object):
                                                                                        """
                                                                                        Threshold information
                                                                                        
                                                                                        .. attribute:: threshold_array
                                                                                        
                                                                                        	Array of threshold
                                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.threshold_array = YList()
                                                                                            self.threshold_array.parent = self
                                                                                            self.threshold_array.name = 'threshold_array'


                                                                                        class ThresholdArray(object):
                                                                                            """
                                                                                            Array of threshold
                                                                                            
                                                                                            .. attribute:: threshold_name
                                                                                            
                                                                                            	Threshold name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_name = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_name is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.threshold_array is not None:
                                                                                                for child_ref in self.threshold_array:
                                                                                                    if child_ref._has_data():
                                                                                                        return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.data_type is not None:
                                                                                            return True

                                                                                        if self.description is not None:
                                                                                            return True

                                                                                        if self.status is not None:
                                                                                            return True

                                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                                            return True

                                                                                        if self.units is not None:
                                                                                            return True

                                                                                        if self.update_rate is not None:
                                                                                            return True

                                                                                        if self.value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                class InvAssetBag(object):
                                                                                    """
                                                                                    Inventory Asset Bag
                                                                                    
                                                                                    .. attribute:: manufacturer_assembly_number
                                                                                    
                                                                                    	Manufacture Assembly number
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_assembly_revision
                                                                                    
                                                                                    	Manufacture assembly revision
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                    
                                                                                    	Common Language Equipment           Identifier number
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                                    
                                                                                    	
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_software_identifier
                                                                                    
                                                                                    	
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                                    
                                                                                    	String containing OEM information           if applicable
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: part_number
                                                                                    
                                                                                    	
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.manufacturer_assembly_number = None
                                                                                        self.manufacturer_assembly_revision = None
                                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                                        self.manufacturer_firmware_identifier = None
                                                                                        self.manufacturer_software_identifier = None
                                                                                        self.original_equipment_manufacturer_string = None
                                                                                        self.part_number = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.manufacturer_assembly_number is not None:
                                                                                            return True

                                                                                        if self.manufacturer_assembly_revision is not None:
                                                                                            return True

                                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                            return True

                                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                                            return True

                                                                                        if self.manufacturer_software_identifier is not None:
                                                                                            return True

                                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                                            return True

                                                                                        if self.part_number is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvAssetBag']['meta_info']


                                                                                class Threshold(object):
                                                                                    """
                                                                                    Threshold
                                                                                    
                                                                                    .. attribute:: critical_hi
                                                                                    
                                                                                    	Critical High
                                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi>`
                                                                                    
                                                                                    .. attribute:: critical_lo
                                                                                    
                                                                                    	Critical Low
                                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo>`
                                                                                    
                                                                                    .. attribute:: major_hi
                                                                                    
                                                                                    	Major High
                                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi>`
                                                                                    
                                                                                    .. attribute:: major_lo
                                                                                    
                                                                                    	Major Low
                                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo>`
                                                                                    
                                                                                    .. attribute:: minor_hi
                                                                                    
                                                                                    	Minor High
                                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi>`
                                                                                    
                                                                                    .. attribute:: minor_lo
                                                                                    
                                                                                    	Minor Low
                                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo>`
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi()
                                                                                        self.critical_hi.parent = self
                                                                                        self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo()
                                                                                        self.critical_lo.parent = self
                                                                                        self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi()
                                                                                        self.major_hi.parent = self
                                                                                        self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo()
                                                                                        self.major_lo.parent = self
                                                                                        self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi()
                                                                                        self.minor_hi.parent = self
                                                                                        self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo()
                                                                                        self.minor_lo.parent = self


                                                                                    class MajorLo(object):
                                                                                        """
                                                                                        Major Low
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo']['meta_info']


                                                                                    class CriticalHi(object):
                                                                                        """
                                                                                        Critical High
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                    class MinorHi(object):
                                                                                        """
                                                                                        Minor High
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi']['meta_info']


                                                                                    class MajorHi(object):
                                                                                        """
                                                                                        Major High
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi']['meta_info']


                                                                                    class CriticalLo(object):
                                                                                        """
                                                                                        Critical Low
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                    class MinorLo(object):
                                                                                        """
                                                                                        Minor Low
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                            return True

                                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                            return True

                                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                                            return True

                                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                                            return True

                                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                            return True

                                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold']['meta_info']


                                                                                class FruInfo(object):
                                                                                    """
                                                                                    Inventory EDM FRU info
                                                                                    
                                                                                    .. attribute:: card_administrative_state
                                                                                    
                                                                                    	card admin state\: shutdown or not
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: card_monitor_state
                                                                                    
                                                                                    	card is monitored by a manager or left unmonitored
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: card_operational_state
                                                                                    
                                                                                    	card operation state
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: card_reset_reason
                                                                                    
                                                                                    	card reset reason enum
                                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                    
                                                                                    .. attribute:: card_up_time
                                                                                    
                                                                                    	card up time
                                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.CardUpTime>`
                                                                                    
                                                                                    .. attribute:: last_operational_state_change
                                                                                    
                                                                                    	last card oper change state
                                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                    
                                                                                    .. attribute:: power_administrative_state
                                                                                    
                                                                                    	power admin state\: up or down
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_current_measurement
                                                                                    
                                                                                    	power current\: not implemented
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_operational_state
                                                                                    
                                                                                    	Power operation state
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.card_administrative_state = None
                                                                                        self.card_monitor_state = None
                                                                                        self.card_operational_state = None
                                                                                        self.card_reset_reason = None
                                                                                        self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.CardUpTime()
                                                                                        self.card_up_time.parent = self
                                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.LastOperationalStateChange()
                                                                                        self.last_operational_state_change.parent = self
                                                                                        self.power_administrative_state = None
                                                                                        self.power_current_measurement = None
                                                                                        self.power_operational_state = None


                                                                                    class LastOperationalStateChange(object):
                                                                                        """
                                                                                        last card oper change state
                                                                                        
                                                                                        .. attribute:: time_in_nano_seconds
                                                                                        
                                                                                        	Time Value in Nano\-seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: nanosecond
                                                                                        
                                                                                        .. attribute:: time_in_seconds
                                                                                        
                                                                                        	Time Value in Seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: second
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.time_in_nano_seconds = None
                                                                                            self.time_in_seconds = None

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                return True

                                                                                            if self.time_in_seconds is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                    class CardUpTime(object):
                                                                                        """
                                                                                        card up time
                                                                                        
                                                                                        .. attribute:: time_in_nano_seconds
                                                                                        
                                                                                        	Time Value in Nano\-seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: nanosecond
                                                                                        
                                                                                        .. attribute:: time_in_seconds
                                                                                        
                                                                                        	Time Value in Seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: second
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.time_in_nano_seconds = None
                                                                                            self.time_in_seconds = None

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                return True

                                                                                            if self.time_in_seconds is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.card_administrative_state is not None:
                                                                                            return True

                                                                                        if self.card_monitor_state is not None:
                                                                                            return True

                                                                                        if self.card_operational_state is not None:
                                                                                            return True

                                                                                        if self.card_reset_reason is not None:
                                                                                            return True

                                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                            return True

                                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                            return True

                                                                                        if self.power_administrative_state is not None:
                                                                                            return True

                                                                                        if self.power_current_measurement is not None:
                                                                                            return True

                                                                                        if self.power_operational_state is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo']['meta_info']


                                                                                class InvBasicBag(object):
                                                                                    """
                                                                                    Inventory Basic Bag
                                                                                    
                                                                                    .. attribute:: alias
                                                                                    
                                                                                    	useful for storing an entity alias 
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: asset_id_str
                                                                                    
                                                                                    	asset Identification string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: asset_identification
                                                                                    
                                                                                    	asset Identification
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: ceport
                                                                                    
                                                                                    	1 if ce port found, 0 if not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: chip_hardware_revision
                                                                                    
                                                                                    	chip module hw revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: composite_class_code
                                                                                    
                                                                                    	Major&minor class of the entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: description
                                                                                    
                                                                                    	describes in user\-readable terms       what the entity in question does
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: environmental_monitor_path
                                                                                    
                                                                                    	sysdb name of sensor in the envmon EDM
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: firmware_revision
                                                                                    
                                                                                    	firmware revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: group_flag
                                                                                    
                                                                                    	indicates if this entity is group       or not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: hardware_revision
                                                                                    
                                                                                    	hw revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: is_field_replaceable_unit
                                                                                    
                                                                                    	1 if Field Replaceable Unit 0, if not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: manufacturer_asset_tags
                                                                                    
                                                                                    	Manufacture Asset Tags
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: manufacturer_name
                                                                                    
                                                                                    	manufacturer's name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: memory_size
                                                                                    
                                                                                    	Size of memory associated with       the entity where applicable
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: model_name
                                                                                    
                                                                                    	model name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: name
                                                                                    
                                                                                    	name string for the entity
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: new_deviation_number
                                                                                    
                                                                                    	integer value for New Deviation Number 0x88
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: physical_layer_interface_module_type
                                                                                    
                                                                                    	integer value for plim type if     applicable to this entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: redundancystate
                                                                                    
                                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: serial_number
                                                                                    
                                                                                    	serial number
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: software_revision
                                                                                    
                                                                                    	software revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: unique_id
                                                                                    
                                                                                    	Unique id for an entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: unrecognized_fru
                                                                                    
                                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: vendor_type
                                                                                    
                                                                                    	maps to the vendor OID string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: xr_scoped
                                                                                    
                                                                                    	1 if xr scoped, 0 if not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.alias = None
                                                                                        self.asset_id_str = None
                                                                                        self.asset_identification = None
                                                                                        self.ceport = None
                                                                                        self.chip_hardware_revision = None
                                                                                        self.composite_class_code = None
                                                                                        self.description = None
                                                                                        self.environmental_monitor_path = None
                                                                                        self.firmware_revision = None
                                                                                        self.group_flag = None
                                                                                        self.hardware_revision = None
                                                                                        self.is_field_replaceable_unit = None
                                                                                        self.manufacturer_asset_tags = None
                                                                                        self.manufacturer_name = None
                                                                                        self.memory_size = None
                                                                                        self.model_name = None
                                                                                        self.name = None
                                                                                        self.new_deviation_number = None
                                                                                        self.physical_layer_interface_module_type = None
                                                                                        self.redundancystate = None
                                                                                        self.serial_number = None
                                                                                        self.software_revision = None
                                                                                        self.unique_id = None
                                                                                        self.unrecognized_fru = None
                                                                                        self.vendor_type = None
                                                                                        self.xr_scoped = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.alias is not None:
                                                                                            return True

                                                                                        if self.asset_id_str is not None:
                                                                                            return True

                                                                                        if self.asset_identification is not None:
                                                                                            return True

                                                                                        if self.ceport is not None:
                                                                                            return True

                                                                                        if self.chip_hardware_revision is not None:
                                                                                            return True

                                                                                        if self.composite_class_code is not None:
                                                                                            return True

                                                                                        if self.description is not None:
                                                                                            return True

                                                                                        if self.environmental_monitor_path is not None:
                                                                                            return True

                                                                                        if self.firmware_revision is not None:
                                                                                            return True

                                                                                        if self.group_flag is not None:
                                                                                            return True

                                                                                        if self.hardware_revision is not None:
                                                                                            return True

                                                                                        if self.is_field_replaceable_unit is not None:
                                                                                            return True

                                                                                        if self.manufacturer_asset_tags is not None:
                                                                                            return True

                                                                                        if self.manufacturer_name is not None:
                                                                                            return True

                                                                                        if self.memory_size is not None:
                                                                                            return True

                                                                                        if self.model_name is not None:
                                                                                            return True

                                                                                        if self.name is not None:
                                                                                            return True

                                                                                        if self.new_deviation_number is not None:
                                                                                            return True

                                                                                        if self.physical_layer_interface_module_type is not None:
                                                                                            return True

                                                                                        if self.redundancystate is not None:
                                                                                            return True

                                                                                        if self.serial_number is not None:
                                                                                            return True

                                                                                        if self.software_revision is not None:
                                                                                            return True

                                                                                        if self.unique_id is not None:
                                                                                            return True

                                                                                        if self.unrecognized_fru is not None:
                                                                                            return True

                                                                                        if self.vendor_type is not None:
                                                                                            return True

                                                                                        if self.xr_scoped is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvBasicBag']['meta_info']


                                                                                class InvEepromInfo(object):
                                                                                    """
                                                                                    Inventory EDM EEPROM Information Bag
                                                                                    
                                                                                    .. attribute:: description
                                                                                    
                                                                                    	A textual description of physical entity
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: eeprom
                                                                                    
                                                                                    	EEPROM data not from hex data
                                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom>`
                                                                                    
                                                                                    .. attribute:: has_eeprom
                                                                                    
                                                                                    	use eeprom instead of opaque data
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: inv_card_type
                                                                                    
                                                                                    	Inventory card type
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..255
                                                                                    
                                                                                    .. attribute:: opaque_data
                                                                                    
                                                                                    	EEPROM hex data
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                    
                                                                                    .. attribute:: opaque_data_size
                                                                                    
                                                                                    	size of the EEPROM hex data
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.description = None
                                                                                        self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom()
                                                                                        self.eeprom.parent = self
                                                                                        self.has_eeprom = None
                                                                                        self.inv_card_type = None
                                                                                        self.opaque_data = None
                                                                                        self.opaque_data_size = None


                                                                                    class Eeprom(object):
                                                                                        """
                                                                                        EEPROM data not from hex data
                                                                                        
                                                                                        .. attribute:: asset_alias
                                                                                        
                                                                                        	Asset Alias
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: asset_id
                                                                                        
                                                                                        	Asset ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address1
                                                                                        
                                                                                        	Base Mac Address #1
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address2
                                                                                        
                                                                                        	Base Mac Address #2
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address3
                                                                                        
                                                                                        	Base Mac Address #3
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address4
                                                                                        
                                                                                        	Base Mac Address #4
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_checksum
                                                                                        
                                                                                        	Block Checksum
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_count
                                                                                        
                                                                                        	Block Count
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_length
                                                                                        
                                                                                        	Block Length
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_signature
                                                                                        
                                                                                        	Block Signature
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_version
                                                                                        
                                                                                        	Block Version
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: chassis_sid
                                                                                        
                                                                                        	Chassis serial number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: clei
                                                                                        
                                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: controller_family
                                                                                        
                                                                                        	Controller family
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: controller_type
                                                                                        
                                                                                        	Controller type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: description
                                                                                        
                                                                                        	A textual description of physical entity
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num1
                                                                                        
                                                                                        	Deviation Number # 1
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num2
                                                                                        
                                                                                        	Deviation Number # 2
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num3
                                                                                        
                                                                                        	Deviation Number # 3
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num4
                                                                                        
                                                                                        	Deviation Number # 4
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num5
                                                                                        
                                                                                        	Deviation Number # 5
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num6
                                                                                        
                                                                                        	Deviation Number # 6
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num7
                                                                                        
                                                                                        	Deviation Number # 7
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: eci
                                                                                        
                                                                                        	Equipment Catalog Item (ECI) number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: eeprom_size
                                                                                        
                                                                                        	EEPROM Size
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: engineer_use
                                                                                        
                                                                                        	Engineer Use
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: fru_major_type
                                                                                        
                                                                                        	FRU Major Type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: fru_minor_type
                                                                                        
                                                                                        	FRU Minor Type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: hw_version
                                                                                        
                                                                                        	Hardware Version
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: hwid
                                                                                        
                                                                                        	Hardware Revision
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: idprom_format_rev
                                                                                        
                                                                                        	IDPROM Format Revision
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size1
                                                                                        
                                                                                        	Mac Address Block Size #1
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size2
                                                                                        
                                                                                        	Mac Address Block Size #2
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size3
                                                                                        
                                                                                        	Mac Address Block Size #3
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size4
                                                                                        
                                                                                        	Mac Address Block Size #4
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: manu_test_data
                                                                                        
                                                                                        	Manufacturing Test Data
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mfg_bits
                                                                                        
                                                                                        	MFG Bits
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mfg_deviation
                                                                                        
                                                                                        	MFG Deviation
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: oem_string
                                                                                        
                                                                                        	OEM String
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: part_number
                                                                                        
                                                                                        	Part Number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: part_revision
                                                                                        
                                                                                        	Part Revision
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pca_num
                                                                                        
                                                                                        	PCA number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pcavid
                                                                                        
                                                                                        	PCA revision ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pcb_serial_num
                                                                                        
                                                                                        	PCB Serial Number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pid
                                                                                        
                                                                                        	Product ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: power_consumption
                                                                                        
                                                                                        	Power Consumption
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: power_supply_type
                                                                                        
                                                                                        	Power Supply Type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: product_id
                                                                                        
                                                                                        	Product ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: rma
                                                                                        
                                                                                        	RMA Data
                                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                        
                                                                                        .. attribute:: rma_code
                                                                                        
                                                                                        	RMA Code
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: serial_number
                                                                                        
                                                                                        	Serial Number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: snmpoid
                                                                                        
                                                                                        	SNMP OID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: top_assem_part_num
                                                                                        
                                                                                        	Top assembly part number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: top_assem_vid
                                                                                        
                                                                                        	Top assembly revision number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: udi_description
                                                                                        
                                                                                        	UDI description
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: udi_name
                                                                                        
                                                                                        	UDI name
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: vid
                                                                                        
                                                                                        	Version ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.asset_alias = None
                                                                                            self.asset_id = None
                                                                                            self.base_mac_address1 = None
                                                                                            self.base_mac_address2 = None
                                                                                            self.base_mac_address3 = None
                                                                                            self.base_mac_address4 = None
                                                                                            self.block_checksum = None
                                                                                            self.block_count = None
                                                                                            self.block_length = None
                                                                                            self.block_signature = None
                                                                                            self.block_version = None
                                                                                            self.chassis_sid = None
                                                                                            self.clei = None
                                                                                            self.controller_family = None
                                                                                            self.controller_type = None
                                                                                            self.description = None
                                                                                            self.dev_num1 = None
                                                                                            self.dev_num2 = None
                                                                                            self.dev_num3 = None
                                                                                            self.dev_num4 = None
                                                                                            self.dev_num5 = None
                                                                                            self.dev_num6 = None
                                                                                            self.dev_num7 = None
                                                                                            self.eci = None
                                                                                            self.eeprom_size = None
                                                                                            self.engineer_use = None
                                                                                            self.fru_major_type = None
                                                                                            self.fru_minor_type = None
                                                                                            self.hw_version = None
                                                                                            self.hwid = None
                                                                                            self.idprom_format_rev = None
                                                                                            self.mac_add_blk_size1 = None
                                                                                            self.mac_add_blk_size2 = None
                                                                                            self.mac_add_blk_size3 = None
                                                                                            self.mac_add_blk_size4 = None
                                                                                            self.manu_test_data = None
                                                                                            self.mfg_bits = None
                                                                                            self.mfg_deviation = None
                                                                                            self.oem_string = None
                                                                                            self.part_number = None
                                                                                            self.part_revision = None
                                                                                            self.pca_num = None
                                                                                            self.pcavid = None
                                                                                            self.pcb_serial_num = None
                                                                                            self.pid = None
                                                                                            self.power_consumption = None
                                                                                            self.power_supply_type = None
                                                                                            self.product_id = None
                                                                                            self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                            self.rma.parent = self
                                                                                            self.rma_code = None
                                                                                            self.serial_number = None
                                                                                            self.snmpoid = None
                                                                                            self.top_assem_part_num = None
                                                                                            self.top_assem_vid = None
                                                                                            self.udi_description = None
                                                                                            self.udi_name = None
                                                                                            self.vid = None


                                                                                        class Rma(object):
                                                                                            """
                                                                                            RMA Data
                                                                                            
                                                                                            .. attribute:: rma_history
                                                                                            
                                                                                            	RMA history
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: rma_number
                                                                                            
                                                                                            	RMA tracking number format is N\-N\-N
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: test_history
                                                                                            
                                                                                            	Test history
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.rma_history = None
                                                                                                self.rma_number = None
                                                                                                self.test_history = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.rma_history is not None:
                                                                                                    return True

                                                                                                if self.rma_number is not None:
                                                                                                    return True

                                                                                                if self.test_history is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.asset_alias is not None:
                                                                                                return True

                                                                                            if self.asset_id is not None:
                                                                                                return True

                                                                                            if self.base_mac_address1 is not None:
                                                                                                return True

                                                                                            if self.base_mac_address2 is not None:
                                                                                                return True

                                                                                            if self.base_mac_address3 is not None:
                                                                                                return True

                                                                                            if self.base_mac_address4 is not None:
                                                                                                return True

                                                                                            if self.block_checksum is not None:
                                                                                                return True

                                                                                            if self.block_count is not None:
                                                                                                return True

                                                                                            if self.block_length is not None:
                                                                                                return True

                                                                                            if self.block_signature is not None:
                                                                                                return True

                                                                                            if self.block_version is not None:
                                                                                                return True

                                                                                            if self.chassis_sid is not None:
                                                                                                return True

                                                                                            if self.clei is not None:
                                                                                                return True

                                                                                            if self.controller_family is not None:
                                                                                                return True

                                                                                            if self.controller_type is not None:
                                                                                                return True

                                                                                            if self.description is not None:
                                                                                                return True

                                                                                            if self.dev_num1 is not None:
                                                                                                return True

                                                                                            if self.dev_num2 is not None:
                                                                                                return True

                                                                                            if self.dev_num3 is not None:
                                                                                                return True

                                                                                            if self.dev_num4 is not None:
                                                                                                return True

                                                                                            if self.dev_num5 is not None:
                                                                                                return True

                                                                                            if self.dev_num6 is not None:
                                                                                                return True

                                                                                            if self.dev_num7 is not None:
                                                                                                return True

                                                                                            if self.eci is not None:
                                                                                                return True

                                                                                            if self.eeprom_size is not None:
                                                                                                return True

                                                                                            if self.engineer_use is not None:
                                                                                                return True

                                                                                            if self.fru_major_type is not None:
                                                                                                return True

                                                                                            if self.fru_minor_type is not None:
                                                                                                return True

                                                                                            if self.hw_version is not None:
                                                                                                return True

                                                                                            if self.hwid is not None:
                                                                                                return True

                                                                                            if self.idprom_format_rev is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size1 is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size2 is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size3 is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size4 is not None:
                                                                                                return True

                                                                                            if self.manu_test_data is not None:
                                                                                                return True

                                                                                            if self.mfg_bits is not None:
                                                                                                return True

                                                                                            if self.mfg_deviation is not None:
                                                                                                return True

                                                                                            if self.oem_string is not None:
                                                                                                return True

                                                                                            if self.part_number is not None:
                                                                                                return True

                                                                                            if self.part_revision is not None:
                                                                                                return True

                                                                                            if self.pca_num is not None:
                                                                                                return True

                                                                                            if self.pcavid is not None:
                                                                                                return True

                                                                                            if self.pcb_serial_num is not None:
                                                                                                return True

                                                                                            if self.pid is not None:
                                                                                                return True

                                                                                            if self.power_consumption is not None:
                                                                                                return True

                                                                                            if self.power_supply_type is not None:
                                                                                                return True

                                                                                            if self.product_id is not None:
                                                                                                return True

                                                                                            if self.rma is not None and self.rma._has_data():
                                                                                                return True

                                                                                            if self.rma_code is not None:
                                                                                                return True

                                                                                            if self.serial_number is not None:
                                                                                                return True

                                                                                            if self.snmpoid is not None:
                                                                                                return True

                                                                                            if self.top_assem_part_num is not None:
                                                                                                return True

                                                                                            if self.top_assem_vid is not None:
                                                                                                return True

                                                                                            if self.udi_description is not None:
                                                                                                return True

                                                                                            if self.udi_name is not None:
                                                                                                return True

                                                                                            if self.vid is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.description is not None:
                                                                                            return True

                                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                                            return True

                                                                                        if self.has_eeprom is not None:
                                                                                            return True

                                                                                        if self.inv_card_type is not None:
                                                                                            return True

                                                                                        if self.opaque_data is not None:
                                                                                            return True

                                                                                        if self.opaque_data_size is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                        return True

                                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                        return True

                                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                                        return True

                                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                        return True

                                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                        return True

                                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                        return True

                                                                                    if self.module_done is not None:
                                                                                        return True

                                                                                    if self.node_id is not None:
                                                                                        return True

                                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                        return True

                                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                                        return True

                                                                                    if self.vm_done is not None:
                                                                                        return True

                                                                                    if self.vm_node_id is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                if self.name is None:
                                                                                    raise YPYModelError('Key property name is None')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi7[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.name is not None:
                                                                                    return True

                                                                                if self.attributes is not None and self.attributes._has_data():
                                                                                    return True

                                                                                if self.tsi8s is not None and self.tsi8s._has_data():
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi7s'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.tsi7 is not None:
                                                                                for child_ref in self.tsi7:
                                                                                    if child_ref._has_data():
                                                                                        return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S']['meta_info']


                                                                    class Attributes(object):
                                                                        """
                                                                        Attributes
                                                                        
                                                                        .. attribute:: env_sensor_info
                                                                        
                                                                        	Environment sensor info
                                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfo>`
                                                                        
                                                                        .. attribute:: env_sensor_info_xml
                                                                        
                                                                        	Environment sensor info XML
                                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml>`
                                                                        
                                                                        .. attribute:: fru_info
                                                                        
                                                                        	Inventory EDM FRU info
                                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo>`
                                                                        
                                                                        .. attribute:: inv_asset_bag
                                                                        
                                                                        	Inventory Asset Bag
                                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvAssetBag>`
                                                                        
                                                                        .. attribute:: inv_basic_bag
                                                                        
                                                                        	Inventory Basic Bag
                                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvBasicBag>`
                                                                        
                                                                        .. attribute:: inv_eeprom_info
                                                                        
                                                                        	Inventory EDM EEPROM Information Bag
                                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo>`
                                                                        
                                                                        .. attribute:: module_done
                                                                        
                                                                        	Inventory EDM Module Done Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**default value**\: 1
                                                                        
                                                                        .. attribute:: node_id
                                                                        
                                                                        	Node ID Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: pwg_info
                                                                        
                                                                        	Inventory EDM PWG info
                                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.PwgInfo>`
                                                                        
                                                                        .. attribute:: threshold
                                                                        
                                                                        	Threshold
                                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold>`
                                                                        
                                                                        .. attribute:: vm_done
                                                                        
                                                                        	VM Done Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        .. attribute:: vm_node_id
                                                                        
                                                                        	VM Node ID Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfo()
                                                                            self.env_sensor_info.parent = self
                                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml()
                                                                            self.env_sensor_info_xml.parent = self
                                                                            self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo()
                                                                            self.fru_info.parent = self
                                                                            self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvAssetBag()
                                                                            self.inv_asset_bag.parent = self
                                                                            self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvBasicBag()
                                                                            self.inv_basic_bag.parent = self
                                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo()
                                                                            self.inv_eeprom_info.parent = self
                                                                            self.module_done = None
                                                                            self.node_id = None
                                                                            self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.PwgInfo()
                                                                            self.pwg_info.parent = self
                                                                            self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold()
                                                                            self.threshold.parent = self
                                                                            self.vm_done = None
                                                                            self.vm_node_id = None


                                                                        class EnvSensorInfo(object):
                                                                            """
                                                                            Environment sensor info
                                                                            
                                                                            .. attribute:: age_time_stamp
                                                                            
                                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: alarm_type
                                                                            
                                                                            	Indicates threshold violation
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: data_type
                                                                            
                                                                            	Sensor data type enums
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: device_description
                                                                            
                                                                            	Device Name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: device_id
                                                                            
                                                                            	Identifier for this device
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: field_validity_bitmap
                                                                            
                                                                            	Sensor valid bitmap
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: precision
                                                                            
                                                                            	Sensor precision range
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: scale
                                                                            
                                                                            	Sensor scale enums
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: status
                                                                            
                                                                            	Sensor operation state enums
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: units
                                                                            
                                                                            	Units of variable being read
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: update_rate
                                                                            
                                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	Current reading of sensor
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.age_time_stamp = None
                                                                                self.alarm_type = None
                                                                                self.data_type = None
                                                                                self.device_description = None
                                                                                self.device_id = None
                                                                                self.field_validity_bitmap = None
                                                                                self.precision = None
                                                                                self.scale = None
                                                                                self.status = None
                                                                                self.units = None
                                                                                self.update_rate = None
                                                                                self.value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.age_time_stamp is not None:
                                                                                    return True

                                                                                if self.alarm_type is not None:
                                                                                    return True

                                                                                if self.data_type is not None:
                                                                                    return True

                                                                                if self.device_description is not None:
                                                                                    return True

                                                                                if self.device_id is not None:
                                                                                    return True

                                                                                if self.field_validity_bitmap is not None:
                                                                                    return True

                                                                                if self.precision is not None:
                                                                                    return True

                                                                                if self.scale is not None:
                                                                                    return True

                                                                                if self.status is not None:
                                                                                    return True

                                                                                if self.units is not None:
                                                                                    return True

                                                                                if self.update_rate is not None:
                                                                                    return True

                                                                                if self.value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfo']['meta_info']


                                                                        class PwgInfo(object):
                                                                            """
                                                                            Inventory EDM PWG info
                                                                            
                                                                            .. attribute:: power_group_available_current
                                                                            
                                                                            	available current
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_group_drawn_current
                                                                            
                                                                            	drawn current
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_group_power_units
                                                                            
                                                                            	power units
                                                                            	**type**\:  str
                                                                            
                                                                            .. attribute:: power_group_redundancy_mode
                                                                            
                                                                            	redundancy mode
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.power_group_available_current = None
                                                                                self.power_group_drawn_current = None
                                                                                self.power_group_power_units = None
                                                                                self.power_group_redundancy_mode = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.power_group_available_current is not None:
                                                                                    return True

                                                                                if self.power_group_drawn_current is not None:
                                                                                    return True

                                                                                if self.power_group_power_units is not None:
                                                                                    return True

                                                                                if self.power_group_redundancy_mode is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.PwgInfo']['meta_info']


                                                                        class EnvSensorInfoXml(object):
                                                                            """
                                                                            Environment sensor info XML
                                                                            
                                                                            .. attribute:: data_type
                                                                            
                                                                            	Sensor data type
                                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                            
                                                                            .. attribute:: description
                                                                            
                                                                            	Device Name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: status
                                                                            
                                                                            	Sensor operation state
                                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                            
                                                                            .. attribute:: threshold
                                                                            
                                                                            	Threshold information
                                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold>`
                                                                            
                                                                            .. attribute:: units
                                                                            
                                                                            	Units of variable being read
                                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                            
                                                                            .. attribute:: update_rate
                                                                            
                                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.data_type = None
                                                                                self.description = None
                                                                                self.status = None
                                                                                self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold()
                                                                                self.threshold.parent = self
                                                                                self.units = None
                                                                                self.update_rate = None
                                                                                self.value = None


                                                                            class Threshold(object):
                                                                                """
                                                                                Threshold information
                                                                                
                                                                                .. attribute:: threshold_array
                                                                                
                                                                                	Array of threshold
                                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.threshold_array = YList()
                                                                                    self.threshold_array.parent = self
                                                                                    self.threshold_array.name = 'threshold_array'


                                                                                class ThresholdArray(object):
                                                                                    """
                                                                                    Array of threshold
                                                                                    
                                                                                    .. attribute:: threshold_name
                                                                                    
                                                                                    	Threshold name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_name = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_name is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.threshold_array is not None:
                                                                                        for child_ref in self.threshold_array:
                                                                                            if child_ref._has_data():
                                                                                                return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.data_type is not None:
                                                                                    return True

                                                                                if self.description is not None:
                                                                                    return True

                                                                                if self.status is not None:
                                                                                    return True

                                                                                if self.threshold is not None and self.threshold._has_data():
                                                                                    return True

                                                                                if self.units is not None:
                                                                                    return True

                                                                                if self.update_rate is not None:
                                                                                    return True

                                                                                if self.value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml']['meta_info']


                                                                        class InvAssetBag(object):
                                                                            """
                                                                            Inventory Asset Bag
                                                                            
                                                                            .. attribute:: manufacturer_assembly_number
                                                                            
                                                                            	Manufacture Assembly number
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_assembly_revision
                                                                            
                                                                            	Manufacture assembly revision
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                                            
                                                                            	Common Language Equipment           Identifier number
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_firmware_identifier
                                                                            
                                                                            	
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_software_identifier
                                                                            
                                                                            	
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: original_equipment_manufacturer_string
                                                                            
                                                                            	String containing OEM information           if applicable
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: part_number
                                                                            
                                                                            	
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.manufacturer_assembly_number = None
                                                                                self.manufacturer_assembly_revision = None
                                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                                self.manufacturer_firmware_identifier = None
                                                                                self.manufacturer_software_identifier = None
                                                                                self.original_equipment_manufacturer_string = None
                                                                                self.part_number = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.manufacturer_assembly_number is not None:
                                                                                    return True

                                                                                if self.manufacturer_assembly_revision is not None:
                                                                                    return True

                                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                    return True

                                                                                if self.manufacturer_firmware_identifier is not None:
                                                                                    return True

                                                                                if self.manufacturer_software_identifier is not None:
                                                                                    return True

                                                                                if self.original_equipment_manufacturer_string is not None:
                                                                                    return True

                                                                                if self.part_number is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvAssetBag']['meta_info']


                                                                        class Threshold(object):
                                                                            """
                                                                            Threshold
                                                                            
                                                                            .. attribute:: critical_hi
                                                                            
                                                                            	Critical High
                                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi>`
                                                                            
                                                                            .. attribute:: critical_lo
                                                                            
                                                                            	Critical Low
                                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo>`
                                                                            
                                                                            .. attribute:: major_hi
                                                                            
                                                                            	Major High
                                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi>`
                                                                            
                                                                            .. attribute:: major_lo
                                                                            
                                                                            	Major Low
                                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo>`
                                                                            
                                                                            .. attribute:: minor_hi
                                                                            
                                                                            	Minor High
                                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi>`
                                                                            
                                                                            .. attribute:: minor_lo
                                                                            
                                                                            	Minor Low
                                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi()
                                                                                self.critical_hi.parent = self
                                                                                self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo()
                                                                                self.critical_lo.parent = self
                                                                                self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi()
                                                                                self.major_hi.parent = self
                                                                                self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo()
                                                                                self.major_lo.parent = self
                                                                                self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi()
                                                                                self.minor_hi.parent = self
                                                                                self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo()
                                                                                self.minor_lo.parent = self


                                                                            class MajorLo(object):
                                                                                """
                                                                                Major Low
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo']['meta_info']


                                                                            class CriticalHi(object):
                                                                                """
                                                                                Critical High
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi']['meta_info']


                                                                            class MinorHi(object):
                                                                                """
                                                                                Minor High
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi']['meta_info']


                                                                            class MajorHi(object):
                                                                                """
                                                                                Major High
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi']['meta_info']


                                                                            class CriticalLo(object):
                                                                                """
                                                                                Critical Low
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo']['meta_info']


                                                                            class MinorLo(object):
                                                                                """
                                                                                Minor Low
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                    return True

                                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                    return True

                                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                                    return True

                                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                                    return True

                                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                    return True

                                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold']['meta_info']


                                                                        class FruInfo(object):
                                                                            """
                                                                            Inventory EDM FRU info
                                                                            
                                                                            .. attribute:: card_administrative_state
                                                                            
                                                                            	card admin state\: shutdown or not
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: card_monitor_state
                                                                            
                                                                            	card is monitored by a manager or left unmonitored
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: card_operational_state
                                                                            
                                                                            	card operation state
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: card_reset_reason
                                                                            
                                                                            	card reset reason enum
                                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                            
                                                                            .. attribute:: card_up_time
                                                                            
                                                                            	card up time
                                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.CardUpTime>`
                                                                            
                                                                            .. attribute:: last_operational_state_change
                                                                            
                                                                            	last card oper change state
                                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.LastOperationalStateChange>`
                                                                            
                                                                            .. attribute:: power_administrative_state
                                                                            
                                                                            	power admin state\: up or down
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_current_measurement
                                                                            
                                                                            	power current\: not implemented
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_operational_state
                                                                            
                                                                            	Power operation state
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.card_administrative_state = None
                                                                                self.card_monitor_state = None
                                                                                self.card_operational_state = None
                                                                                self.card_reset_reason = None
                                                                                self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.CardUpTime()
                                                                                self.card_up_time.parent = self
                                                                                self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.LastOperationalStateChange()
                                                                                self.last_operational_state_change.parent = self
                                                                                self.power_administrative_state = None
                                                                                self.power_current_measurement = None
                                                                                self.power_operational_state = None


                                                                            class LastOperationalStateChange(object):
                                                                                """
                                                                                last card oper change state
                                                                                
                                                                                .. attribute:: time_in_nano_seconds
                                                                                
                                                                                	Time Value in Nano\-seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: nanosecond
                                                                                
                                                                                .. attribute:: time_in_seconds
                                                                                
                                                                                	Time Value in Seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: second
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.time_in_nano_seconds = None
                                                                                    self.time_in_seconds = None

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.time_in_nano_seconds is not None:
                                                                                        return True

                                                                                    if self.time_in_seconds is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                            class CardUpTime(object):
                                                                                """
                                                                                card up time
                                                                                
                                                                                .. attribute:: time_in_nano_seconds
                                                                                
                                                                                	Time Value in Nano\-seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: nanosecond
                                                                                
                                                                                .. attribute:: time_in_seconds
                                                                                
                                                                                	Time Value in Seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: second
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.time_in_nano_seconds = None
                                                                                    self.time_in_seconds = None

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.time_in_nano_seconds is not None:
                                                                                        return True

                                                                                    if self.time_in_seconds is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.card_administrative_state is not None:
                                                                                    return True

                                                                                if self.card_monitor_state is not None:
                                                                                    return True

                                                                                if self.card_operational_state is not None:
                                                                                    return True

                                                                                if self.card_reset_reason is not None:
                                                                                    return True

                                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                    return True

                                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                    return True

                                                                                if self.power_administrative_state is not None:
                                                                                    return True

                                                                                if self.power_current_measurement is not None:
                                                                                    return True

                                                                                if self.power_operational_state is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo']['meta_info']


                                                                        class InvBasicBag(object):
                                                                            """
                                                                            Inventory Basic Bag
                                                                            
                                                                            .. attribute:: alias
                                                                            
                                                                            	useful for storing an entity alias 
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: asset_id_str
                                                                            
                                                                            	asset Identification string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: asset_identification
                                                                            
                                                                            	asset Identification
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: ceport
                                                                            
                                                                            	1 if ce port found, 0 if not
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: chip_hardware_revision
                                                                            
                                                                            	chip module hw revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: composite_class_code
                                                                            
                                                                            	Major&minor class of the entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: description
                                                                            
                                                                            	describes in user\-readable terms       what the entity in question does
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: environmental_monitor_path
                                                                            
                                                                            	sysdb name of sensor in the envmon EDM
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: firmware_revision
                                                                            
                                                                            	firmware revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: group_flag
                                                                            
                                                                            	indicates if this entity is group       or not
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: hardware_revision
                                                                            
                                                                            	hw revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: is_field_replaceable_unit
                                                                            
                                                                            	1 if Field Replaceable Unit 0, if not
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: manufacturer_asset_tags
                                                                            
                                                                            	Manufacture Asset Tags
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: manufacturer_name
                                                                            
                                                                            	manufacturer's name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: memory_size
                                                                            
                                                                            	Size of memory associated with       the entity where applicable
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: model_name
                                                                            
                                                                            	model name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: name
                                                                            
                                                                            	name string for the entity
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: new_deviation_number
                                                                            
                                                                            	integer value for New Deviation Number 0x88
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: physical_layer_interface_module_type
                                                                            
                                                                            	integer value for plim type if     applicable to this entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: redundancystate
                                                                            
                                                                            	integer value for Redundancy State if     applicable to this entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: serial_number
                                                                            
                                                                            	serial number
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: software_revision
                                                                            
                                                                            	software revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: unique_id
                                                                            
                                                                            	Unique id for an entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: unrecognized_fru
                                                                            
                                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: vendor_type
                                                                            
                                                                            	maps to the vendor OID string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: xr_scoped
                                                                            
                                                                            	1 if xr scoped, 0 if not
                                                                            	**type**\:  bool
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.alias = None
                                                                                self.asset_id_str = None
                                                                                self.asset_identification = None
                                                                                self.ceport = None
                                                                                self.chip_hardware_revision = None
                                                                                self.composite_class_code = None
                                                                                self.description = None
                                                                                self.environmental_monitor_path = None
                                                                                self.firmware_revision = None
                                                                                self.group_flag = None
                                                                                self.hardware_revision = None
                                                                                self.is_field_replaceable_unit = None
                                                                                self.manufacturer_asset_tags = None
                                                                                self.manufacturer_name = None
                                                                                self.memory_size = None
                                                                                self.model_name = None
                                                                                self.name = None
                                                                                self.new_deviation_number = None
                                                                                self.physical_layer_interface_module_type = None
                                                                                self.redundancystate = None
                                                                                self.serial_number = None
                                                                                self.software_revision = None
                                                                                self.unique_id = None
                                                                                self.unrecognized_fru = None
                                                                                self.vendor_type = None
                                                                                self.xr_scoped = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.alias is not None:
                                                                                    return True

                                                                                if self.asset_id_str is not None:
                                                                                    return True

                                                                                if self.asset_identification is not None:
                                                                                    return True

                                                                                if self.ceport is not None:
                                                                                    return True

                                                                                if self.chip_hardware_revision is not None:
                                                                                    return True

                                                                                if self.composite_class_code is not None:
                                                                                    return True

                                                                                if self.description is not None:
                                                                                    return True

                                                                                if self.environmental_monitor_path is not None:
                                                                                    return True

                                                                                if self.firmware_revision is not None:
                                                                                    return True

                                                                                if self.group_flag is not None:
                                                                                    return True

                                                                                if self.hardware_revision is not None:
                                                                                    return True

                                                                                if self.is_field_replaceable_unit is not None:
                                                                                    return True

                                                                                if self.manufacturer_asset_tags is not None:
                                                                                    return True

                                                                                if self.manufacturer_name is not None:
                                                                                    return True

                                                                                if self.memory_size is not None:
                                                                                    return True

                                                                                if self.model_name is not None:
                                                                                    return True

                                                                                if self.name is not None:
                                                                                    return True

                                                                                if self.new_deviation_number is not None:
                                                                                    return True

                                                                                if self.physical_layer_interface_module_type is not None:
                                                                                    return True

                                                                                if self.redundancystate is not None:
                                                                                    return True

                                                                                if self.serial_number is not None:
                                                                                    return True

                                                                                if self.software_revision is not None:
                                                                                    return True

                                                                                if self.unique_id is not None:
                                                                                    return True

                                                                                if self.unrecognized_fru is not None:
                                                                                    return True

                                                                                if self.vendor_type is not None:
                                                                                    return True

                                                                                if self.xr_scoped is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvBasicBag']['meta_info']


                                                                        class InvEepromInfo(object):
                                                                            """
                                                                            Inventory EDM EEPROM Information Bag
                                                                            
                                                                            .. attribute:: description
                                                                            
                                                                            	A textual description of physical entity
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: eeprom
                                                                            
                                                                            	EEPROM data not from hex data
                                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom>`
                                                                            
                                                                            .. attribute:: has_eeprom
                                                                            
                                                                            	use eeprom instead of opaque data
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: inv_card_type
                                                                            
                                                                            	Inventory card type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: opaque_data
                                                                            
                                                                            	EEPROM hex data
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: opaque_data_size
                                                                            
                                                                            	size of the EEPROM hex data
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.description = None
                                                                                self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom()
                                                                                self.eeprom.parent = self
                                                                                self.has_eeprom = None
                                                                                self.inv_card_type = None
                                                                                self.opaque_data = None
                                                                                self.opaque_data_size = None


                                                                            class Eeprom(object):
                                                                                """
                                                                                EEPROM data not from hex data
                                                                                
                                                                                .. attribute:: asset_alias
                                                                                
                                                                                	Asset Alias
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: asset_id
                                                                                
                                                                                	Asset ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address1
                                                                                
                                                                                	Base Mac Address #1
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address2
                                                                                
                                                                                	Base Mac Address #2
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address3
                                                                                
                                                                                	Base Mac Address #3
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address4
                                                                                
                                                                                	Base Mac Address #4
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_checksum
                                                                                
                                                                                	Block Checksum
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_count
                                                                                
                                                                                	Block Count
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_length
                                                                                
                                                                                	Block Length
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_signature
                                                                                
                                                                                	Block Signature
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_version
                                                                                
                                                                                	Block Version
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: chassis_sid
                                                                                
                                                                                	Chassis serial number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: clei
                                                                                
                                                                                	Common Language Equipment Identifier (CLEI) code
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: controller_family
                                                                                
                                                                                	Controller family
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: controller_type
                                                                                
                                                                                	Controller type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: description
                                                                                
                                                                                	A textual description of physical entity
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num1
                                                                                
                                                                                	Deviation Number # 1
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num2
                                                                                
                                                                                	Deviation Number # 2
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num3
                                                                                
                                                                                	Deviation Number # 3
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num4
                                                                                
                                                                                	Deviation Number # 4
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num5
                                                                                
                                                                                	Deviation Number # 5
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num6
                                                                                
                                                                                	Deviation Number # 6
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num7
                                                                                
                                                                                	Deviation Number # 7
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: eci
                                                                                
                                                                                	Equipment Catalog Item (ECI) number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: eeprom_size
                                                                                
                                                                                	EEPROM Size
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: engineer_use
                                                                                
                                                                                	Engineer Use
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: fru_major_type
                                                                                
                                                                                	FRU Major Type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: fru_minor_type
                                                                                
                                                                                	FRU Minor Type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: hw_version
                                                                                
                                                                                	Hardware Version
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: hwid
                                                                                
                                                                                	Hardware Revision
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: idprom_format_rev
                                                                                
                                                                                	IDPROM Format Revision
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size1
                                                                                
                                                                                	Mac Address Block Size #1
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size2
                                                                                
                                                                                	Mac Address Block Size #2
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size3
                                                                                
                                                                                	Mac Address Block Size #3
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size4
                                                                                
                                                                                	Mac Address Block Size #4
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: manu_test_data
                                                                                
                                                                                	Manufacturing Test Data
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mfg_bits
                                                                                
                                                                                	MFG Bits
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mfg_deviation
                                                                                
                                                                                	MFG Deviation
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: oem_string
                                                                                
                                                                                	OEM String
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: part_number
                                                                                
                                                                                	Part Number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: part_revision
                                                                                
                                                                                	Part Revision
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pca_num
                                                                                
                                                                                	PCA number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pcavid
                                                                                
                                                                                	PCA revision ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pcb_serial_num
                                                                                
                                                                                	PCB Serial Number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pid
                                                                                
                                                                                	Product ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: power_consumption
                                                                                
                                                                                	Power Consumption
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: power_supply_type
                                                                                
                                                                                	Power Supply Type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: product_id
                                                                                
                                                                                	Product ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: rma
                                                                                
                                                                                	RMA Data
                                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                
                                                                                .. attribute:: rma_code
                                                                                
                                                                                	RMA Code
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: serial_number
                                                                                
                                                                                	Serial Number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: snmpoid
                                                                                
                                                                                	SNMP OID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: top_assem_part_num
                                                                                
                                                                                	Top assembly part number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: top_assem_vid
                                                                                
                                                                                	Top assembly revision number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: udi_description
                                                                                
                                                                                	UDI description
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: udi_name
                                                                                
                                                                                	UDI name
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: vid
                                                                                
                                                                                	Version ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.asset_alias = None
                                                                                    self.asset_id = None
                                                                                    self.base_mac_address1 = None
                                                                                    self.base_mac_address2 = None
                                                                                    self.base_mac_address3 = None
                                                                                    self.base_mac_address4 = None
                                                                                    self.block_checksum = None
                                                                                    self.block_count = None
                                                                                    self.block_length = None
                                                                                    self.block_signature = None
                                                                                    self.block_version = None
                                                                                    self.chassis_sid = None
                                                                                    self.clei = None
                                                                                    self.controller_family = None
                                                                                    self.controller_type = None
                                                                                    self.description = None
                                                                                    self.dev_num1 = None
                                                                                    self.dev_num2 = None
                                                                                    self.dev_num3 = None
                                                                                    self.dev_num4 = None
                                                                                    self.dev_num5 = None
                                                                                    self.dev_num6 = None
                                                                                    self.dev_num7 = None
                                                                                    self.eci = None
                                                                                    self.eeprom_size = None
                                                                                    self.engineer_use = None
                                                                                    self.fru_major_type = None
                                                                                    self.fru_minor_type = None
                                                                                    self.hw_version = None
                                                                                    self.hwid = None
                                                                                    self.idprom_format_rev = None
                                                                                    self.mac_add_blk_size1 = None
                                                                                    self.mac_add_blk_size2 = None
                                                                                    self.mac_add_blk_size3 = None
                                                                                    self.mac_add_blk_size4 = None
                                                                                    self.manu_test_data = None
                                                                                    self.mfg_bits = None
                                                                                    self.mfg_deviation = None
                                                                                    self.oem_string = None
                                                                                    self.part_number = None
                                                                                    self.part_revision = None
                                                                                    self.pca_num = None
                                                                                    self.pcavid = None
                                                                                    self.pcb_serial_num = None
                                                                                    self.pid = None
                                                                                    self.power_consumption = None
                                                                                    self.power_supply_type = None
                                                                                    self.product_id = None
                                                                                    self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                    self.rma.parent = self
                                                                                    self.rma_code = None
                                                                                    self.serial_number = None
                                                                                    self.snmpoid = None
                                                                                    self.top_assem_part_num = None
                                                                                    self.top_assem_vid = None
                                                                                    self.udi_description = None
                                                                                    self.udi_name = None
                                                                                    self.vid = None


                                                                                class Rma(object):
                                                                                    """
                                                                                    RMA Data
                                                                                    
                                                                                    .. attribute:: rma_history
                                                                                    
                                                                                    	RMA history
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: rma_number
                                                                                    
                                                                                    	RMA tracking number format is N\-N\-N
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: test_history
                                                                                    
                                                                                    	Test history
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.rma_history = None
                                                                                        self.rma_number = None
                                                                                        self.test_history = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.rma_history is not None:
                                                                                            return True

                                                                                        if self.rma_number is not None:
                                                                                            return True

                                                                                        if self.test_history is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.asset_alias is not None:
                                                                                        return True

                                                                                    if self.asset_id is not None:
                                                                                        return True

                                                                                    if self.base_mac_address1 is not None:
                                                                                        return True

                                                                                    if self.base_mac_address2 is not None:
                                                                                        return True

                                                                                    if self.base_mac_address3 is not None:
                                                                                        return True

                                                                                    if self.base_mac_address4 is not None:
                                                                                        return True

                                                                                    if self.block_checksum is not None:
                                                                                        return True

                                                                                    if self.block_count is not None:
                                                                                        return True

                                                                                    if self.block_length is not None:
                                                                                        return True

                                                                                    if self.block_signature is not None:
                                                                                        return True

                                                                                    if self.block_version is not None:
                                                                                        return True

                                                                                    if self.chassis_sid is not None:
                                                                                        return True

                                                                                    if self.clei is not None:
                                                                                        return True

                                                                                    if self.controller_family is not None:
                                                                                        return True

                                                                                    if self.controller_type is not None:
                                                                                        return True

                                                                                    if self.description is not None:
                                                                                        return True

                                                                                    if self.dev_num1 is not None:
                                                                                        return True

                                                                                    if self.dev_num2 is not None:
                                                                                        return True

                                                                                    if self.dev_num3 is not None:
                                                                                        return True

                                                                                    if self.dev_num4 is not None:
                                                                                        return True

                                                                                    if self.dev_num5 is not None:
                                                                                        return True

                                                                                    if self.dev_num6 is not None:
                                                                                        return True

                                                                                    if self.dev_num7 is not None:
                                                                                        return True

                                                                                    if self.eci is not None:
                                                                                        return True

                                                                                    if self.eeprom_size is not None:
                                                                                        return True

                                                                                    if self.engineer_use is not None:
                                                                                        return True

                                                                                    if self.fru_major_type is not None:
                                                                                        return True

                                                                                    if self.fru_minor_type is not None:
                                                                                        return True

                                                                                    if self.hw_version is not None:
                                                                                        return True

                                                                                    if self.hwid is not None:
                                                                                        return True

                                                                                    if self.idprom_format_rev is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size1 is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size2 is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size3 is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size4 is not None:
                                                                                        return True

                                                                                    if self.manu_test_data is not None:
                                                                                        return True

                                                                                    if self.mfg_bits is not None:
                                                                                        return True

                                                                                    if self.mfg_deviation is not None:
                                                                                        return True

                                                                                    if self.oem_string is not None:
                                                                                        return True

                                                                                    if self.part_number is not None:
                                                                                        return True

                                                                                    if self.part_revision is not None:
                                                                                        return True

                                                                                    if self.pca_num is not None:
                                                                                        return True

                                                                                    if self.pcavid is not None:
                                                                                        return True

                                                                                    if self.pcb_serial_num is not None:
                                                                                        return True

                                                                                    if self.pid is not None:
                                                                                        return True

                                                                                    if self.power_consumption is not None:
                                                                                        return True

                                                                                    if self.power_supply_type is not None:
                                                                                        return True

                                                                                    if self.product_id is not None:
                                                                                        return True

                                                                                    if self.rma is not None and self.rma._has_data():
                                                                                        return True

                                                                                    if self.rma_code is not None:
                                                                                        return True

                                                                                    if self.serial_number is not None:
                                                                                        return True

                                                                                    if self.snmpoid is not None:
                                                                                        return True

                                                                                    if self.top_assem_part_num is not None:
                                                                                        return True

                                                                                    if self.top_assem_vid is not None:
                                                                                        return True

                                                                                    if self.udi_description is not None:
                                                                                        return True

                                                                                    if self.udi_name is not None:
                                                                                        return True

                                                                                    if self.vid is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.description is not None:
                                                                                    return True

                                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                                    return True

                                                                                if self.has_eeprom is not None:
                                                                                    return True

                                                                                if self.inv_card_type is not None:
                                                                                    return True

                                                                                if self.opaque_data is not None:
                                                                                    return True

                                                                                if self.opaque_data_size is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                return True

                                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                return True

                                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                                return True

                                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                return True

                                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                return True

                                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                return True

                                                                            if self.module_done is not None:
                                                                                return True

                                                                            if self.node_id is not None:
                                                                                return True

                                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                return True

                                                                            if self.threshold is not None and self.threshold._has_data():
                                                                                return True

                                                                            if self.vm_done is not None:
                                                                                return True

                                                                            if self.vm_node_id is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                                        if self.name is None:
                                                                            raise YPYModelError('Key property name is None')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi6[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.name is not None:
                                                                            return True

                                                                        if self.attributes is not None and self.attributes._has_data():
                                                                            return True

                                                                        if self.tsi7s is not None and self.tsi7s._has_data():
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi6s'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.tsi6 is not None:
                                                                        for child_ref in self.tsi6:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S']['meta_info']


                                                            class Attributes(object):
                                                                """
                                                                Attributes
                                                                
                                                                .. attribute:: env_sensor_info
                                                                
                                                                	Environment sensor info
                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfo>`
                                                                
                                                                .. attribute:: env_sensor_info_xml
                                                                
                                                                	Environment sensor info XML
                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml>`
                                                                
                                                                .. attribute:: fru_info
                                                                
                                                                	Inventory EDM FRU info
                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo>`
                                                                
                                                                .. attribute:: inv_asset_bag
                                                                
                                                                	Inventory Asset Bag
                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvAssetBag>`
                                                                
                                                                .. attribute:: inv_basic_bag
                                                                
                                                                	Inventory Basic Bag
                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvBasicBag>`
                                                                
                                                                .. attribute:: inv_eeprom_info
                                                                
                                                                	Inventory EDM EEPROM Information Bag
                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo>`
                                                                
                                                                .. attribute:: module_done
                                                                
                                                                	Inventory EDM Module Done Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**default value**\: 1
                                                                
                                                                .. attribute:: node_id
                                                                
                                                                	Node ID Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pwg_info
                                                                
                                                                	Inventory EDM PWG info
                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.PwgInfo>`
                                                                
                                                                .. attribute:: threshold
                                                                
                                                                	Threshold
                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold>`
                                                                
                                                                .. attribute:: vm_done
                                                                
                                                                	VM Done Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                .. attribute:: vm_node_id
                                                                
                                                                	VM Node ID Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfo()
                                                                    self.env_sensor_info.parent = self
                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml()
                                                                    self.env_sensor_info_xml.parent = self
                                                                    self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo()
                                                                    self.fru_info.parent = self
                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvAssetBag()
                                                                    self.inv_asset_bag.parent = self
                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvBasicBag()
                                                                    self.inv_basic_bag.parent = self
                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo()
                                                                    self.inv_eeprom_info.parent = self
                                                                    self.module_done = None
                                                                    self.node_id = None
                                                                    self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.PwgInfo()
                                                                    self.pwg_info.parent = self
                                                                    self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold()
                                                                    self.threshold.parent = self
                                                                    self.vm_done = None
                                                                    self.vm_node_id = None


                                                                class EnvSensorInfo(object):
                                                                    """
                                                                    Environment sensor info
                                                                    
                                                                    .. attribute:: age_time_stamp
                                                                    
                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: alarm_type
                                                                    
                                                                    	Indicates threshold violation
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: data_type
                                                                    
                                                                    	Sensor data type enums
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: device_description
                                                                    
                                                                    	Device Name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: device_id
                                                                    
                                                                    	Identifier for this device
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: field_validity_bitmap
                                                                    
                                                                    	Sensor valid bitmap
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: precision
                                                                    
                                                                    	Sensor precision range
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: scale
                                                                    
                                                                    	Sensor scale enums
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: status
                                                                    
                                                                    	Sensor operation state enums
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: units
                                                                    
                                                                    	Units of variable being read
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: update_rate
                                                                    
                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	Current reading of sensor
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.age_time_stamp = None
                                                                        self.alarm_type = None
                                                                        self.data_type = None
                                                                        self.device_description = None
                                                                        self.device_id = None
                                                                        self.field_validity_bitmap = None
                                                                        self.precision = None
                                                                        self.scale = None
                                                                        self.status = None
                                                                        self.units = None
                                                                        self.update_rate = None
                                                                        self.value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.age_time_stamp is not None:
                                                                            return True

                                                                        if self.alarm_type is not None:
                                                                            return True

                                                                        if self.data_type is not None:
                                                                            return True

                                                                        if self.device_description is not None:
                                                                            return True

                                                                        if self.device_id is not None:
                                                                            return True

                                                                        if self.field_validity_bitmap is not None:
                                                                            return True

                                                                        if self.precision is not None:
                                                                            return True

                                                                        if self.scale is not None:
                                                                            return True

                                                                        if self.status is not None:
                                                                            return True

                                                                        if self.units is not None:
                                                                            return True

                                                                        if self.update_rate is not None:
                                                                            return True

                                                                        if self.value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfo']['meta_info']


                                                                class PwgInfo(object):
                                                                    """
                                                                    Inventory EDM PWG info
                                                                    
                                                                    .. attribute:: power_group_available_current
                                                                    
                                                                    	available current
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_group_drawn_current
                                                                    
                                                                    	drawn current
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_group_power_units
                                                                    
                                                                    	power units
                                                                    	**type**\:  str
                                                                    
                                                                    .. attribute:: power_group_redundancy_mode
                                                                    
                                                                    	redundancy mode
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.power_group_available_current = None
                                                                        self.power_group_drawn_current = None
                                                                        self.power_group_power_units = None
                                                                        self.power_group_redundancy_mode = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.power_group_available_current is not None:
                                                                            return True

                                                                        if self.power_group_drawn_current is not None:
                                                                            return True

                                                                        if self.power_group_power_units is not None:
                                                                            return True

                                                                        if self.power_group_redundancy_mode is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.PwgInfo']['meta_info']


                                                                class EnvSensorInfoXml(object):
                                                                    """
                                                                    Environment sensor info XML
                                                                    
                                                                    .. attribute:: data_type
                                                                    
                                                                    	Sensor data type
                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                    
                                                                    .. attribute:: description
                                                                    
                                                                    	Device Name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: status
                                                                    
                                                                    	Sensor operation state
                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                    
                                                                    .. attribute:: threshold
                                                                    
                                                                    	Threshold information
                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold>`
                                                                    
                                                                    .. attribute:: units
                                                                    
                                                                    	Units of variable being read
                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                    
                                                                    .. attribute:: update_rate
                                                                    
                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.data_type = None
                                                                        self.description = None
                                                                        self.status = None
                                                                        self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold()
                                                                        self.threshold.parent = self
                                                                        self.units = None
                                                                        self.update_rate = None
                                                                        self.value = None


                                                                    class Threshold(object):
                                                                        """
                                                                        Threshold information
                                                                        
                                                                        .. attribute:: threshold_array
                                                                        
                                                                        	Array of threshold
                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.threshold_array = YList()
                                                                            self.threshold_array.parent = self
                                                                            self.threshold_array.name = 'threshold_array'


                                                                        class ThresholdArray(object):
                                                                            """
                                                                            Array of threshold
                                                                            
                                                                            .. attribute:: threshold_name
                                                                            
                                                                            	Threshold name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_name = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_name is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.threshold_array is not None:
                                                                                for child_ref in self.threshold_array:
                                                                                    if child_ref._has_data():
                                                                                        return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.data_type is not None:
                                                                            return True

                                                                        if self.description is not None:
                                                                            return True

                                                                        if self.status is not None:
                                                                            return True

                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                            return True

                                                                        if self.units is not None:
                                                                            return True

                                                                        if self.update_rate is not None:
                                                                            return True

                                                                        if self.value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml']['meta_info']


                                                                class InvAssetBag(object):
                                                                    """
                                                                    Inventory Asset Bag
                                                                    
                                                                    .. attribute:: manufacturer_assembly_number
                                                                    
                                                                    	Manufacture Assembly number
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_assembly_revision
                                                                    
                                                                    	Manufacture assembly revision
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                    
                                                                    	Common Language Equipment           Identifier number
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_software_identifier
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                    
                                                                    	String containing OEM information           if applicable
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: part_number
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.manufacturer_assembly_number = None
                                                                        self.manufacturer_assembly_revision = None
                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                        self.manufacturer_firmware_identifier = None
                                                                        self.manufacturer_software_identifier = None
                                                                        self.original_equipment_manufacturer_string = None
                                                                        self.part_number = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.manufacturer_assembly_number is not None:
                                                                            return True

                                                                        if self.manufacturer_assembly_revision is not None:
                                                                            return True

                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                            return True

                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                            return True

                                                                        if self.manufacturer_software_identifier is not None:
                                                                            return True

                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                            return True

                                                                        if self.part_number is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvAssetBag']['meta_info']


                                                                class Threshold(object):
                                                                    """
                                                                    Threshold
                                                                    
                                                                    .. attribute:: critical_hi
                                                                    
                                                                    	Critical High
                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi>`
                                                                    
                                                                    .. attribute:: critical_lo
                                                                    
                                                                    	Critical Low
                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo>`
                                                                    
                                                                    .. attribute:: major_hi
                                                                    
                                                                    	Major High
                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi>`
                                                                    
                                                                    .. attribute:: major_lo
                                                                    
                                                                    	Major Low
                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo>`
                                                                    
                                                                    .. attribute:: minor_hi
                                                                    
                                                                    	Minor High
                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi>`
                                                                    
                                                                    .. attribute:: minor_lo
                                                                    
                                                                    	Minor Low
                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi()
                                                                        self.critical_hi.parent = self
                                                                        self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo()
                                                                        self.critical_lo.parent = self
                                                                        self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi()
                                                                        self.major_hi.parent = self
                                                                        self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo()
                                                                        self.major_lo.parent = self
                                                                        self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi()
                                                                        self.minor_hi.parent = self
                                                                        self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo()
                                                                        self.minor_lo.parent = self


                                                                    class MajorLo(object):
                                                                        """
                                                                        Major Low
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo']['meta_info']


                                                                    class CriticalHi(object):
                                                                        """
                                                                        Critical High
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi']['meta_info']


                                                                    class MinorHi(object):
                                                                        """
                                                                        Minor High
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi']['meta_info']


                                                                    class MajorHi(object):
                                                                        """
                                                                        Major High
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi']['meta_info']


                                                                    class CriticalLo(object):
                                                                        """
                                                                        Critical Low
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo']['meta_info']


                                                                    class MinorLo(object):
                                                                        """
                                                                        Minor Low
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                            return True

                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                            return True

                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                            return True

                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                            return True

                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                            return True

                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold']['meta_info']


                                                                class FruInfo(object):
                                                                    """
                                                                    Inventory EDM FRU info
                                                                    
                                                                    .. attribute:: card_administrative_state
                                                                    
                                                                    	card admin state\: shutdown or not
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: card_monitor_state
                                                                    
                                                                    	card is monitored by a manager or left unmonitored
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: card_operational_state
                                                                    
                                                                    	card operation state
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: card_reset_reason
                                                                    
                                                                    	card reset reason enum
                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                    
                                                                    .. attribute:: card_up_time
                                                                    
                                                                    	card up time
                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.CardUpTime>`
                                                                    
                                                                    .. attribute:: last_operational_state_change
                                                                    
                                                                    	last card oper change state
                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.LastOperationalStateChange>`
                                                                    
                                                                    .. attribute:: power_administrative_state
                                                                    
                                                                    	power admin state\: up or down
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_current_measurement
                                                                    
                                                                    	power current\: not implemented
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_operational_state
                                                                    
                                                                    	Power operation state
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.card_administrative_state = None
                                                                        self.card_monitor_state = None
                                                                        self.card_operational_state = None
                                                                        self.card_reset_reason = None
                                                                        self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.CardUpTime()
                                                                        self.card_up_time.parent = self
                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.LastOperationalStateChange()
                                                                        self.last_operational_state_change.parent = self
                                                                        self.power_administrative_state = None
                                                                        self.power_current_measurement = None
                                                                        self.power_operational_state = None


                                                                    class LastOperationalStateChange(object):
                                                                        """
                                                                        last card oper change state
                                                                        
                                                                        .. attribute:: time_in_nano_seconds
                                                                        
                                                                        	Time Value in Nano\-seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: nanosecond
                                                                        
                                                                        .. attribute:: time_in_seconds
                                                                        
                                                                        	Time Value in Seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.time_in_nano_seconds = None
                                                                            self.time_in_seconds = None

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.time_in_nano_seconds is not None:
                                                                                return True

                                                                            if self.time_in_seconds is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                    class CardUpTime(object):
                                                                        """
                                                                        card up time
                                                                        
                                                                        .. attribute:: time_in_nano_seconds
                                                                        
                                                                        	Time Value in Nano\-seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: nanosecond
                                                                        
                                                                        .. attribute:: time_in_seconds
                                                                        
                                                                        	Time Value in Seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.time_in_nano_seconds = None
                                                                            self.time_in_seconds = None

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.time_in_nano_seconds is not None:
                                                                                return True

                                                                            if self.time_in_seconds is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.card_administrative_state is not None:
                                                                            return True

                                                                        if self.card_monitor_state is not None:
                                                                            return True

                                                                        if self.card_operational_state is not None:
                                                                            return True

                                                                        if self.card_reset_reason is not None:
                                                                            return True

                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                            return True

                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                            return True

                                                                        if self.power_administrative_state is not None:
                                                                            return True

                                                                        if self.power_current_measurement is not None:
                                                                            return True

                                                                        if self.power_operational_state is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo']['meta_info']


                                                                class InvBasicBag(object):
                                                                    """
                                                                    Inventory Basic Bag
                                                                    
                                                                    .. attribute:: alias
                                                                    
                                                                    	useful for storing an entity alias 
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: asset_id_str
                                                                    
                                                                    	asset Identification string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: asset_identification
                                                                    
                                                                    	asset Identification
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: ceport
                                                                    
                                                                    	1 if ce port found, 0 if not
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: chip_hardware_revision
                                                                    
                                                                    	chip module hw revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: composite_class_code
                                                                    
                                                                    	Major&minor class of the entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: description
                                                                    
                                                                    	describes in user\-readable terms       what the entity in question does
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: environmental_monitor_path
                                                                    
                                                                    	sysdb name of sensor in the envmon EDM
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: firmware_revision
                                                                    
                                                                    	firmware revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: group_flag
                                                                    
                                                                    	indicates if this entity is group       or not
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: hardware_revision
                                                                    
                                                                    	hw revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: is_field_replaceable_unit
                                                                    
                                                                    	1 if Field Replaceable Unit 0, if not
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: manufacturer_asset_tags
                                                                    
                                                                    	Manufacture Asset Tags
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: manufacturer_name
                                                                    
                                                                    	manufacturer's name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: memory_size
                                                                    
                                                                    	Size of memory associated with       the entity where applicable
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: model_name
                                                                    
                                                                    	model name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: name
                                                                    
                                                                    	name string for the entity
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: new_deviation_number
                                                                    
                                                                    	integer value for New Deviation Number 0x88
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: physical_layer_interface_module_type
                                                                    
                                                                    	integer value for plim type if     applicable to this entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: redundancystate
                                                                    
                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: serial_number
                                                                    
                                                                    	serial number
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: software_revision
                                                                    
                                                                    	software revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: unique_id
                                                                    
                                                                    	Unique id for an entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: unrecognized_fru
                                                                    
                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: vendor_type
                                                                    
                                                                    	maps to the vendor OID string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: xr_scoped
                                                                    
                                                                    	1 if xr scoped, 0 if not
                                                                    	**type**\:  bool
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.alias = None
                                                                        self.asset_id_str = None
                                                                        self.asset_identification = None
                                                                        self.ceport = None
                                                                        self.chip_hardware_revision = None
                                                                        self.composite_class_code = None
                                                                        self.description = None
                                                                        self.environmental_monitor_path = None
                                                                        self.firmware_revision = None
                                                                        self.group_flag = None
                                                                        self.hardware_revision = None
                                                                        self.is_field_replaceable_unit = None
                                                                        self.manufacturer_asset_tags = None
                                                                        self.manufacturer_name = None
                                                                        self.memory_size = None
                                                                        self.model_name = None
                                                                        self.name = None
                                                                        self.new_deviation_number = None
                                                                        self.physical_layer_interface_module_type = None
                                                                        self.redundancystate = None
                                                                        self.serial_number = None
                                                                        self.software_revision = None
                                                                        self.unique_id = None
                                                                        self.unrecognized_fru = None
                                                                        self.vendor_type = None
                                                                        self.xr_scoped = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.alias is not None:
                                                                            return True

                                                                        if self.asset_id_str is not None:
                                                                            return True

                                                                        if self.asset_identification is not None:
                                                                            return True

                                                                        if self.ceport is not None:
                                                                            return True

                                                                        if self.chip_hardware_revision is not None:
                                                                            return True

                                                                        if self.composite_class_code is not None:
                                                                            return True

                                                                        if self.description is not None:
                                                                            return True

                                                                        if self.environmental_monitor_path is not None:
                                                                            return True

                                                                        if self.firmware_revision is not None:
                                                                            return True

                                                                        if self.group_flag is not None:
                                                                            return True

                                                                        if self.hardware_revision is not None:
                                                                            return True

                                                                        if self.is_field_replaceable_unit is not None:
                                                                            return True

                                                                        if self.manufacturer_asset_tags is not None:
                                                                            return True

                                                                        if self.manufacturer_name is not None:
                                                                            return True

                                                                        if self.memory_size is not None:
                                                                            return True

                                                                        if self.model_name is not None:
                                                                            return True

                                                                        if self.name is not None:
                                                                            return True

                                                                        if self.new_deviation_number is not None:
                                                                            return True

                                                                        if self.physical_layer_interface_module_type is not None:
                                                                            return True

                                                                        if self.redundancystate is not None:
                                                                            return True

                                                                        if self.serial_number is not None:
                                                                            return True

                                                                        if self.software_revision is not None:
                                                                            return True

                                                                        if self.unique_id is not None:
                                                                            return True

                                                                        if self.unrecognized_fru is not None:
                                                                            return True

                                                                        if self.vendor_type is not None:
                                                                            return True

                                                                        if self.xr_scoped is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvBasicBag']['meta_info']


                                                                class InvEepromInfo(object):
                                                                    """
                                                                    Inventory EDM EEPROM Information Bag
                                                                    
                                                                    .. attribute:: description
                                                                    
                                                                    	A textual description of physical entity
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: eeprom
                                                                    
                                                                    	EEPROM data not from hex data
                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom>`
                                                                    
                                                                    .. attribute:: has_eeprom
                                                                    
                                                                    	use eeprom instead of opaque data
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: inv_card_type
                                                                    
                                                                    	Inventory card type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: opaque_data
                                                                    
                                                                    	EEPROM hex data
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: opaque_data_size
                                                                    
                                                                    	size of the EEPROM hex data
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.description = None
                                                                        self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom()
                                                                        self.eeprom.parent = self
                                                                        self.has_eeprom = None
                                                                        self.inv_card_type = None
                                                                        self.opaque_data = None
                                                                        self.opaque_data_size = None


                                                                    class Eeprom(object):
                                                                        """
                                                                        EEPROM data not from hex data
                                                                        
                                                                        .. attribute:: asset_alias
                                                                        
                                                                        	Asset Alias
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: asset_id
                                                                        
                                                                        	Asset ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address1
                                                                        
                                                                        	Base Mac Address #1
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address2
                                                                        
                                                                        	Base Mac Address #2
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address3
                                                                        
                                                                        	Base Mac Address #3
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address4
                                                                        
                                                                        	Base Mac Address #4
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_checksum
                                                                        
                                                                        	Block Checksum
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_count
                                                                        
                                                                        	Block Count
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_length
                                                                        
                                                                        	Block Length
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_signature
                                                                        
                                                                        	Block Signature
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_version
                                                                        
                                                                        	Block Version
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: chassis_sid
                                                                        
                                                                        	Chassis serial number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: clei
                                                                        
                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: controller_family
                                                                        
                                                                        	Controller family
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: controller_type
                                                                        
                                                                        	Controller type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: description
                                                                        
                                                                        	A textual description of physical entity
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num1
                                                                        
                                                                        	Deviation Number # 1
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num2
                                                                        
                                                                        	Deviation Number # 2
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num3
                                                                        
                                                                        	Deviation Number # 3
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num4
                                                                        
                                                                        	Deviation Number # 4
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num5
                                                                        
                                                                        	Deviation Number # 5
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num6
                                                                        
                                                                        	Deviation Number # 6
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num7
                                                                        
                                                                        	Deviation Number # 7
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: eci
                                                                        
                                                                        	Equipment Catalog Item (ECI) number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: eeprom_size
                                                                        
                                                                        	EEPROM Size
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: engineer_use
                                                                        
                                                                        	Engineer Use
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: fru_major_type
                                                                        
                                                                        	FRU Major Type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: fru_minor_type
                                                                        
                                                                        	FRU Minor Type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: hw_version
                                                                        
                                                                        	Hardware Version
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: hwid
                                                                        
                                                                        	Hardware Revision
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: idprom_format_rev
                                                                        
                                                                        	IDPROM Format Revision
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size1
                                                                        
                                                                        	Mac Address Block Size #1
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size2
                                                                        
                                                                        	Mac Address Block Size #2
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size3
                                                                        
                                                                        	Mac Address Block Size #3
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size4
                                                                        
                                                                        	Mac Address Block Size #4
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: manu_test_data
                                                                        
                                                                        	Manufacturing Test Data
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mfg_bits
                                                                        
                                                                        	MFG Bits
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mfg_deviation
                                                                        
                                                                        	MFG Deviation
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: oem_string
                                                                        
                                                                        	OEM String
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: part_number
                                                                        
                                                                        	Part Number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: part_revision
                                                                        
                                                                        	Part Revision
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pca_num
                                                                        
                                                                        	PCA number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pcavid
                                                                        
                                                                        	PCA revision ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pcb_serial_num
                                                                        
                                                                        	PCB Serial Number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pid
                                                                        
                                                                        	Product ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: power_consumption
                                                                        
                                                                        	Power Consumption
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: power_supply_type
                                                                        
                                                                        	Power Supply Type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: product_id
                                                                        
                                                                        	Product ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: rma
                                                                        
                                                                        	RMA Data
                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                        
                                                                        .. attribute:: rma_code
                                                                        
                                                                        	RMA Code
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: serial_number
                                                                        
                                                                        	Serial Number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: snmpoid
                                                                        
                                                                        	SNMP OID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: top_assem_part_num
                                                                        
                                                                        	Top assembly part number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: top_assem_vid
                                                                        
                                                                        	Top assembly revision number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: udi_description
                                                                        
                                                                        	UDI description
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: udi_name
                                                                        
                                                                        	UDI name
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: vid
                                                                        
                                                                        	Version ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.asset_alias = None
                                                                            self.asset_id = None
                                                                            self.base_mac_address1 = None
                                                                            self.base_mac_address2 = None
                                                                            self.base_mac_address3 = None
                                                                            self.base_mac_address4 = None
                                                                            self.block_checksum = None
                                                                            self.block_count = None
                                                                            self.block_length = None
                                                                            self.block_signature = None
                                                                            self.block_version = None
                                                                            self.chassis_sid = None
                                                                            self.clei = None
                                                                            self.controller_family = None
                                                                            self.controller_type = None
                                                                            self.description = None
                                                                            self.dev_num1 = None
                                                                            self.dev_num2 = None
                                                                            self.dev_num3 = None
                                                                            self.dev_num4 = None
                                                                            self.dev_num5 = None
                                                                            self.dev_num6 = None
                                                                            self.dev_num7 = None
                                                                            self.eci = None
                                                                            self.eeprom_size = None
                                                                            self.engineer_use = None
                                                                            self.fru_major_type = None
                                                                            self.fru_minor_type = None
                                                                            self.hw_version = None
                                                                            self.hwid = None
                                                                            self.idprom_format_rev = None
                                                                            self.mac_add_blk_size1 = None
                                                                            self.mac_add_blk_size2 = None
                                                                            self.mac_add_blk_size3 = None
                                                                            self.mac_add_blk_size4 = None
                                                                            self.manu_test_data = None
                                                                            self.mfg_bits = None
                                                                            self.mfg_deviation = None
                                                                            self.oem_string = None
                                                                            self.part_number = None
                                                                            self.part_revision = None
                                                                            self.pca_num = None
                                                                            self.pcavid = None
                                                                            self.pcb_serial_num = None
                                                                            self.pid = None
                                                                            self.power_consumption = None
                                                                            self.power_supply_type = None
                                                                            self.product_id = None
                                                                            self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                            self.rma.parent = self
                                                                            self.rma_code = None
                                                                            self.serial_number = None
                                                                            self.snmpoid = None
                                                                            self.top_assem_part_num = None
                                                                            self.top_assem_vid = None
                                                                            self.udi_description = None
                                                                            self.udi_name = None
                                                                            self.vid = None


                                                                        class Rma(object):
                                                                            """
                                                                            RMA Data
                                                                            
                                                                            .. attribute:: rma_history
                                                                            
                                                                            	RMA history
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: rma_number
                                                                            
                                                                            	RMA tracking number format is N\-N\-N
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: test_history
                                                                            
                                                                            	Test history
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.rma_history = None
                                                                                self.rma_number = None
                                                                                self.test_history = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.rma_history is not None:
                                                                                    return True

                                                                                if self.rma_number is not None:
                                                                                    return True

                                                                                if self.test_history is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.asset_alias is not None:
                                                                                return True

                                                                            if self.asset_id is not None:
                                                                                return True

                                                                            if self.base_mac_address1 is not None:
                                                                                return True

                                                                            if self.base_mac_address2 is not None:
                                                                                return True

                                                                            if self.base_mac_address3 is not None:
                                                                                return True

                                                                            if self.base_mac_address4 is not None:
                                                                                return True

                                                                            if self.block_checksum is not None:
                                                                                return True

                                                                            if self.block_count is not None:
                                                                                return True

                                                                            if self.block_length is not None:
                                                                                return True

                                                                            if self.block_signature is not None:
                                                                                return True

                                                                            if self.block_version is not None:
                                                                                return True

                                                                            if self.chassis_sid is not None:
                                                                                return True

                                                                            if self.clei is not None:
                                                                                return True

                                                                            if self.controller_family is not None:
                                                                                return True

                                                                            if self.controller_type is not None:
                                                                                return True

                                                                            if self.description is not None:
                                                                                return True

                                                                            if self.dev_num1 is not None:
                                                                                return True

                                                                            if self.dev_num2 is not None:
                                                                                return True

                                                                            if self.dev_num3 is not None:
                                                                                return True

                                                                            if self.dev_num4 is not None:
                                                                                return True

                                                                            if self.dev_num5 is not None:
                                                                                return True

                                                                            if self.dev_num6 is not None:
                                                                                return True

                                                                            if self.dev_num7 is not None:
                                                                                return True

                                                                            if self.eci is not None:
                                                                                return True

                                                                            if self.eeprom_size is not None:
                                                                                return True

                                                                            if self.engineer_use is not None:
                                                                                return True

                                                                            if self.fru_major_type is not None:
                                                                                return True

                                                                            if self.fru_minor_type is not None:
                                                                                return True

                                                                            if self.hw_version is not None:
                                                                                return True

                                                                            if self.hwid is not None:
                                                                                return True

                                                                            if self.idprom_format_rev is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size1 is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size2 is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size3 is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size4 is not None:
                                                                                return True

                                                                            if self.manu_test_data is not None:
                                                                                return True

                                                                            if self.mfg_bits is not None:
                                                                                return True

                                                                            if self.mfg_deviation is not None:
                                                                                return True

                                                                            if self.oem_string is not None:
                                                                                return True

                                                                            if self.part_number is not None:
                                                                                return True

                                                                            if self.part_revision is not None:
                                                                                return True

                                                                            if self.pca_num is not None:
                                                                                return True

                                                                            if self.pcavid is not None:
                                                                                return True

                                                                            if self.pcb_serial_num is not None:
                                                                                return True

                                                                            if self.pid is not None:
                                                                                return True

                                                                            if self.power_consumption is not None:
                                                                                return True

                                                                            if self.power_supply_type is not None:
                                                                                return True

                                                                            if self.product_id is not None:
                                                                                return True

                                                                            if self.rma is not None and self.rma._has_data():
                                                                                return True

                                                                            if self.rma_code is not None:
                                                                                return True

                                                                            if self.serial_number is not None:
                                                                                return True

                                                                            if self.snmpoid is not None:
                                                                                return True

                                                                            if self.top_assem_part_num is not None:
                                                                                return True

                                                                            if self.top_assem_vid is not None:
                                                                                return True

                                                                            if self.udi_description is not None:
                                                                                return True

                                                                            if self.udi_name is not None:
                                                                                return True

                                                                            if self.vid is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.description is not None:
                                                                            return True

                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                            return True

                                                                        if self.has_eeprom is not None:
                                                                            return True

                                                                        if self.inv_card_type is not None:
                                                                            return True

                                                                        if self.opaque_data is not None:
                                                                            return True

                                                                        if self.opaque_data_size is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                        return True

                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                        return True

                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                        return True

                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                        return True

                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                        return True

                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                        return True

                                                                    if self.module_done is not None:
                                                                        return True

                                                                    if self.node_id is not None:
                                                                        return True

                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                        return True

                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                        return True

                                                                    if self.vm_done is not None:
                                                                        return True

                                                                    if self.vm_node_id is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                if self.name is None:
                                                                    raise YPYModelError('Key property name is None')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi5[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.name is not None:
                                                                    return True

                                                                if self.attributes is not None and self.attributes._has_data():
                                                                    return True

                                                                if self.tsi6s is not None and self.tsi6s._has_data():
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi5s'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.tsi5 is not None:
                                                                for child_ref in self.tsi5:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S']['meta_info']


                                                    class Attributes(object):
                                                        """
                                                        Attributes
                                                        
                                                        .. attribute:: env_sensor_info
                                                        
                                                        	Environment sensor info
                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfo>`
                                                        
                                                        .. attribute:: env_sensor_info_xml
                                                        
                                                        	Environment sensor info XML
                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml>`
                                                        
                                                        .. attribute:: fru_info
                                                        
                                                        	Inventory EDM FRU info
                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo>`
                                                        
                                                        .. attribute:: inv_asset_bag
                                                        
                                                        	Inventory Asset Bag
                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvAssetBag>`
                                                        
                                                        .. attribute:: inv_basic_bag
                                                        
                                                        	Inventory Basic Bag
                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvBasicBag>`
                                                        
                                                        .. attribute:: inv_eeprom_info
                                                        
                                                        	Inventory EDM EEPROM Information Bag
                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo>`
                                                        
                                                        .. attribute:: module_done
                                                        
                                                        	Inventory EDM Module Done Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: node_id
                                                        
                                                        	Node ID Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pwg_info
                                                        
                                                        	Inventory EDM PWG info
                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.PwgInfo>`
                                                        
                                                        .. attribute:: threshold
                                                        
                                                        	Threshold
                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold>`
                                                        
                                                        .. attribute:: vm_done
                                                        
                                                        	VM Done Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        .. attribute:: vm_node_id
                                                        
                                                        	VM Node ID Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfo()
                                                            self.env_sensor_info.parent = self
                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml()
                                                            self.env_sensor_info_xml.parent = self
                                                            self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo()
                                                            self.fru_info.parent = self
                                                            self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvAssetBag()
                                                            self.inv_asset_bag.parent = self
                                                            self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvBasicBag()
                                                            self.inv_basic_bag.parent = self
                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo()
                                                            self.inv_eeprom_info.parent = self
                                                            self.module_done = None
                                                            self.node_id = None
                                                            self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.PwgInfo()
                                                            self.pwg_info.parent = self
                                                            self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold()
                                                            self.threshold.parent = self
                                                            self.vm_done = None
                                                            self.vm_node_id = None


                                                        class EnvSensorInfo(object):
                                                            """
                                                            Environment sensor info
                                                            
                                                            .. attribute:: age_time_stamp
                                                            
                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: alarm_type
                                                            
                                                            	Indicates threshold violation
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: data_type
                                                            
                                                            	Sensor data type enums
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: device_description
                                                            
                                                            	Device Name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: device_id
                                                            
                                                            	Identifier for this device
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: field_validity_bitmap
                                                            
                                                            	Sensor valid bitmap
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: precision
                                                            
                                                            	Sensor precision range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: scale
                                                            
                                                            	Sensor scale enums
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: status
                                                            
                                                            	Sensor operation state enums
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: units
                                                            
                                                            	Units of variable being read
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: update_rate
                                                            
                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: value
                                                            
                                                            	Current reading of sensor
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.age_time_stamp = None
                                                                self.alarm_type = None
                                                                self.data_type = None
                                                                self.device_description = None
                                                                self.device_id = None
                                                                self.field_validity_bitmap = None
                                                                self.precision = None
                                                                self.scale = None
                                                                self.status = None
                                                                self.units = None
                                                                self.update_rate = None
                                                                self.value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.age_time_stamp is not None:
                                                                    return True

                                                                if self.alarm_type is not None:
                                                                    return True

                                                                if self.data_type is not None:
                                                                    return True

                                                                if self.device_description is not None:
                                                                    return True

                                                                if self.device_id is not None:
                                                                    return True

                                                                if self.field_validity_bitmap is not None:
                                                                    return True

                                                                if self.precision is not None:
                                                                    return True

                                                                if self.scale is not None:
                                                                    return True

                                                                if self.status is not None:
                                                                    return True

                                                                if self.units is not None:
                                                                    return True

                                                                if self.update_rate is not None:
                                                                    return True

                                                                if self.value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfo']['meta_info']


                                                        class PwgInfo(object):
                                                            """
                                                            Inventory EDM PWG info
                                                            
                                                            .. attribute:: power_group_available_current
                                                            
                                                            	available current
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_group_drawn_current
                                                            
                                                            	drawn current
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_group_power_units
                                                            
                                                            	power units
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: power_group_redundancy_mode
                                                            
                                                            	redundancy mode
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.power_group_available_current = None
                                                                self.power_group_drawn_current = None
                                                                self.power_group_power_units = None
                                                                self.power_group_redundancy_mode = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.power_group_available_current is not None:
                                                                    return True

                                                                if self.power_group_drawn_current is not None:
                                                                    return True

                                                                if self.power_group_power_units is not None:
                                                                    return True

                                                                if self.power_group_redundancy_mode is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.PwgInfo']['meta_info']


                                                        class EnvSensorInfoXml(object):
                                                            """
                                                            Environment sensor info XML
                                                            
                                                            .. attribute:: data_type
                                                            
                                                            	Sensor data type
                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                            
                                                            .. attribute:: description
                                                            
                                                            	Device Name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: status
                                                            
                                                            	Sensor operation state
                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                            
                                                            .. attribute:: threshold
                                                            
                                                            	Threshold information
                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold>`
                                                            
                                                            .. attribute:: units
                                                            
                                                            	Units of variable being read
                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                            
                                                            .. attribute:: update_rate
                                                            
                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: value
                                                            
                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.data_type = None
                                                                self.description = None
                                                                self.status = None
                                                                self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold()
                                                                self.threshold.parent = self
                                                                self.units = None
                                                                self.update_rate = None
                                                                self.value = None


                                                            class Threshold(object):
                                                                """
                                                                Threshold information
                                                                
                                                                .. attribute:: threshold_array
                                                                
                                                                	Array of threshold
                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.threshold_array = YList()
                                                                    self.threshold_array.parent = self
                                                                    self.threshold_array.name = 'threshold_array'


                                                                class ThresholdArray(object):
                                                                    """
                                                                    Array of threshold
                                                                    
                                                                    .. attribute:: threshold_name
                                                                    
                                                                    	Threshold name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_name = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_name is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.threshold_array is not None:
                                                                        for child_ref in self.threshold_array:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.data_type is not None:
                                                                    return True

                                                                if self.description is not None:
                                                                    return True

                                                                if self.status is not None:
                                                                    return True

                                                                if self.threshold is not None and self.threshold._has_data():
                                                                    return True

                                                                if self.units is not None:
                                                                    return True

                                                                if self.update_rate is not None:
                                                                    return True

                                                                if self.value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml']['meta_info']


                                                        class InvAssetBag(object):
                                                            """
                                                            Inventory Asset Bag
                                                            
                                                            .. attribute:: manufacturer_assembly_number
                                                            
                                                            	Manufacture Assembly number
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_assembly_revision
                                                            
                                                            	Manufacture assembly revision
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                            
                                                            	Common Language Equipment           Identifier number
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_firmware_identifier
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_software_identifier
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: original_equipment_manufacturer_string
                                                            
                                                            	String containing OEM information           if applicable
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: part_number
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.manufacturer_assembly_number = None
                                                                self.manufacturer_assembly_revision = None
                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                self.manufacturer_firmware_identifier = None
                                                                self.manufacturer_software_identifier = None
                                                                self.original_equipment_manufacturer_string = None
                                                                self.part_number = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.manufacturer_assembly_number is not None:
                                                                    return True

                                                                if self.manufacturer_assembly_revision is not None:
                                                                    return True

                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                    return True

                                                                if self.manufacturer_firmware_identifier is not None:
                                                                    return True

                                                                if self.manufacturer_software_identifier is not None:
                                                                    return True

                                                                if self.original_equipment_manufacturer_string is not None:
                                                                    return True

                                                                if self.part_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvAssetBag']['meta_info']


                                                        class Threshold(object):
                                                            """
                                                            Threshold
                                                            
                                                            .. attribute:: critical_hi
                                                            
                                                            	Critical High
                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi>`
                                                            
                                                            .. attribute:: critical_lo
                                                            
                                                            	Critical Low
                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo>`
                                                            
                                                            .. attribute:: major_hi
                                                            
                                                            	Major High
                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi>`
                                                            
                                                            .. attribute:: major_lo
                                                            
                                                            	Major Low
                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo>`
                                                            
                                                            .. attribute:: minor_hi
                                                            
                                                            	Minor High
                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi>`
                                                            
                                                            .. attribute:: minor_lo
                                                            
                                                            	Minor Low
                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi()
                                                                self.critical_hi.parent = self
                                                                self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo()
                                                                self.critical_lo.parent = self
                                                                self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi()
                                                                self.major_hi.parent = self
                                                                self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo()
                                                                self.major_lo.parent = self
                                                                self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi()
                                                                self.minor_hi.parent = self
                                                                self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo()
                                                                self.minor_lo.parent = self


                                                            class MajorLo(object):
                                                                """
                                                                Major Low
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo']['meta_info']


                                                            class CriticalHi(object):
                                                                """
                                                                Critical High
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi']['meta_info']


                                                            class MinorHi(object):
                                                                """
                                                                Minor High
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi']['meta_info']


                                                            class MajorHi(object):
                                                                """
                                                                Major High
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi']['meta_info']


                                                            class CriticalLo(object):
                                                                """
                                                                Critical Low
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo']['meta_info']


                                                            class MinorLo(object):
                                                                """
                                                                Minor Low
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                    return True

                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                    return True

                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                    return True

                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                    return True

                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                    return True

                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold']['meta_info']


                                                        class FruInfo(object):
                                                            """
                                                            Inventory EDM FRU info
                                                            
                                                            .. attribute:: card_administrative_state
                                                            
                                                            	card admin state\: shutdown or not
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: card_monitor_state
                                                            
                                                            	card is monitored by a manager or left unmonitored
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: card_operational_state
                                                            
                                                            	card operation state
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: card_reset_reason
                                                            
                                                            	card reset reason enum
                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                            
                                                            .. attribute:: card_up_time
                                                            
                                                            	card up time
                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.CardUpTime>`
                                                            
                                                            .. attribute:: last_operational_state_change
                                                            
                                                            	last card oper change state
                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.LastOperationalStateChange>`
                                                            
                                                            .. attribute:: power_administrative_state
                                                            
                                                            	power admin state\: up or down
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_current_measurement
                                                            
                                                            	power current\: not implemented
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_operational_state
                                                            
                                                            	Power operation state
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.card_administrative_state = None
                                                                self.card_monitor_state = None
                                                                self.card_operational_state = None
                                                                self.card_reset_reason = None
                                                                self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.CardUpTime()
                                                                self.card_up_time.parent = self
                                                                self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.LastOperationalStateChange()
                                                                self.last_operational_state_change.parent = self
                                                                self.power_administrative_state = None
                                                                self.power_current_measurement = None
                                                                self.power_operational_state = None


                                                            class LastOperationalStateChange(object):
                                                                """
                                                                last card oper change state
                                                                
                                                                .. attribute:: time_in_nano_seconds
                                                                
                                                                	Time Value in Nano\-seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: nanosecond
                                                                
                                                                .. attribute:: time_in_seconds
                                                                
                                                                	Time Value in Seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: second
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.time_in_nano_seconds = None
                                                                    self.time_in_seconds = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.time_in_nano_seconds is not None:
                                                                        return True

                                                                    if self.time_in_seconds is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                            class CardUpTime(object):
                                                                """
                                                                card up time
                                                                
                                                                .. attribute:: time_in_nano_seconds
                                                                
                                                                	Time Value in Nano\-seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: nanosecond
                                                                
                                                                .. attribute:: time_in_seconds
                                                                
                                                                	Time Value in Seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: second
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.time_in_nano_seconds = None
                                                                    self.time_in_seconds = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.time_in_nano_seconds is not None:
                                                                        return True

                                                                    if self.time_in_seconds is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.CardUpTime']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.card_administrative_state is not None:
                                                                    return True

                                                                if self.card_monitor_state is not None:
                                                                    return True

                                                                if self.card_operational_state is not None:
                                                                    return True

                                                                if self.card_reset_reason is not None:
                                                                    return True

                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                    return True

                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                    return True

                                                                if self.power_administrative_state is not None:
                                                                    return True

                                                                if self.power_current_measurement is not None:
                                                                    return True

                                                                if self.power_operational_state is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo']['meta_info']


                                                        class InvBasicBag(object):
                                                            """
                                                            Inventory Basic Bag
                                                            
                                                            .. attribute:: alias
                                                            
                                                            	useful for storing an entity alias 
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: asset_id_str
                                                            
                                                            	asset Identification string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: asset_identification
                                                            
                                                            	asset Identification
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: ceport
                                                            
                                                            	1 if ce port found, 0 if not
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: chip_hardware_revision
                                                            
                                                            	chip module hw revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: composite_class_code
                                                            
                                                            	Major&minor class of the entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: description
                                                            
                                                            	describes in user\-readable terms       what the entity in question does
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: environmental_monitor_path
                                                            
                                                            	sysdb name of sensor in the envmon EDM
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: firmware_revision
                                                            
                                                            	firmware revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: group_flag
                                                            
                                                            	indicates if this entity is group       or not
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: hardware_revision
                                                            
                                                            	hw revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: is_field_replaceable_unit
                                                            
                                                            	1 if Field Replaceable Unit 0, if not
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: manufacturer_asset_tags
                                                            
                                                            	Manufacture Asset Tags
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: manufacturer_name
                                                            
                                                            	manufacturer's name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: memory_size
                                                            
                                                            	Size of memory associated with       the entity where applicable
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: model_name
                                                            
                                                            	model name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: name
                                                            
                                                            	name string for the entity
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: new_deviation_number
                                                            
                                                            	integer value for New Deviation Number 0x88
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: physical_layer_interface_module_type
                                                            
                                                            	integer value for plim type if     applicable to this entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: redundancystate
                                                            
                                                            	integer value for Redundancy State if     applicable to this entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: serial_number
                                                            
                                                            	serial number
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: software_revision
                                                            
                                                            	software revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: unique_id
                                                            
                                                            	Unique id for an entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: unrecognized_fru
                                                            
                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: vendor_type
                                                            
                                                            	maps to the vendor OID string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: xr_scoped
                                                            
                                                            	1 if xr scoped, 0 if not
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.alias = None
                                                                self.asset_id_str = None
                                                                self.asset_identification = None
                                                                self.ceport = None
                                                                self.chip_hardware_revision = None
                                                                self.composite_class_code = None
                                                                self.description = None
                                                                self.environmental_monitor_path = None
                                                                self.firmware_revision = None
                                                                self.group_flag = None
                                                                self.hardware_revision = None
                                                                self.is_field_replaceable_unit = None
                                                                self.manufacturer_asset_tags = None
                                                                self.manufacturer_name = None
                                                                self.memory_size = None
                                                                self.model_name = None
                                                                self.name = None
                                                                self.new_deviation_number = None
                                                                self.physical_layer_interface_module_type = None
                                                                self.redundancystate = None
                                                                self.serial_number = None
                                                                self.software_revision = None
                                                                self.unique_id = None
                                                                self.unrecognized_fru = None
                                                                self.vendor_type = None
                                                                self.xr_scoped = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.alias is not None:
                                                                    return True

                                                                if self.asset_id_str is not None:
                                                                    return True

                                                                if self.asset_identification is not None:
                                                                    return True

                                                                if self.ceport is not None:
                                                                    return True

                                                                if self.chip_hardware_revision is not None:
                                                                    return True

                                                                if self.composite_class_code is not None:
                                                                    return True

                                                                if self.description is not None:
                                                                    return True

                                                                if self.environmental_monitor_path is not None:
                                                                    return True

                                                                if self.firmware_revision is not None:
                                                                    return True

                                                                if self.group_flag is not None:
                                                                    return True

                                                                if self.hardware_revision is not None:
                                                                    return True

                                                                if self.is_field_replaceable_unit is not None:
                                                                    return True

                                                                if self.manufacturer_asset_tags is not None:
                                                                    return True

                                                                if self.manufacturer_name is not None:
                                                                    return True

                                                                if self.memory_size is not None:
                                                                    return True

                                                                if self.model_name is not None:
                                                                    return True

                                                                if self.name is not None:
                                                                    return True

                                                                if self.new_deviation_number is not None:
                                                                    return True

                                                                if self.physical_layer_interface_module_type is not None:
                                                                    return True

                                                                if self.redundancystate is not None:
                                                                    return True

                                                                if self.serial_number is not None:
                                                                    return True

                                                                if self.software_revision is not None:
                                                                    return True

                                                                if self.unique_id is not None:
                                                                    return True

                                                                if self.unrecognized_fru is not None:
                                                                    return True

                                                                if self.vendor_type is not None:
                                                                    return True

                                                                if self.xr_scoped is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvBasicBag']['meta_info']


                                                        class InvEepromInfo(object):
                                                            """
                                                            Inventory EDM EEPROM Information Bag
                                                            
                                                            .. attribute:: description
                                                            
                                                            	A textual description of physical entity
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: eeprom
                                                            
                                                            	EEPROM data not from hex data
                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom>`
                                                            
                                                            .. attribute:: has_eeprom
                                                            
                                                            	use eeprom instead of opaque data
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: inv_card_type
                                                            
                                                            	Inventory card type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: opaque_data
                                                            
                                                            	EEPROM hex data
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: opaque_data_size
                                                            
                                                            	size of the EEPROM hex data
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.description = None
                                                                self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom()
                                                                self.eeprom.parent = self
                                                                self.has_eeprom = None
                                                                self.inv_card_type = None
                                                                self.opaque_data = None
                                                                self.opaque_data_size = None


                                                            class Eeprom(object):
                                                                """
                                                                EEPROM data not from hex data
                                                                
                                                                .. attribute:: asset_alias
                                                                
                                                                	Asset Alias
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: asset_id
                                                                
                                                                	Asset ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address1
                                                                
                                                                	Base Mac Address #1
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address2
                                                                
                                                                	Base Mac Address #2
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address3
                                                                
                                                                	Base Mac Address #3
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address4
                                                                
                                                                	Base Mac Address #4
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_checksum
                                                                
                                                                	Block Checksum
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_count
                                                                
                                                                	Block Count
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_length
                                                                
                                                                	Block Length
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_signature
                                                                
                                                                	Block Signature
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_version
                                                                
                                                                	Block Version
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: chassis_sid
                                                                
                                                                	Chassis serial number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: clei
                                                                
                                                                	Common Language Equipment Identifier (CLEI) code
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: controller_family
                                                                
                                                                	Controller family
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: controller_type
                                                                
                                                                	Controller type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: description
                                                                
                                                                	A textual description of physical entity
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num1
                                                                
                                                                	Deviation Number # 1
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num2
                                                                
                                                                	Deviation Number # 2
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num3
                                                                
                                                                	Deviation Number # 3
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num4
                                                                
                                                                	Deviation Number # 4
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num5
                                                                
                                                                	Deviation Number # 5
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num6
                                                                
                                                                	Deviation Number # 6
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num7
                                                                
                                                                	Deviation Number # 7
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: eci
                                                                
                                                                	Equipment Catalog Item (ECI) number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: eeprom_size
                                                                
                                                                	EEPROM Size
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: engineer_use
                                                                
                                                                	Engineer Use
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: fru_major_type
                                                                
                                                                	FRU Major Type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: fru_minor_type
                                                                
                                                                	FRU Minor Type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: hw_version
                                                                
                                                                	Hardware Version
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: hwid
                                                                
                                                                	Hardware Revision
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: idprom_format_rev
                                                                
                                                                	IDPROM Format Revision
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size1
                                                                
                                                                	Mac Address Block Size #1
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size2
                                                                
                                                                	Mac Address Block Size #2
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size3
                                                                
                                                                	Mac Address Block Size #3
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size4
                                                                
                                                                	Mac Address Block Size #4
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: manu_test_data
                                                                
                                                                	Manufacturing Test Data
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mfg_bits
                                                                
                                                                	MFG Bits
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mfg_deviation
                                                                
                                                                	MFG Deviation
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: oem_string
                                                                
                                                                	OEM String
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: part_number
                                                                
                                                                	Part Number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: part_revision
                                                                
                                                                	Part Revision
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pca_num
                                                                
                                                                	PCA number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pcavid
                                                                
                                                                	PCA revision ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pcb_serial_num
                                                                
                                                                	PCB Serial Number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pid
                                                                
                                                                	Product ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: power_consumption
                                                                
                                                                	Power Consumption
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: power_supply_type
                                                                
                                                                	Power Supply Type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: product_id
                                                                
                                                                	Product ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: rma
                                                                
                                                                	RMA Data
                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                
                                                                .. attribute:: rma_code
                                                                
                                                                	RMA Code
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: serial_number
                                                                
                                                                	Serial Number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: snmpoid
                                                                
                                                                	SNMP OID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: top_assem_part_num
                                                                
                                                                	Top assembly part number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: top_assem_vid
                                                                
                                                                	Top assembly revision number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: udi_description
                                                                
                                                                	UDI description
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: udi_name
                                                                
                                                                	UDI name
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: vid
                                                                
                                                                	Version ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.asset_alias = None
                                                                    self.asset_id = None
                                                                    self.base_mac_address1 = None
                                                                    self.base_mac_address2 = None
                                                                    self.base_mac_address3 = None
                                                                    self.base_mac_address4 = None
                                                                    self.block_checksum = None
                                                                    self.block_count = None
                                                                    self.block_length = None
                                                                    self.block_signature = None
                                                                    self.block_version = None
                                                                    self.chassis_sid = None
                                                                    self.clei = None
                                                                    self.controller_family = None
                                                                    self.controller_type = None
                                                                    self.description = None
                                                                    self.dev_num1 = None
                                                                    self.dev_num2 = None
                                                                    self.dev_num3 = None
                                                                    self.dev_num4 = None
                                                                    self.dev_num5 = None
                                                                    self.dev_num6 = None
                                                                    self.dev_num7 = None
                                                                    self.eci = None
                                                                    self.eeprom_size = None
                                                                    self.engineer_use = None
                                                                    self.fru_major_type = None
                                                                    self.fru_minor_type = None
                                                                    self.hw_version = None
                                                                    self.hwid = None
                                                                    self.idprom_format_rev = None
                                                                    self.mac_add_blk_size1 = None
                                                                    self.mac_add_blk_size2 = None
                                                                    self.mac_add_blk_size3 = None
                                                                    self.mac_add_blk_size4 = None
                                                                    self.manu_test_data = None
                                                                    self.mfg_bits = None
                                                                    self.mfg_deviation = None
                                                                    self.oem_string = None
                                                                    self.part_number = None
                                                                    self.part_revision = None
                                                                    self.pca_num = None
                                                                    self.pcavid = None
                                                                    self.pcb_serial_num = None
                                                                    self.pid = None
                                                                    self.power_consumption = None
                                                                    self.power_supply_type = None
                                                                    self.product_id = None
                                                                    self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                    self.rma.parent = self
                                                                    self.rma_code = None
                                                                    self.serial_number = None
                                                                    self.snmpoid = None
                                                                    self.top_assem_part_num = None
                                                                    self.top_assem_vid = None
                                                                    self.udi_description = None
                                                                    self.udi_name = None
                                                                    self.vid = None


                                                                class Rma(object):
                                                                    """
                                                                    RMA Data
                                                                    
                                                                    .. attribute:: rma_history
                                                                    
                                                                    	RMA history
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: rma_number
                                                                    
                                                                    	RMA tracking number format is N\-N\-N
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: test_history
                                                                    
                                                                    	Test history
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.rma_history = None
                                                                        self.rma_number = None
                                                                        self.test_history = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.rma_history is not None:
                                                                            return True

                                                                        if self.rma_number is not None:
                                                                            return True

                                                                        if self.test_history is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.asset_alias is not None:
                                                                        return True

                                                                    if self.asset_id is not None:
                                                                        return True

                                                                    if self.base_mac_address1 is not None:
                                                                        return True

                                                                    if self.base_mac_address2 is not None:
                                                                        return True

                                                                    if self.base_mac_address3 is not None:
                                                                        return True

                                                                    if self.base_mac_address4 is not None:
                                                                        return True

                                                                    if self.block_checksum is not None:
                                                                        return True

                                                                    if self.block_count is not None:
                                                                        return True

                                                                    if self.block_length is not None:
                                                                        return True

                                                                    if self.block_signature is not None:
                                                                        return True

                                                                    if self.block_version is not None:
                                                                        return True

                                                                    if self.chassis_sid is not None:
                                                                        return True

                                                                    if self.clei is not None:
                                                                        return True

                                                                    if self.controller_family is not None:
                                                                        return True

                                                                    if self.controller_type is not None:
                                                                        return True

                                                                    if self.description is not None:
                                                                        return True

                                                                    if self.dev_num1 is not None:
                                                                        return True

                                                                    if self.dev_num2 is not None:
                                                                        return True

                                                                    if self.dev_num3 is not None:
                                                                        return True

                                                                    if self.dev_num4 is not None:
                                                                        return True

                                                                    if self.dev_num5 is not None:
                                                                        return True

                                                                    if self.dev_num6 is not None:
                                                                        return True

                                                                    if self.dev_num7 is not None:
                                                                        return True

                                                                    if self.eci is not None:
                                                                        return True

                                                                    if self.eeprom_size is not None:
                                                                        return True

                                                                    if self.engineer_use is not None:
                                                                        return True

                                                                    if self.fru_major_type is not None:
                                                                        return True

                                                                    if self.fru_minor_type is not None:
                                                                        return True

                                                                    if self.hw_version is not None:
                                                                        return True

                                                                    if self.hwid is not None:
                                                                        return True

                                                                    if self.idprom_format_rev is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size1 is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size2 is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size3 is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size4 is not None:
                                                                        return True

                                                                    if self.manu_test_data is not None:
                                                                        return True

                                                                    if self.mfg_bits is not None:
                                                                        return True

                                                                    if self.mfg_deviation is not None:
                                                                        return True

                                                                    if self.oem_string is not None:
                                                                        return True

                                                                    if self.part_number is not None:
                                                                        return True

                                                                    if self.part_revision is not None:
                                                                        return True

                                                                    if self.pca_num is not None:
                                                                        return True

                                                                    if self.pcavid is not None:
                                                                        return True

                                                                    if self.pcb_serial_num is not None:
                                                                        return True

                                                                    if self.pid is not None:
                                                                        return True

                                                                    if self.power_consumption is not None:
                                                                        return True

                                                                    if self.power_supply_type is not None:
                                                                        return True

                                                                    if self.product_id is not None:
                                                                        return True

                                                                    if self.rma is not None and self.rma._has_data():
                                                                        return True

                                                                    if self.rma_code is not None:
                                                                        return True

                                                                    if self.serial_number is not None:
                                                                        return True

                                                                    if self.snmpoid is not None:
                                                                        return True

                                                                    if self.top_assem_part_num is not None:
                                                                        return True

                                                                    if self.top_assem_vid is not None:
                                                                        return True

                                                                    if self.udi_description is not None:
                                                                        return True

                                                                    if self.udi_name is not None:
                                                                        return True

                                                                    if self.vid is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.description is not None:
                                                                    return True

                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                    return True

                                                                if self.has_eeprom is not None:
                                                                    return True

                                                                if self.inv_card_type is not None:
                                                                    return True

                                                                if self.opaque_data is not None:
                                                                    return True

                                                                if self.opaque_data_size is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                return True

                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                return True

                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                return True

                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                return True

                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                return True

                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                return True

                                                            if self.module_done is not None:
                                                                return True

                                                            if self.node_id is not None:
                                                                return True

                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                return True

                                                            if self.threshold is not None and self.threshold._has_data():
                                                                return True

                                                            if self.vm_done is not None:
                                                                return True

                                                            if self.vm_node_id is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.name is None:
                                                            raise YPYModelError('Key property name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi4[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.name is not None:
                                                            return True

                                                        if self.attributes is not None and self.attributes._has_data():
                                                            return True

                                                        if self.tsi5s is not None and self.tsi5s._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi4s'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.tsi4 is not None:
                                                        for child_ref in self.tsi4:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S']['meta_info']


                                            class Attributes(object):
                                                """
                                                Attributes
                                                
                                                .. attribute:: env_sensor_info
                                                
                                                	Environment sensor info
                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfo>`
                                                
                                                .. attribute:: env_sensor_info_xml
                                                
                                                	Environment sensor info XML
                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml>`
                                                
                                                .. attribute:: fru_info
                                                
                                                	Inventory EDM FRU info
                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo>`
                                                
                                                .. attribute:: inv_asset_bag
                                                
                                                	Inventory Asset Bag
                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvAssetBag>`
                                                
                                                .. attribute:: inv_basic_bag
                                                
                                                	Inventory Basic Bag
                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvBasicBag>`
                                                
                                                .. attribute:: inv_eeprom_info
                                                
                                                	Inventory EDM EEPROM Information Bag
                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo>`
                                                
                                                .. attribute:: module_done
                                                
                                                	Inventory EDM Module Done Tuple
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: node_id
                                                
                                                	Node ID Tuple
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pwg_info
                                                
                                                	Inventory EDM PWG info
                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.PwgInfo>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold
                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold>`
                                                
                                                .. attribute:: vm_done
                                                
                                                	VM Done Tuple
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: vm_node_id
                                                
                                                	VM Node ID Tuple
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfo()
                                                    self.env_sensor_info.parent = self
                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml()
                                                    self.env_sensor_info_xml.parent = self
                                                    self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo()
                                                    self.fru_info.parent = self
                                                    self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvAssetBag()
                                                    self.inv_asset_bag.parent = self
                                                    self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvBasicBag()
                                                    self.inv_basic_bag.parent = self
                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo()
                                                    self.inv_eeprom_info.parent = self
                                                    self.module_done = None
                                                    self.node_id = None
                                                    self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.PwgInfo()
                                                    self.pwg_info.parent = self
                                                    self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold()
                                                    self.threshold.parent = self
                                                    self.vm_done = None
                                                    self.vm_node_id = None


                                                class EnvSensorInfo(object):
                                                    """
                                                    Environment sensor info
                                                    
                                                    .. attribute:: age_time_stamp
                                                    
                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: alarm_type
                                                    
                                                    	Indicates threshold violation
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: data_type
                                                    
                                                    	Sensor data type enums
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: device_description
                                                    
                                                    	Device Name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: device_id
                                                    
                                                    	Identifier for this device
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: field_validity_bitmap
                                                    
                                                    	Sensor valid bitmap
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: precision
                                                    
                                                    	Sensor precision range
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: scale
                                                    
                                                    	Sensor scale enums
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: status
                                                    
                                                    	Sensor operation state enums
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: units
                                                    
                                                    	Units of variable being read
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: update_rate
                                                    
                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Current reading of sensor
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.age_time_stamp = None
                                                        self.alarm_type = None
                                                        self.data_type = None
                                                        self.device_description = None
                                                        self.device_id = None
                                                        self.field_validity_bitmap = None
                                                        self.precision = None
                                                        self.scale = None
                                                        self.status = None
                                                        self.units = None
                                                        self.update_rate = None
                                                        self.value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.age_time_stamp is not None:
                                                            return True

                                                        if self.alarm_type is not None:
                                                            return True

                                                        if self.data_type is not None:
                                                            return True

                                                        if self.device_description is not None:
                                                            return True

                                                        if self.device_id is not None:
                                                            return True

                                                        if self.field_validity_bitmap is not None:
                                                            return True

                                                        if self.precision is not None:
                                                            return True

                                                        if self.scale is not None:
                                                            return True

                                                        if self.status is not None:
                                                            return True

                                                        if self.units is not None:
                                                            return True

                                                        if self.update_rate is not None:
                                                            return True

                                                        if self.value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfo']['meta_info']


                                                class PwgInfo(object):
                                                    """
                                                    Inventory EDM PWG info
                                                    
                                                    .. attribute:: power_group_available_current
                                                    
                                                    	available current
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_group_drawn_current
                                                    
                                                    	drawn current
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_group_power_units
                                                    
                                                    	power units
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: power_group_redundancy_mode
                                                    
                                                    	redundancy mode
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.power_group_available_current = None
                                                        self.power_group_drawn_current = None
                                                        self.power_group_power_units = None
                                                        self.power_group_redundancy_mode = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.power_group_available_current is not None:
                                                            return True

                                                        if self.power_group_drawn_current is not None:
                                                            return True

                                                        if self.power_group_power_units is not None:
                                                            return True

                                                        if self.power_group_redundancy_mode is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.PwgInfo']['meta_info']


                                                class EnvSensorInfoXml(object):
                                                    """
                                                    Environment sensor info XML
                                                    
                                                    .. attribute:: data_type
                                                    
                                                    	Sensor data type
                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Device Name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: status
                                                    
                                                    	Sensor operation state
                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold information
                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold>`
                                                    
                                                    .. attribute:: units
                                                    
                                                    	Units of variable being read
                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                    
                                                    .. attribute:: update_rate
                                                    
                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data_type = None
                                                        self.description = None
                                                        self.status = None
                                                        self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold()
                                                        self.threshold.parent = self
                                                        self.units = None
                                                        self.update_rate = None
                                                        self.value = None


                                                    class Threshold(object):
                                                        """
                                                        Threshold information
                                                        
                                                        .. attribute:: threshold_array
                                                        
                                                        	Array of threshold
                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.threshold_array = YList()
                                                            self.threshold_array.parent = self
                                                            self.threshold_array.name = 'threshold_array'


                                                        class ThresholdArray(object):
                                                            """
                                                            Array of threshold
                                                            
                                                            .. attribute:: threshold_name
                                                            
                                                            	Threshold name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_name = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_name is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.threshold_array is not None:
                                                                for child_ref in self.threshold_array:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data_type is not None:
                                                            return True

                                                        if self.description is not None:
                                                            return True

                                                        if self.status is not None:
                                                            return True

                                                        if self.threshold is not None and self.threshold._has_data():
                                                            return True

                                                        if self.units is not None:
                                                            return True

                                                        if self.update_rate is not None:
                                                            return True

                                                        if self.value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml']['meta_info']


                                                class InvAssetBag(object):
                                                    """
                                                    Inventory Asset Bag
                                                    
                                                    .. attribute:: manufacturer_assembly_number
                                                    
                                                    	Manufacture Assembly number
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_assembly_revision
                                                    
                                                    	Manufacture assembly revision
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                    
                                                    	Common Language Equipment           Identifier number
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_firmware_identifier
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_software_identifier
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: original_equipment_manufacturer_string
                                                    
                                                    	String containing OEM information           if applicable
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: part_number
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.manufacturer_assembly_number = None
                                                        self.manufacturer_assembly_revision = None
                                                        self.manufacturer_common_language_equipment_identifier = None
                                                        self.manufacturer_firmware_identifier = None
                                                        self.manufacturer_software_identifier = None
                                                        self.original_equipment_manufacturer_string = None
                                                        self.part_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.manufacturer_assembly_number is not None:
                                                            return True

                                                        if self.manufacturer_assembly_revision is not None:
                                                            return True

                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                            return True

                                                        if self.manufacturer_firmware_identifier is not None:
                                                            return True

                                                        if self.manufacturer_software_identifier is not None:
                                                            return True

                                                        if self.original_equipment_manufacturer_string is not None:
                                                            return True

                                                        if self.part_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvAssetBag']['meta_info']


                                                class Threshold(object):
                                                    """
                                                    Threshold
                                                    
                                                    .. attribute:: critical_hi
                                                    
                                                    	Critical High
                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi>`
                                                    
                                                    .. attribute:: critical_lo
                                                    
                                                    	Critical Low
                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo>`
                                                    
                                                    .. attribute:: major_hi
                                                    
                                                    	Major High
                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi>`
                                                    
                                                    .. attribute:: major_lo
                                                    
                                                    	Major Low
                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo>`
                                                    
                                                    .. attribute:: minor_hi
                                                    
                                                    	Minor High
                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi>`
                                                    
                                                    .. attribute:: minor_lo
                                                    
                                                    	Minor Low
                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi()
                                                        self.critical_hi.parent = self
                                                        self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo()
                                                        self.critical_lo.parent = self
                                                        self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi()
                                                        self.major_hi.parent = self
                                                        self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo()
                                                        self.major_lo.parent = self
                                                        self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi()
                                                        self.minor_hi.parent = self
                                                        self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo()
                                                        self.minor_lo.parent = self


                                                    class MajorLo(object):
                                                        """
                                                        Major Low
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo']['meta_info']


                                                    class CriticalHi(object):
                                                        """
                                                        Critical High
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi']['meta_info']


                                                    class MinorHi(object):
                                                        """
                                                        Minor High
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi']['meta_info']


                                                    class MajorHi(object):
                                                        """
                                                        Major High
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi']['meta_info']


                                                    class CriticalLo(object):
                                                        """
                                                        Critical Low
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo']['meta_info']


                                                    class MinorLo(object):
                                                        """
                                                        Minor Low
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                            return True

                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                            return True

                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                            return True

                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                            return True

                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                            return True

                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold']['meta_info']


                                                class FruInfo(object):
                                                    """
                                                    Inventory EDM FRU info
                                                    
                                                    .. attribute:: card_administrative_state
                                                    
                                                    	card admin state\: shutdown or not
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: card_monitor_state
                                                    
                                                    	card is monitored by a manager or left unmonitored
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: card_operational_state
                                                    
                                                    	card operation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: card_reset_reason
                                                    
                                                    	card reset reason enum
                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                    
                                                    .. attribute:: card_up_time
                                                    
                                                    	card up time
                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.CardUpTime>`
                                                    
                                                    .. attribute:: last_operational_state_change
                                                    
                                                    	last card oper change state
                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.LastOperationalStateChange>`
                                                    
                                                    .. attribute:: power_administrative_state
                                                    
                                                    	power admin state\: up or down
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_current_measurement
                                                    
                                                    	power current\: not implemented
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_operational_state
                                                    
                                                    	Power operation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.card_administrative_state = None
                                                        self.card_monitor_state = None
                                                        self.card_operational_state = None
                                                        self.card_reset_reason = None
                                                        self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.CardUpTime()
                                                        self.card_up_time.parent = self
                                                        self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.LastOperationalStateChange()
                                                        self.last_operational_state_change.parent = self
                                                        self.power_administrative_state = None
                                                        self.power_current_measurement = None
                                                        self.power_operational_state = None


                                                    class LastOperationalStateChange(object):
                                                        """
                                                        last card oper change state
                                                        
                                                        .. attribute:: time_in_nano_seconds
                                                        
                                                        	Time Value in Nano\-seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: time_in_seconds
                                                        
                                                        	Time Value in Seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.time_in_nano_seconds = None
                                                            self.time_in_seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.time_in_nano_seconds is not None:
                                                                return True

                                                            if self.time_in_seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                    class CardUpTime(object):
                                                        """
                                                        card up time
                                                        
                                                        .. attribute:: time_in_nano_seconds
                                                        
                                                        	Time Value in Nano\-seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: time_in_seconds
                                                        
                                                        	Time Value in Seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.time_in_nano_seconds = None
                                                            self.time_in_seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.time_in_nano_seconds is not None:
                                                                return True

                                                            if self.time_in_seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.CardUpTime']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.card_administrative_state is not None:
                                                            return True

                                                        if self.card_monitor_state is not None:
                                                            return True

                                                        if self.card_operational_state is not None:
                                                            return True

                                                        if self.card_reset_reason is not None:
                                                            return True

                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                            return True

                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                            return True

                                                        if self.power_administrative_state is not None:
                                                            return True

                                                        if self.power_current_measurement is not None:
                                                            return True

                                                        if self.power_operational_state is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo']['meta_info']


                                                class InvBasicBag(object):
                                                    """
                                                    Inventory Basic Bag
                                                    
                                                    .. attribute:: alias
                                                    
                                                    	useful for storing an entity alias 
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: asset_id_str
                                                    
                                                    	asset Identification string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: asset_identification
                                                    
                                                    	asset Identification
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: ceport
                                                    
                                                    	1 if ce port found, 0 if not
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: chip_hardware_revision
                                                    
                                                    	chip module hw revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: composite_class_code
                                                    
                                                    	Major&minor class of the entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: description
                                                    
                                                    	describes in user\-readable terms       what the entity in question does
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: environmental_monitor_path
                                                    
                                                    	sysdb name of sensor in the envmon EDM
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: firmware_revision
                                                    
                                                    	firmware revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: group_flag
                                                    
                                                    	indicates if this entity is group       or not
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: hardware_revision
                                                    
                                                    	hw revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: is_field_replaceable_unit
                                                    
                                                    	1 if Field Replaceable Unit 0, if not
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: manufacturer_asset_tags
                                                    
                                                    	Manufacture Asset Tags
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: manufacturer_name
                                                    
                                                    	manufacturer's name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: memory_size
                                                    
                                                    	Size of memory associated with       the entity where applicable
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: model_name
                                                    
                                                    	model name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: name
                                                    
                                                    	name string for the entity
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: new_deviation_number
                                                    
                                                    	integer value for New Deviation Number 0x88
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: physical_layer_interface_module_type
                                                    
                                                    	integer value for plim type if     applicable to this entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: redundancystate
                                                    
                                                    	integer value for Redundancy State if     applicable to this entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: serial_number
                                                    
                                                    	serial number
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: software_revision
                                                    
                                                    	software revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: unique_id
                                                    
                                                    	Unique id for an entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: unrecognized_fru
                                                    
                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vendor_type
                                                    
                                                    	maps to the vendor OID string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: xr_scoped
                                                    
                                                    	1 if xr scoped, 0 if not
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.alias = None
                                                        self.asset_id_str = None
                                                        self.asset_identification = None
                                                        self.ceport = None
                                                        self.chip_hardware_revision = None
                                                        self.composite_class_code = None
                                                        self.description = None
                                                        self.environmental_monitor_path = None
                                                        self.firmware_revision = None
                                                        self.group_flag = None
                                                        self.hardware_revision = None
                                                        self.is_field_replaceable_unit = None
                                                        self.manufacturer_asset_tags = None
                                                        self.manufacturer_name = None
                                                        self.memory_size = None
                                                        self.model_name = None
                                                        self.name = None
                                                        self.new_deviation_number = None
                                                        self.physical_layer_interface_module_type = None
                                                        self.redundancystate = None
                                                        self.serial_number = None
                                                        self.software_revision = None
                                                        self.unique_id = None
                                                        self.unrecognized_fru = None
                                                        self.vendor_type = None
                                                        self.xr_scoped = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.alias is not None:
                                                            return True

                                                        if self.asset_id_str is not None:
                                                            return True

                                                        if self.asset_identification is not None:
                                                            return True

                                                        if self.ceport is not None:
                                                            return True

                                                        if self.chip_hardware_revision is not None:
                                                            return True

                                                        if self.composite_class_code is not None:
                                                            return True

                                                        if self.description is not None:
                                                            return True

                                                        if self.environmental_monitor_path is not None:
                                                            return True

                                                        if self.firmware_revision is not None:
                                                            return True

                                                        if self.group_flag is not None:
                                                            return True

                                                        if self.hardware_revision is not None:
                                                            return True

                                                        if self.is_field_replaceable_unit is not None:
                                                            return True

                                                        if self.manufacturer_asset_tags is not None:
                                                            return True

                                                        if self.manufacturer_name is not None:
                                                            return True

                                                        if self.memory_size is not None:
                                                            return True

                                                        if self.model_name is not None:
                                                            return True

                                                        if self.name is not None:
                                                            return True

                                                        if self.new_deviation_number is not None:
                                                            return True

                                                        if self.physical_layer_interface_module_type is not None:
                                                            return True

                                                        if self.redundancystate is not None:
                                                            return True

                                                        if self.serial_number is not None:
                                                            return True

                                                        if self.software_revision is not None:
                                                            return True

                                                        if self.unique_id is not None:
                                                            return True

                                                        if self.unrecognized_fru is not None:
                                                            return True

                                                        if self.vendor_type is not None:
                                                            return True

                                                        if self.xr_scoped is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvBasicBag']['meta_info']


                                                class InvEepromInfo(object):
                                                    """
                                                    Inventory EDM EEPROM Information Bag
                                                    
                                                    .. attribute:: description
                                                    
                                                    	A textual description of physical entity
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: eeprom
                                                    
                                                    	EEPROM data not from hex data
                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom>`
                                                    
                                                    .. attribute:: has_eeprom
                                                    
                                                    	use eeprom instead of opaque data
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: inv_card_type
                                                    
                                                    	Inventory card type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: opaque_data
                                                    
                                                    	EEPROM hex data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: opaque_data_size
                                                    
                                                    	size of the EEPROM hex data
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.description = None
                                                        self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom()
                                                        self.eeprom.parent = self
                                                        self.has_eeprom = None
                                                        self.inv_card_type = None
                                                        self.opaque_data = None
                                                        self.opaque_data_size = None


                                                    class Eeprom(object):
                                                        """
                                                        EEPROM data not from hex data
                                                        
                                                        .. attribute:: asset_alias
                                                        
                                                        	Asset Alias
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: asset_id
                                                        
                                                        	Asset ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address1
                                                        
                                                        	Base Mac Address #1
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address2
                                                        
                                                        	Base Mac Address #2
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address3
                                                        
                                                        	Base Mac Address #3
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address4
                                                        
                                                        	Base Mac Address #4
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_checksum
                                                        
                                                        	Block Checksum
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_count
                                                        
                                                        	Block Count
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_length
                                                        
                                                        	Block Length
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_signature
                                                        
                                                        	Block Signature
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_version
                                                        
                                                        	Block Version
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: chassis_sid
                                                        
                                                        	Chassis serial number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: clei
                                                        
                                                        	Common Language Equipment Identifier (CLEI) code
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: controller_family
                                                        
                                                        	Controller family
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: controller_type
                                                        
                                                        	Controller type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: description
                                                        
                                                        	A textual description of physical entity
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num1
                                                        
                                                        	Deviation Number # 1
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num2
                                                        
                                                        	Deviation Number # 2
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num3
                                                        
                                                        	Deviation Number # 3
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num4
                                                        
                                                        	Deviation Number # 4
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num5
                                                        
                                                        	Deviation Number # 5
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num6
                                                        
                                                        	Deviation Number # 6
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num7
                                                        
                                                        	Deviation Number # 7
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: eci
                                                        
                                                        	Equipment Catalog Item (ECI) number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: eeprom_size
                                                        
                                                        	EEPROM Size
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: engineer_use
                                                        
                                                        	Engineer Use
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: fru_major_type
                                                        
                                                        	FRU Major Type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: fru_minor_type
                                                        
                                                        	FRU Minor Type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: hw_version
                                                        
                                                        	Hardware Version
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: hwid
                                                        
                                                        	Hardware Revision
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: idprom_format_rev
                                                        
                                                        	IDPROM Format Revision
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size1
                                                        
                                                        	Mac Address Block Size #1
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size2
                                                        
                                                        	Mac Address Block Size #2
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size3
                                                        
                                                        	Mac Address Block Size #3
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size4
                                                        
                                                        	Mac Address Block Size #4
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: manu_test_data
                                                        
                                                        	Manufacturing Test Data
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mfg_bits
                                                        
                                                        	MFG Bits
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mfg_deviation
                                                        
                                                        	MFG Deviation
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: oem_string
                                                        
                                                        	OEM String
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: part_number
                                                        
                                                        	Part Number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: part_revision
                                                        
                                                        	Part Revision
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pca_num
                                                        
                                                        	PCA number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pcavid
                                                        
                                                        	PCA revision ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pcb_serial_num
                                                        
                                                        	PCB Serial Number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pid
                                                        
                                                        	Product ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: power_consumption
                                                        
                                                        	Power Consumption
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: power_supply_type
                                                        
                                                        	Power Supply Type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: product_id
                                                        
                                                        	Product ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: rma
                                                        
                                                        	RMA Data
                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                        
                                                        .. attribute:: rma_code
                                                        
                                                        	RMA Code
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: serial_number
                                                        
                                                        	Serial Number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: snmpoid
                                                        
                                                        	SNMP OID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: top_assem_part_num
                                                        
                                                        	Top assembly part number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: top_assem_vid
                                                        
                                                        	Top assembly revision number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: udi_description
                                                        
                                                        	UDI description
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: udi_name
                                                        
                                                        	UDI name
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: vid
                                                        
                                                        	Version ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.asset_alias = None
                                                            self.asset_id = None
                                                            self.base_mac_address1 = None
                                                            self.base_mac_address2 = None
                                                            self.base_mac_address3 = None
                                                            self.base_mac_address4 = None
                                                            self.block_checksum = None
                                                            self.block_count = None
                                                            self.block_length = None
                                                            self.block_signature = None
                                                            self.block_version = None
                                                            self.chassis_sid = None
                                                            self.clei = None
                                                            self.controller_family = None
                                                            self.controller_type = None
                                                            self.description = None
                                                            self.dev_num1 = None
                                                            self.dev_num2 = None
                                                            self.dev_num3 = None
                                                            self.dev_num4 = None
                                                            self.dev_num5 = None
                                                            self.dev_num6 = None
                                                            self.dev_num7 = None
                                                            self.eci = None
                                                            self.eeprom_size = None
                                                            self.engineer_use = None
                                                            self.fru_major_type = None
                                                            self.fru_minor_type = None
                                                            self.hw_version = None
                                                            self.hwid = None
                                                            self.idprom_format_rev = None
                                                            self.mac_add_blk_size1 = None
                                                            self.mac_add_blk_size2 = None
                                                            self.mac_add_blk_size3 = None
                                                            self.mac_add_blk_size4 = None
                                                            self.manu_test_data = None
                                                            self.mfg_bits = None
                                                            self.mfg_deviation = None
                                                            self.oem_string = None
                                                            self.part_number = None
                                                            self.part_revision = None
                                                            self.pca_num = None
                                                            self.pcavid = None
                                                            self.pcb_serial_num = None
                                                            self.pid = None
                                                            self.power_consumption = None
                                                            self.power_supply_type = None
                                                            self.product_id = None
                                                            self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom.Rma()
                                                            self.rma.parent = self
                                                            self.rma_code = None
                                                            self.serial_number = None
                                                            self.snmpoid = None
                                                            self.top_assem_part_num = None
                                                            self.top_assem_vid = None
                                                            self.udi_description = None
                                                            self.udi_name = None
                                                            self.vid = None


                                                        class Rma(object):
                                                            """
                                                            RMA Data
                                                            
                                                            .. attribute:: rma_history
                                                            
                                                            	RMA history
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: rma_number
                                                            
                                                            	RMA tracking number format is N\-N\-N
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: test_history
                                                            
                                                            	Test history
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.rma_history = None
                                                                self.rma_number = None
                                                                self.test_history = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.rma_history is not None:
                                                                    return True

                                                                if self.rma_number is not None:
                                                                    return True

                                                                if self.test_history is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.asset_alias is not None:
                                                                return True

                                                            if self.asset_id is not None:
                                                                return True

                                                            if self.base_mac_address1 is not None:
                                                                return True

                                                            if self.base_mac_address2 is not None:
                                                                return True

                                                            if self.base_mac_address3 is not None:
                                                                return True

                                                            if self.base_mac_address4 is not None:
                                                                return True

                                                            if self.block_checksum is not None:
                                                                return True

                                                            if self.block_count is not None:
                                                                return True

                                                            if self.block_length is not None:
                                                                return True

                                                            if self.block_signature is not None:
                                                                return True

                                                            if self.block_version is not None:
                                                                return True

                                                            if self.chassis_sid is not None:
                                                                return True

                                                            if self.clei is not None:
                                                                return True

                                                            if self.controller_family is not None:
                                                                return True

                                                            if self.controller_type is not None:
                                                                return True

                                                            if self.description is not None:
                                                                return True

                                                            if self.dev_num1 is not None:
                                                                return True

                                                            if self.dev_num2 is not None:
                                                                return True

                                                            if self.dev_num3 is not None:
                                                                return True

                                                            if self.dev_num4 is not None:
                                                                return True

                                                            if self.dev_num5 is not None:
                                                                return True

                                                            if self.dev_num6 is not None:
                                                                return True

                                                            if self.dev_num7 is not None:
                                                                return True

                                                            if self.eci is not None:
                                                                return True

                                                            if self.eeprom_size is not None:
                                                                return True

                                                            if self.engineer_use is not None:
                                                                return True

                                                            if self.fru_major_type is not None:
                                                                return True

                                                            if self.fru_minor_type is not None:
                                                                return True

                                                            if self.hw_version is not None:
                                                                return True

                                                            if self.hwid is not None:
                                                                return True

                                                            if self.idprom_format_rev is not None:
                                                                return True

                                                            if self.mac_add_blk_size1 is not None:
                                                                return True

                                                            if self.mac_add_blk_size2 is not None:
                                                                return True

                                                            if self.mac_add_blk_size3 is not None:
                                                                return True

                                                            if self.mac_add_blk_size4 is not None:
                                                                return True

                                                            if self.manu_test_data is not None:
                                                                return True

                                                            if self.mfg_bits is not None:
                                                                return True

                                                            if self.mfg_deviation is not None:
                                                                return True

                                                            if self.oem_string is not None:
                                                                return True

                                                            if self.part_number is not None:
                                                                return True

                                                            if self.part_revision is not None:
                                                                return True

                                                            if self.pca_num is not None:
                                                                return True

                                                            if self.pcavid is not None:
                                                                return True

                                                            if self.pcb_serial_num is not None:
                                                                return True

                                                            if self.pid is not None:
                                                                return True

                                                            if self.power_consumption is not None:
                                                                return True

                                                            if self.power_supply_type is not None:
                                                                return True

                                                            if self.product_id is not None:
                                                                return True

                                                            if self.rma is not None and self.rma._has_data():
                                                                return True

                                                            if self.rma_code is not None:
                                                                return True

                                                            if self.serial_number is not None:
                                                                return True

                                                            if self.snmpoid is not None:
                                                                return True

                                                            if self.top_assem_part_num is not None:
                                                                return True

                                                            if self.top_assem_vid is not None:
                                                                return True

                                                            if self.udi_description is not None:
                                                                return True

                                                            if self.udi_name is not None:
                                                                return True

                                                            if self.vid is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.description is not None:
                                                            return True

                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                            return True

                                                        if self.has_eeprom is not None:
                                                            return True

                                                        if self.inv_card_type is not None:
                                                            return True

                                                        if self.opaque_data is not None:
                                                            return True

                                                        if self.opaque_data_size is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                        return True

                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                        return True

                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                        return True

                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                        return True

                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                        return True

                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                        return True

                                                    if self.module_done is not None:
                                                        return True

                                                    if self.node_id is not None:
                                                        return True

                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                        return True

                                                    if self.threshold is not None and self.threshold._has_data():
                                                        return True

                                                    if self.vm_done is not None:
                                                        return True

                                                    if self.vm_node_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.name is None:
                                                    raise YPYModelError('Key property name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi3[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.name is not None:
                                                    return True

                                                if self.attributes is not None and self.attributes._has_data():
                                                    return True

                                                if self.tsi4s is not None and self.tsi4s._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi3s'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tsi3 is not None:
                                                for child_ref in self.tsi3:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S']['meta_info']


                                    class Attributes(object):
                                        """
                                        Attributes
                                        
                                        .. attribute:: env_sensor_info
                                        
                                        	Environment sensor info
                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfo>`
                                        
                                        .. attribute:: env_sensor_info_xml
                                        
                                        	Environment sensor info XML
                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml>`
                                        
                                        .. attribute:: fru_info
                                        
                                        	Inventory EDM FRU info
                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo>`
                                        
                                        .. attribute:: inv_asset_bag
                                        
                                        	Inventory Asset Bag
                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvAssetBag>`
                                        
                                        .. attribute:: inv_basic_bag
                                        
                                        	Inventory Basic Bag
                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvBasicBag>`
                                        
                                        .. attribute:: inv_eeprom_info
                                        
                                        	Inventory EDM EEPROM Information Bag
                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo>`
                                        
                                        .. attribute:: module_done
                                        
                                        	Inventory EDM Module Done Tuple
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: node_id
                                        
                                        	Node ID Tuple
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pwg_info
                                        
                                        	Inventory EDM PWG info
                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.PwgInfo>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold
                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold>`
                                        
                                        .. attribute:: vm_done
                                        
                                        	VM Done Tuple
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: vm_node_id
                                        
                                        	VM Node ID Tuple
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfo()
                                            self.env_sensor_info.parent = self
                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml()
                                            self.env_sensor_info_xml.parent = self
                                            self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo()
                                            self.fru_info.parent = self
                                            self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvAssetBag()
                                            self.inv_asset_bag.parent = self
                                            self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvBasicBag()
                                            self.inv_basic_bag.parent = self
                                            self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo()
                                            self.inv_eeprom_info.parent = self
                                            self.module_done = None
                                            self.node_id = None
                                            self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.PwgInfo()
                                            self.pwg_info.parent = self
                                            self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold()
                                            self.threshold.parent = self
                                            self.vm_done = None
                                            self.vm_node_id = None


                                        class EnvSensorInfo(object):
                                            """
                                            Environment sensor info
                                            
                                            .. attribute:: age_time_stamp
                                            
                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: alarm_type
                                            
                                            	Indicates threshold violation
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_type
                                            
                                            	Sensor data type enums
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: device_description
                                            
                                            	Device Name
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: device_id
                                            
                                            	Identifier for this device
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: field_validity_bitmap
                                            
                                            	Sensor valid bitmap
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: precision
                                            
                                            	Sensor precision range
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scale
                                            
                                            	Sensor scale enums
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: status
                                            
                                            	Sensor operation state enums
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: units
                                            
                                            	Units of variable being read
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: update_rate
                                            
                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: value
                                            
                                            	Current reading of sensor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.age_time_stamp = None
                                                self.alarm_type = None
                                                self.data_type = None
                                                self.device_description = None
                                                self.device_id = None
                                                self.field_validity_bitmap = None
                                                self.precision = None
                                                self.scale = None
                                                self.status = None
                                                self.units = None
                                                self.update_rate = None
                                                self.value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.age_time_stamp is not None:
                                                    return True

                                                if self.alarm_type is not None:
                                                    return True

                                                if self.data_type is not None:
                                                    return True

                                                if self.device_description is not None:
                                                    return True

                                                if self.device_id is not None:
                                                    return True

                                                if self.field_validity_bitmap is not None:
                                                    return True

                                                if self.precision is not None:
                                                    return True

                                                if self.scale is not None:
                                                    return True

                                                if self.status is not None:
                                                    return True

                                                if self.units is not None:
                                                    return True

                                                if self.update_rate is not None:
                                                    return True

                                                if self.value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfo']['meta_info']


                                        class PwgInfo(object):
                                            """
                                            Inventory EDM PWG info
                                            
                                            .. attribute:: power_group_available_current
                                            
                                            	available current
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_group_drawn_current
                                            
                                            	drawn current
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_group_power_units
                                            
                                            	power units
                                            	**type**\:  str
                                            
                                            .. attribute:: power_group_redundancy_mode
                                            
                                            	redundancy mode
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.power_group_available_current = None
                                                self.power_group_drawn_current = None
                                                self.power_group_power_units = None
                                                self.power_group_redundancy_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.power_group_available_current is not None:
                                                    return True

                                                if self.power_group_drawn_current is not None:
                                                    return True

                                                if self.power_group_power_units is not None:
                                                    return True

                                                if self.power_group_redundancy_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.PwgInfo']['meta_info']


                                        class EnvSensorInfoXml(object):
                                            """
                                            Environment sensor info XML
                                            
                                            .. attribute:: data_type
                                            
                                            	Sensor data type
                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                            
                                            .. attribute:: description
                                            
                                            	Device Name
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: status
                                            
                                            	Sensor operation state
                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold information
                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold>`
                                            
                                            .. attribute:: units
                                            
                                            	Units of variable being read
                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                            
                                            .. attribute:: update_rate
                                            
                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: value
                                            
                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.data_type = None
                                                self.description = None
                                                self.status = None
                                                self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold()
                                                self.threshold.parent = self
                                                self.units = None
                                                self.update_rate = None
                                                self.value = None


                                            class Threshold(object):
                                                """
                                                Threshold information
                                                
                                                .. attribute:: threshold_array
                                                
                                                	Array of threshold
                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.threshold_array = YList()
                                                    self.threshold_array.parent = self
                                                    self.threshold_array.name = 'threshold_array'


                                                class ThresholdArray(object):
                                                    """
                                                    Array of threshold
                                                    
                                                    .. attribute:: threshold_name
                                                    
                                                    	Threshold name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_name = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_name is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.threshold_array is not None:
                                                        for child_ref in self.threshold_array:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.data_type is not None:
                                                    return True

                                                if self.description is not None:
                                                    return True

                                                if self.status is not None:
                                                    return True

                                                if self.threshold is not None and self.threshold._has_data():
                                                    return True

                                                if self.units is not None:
                                                    return True

                                                if self.update_rate is not None:
                                                    return True

                                                if self.value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml']['meta_info']


                                        class InvAssetBag(object):
                                            """
                                            Inventory Asset Bag
                                            
                                            .. attribute:: manufacturer_assembly_number
                                            
                                            	Manufacture Assembly number
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_assembly_revision
                                            
                                            	Manufacture assembly revision
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                            
                                            	Common Language Equipment           Identifier number
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_firmware_identifier
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_software_identifier
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: original_equipment_manufacturer_string
                                            
                                            	String containing OEM information           if applicable
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: part_number
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.manufacturer_assembly_number = None
                                                self.manufacturer_assembly_revision = None
                                                self.manufacturer_common_language_equipment_identifier = None
                                                self.manufacturer_firmware_identifier = None
                                                self.manufacturer_software_identifier = None
                                                self.original_equipment_manufacturer_string = None
                                                self.part_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.manufacturer_assembly_number is not None:
                                                    return True

                                                if self.manufacturer_assembly_revision is not None:
                                                    return True

                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                    return True

                                                if self.manufacturer_firmware_identifier is not None:
                                                    return True

                                                if self.manufacturer_software_identifier is not None:
                                                    return True

                                                if self.original_equipment_manufacturer_string is not None:
                                                    return True

                                                if self.part_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvAssetBag']['meta_info']


                                        class Threshold(object):
                                            """
                                            Threshold
                                            
                                            .. attribute:: critical_hi
                                            
                                            	Critical High
                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi>`
                                            
                                            .. attribute:: critical_lo
                                            
                                            	Critical Low
                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo>`
                                            
                                            .. attribute:: major_hi
                                            
                                            	Major High
                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi>`
                                            
                                            .. attribute:: major_lo
                                            
                                            	Major Low
                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo>`
                                            
                                            .. attribute:: minor_hi
                                            
                                            	Minor High
                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi>`
                                            
                                            .. attribute:: minor_lo
                                            
                                            	Minor Low
                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo>`
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi()
                                                self.critical_hi.parent = self
                                                self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo()
                                                self.critical_lo.parent = self
                                                self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi()
                                                self.major_hi.parent = self
                                                self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo()
                                                self.major_lo.parent = self
                                                self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi()
                                                self.minor_hi.parent = self
                                                self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo()
                                                self.minor_lo.parent = self


                                            class MajorLo(object):
                                                """
                                                Major Low
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo']['meta_info']


                                            class CriticalHi(object):
                                                """
                                                Critical High
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi']['meta_info']


                                            class MinorHi(object):
                                                """
                                                Minor High
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi']['meta_info']


                                            class MajorHi(object):
                                                """
                                                Major High
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi']['meta_info']


                                            class CriticalLo(object):
                                                """
                                                Critical Low
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo']['meta_info']


                                            class MinorLo(object):
                                                """
                                                Minor Low
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                    return True

                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                    return True

                                                if self.major_hi is not None and self.major_hi._has_data():
                                                    return True

                                                if self.major_lo is not None and self.major_lo._has_data():
                                                    return True

                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                    return True

                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold']['meta_info']


                                        class FruInfo(object):
                                            """
                                            Inventory EDM FRU info
                                            
                                            .. attribute:: card_administrative_state
                                            
                                            	card admin state\: shutdown or not
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: card_monitor_state
                                            
                                            	card is monitored by a manager or left unmonitored
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: card_operational_state
                                            
                                            	card operation state
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: card_reset_reason
                                            
                                            	card reset reason enum
                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                            
                                            .. attribute:: card_up_time
                                            
                                            	card up time
                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.CardUpTime>`
                                            
                                            .. attribute:: last_operational_state_change
                                            
                                            	last card oper change state
                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.LastOperationalStateChange>`
                                            
                                            .. attribute:: power_administrative_state
                                            
                                            	power admin state\: up or down
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_current_measurement
                                            
                                            	power current\: not implemented
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_operational_state
                                            
                                            	Power operation state
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.card_administrative_state = None
                                                self.card_monitor_state = None
                                                self.card_operational_state = None
                                                self.card_reset_reason = None
                                                self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.CardUpTime()
                                                self.card_up_time.parent = self
                                                self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.LastOperationalStateChange()
                                                self.last_operational_state_change.parent = self
                                                self.power_administrative_state = None
                                                self.power_current_measurement = None
                                                self.power_operational_state = None


                                            class LastOperationalStateChange(object):
                                                """
                                                last card oper change state
                                                
                                                .. attribute:: time_in_nano_seconds
                                                
                                                	Time Value in Nano\-seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: time_in_seconds
                                                
                                                	Time Value in Seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.time_in_nano_seconds = None
                                                    self.time_in_seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.time_in_nano_seconds is not None:
                                                        return True

                                                    if self.time_in_seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                            class CardUpTime(object):
                                                """
                                                card up time
                                                
                                                .. attribute:: time_in_nano_seconds
                                                
                                                	Time Value in Nano\-seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: time_in_seconds
                                                
                                                	Time Value in Seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.time_in_nano_seconds = None
                                                    self.time_in_seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.time_in_nano_seconds is not None:
                                                        return True

                                                    if self.time_in_seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.CardUpTime']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.card_administrative_state is not None:
                                                    return True

                                                if self.card_monitor_state is not None:
                                                    return True

                                                if self.card_operational_state is not None:
                                                    return True

                                                if self.card_reset_reason is not None:
                                                    return True

                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                    return True

                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                    return True

                                                if self.power_administrative_state is not None:
                                                    return True

                                                if self.power_current_measurement is not None:
                                                    return True

                                                if self.power_operational_state is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo']['meta_info']


                                        class InvBasicBag(object):
                                            """
                                            Inventory Basic Bag
                                            
                                            .. attribute:: alias
                                            
                                            	useful for storing an entity alias 
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: asset_id_str
                                            
                                            	asset Identification string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: asset_identification
                                            
                                            	asset Identification
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ceport
                                            
                                            	1 if ce port found, 0 if not
                                            	**type**\:  bool
                                            
                                            .. attribute:: chip_hardware_revision
                                            
                                            	chip module hw revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: composite_class_code
                                            
                                            	Major&minor class of the entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: description
                                            
                                            	describes in user\-readable terms       what the entity in question does
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: environmental_monitor_path
                                            
                                            	sysdb name of sensor in the envmon EDM
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: firmware_revision
                                            
                                            	firmware revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: group_flag
                                            
                                            	indicates if this entity is group       or not
                                            	**type**\:  bool
                                            
                                            .. attribute:: hardware_revision
                                            
                                            	hw revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: is_field_replaceable_unit
                                            
                                            	1 if Field Replaceable Unit 0, if not
                                            	**type**\:  bool
                                            
                                            .. attribute:: manufacturer_asset_tags
                                            
                                            	Manufacture Asset Tags
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: manufacturer_name
                                            
                                            	manufacturer's name
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: memory_size
                                            
                                            	Size of memory associated with       the entity where applicable
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: model_name
                                            
                                            	model name
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: name
                                            
                                            	name string for the entity
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: new_deviation_number
                                            
                                            	integer value for New Deviation Number 0x88
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: physical_layer_interface_module_type
                                            
                                            	integer value for plim type if     applicable to this entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: redundancystate
                                            
                                            	integer value for Redundancy State if     applicable to this entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: serial_number
                                            
                                            	serial number
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: software_revision
                                            
                                            	software revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: unique_id
                                            
                                            	Unique id for an entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: unrecognized_fru
                                            
                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                            	**type**\:  bool
                                            
                                            .. attribute:: vendor_type
                                            
                                            	maps to the vendor OID string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: xr_scoped
                                            
                                            	1 if xr scoped, 0 if not
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.alias = None
                                                self.asset_id_str = None
                                                self.asset_identification = None
                                                self.ceport = None
                                                self.chip_hardware_revision = None
                                                self.composite_class_code = None
                                                self.description = None
                                                self.environmental_monitor_path = None
                                                self.firmware_revision = None
                                                self.group_flag = None
                                                self.hardware_revision = None
                                                self.is_field_replaceable_unit = None
                                                self.manufacturer_asset_tags = None
                                                self.manufacturer_name = None
                                                self.memory_size = None
                                                self.model_name = None
                                                self.name = None
                                                self.new_deviation_number = None
                                                self.physical_layer_interface_module_type = None
                                                self.redundancystate = None
                                                self.serial_number = None
                                                self.software_revision = None
                                                self.unique_id = None
                                                self.unrecognized_fru = None
                                                self.vendor_type = None
                                                self.xr_scoped = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.alias is not None:
                                                    return True

                                                if self.asset_id_str is not None:
                                                    return True

                                                if self.asset_identification is not None:
                                                    return True

                                                if self.ceport is not None:
                                                    return True

                                                if self.chip_hardware_revision is not None:
                                                    return True

                                                if self.composite_class_code is not None:
                                                    return True

                                                if self.description is not None:
                                                    return True

                                                if self.environmental_monitor_path is not None:
                                                    return True

                                                if self.firmware_revision is not None:
                                                    return True

                                                if self.group_flag is not None:
                                                    return True

                                                if self.hardware_revision is not None:
                                                    return True

                                                if self.is_field_replaceable_unit is not None:
                                                    return True

                                                if self.manufacturer_asset_tags is not None:
                                                    return True

                                                if self.manufacturer_name is not None:
                                                    return True

                                                if self.memory_size is not None:
                                                    return True

                                                if self.model_name is not None:
                                                    return True

                                                if self.name is not None:
                                                    return True

                                                if self.new_deviation_number is not None:
                                                    return True

                                                if self.physical_layer_interface_module_type is not None:
                                                    return True

                                                if self.redundancystate is not None:
                                                    return True

                                                if self.serial_number is not None:
                                                    return True

                                                if self.software_revision is not None:
                                                    return True

                                                if self.unique_id is not None:
                                                    return True

                                                if self.unrecognized_fru is not None:
                                                    return True

                                                if self.vendor_type is not None:
                                                    return True

                                                if self.xr_scoped is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvBasicBag']['meta_info']


                                        class InvEepromInfo(object):
                                            """
                                            Inventory EDM EEPROM Information Bag
                                            
                                            .. attribute:: description
                                            
                                            	A textual description of physical entity
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: eeprom
                                            
                                            	EEPROM data not from hex data
                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom>`
                                            
                                            .. attribute:: has_eeprom
                                            
                                            	use eeprom instead of opaque data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inv_card_type
                                            
                                            	Inventory card type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: opaque_data
                                            
                                            	EEPROM hex data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: opaque_data_size
                                            
                                            	size of the EEPROM hex data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom()
                                                self.eeprom.parent = self
                                                self.has_eeprom = None
                                                self.inv_card_type = None
                                                self.opaque_data = None
                                                self.opaque_data_size = None


                                            class Eeprom(object):
                                                """
                                                EEPROM data not from hex data
                                                
                                                .. attribute:: asset_alias
                                                
                                                	Asset Alias
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: asset_id
                                                
                                                	Asset ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address1
                                                
                                                	Base Mac Address #1
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address2
                                                
                                                	Base Mac Address #2
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address3
                                                
                                                	Base Mac Address #3
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address4
                                                
                                                	Base Mac Address #4
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_checksum
                                                
                                                	Block Checksum
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_count
                                                
                                                	Block Count
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_length
                                                
                                                	Block Length
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_signature
                                                
                                                	Block Signature
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_version
                                                
                                                	Block Version
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: chassis_sid
                                                
                                                	Chassis serial number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: clei
                                                
                                                	Common Language Equipment Identifier (CLEI) code
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: controller_family
                                                
                                                	Controller family
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: controller_type
                                                
                                                	Controller type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: description
                                                
                                                	A textual description of physical entity
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num1
                                                
                                                	Deviation Number # 1
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num2
                                                
                                                	Deviation Number # 2
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num3
                                                
                                                	Deviation Number # 3
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num4
                                                
                                                	Deviation Number # 4
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num5
                                                
                                                	Deviation Number # 5
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num6
                                                
                                                	Deviation Number # 6
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num7
                                                
                                                	Deviation Number # 7
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: eci
                                                
                                                	Equipment Catalog Item (ECI) number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: eeprom_size
                                                
                                                	EEPROM Size
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: engineer_use
                                                
                                                	Engineer Use
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: fru_major_type
                                                
                                                	FRU Major Type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: fru_minor_type
                                                
                                                	FRU Minor Type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: hw_version
                                                
                                                	Hardware Version
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: hwid
                                                
                                                	Hardware Revision
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: idprom_format_rev
                                                
                                                	IDPROM Format Revision
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size1
                                                
                                                	Mac Address Block Size #1
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size2
                                                
                                                	Mac Address Block Size #2
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size3
                                                
                                                	Mac Address Block Size #3
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size4
                                                
                                                	Mac Address Block Size #4
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: manu_test_data
                                                
                                                	Manufacturing Test Data
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mfg_bits
                                                
                                                	MFG Bits
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mfg_deviation
                                                
                                                	MFG Deviation
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: oem_string
                                                
                                                	OEM String
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: part_number
                                                
                                                	Part Number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: part_revision
                                                
                                                	Part Revision
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pca_num
                                                
                                                	PCA number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pcavid
                                                
                                                	PCA revision ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pcb_serial_num
                                                
                                                	PCB Serial Number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pid
                                                
                                                	Product ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: power_consumption
                                                
                                                	Power Consumption
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: power_supply_type
                                                
                                                	Power Supply Type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: product_id
                                                
                                                	Product ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: rma
                                                
                                                	RMA Data
                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                
                                                .. attribute:: rma_code
                                                
                                                	RMA Code
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: serial_number
                                                
                                                	Serial Number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: snmpoid
                                                
                                                	SNMP OID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: top_assem_part_num
                                                
                                                	Top assembly part number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: top_assem_vid
                                                
                                                	Top assembly revision number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: udi_description
                                                
                                                	UDI description
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: udi_name
                                                
                                                	UDI name
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: vid
                                                
                                                	Version ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asset_alias = None
                                                    self.asset_id = None
                                                    self.base_mac_address1 = None
                                                    self.base_mac_address2 = None
                                                    self.base_mac_address3 = None
                                                    self.base_mac_address4 = None
                                                    self.block_checksum = None
                                                    self.block_count = None
                                                    self.block_length = None
                                                    self.block_signature = None
                                                    self.block_version = None
                                                    self.chassis_sid = None
                                                    self.clei = None
                                                    self.controller_family = None
                                                    self.controller_type = None
                                                    self.description = None
                                                    self.dev_num1 = None
                                                    self.dev_num2 = None
                                                    self.dev_num3 = None
                                                    self.dev_num4 = None
                                                    self.dev_num5 = None
                                                    self.dev_num6 = None
                                                    self.dev_num7 = None
                                                    self.eci = None
                                                    self.eeprom_size = None
                                                    self.engineer_use = None
                                                    self.fru_major_type = None
                                                    self.fru_minor_type = None
                                                    self.hw_version = None
                                                    self.hwid = None
                                                    self.idprom_format_rev = None
                                                    self.mac_add_blk_size1 = None
                                                    self.mac_add_blk_size2 = None
                                                    self.mac_add_blk_size3 = None
                                                    self.mac_add_blk_size4 = None
                                                    self.manu_test_data = None
                                                    self.mfg_bits = None
                                                    self.mfg_deviation = None
                                                    self.oem_string = None
                                                    self.part_number = None
                                                    self.part_revision = None
                                                    self.pca_num = None
                                                    self.pcavid = None
                                                    self.pcb_serial_num = None
                                                    self.pid = None
                                                    self.power_consumption = None
                                                    self.power_supply_type = None
                                                    self.product_id = None
                                                    self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom.Rma()
                                                    self.rma.parent = self
                                                    self.rma_code = None
                                                    self.serial_number = None
                                                    self.snmpoid = None
                                                    self.top_assem_part_num = None
                                                    self.top_assem_vid = None
                                                    self.udi_description = None
                                                    self.udi_name = None
                                                    self.vid = None


                                                class Rma(object):
                                                    """
                                                    RMA Data
                                                    
                                                    .. attribute:: rma_history
                                                    
                                                    	RMA history
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: rma_number
                                                    
                                                    	RMA tracking number format is N\-N\-N
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: test_history
                                                    
                                                    	Test history
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.rma_history = None
                                                        self.rma_number = None
                                                        self.test_history = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.rma_history is not None:
                                                            return True

                                                        if self.rma_number is not None:
                                                            return True

                                                        if self.test_history is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asset_alias is not None:
                                                        return True

                                                    if self.asset_id is not None:
                                                        return True

                                                    if self.base_mac_address1 is not None:
                                                        return True

                                                    if self.base_mac_address2 is not None:
                                                        return True

                                                    if self.base_mac_address3 is not None:
                                                        return True

                                                    if self.base_mac_address4 is not None:
                                                        return True

                                                    if self.block_checksum is not None:
                                                        return True

                                                    if self.block_count is not None:
                                                        return True

                                                    if self.block_length is not None:
                                                        return True

                                                    if self.block_signature is not None:
                                                        return True

                                                    if self.block_version is not None:
                                                        return True

                                                    if self.chassis_sid is not None:
                                                        return True

                                                    if self.clei is not None:
                                                        return True

                                                    if self.controller_family is not None:
                                                        return True

                                                    if self.controller_type is not None:
                                                        return True

                                                    if self.description is not None:
                                                        return True

                                                    if self.dev_num1 is not None:
                                                        return True

                                                    if self.dev_num2 is not None:
                                                        return True

                                                    if self.dev_num3 is not None:
                                                        return True

                                                    if self.dev_num4 is not None:
                                                        return True

                                                    if self.dev_num5 is not None:
                                                        return True

                                                    if self.dev_num6 is not None:
                                                        return True

                                                    if self.dev_num7 is not None:
                                                        return True

                                                    if self.eci is not None:
                                                        return True

                                                    if self.eeprom_size is not None:
                                                        return True

                                                    if self.engineer_use is not None:
                                                        return True

                                                    if self.fru_major_type is not None:
                                                        return True

                                                    if self.fru_minor_type is not None:
                                                        return True

                                                    if self.hw_version is not None:
                                                        return True

                                                    if self.hwid is not None:
                                                        return True

                                                    if self.idprom_format_rev is not None:
                                                        return True

                                                    if self.mac_add_blk_size1 is not None:
                                                        return True

                                                    if self.mac_add_blk_size2 is not None:
                                                        return True

                                                    if self.mac_add_blk_size3 is not None:
                                                        return True

                                                    if self.mac_add_blk_size4 is not None:
                                                        return True

                                                    if self.manu_test_data is not None:
                                                        return True

                                                    if self.mfg_bits is not None:
                                                        return True

                                                    if self.mfg_deviation is not None:
                                                        return True

                                                    if self.oem_string is not None:
                                                        return True

                                                    if self.part_number is not None:
                                                        return True

                                                    if self.part_revision is not None:
                                                        return True

                                                    if self.pca_num is not None:
                                                        return True

                                                    if self.pcavid is not None:
                                                        return True

                                                    if self.pcb_serial_num is not None:
                                                        return True

                                                    if self.pid is not None:
                                                        return True

                                                    if self.power_consumption is not None:
                                                        return True

                                                    if self.power_supply_type is not None:
                                                        return True

                                                    if self.product_id is not None:
                                                        return True

                                                    if self.rma is not None and self.rma._has_data():
                                                        return True

                                                    if self.rma_code is not None:
                                                        return True

                                                    if self.serial_number is not None:
                                                        return True

                                                    if self.snmpoid is not None:
                                                        return True

                                                    if self.top_assem_part_num is not None:
                                                        return True

                                                    if self.top_assem_vid is not None:
                                                        return True

                                                    if self.udi_description is not None:
                                                        return True

                                                    if self.udi_name is not None:
                                                        return True

                                                    if self.vid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.eeprom is not None and self.eeprom._has_data():
                                                    return True

                                                if self.has_eeprom is not None:
                                                    return True

                                                if self.inv_card_type is not None:
                                                    return True

                                                if self.opaque_data is not None:
                                                    return True

                                                if self.opaque_data_size is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                return True

                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                return True

                                            if self.fru_info is not None and self.fru_info._has_data():
                                                return True

                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                return True

                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                return True

                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                return True

                                            if self.module_done is not None:
                                                return True

                                            if self.node_id is not None:
                                                return True

                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                return True

                                            if self.threshold is not None and self.threshold._has_data():
                                                return True

                                            if self.vm_done is not None:
                                                return True

                                            if self.vm_node_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.name is None:
                                            raise YPYModelError('Key property name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi2[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.name is not None:
                                            return True

                                        if self.attributes is not None and self.attributes._has_data():
                                            return True

                                        if self.tsi3s is not None and self.tsi3s._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi2s'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tsi2 is not None:
                                        for child_ref in self.tsi2:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Tsi2S']['meta_info']


                            class Attributes(object):
                                """
                                Attributes
                                
                                .. attribute:: env_sensor_info
                                
                                	Environment sensor info
                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfo>`
                                
                                .. attribute:: env_sensor_info_xml
                                
                                	Environment sensor info XML
                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml>`
                                
                                .. attribute:: fru_info
                                
                                	Inventory EDM FRU info
                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.FruInfo>`
                                
                                .. attribute:: inv_asset_bag
                                
                                	Inventory Asset Bag
                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvAssetBag>`
                                
                                .. attribute:: inv_basic_bag
                                
                                	Inventory Basic Bag
                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvBasicBag>`
                                
                                .. attribute:: inv_eeprom_info
                                
                                	Inventory EDM EEPROM Information Bag
                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo>`
                                
                                .. attribute:: module_done
                                
                                	Inventory EDM Module Done Tuple
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**default value**\: 1
                                
                                .. attribute:: node_id
                                
                                	Node ID Tuple
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pwg_info
                                
                                	Inventory EDM PWG info
                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.PwgInfo>`
                                
                                .. attribute:: threshold
                                
                                	Threshold
                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold>`
                                
                                .. attribute:: vm_done
                                
                                	VM Done Tuple
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: vm_node_id
                                
                                	VM Node ID Tuple
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfo()
                                    self.env_sensor_info.parent = self
                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml()
                                    self.env_sensor_info_xml.parent = self
                                    self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.FruInfo()
                                    self.fru_info.parent = self
                                    self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvAssetBag()
                                    self.inv_asset_bag.parent = self
                                    self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvBasicBag()
                                    self.inv_basic_bag.parent = self
                                    self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo()
                                    self.inv_eeprom_info.parent = self
                                    self.module_done = None
                                    self.node_id = None
                                    self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.PwgInfo()
                                    self.pwg_info.parent = self
                                    self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold()
                                    self.threshold.parent = self
                                    self.vm_done = None
                                    self.vm_node_id = None


                                class EnvSensorInfo(object):
                                    """
                                    Environment sensor info
                                    
                                    .. attribute:: age_time_stamp
                                    
                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: alarm_type
                                    
                                    	Indicates threshold violation
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_type
                                    
                                    	Sensor data type enums
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: device_description
                                    
                                    	Device Name
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: device_id
                                    
                                    	Identifier for this device
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: field_validity_bitmap
                                    
                                    	Sensor valid bitmap
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: precision
                                    
                                    	Sensor precision range
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scale
                                    
                                    	Sensor scale enums
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status
                                    
                                    	Sensor operation state enums
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: units
                                    
                                    	Units of variable being read
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: update_rate
                                    
                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: value
                                    
                                    	Current reading of sensor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.age_time_stamp = None
                                        self.alarm_type = None
                                        self.data_type = None
                                        self.device_description = None
                                        self.device_id = None
                                        self.field_validity_bitmap = None
                                        self.precision = None
                                        self.scale = None
                                        self.status = None
                                        self.units = None
                                        self.update_rate = None
                                        self.value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.age_time_stamp is not None:
                                            return True

                                        if self.alarm_type is not None:
                                            return True

                                        if self.data_type is not None:
                                            return True

                                        if self.device_description is not None:
                                            return True

                                        if self.device_id is not None:
                                            return True

                                        if self.field_validity_bitmap is not None:
                                            return True

                                        if self.precision is not None:
                                            return True

                                        if self.scale is not None:
                                            return True

                                        if self.status is not None:
                                            return True

                                        if self.units is not None:
                                            return True

                                        if self.update_rate is not None:
                                            return True

                                        if self.value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfo']['meta_info']


                                class PwgInfo(object):
                                    """
                                    Inventory EDM PWG info
                                    
                                    .. attribute:: power_group_available_current
                                    
                                    	available current
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_group_drawn_current
                                    
                                    	drawn current
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_group_power_units
                                    
                                    	power units
                                    	**type**\:  str
                                    
                                    .. attribute:: power_group_redundancy_mode
                                    
                                    	redundancy mode
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.power_group_available_current = None
                                        self.power_group_drawn_current = None
                                        self.power_group_power_units = None
                                        self.power_group_redundancy_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.power_group_available_current is not None:
                                            return True

                                        if self.power_group_drawn_current is not None:
                                            return True

                                        if self.power_group_power_units is not None:
                                            return True

                                        if self.power_group_redundancy_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.PwgInfo']['meta_info']


                                class EnvSensorInfoXml(object):
                                    """
                                    Environment sensor info XML
                                    
                                    .. attribute:: data_type
                                    
                                    	Sensor data type
                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                    
                                    .. attribute:: description
                                    
                                    	Device Name
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: status
                                    
                                    	Sensor operation state
                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold information
                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold>`
                                    
                                    .. attribute:: units
                                    
                                    	Units of variable being read
                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                    
                                    .. attribute:: update_rate
                                    
                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: value
                                    
                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data_type = None
                                        self.description = None
                                        self.status = None
                                        self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold()
                                        self.threshold.parent = self
                                        self.units = None
                                        self.update_rate = None
                                        self.value = None


                                    class Threshold(object):
                                        """
                                        Threshold information
                                        
                                        .. attribute:: threshold_array
                                        
                                        	Array of threshold
                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.threshold_array = YList()
                                            self.threshold_array.parent = self
                                            self.threshold_array.name = 'threshold_array'


                                        class ThresholdArray(object):
                                            """
                                            Array of threshold
                                            
                                            .. attribute:: threshold_name
                                            
                                            	Threshold name
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_name = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_name is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.threshold_array is not None:
                                                for child_ref in self.threshold_array:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data_type is not None:
                                            return True

                                        if self.description is not None:
                                            return True

                                        if self.status is not None:
                                            return True

                                        if self.threshold is not None and self.threshold._has_data():
                                            return True

                                        if self.units is not None:
                                            return True

                                        if self.update_rate is not None:
                                            return True

                                        if self.value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml']['meta_info']


                                class InvAssetBag(object):
                                    """
                                    Inventory Asset Bag
                                    
                                    .. attribute:: manufacturer_assembly_number
                                    
                                    	Manufacture Assembly number
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_assembly_revision
                                    
                                    	Manufacture assembly revision
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                    
                                    	Common Language Equipment           Identifier number
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_firmware_identifier
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_software_identifier
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: original_equipment_manufacturer_string
                                    
                                    	String containing OEM information           if applicable
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: part_number
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.manufacturer_assembly_number = None
                                        self.manufacturer_assembly_revision = None
                                        self.manufacturer_common_language_equipment_identifier = None
                                        self.manufacturer_firmware_identifier = None
                                        self.manufacturer_software_identifier = None
                                        self.original_equipment_manufacturer_string = None
                                        self.part_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.manufacturer_assembly_number is not None:
                                            return True

                                        if self.manufacturer_assembly_revision is not None:
                                            return True

                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                            return True

                                        if self.manufacturer_firmware_identifier is not None:
                                            return True

                                        if self.manufacturer_software_identifier is not None:
                                            return True

                                        if self.original_equipment_manufacturer_string is not None:
                                            return True

                                        if self.part_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvAssetBag']['meta_info']


                                class Threshold(object):
                                    """
                                    Threshold
                                    
                                    .. attribute:: critical_hi
                                    
                                    	Critical High
                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi>`
                                    
                                    .. attribute:: critical_lo
                                    
                                    	Critical Low
                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo>`
                                    
                                    .. attribute:: major_hi
                                    
                                    	Major High
                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi>`
                                    
                                    .. attribute:: major_lo
                                    
                                    	Major Low
                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo>`
                                    
                                    .. attribute:: minor_hi
                                    
                                    	Minor High
                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi>`
                                    
                                    .. attribute:: minor_lo
                                    
                                    	Minor Low
                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo>`
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi()
                                        self.critical_hi.parent = self
                                        self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo()
                                        self.critical_lo.parent = self
                                        self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi()
                                        self.major_hi.parent = self
                                        self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo()
                                        self.major_lo.parent = self
                                        self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi()
                                        self.minor_hi.parent = self
                                        self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo()
                                        self.minor_lo.parent = self


                                    class MajorLo(object):
                                        """
                                        Major Low
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo']['meta_info']


                                    class CriticalHi(object):
                                        """
                                        Critical High
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi']['meta_info']


                                    class MinorHi(object):
                                        """
                                        Minor High
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi']['meta_info']


                                    class MajorHi(object):
                                        """
                                        Major High
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi']['meta_info']


                                    class CriticalLo(object):
                                        """
                                        Critical Low
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo']['meta_info']


                                    class MinorLo(object):
                                        """
                                        Minor Low
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                            return True

                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                            return True

                                        if self.major_hi is not None and self.major_hi._has_data():
                                            return True

                                        if self.major_lo is not None and self.major_lo._has_data():
                                            return True

                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                            return True

                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.Threshold']['meta_info']


                                class FruInfo(object):
                                    """
                                    Inventory EDM FRU info
                                    
                                    .. attribute:: card_administrative_state
                                    
                                    	card admin state\: shutdown or not
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: card_monitor_state
                                    
                                    	card is monitored by a manager or left unmonitored
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: card_operational_state
                                    
                                    	card operation state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: card_reset_reason
                                    
                                    	card reset reason enum
                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                    
                                    .. attribute:: card_up_time
                                    
                                    	card up time
                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.FruInfo.CardUpTime>`
                                    
                                    .. attribute:: last_operational_state_change
                                    
                                    	last card oper change state
                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.FruInfo.LastOperationalStateChange>`
                                    
                                    .. attribute:: power_administrative_state
                                    
                                    	power admin state\: up or down
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_current_measurement
                                    
                                    	power current\: not implemented
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_operational_state
                                    
                                    	Power operation state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.card_administrative_state = None
                                        self.card_monitor_state = None
                                        self.card_operational_state = None
                                        self.card_reset_reason = None
                                        self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.FruInfo.CardUpTime()
                                        self.card_up_time.parent = self
                                        self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.FruInfo.LastOperationalStateChange()
                                        self.last_operational_state_change.parent = self
                                        self.power_administrative_state = None
                                        self.power_current_measurement = None
                                        self.power_operational_state = None


                                    class LastOperationalStateChange(object):
                                        """
                                        last card oper change state
                                        
                                        .. attribute:: time_in_nano_seconds
                                        
                                        	Time Value in Nano\-seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: time_in_seconds
                                        
                                        	Time Value in Seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.time_in_nano_seconds = None
                                            self.time_in_seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.time_in_nano_seconds is not None:
                                                return True

                                            if self.time_in_seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                    class CardUpTime(object):
                                        """
                                        card up time
                                        
                                        .. attribute:: time_in_nano_seconds
                                        
                                        	Time Value in Nano\-seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: time_in_seconds
                                        
                                        	Time Value in Seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.time_in_nano_seconds = None
                                            self.time_in_seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.time_in_nano_seconds is not None:
                                                return True

                                            if self.time_in_seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.FruInfo.CardUpTime']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.card_administrative_state is not None:
                                            return True

                                        if self.card_monitor_state is not None:
                                            return True

                                        if self.card_operational_state is not None:
                                            return True

                                        if self.card_reset_reason is not None:
                                            return True

                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                            return True

                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                            return True

                                        if self.power_administrative_state is not None:
                                            return True

                                        if self.power_current_measurement is not None:
                                            return True

                                        if self.power_operational_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.FruInfo']['meta_info']


                                class InvBasicBag(object):
                                    """
                                    Inventory Basic Bag
                                    
                                    .. attribute:: alias
                                    
                                    	useful for storing an entity alias 
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: asset_id_str
                                    
                                    	asset Identification string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: asset_identification
                                    
                                    	asset Identification
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ceport
                                    
                                    	1 if ce port found, 0 if not
                                    	**type**\:  bool
                                    
                                    .. attribute:: chip_hardware_revision
                                    
                                    	chip module hw revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: composite_class_code
                                    
                                    	Major&minor class of the entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: description
                                    
                                    	describes in user\-readable terms       what the entity in question does
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: environmental_monitor_path
                                    
                                    	sysdb name of sensor in the envmon EDM
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: firmware_revision
                                    
                                    	firmware revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: group_flag
                                    
                                    	indicates if this entity is group       or not
                                    	**type**\:  bool
                                    
                                    .. attribute:: hardware_revision
                                    
                                    	hw revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: is_field_replaceable_unit
                                    
                                    	1 if Field Replaceable Unit 0, if not
                                    	**type**\:  bool
                                    
                                    .. attribute:: manufacturer_asset_tags
                                    
                                    	Manufacture Asset Tags
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: manufacturer_name
                                    
                                    	manufacturer's name
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: memory_size
                                    
                                    	Size of memory associated with       the entity where applicable
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: model_name
                                    
                                    	model name
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: name
                                    
                                    	name string for the entity
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: new_deviation_number
                                    
                                    	integer value for New Deviation Number 0x88
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: physical_layer_interface_module_type
                                    
                                    	integer value for plim type if     applicable to this entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: redundancystate
                                    
                                    	integer value for Redundancy State if     applicable to this entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: serial_number
                                    
                                    	serial number
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: software_revision
                                    
                                    	software revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: unique_id
                                    
                                    	Unique id for an entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: unrecognized_fru
                                    
                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                    	**type**\:  bool
                                    
                                    .. attribute:: vendor_type
                                    
                                    	maps to the vendor OID string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: xr_scoped
                                    
                                    	1 if xr scoped, 0 if not
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.alias = None
                                        self.asset_id_str = None
                                        self.asset_identification = None
                                        self.ceport = None
                                        self.chip_hardware_revision = None
                                        self.composite_class_code = None
                                        self.description = None
                                        self.environmental_monitor_path = None
                                        self.firmware_revision = None
                                        self.group_flag = None
                                        self.hardware_revision = None
                                        self.is_field_replaceable_unit = None
                                        self.manufacturer_asset_tags = None
                                        self.manufacturer_name = None
                                        self.memory_size = None
                                        self.model_name = None
                                        self.name = None
                                        self.new_deviation_number = None
                                        self.physical_layer_interface_module_type = None
                                        self.redundancystate = None
                                        self.serial_number = None
                                        self.software_revision = None
                                        self.unique_id = None
                                        self.unrecognized_fru = None
                                        self.vendor_type = None
                                        self.xr_scoped = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.alias is not None:
                                            return True

                                        if self.asset_id_str is not None:
                                            return True

                                        if self.asset_identification is not None:
                                            return True

                                        if self.ceport is not None:
                                            return True

                                        if self.chip_hardware_revision is not None:
                                            return True

                                        if self.composite_class_code is not None:
                                            return True

                                        if self.description is not None:
                                            return True

                                        if self.environmental_monitor_path is not None:
                                            return True

                                        if self.firmware_revision is not None:
                                            return True

                                        if self.group_flag is not None:
                                            return True

                                        if self.hardware_revision is not None:
                                            return True

                                        if self.is_field_replaceable_unit is not None:
                                            return True

                                        if self.manufacturer_asset_tags is not None:
                                            return True

                                        if self.manufacturer_name is not None:
                                            return True

                                        if self.memory_size is not None:
                                            return True

                                        if self.model_name is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.new_deviation_number is not None:
                                            return True

                                        if self.physical_layer_interface_module_type is not None:
                                            return True

                                        if self.redundancystate is not None:
                                            return True

                                        if self.serial_number is not None:
                                            return True

                                        if self.software_revision is not None:
                                            return True

                                        if self.unique_id is not None:
                                            return True

                                        if self.unrecognized_fru is not None:
                                            return True

                                        if self.vendor_type is not None:
                                            return True

                                        if self.xr_scoped is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvBasicBag']['meta_info']


                                class InvEepromInfo(object):
                                    """
                                    Inventory EDM EEPROM Information Bag
                                    
                                    .. attribute:: description
                                    
                                    	A textual description of physical entity
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: eeprom
                                    
                                    	EEPROM data not from hex data
                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom>`
                                    
                                    .. attribute:: has_eeprom
                                    
                                    	use eeprom instead of opaque data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inv_card_type
                                    
                                    	Inventory card type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: opaque_data
                                    
                                    	EEPROM hex data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: opaque_data_size
                                    
                                    	size of the EEPROM hex data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom()
                                        self.eeprom.parent = self
                                        self.has_eeprom = None
                                        self.inv_card_type = None
                                        self.opaque_data = None
                                        self.opaque_data_size = None


                                    class Eeprom(object):
                                        """
                                        EEPROM data not from hex data
                                        
                                        .. attribute:: asset_alias
                                        
                                        	Asset Alias
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: asset_id
                                        
                                        	Asset ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address1
                                        
                                        	Base Mac Address #1
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address2
                                        
                                        	Base Mac Address #2
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address3
                                        
                                        	Base Mac Address #3
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address4
                                        
                                        	Base Mac Address #4
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_checksum
                                        
                                        	Block Checksum
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_count
                                        
                                        	Block Count
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_length
                                        
                                        	Block Length
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_signature
                                        
                                        	Block Signature
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_version
                                        
                                        	Block Version
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: chassis_sid
                                        
                                        	Chassis serial number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: clei
                                        
                                        	Common Language Equipment Identifier (CLEI) code
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: controller_family
                                        
                                        	Controller family
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: controller_type
                                        
                                        	Controller type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: description
                                        
                                        	A textual description of physical entity
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num1
                                        
                                        	Deviation Number # 1
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num2
                                        
                                        	Deviation Number # 2
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num3
                                        
                                        	Deviation Number # 3
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num4
                                        
                                        	Deviation Number # 4
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num5
                                        
                                        	Deviation Number # 5
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num6
                                        
                                        	Deviation Number # 6
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num7
                                        
                                        	Deviation Number # 7
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: eci
                                        
                                        	Equipment Catalog Item (ECI) number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: eeprom_size
                                        
                                        	EEPROM Size
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: engineer_use
                                        
                                        	Engineer Use
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: fru_major_type
                                        
                                        	FRU Major Type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: fru_minor_type
                                        
                                        	FRU Minor Type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: hw_version
                                        
                                        	Hardware Version
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: hwid
                                        
                                        	Hardware Revision
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: idprom_format_rev
                                        
                                        	IDPROM Format Revision
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size1
                                        
                                        	Mac Address Block Size #1
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size2
                                        
                                        	Mac Address Block Size #2
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size3
                                        
                                        	Mac Address Block Size #3
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size4
                                        
                                        	Mac Address Block Size #4
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: manu_test_data
                                        
                                        	Manufacturing Test Data
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mfg_bits
                                        
                                        	MFG Bits
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mfg_deviation
                                        
                                        	MFG Deviation
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: oem_string
                                        
                                        	OEM String
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: part_number
                                        
                                        	Part Number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: part_revision
                                        
                                        	Part Revision
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pca_num
                                        
                                        	PCA number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pcavid
                                        
                                        	PCA revision ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pcb_serial_num
                                        
                                        	PCB Serial Number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pid
                                        
                                        	Product ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: power_consumption
                                        
                                        	Power Consumption
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: power_supply_type
                                        
                                        	Power Supply Type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: product_id
                                        
                                        	Product ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: rma
                                        
                                        	RMA Data
                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom.Rma>`
                                        
                                        .. attribute:: rma_code
                                        
                                        	RMA Code
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: serial_number
                                        
                                        	Serial Number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: snmpoid
                                        
                                        	SNMP OID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: top_assem_part_num
                                        
                                        	Top assembly part number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: top_assem_vid
                                        
                                        	Top assembly revision number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: udi_description
                                        
                                        	UDI description
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: udi_name
                                        
                                        	UDI name
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: vid
                                        
                                        	Version ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asset_alias = None
                                            self.asset_id = None
                                            self.base_mac_address1 = None
                                            self.base_mac_address2 = None
                                            self.base_mac_address3 = None
                                            self.base_mac_address4 = None
                                            self.block_checksum = None
                                            self.block_count = None
                                            self.block_length = None
                                            self.block_signature = None
                                            self.block_version = None
                                            self.chassis_sid = None
                                            self.clei = None
                                            self.controller_family = None
                                            self.controller_type = None
                                            self.description = None
                                            self.dev_num1 = None
                                            self.dev_num2 = None
                                            self.dev_num3 = None
                                            self.dev_num4 = None
                                            self.dev_num5 = None
                                            self.dev_num6 = None
                                            self.dev_num7 = None
                                            self.eci = None
                                            self.eeprom_size = None
                                            self.engineer_use = None
                                            self.fru_major_type = None
                                            self.fru_minor_type = None
                                            self.hw_version = None
                                            self.hwid = None
                                            self.idprom_format_rev = None
                                            self.mac_add_blk_size1 = None
                                            self.mac_add_blk_size2 = None
                                            self.mac_add_blk_size3 = None
                                            self.mac_add_blk_size4 = None
                                            self.manu_test_data = None
                                            self.mfg_bits = None
                                            self.mfg_deviation = None
                                            self.oem_string = None
                                            self.part_number = None
                                            self.part_revision = None
                                            self.pca_num = None
                                            self.pcavid = None
                                            self.pcb_serial_num = None
                                            self.pid = None
                                            self.power_consumption = None
                                            self.power_supply_type = None
                                            self.product_id = None
                                            self.rma = Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom.Rma()
                                            self.rma.parent = self
                                            self.rma_code = None
                                            self.serial_number = None
                                            self.snmpoid = None
                                            self.top_assem_part_num = None
                                            self.top_assem_vid = None
                                            self.udi_description = None
                                            self.udi_name = None
                                            self.vid = None


                                        class Rma(object):
                                            """
                                            RMA Data
                                            
                                            .. attribute:: rma_history
                                            
                                            	RMA history
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: rma_number
                                            
                                            	RMA tracking number format is N\-N\-N
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: test_history
                                            
                                            	Test history
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.rma_history = None
                                                self.rma_number = None
                                                self.test_history = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rma_history is not None:
                                                    return True

                                                if self.rma_number is not None:
                                                    return True

                                                if self.test_history is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asset_alias is not None:
                                                return True

                                            if self.asset_id is not None:
                                                return True

                                            if self.base_mac_address1 is not None:
                                                return True

                                            if self.base_mac_address2 is not None:
                                                return True

                                            if self.base_mac_address3 is not None:
                                                return True

                                            if self.base_mac_address4 is not None:
                                                return True

                                            if self.block_checksum is not None:
                                                return True

                                            if self.block_count is not None:
                                                return True

                                            if self.block_length is not None:
                                                return True

                                            if self.block_signature is not None:
                                                return True

                                            if self.block_version is not None:
                                                return True

                                            if self.chassis_sid is not None:
                                                return True

                                            if self.clei is not None:
                                                return True

                                            if self.controller_family is not None:
                                                return True

                                            if self.controller_type is not None:
                                                return True

                                            if self.description is not None:
                                                return True

                                            if self.dev_num1 is not None:
                                                return True

                                            if self.dev_num2 is not None:
                                                return True

                                            if self.dev_num3 is not None:
                                                return True

                                            if self.dev_num4 is not None:
                                                return True

                                            if self.dev_num5 is not None:
                                                return True

                                            if self.dev_num6 is not None:
                                                return True

                                            if self.dev_num7 is not None:
                                                return True

                                            if self.eci is not None:
                                                return True

                                            if self.eeprom_size is not None:
                                                return True

                                            if self.engineer_use is not None:
                                                return True

                                            if self.fru_major_type is not None:
                                                return True

                                            if self.fru_minor_type is not None:
                                                return True

                                            if self.hw_version is not None:
                                                return True

                                            if self.hwid is not None:
                                                return True

                                            if self.idprom_format_rev is not None:
                                                return True

                                            if self.mac_add_blk_size1 is not None:
                                                return True

                                            if self.mac_add_blk_size2 is not None:
                                                return True

                                            if self.mac_add_blk_size3 is not None:
                                                return True

                                            if self.mac_add_blk_size4 is not None:
                                                return True

                                            if self.manu_test_data is not None:
                                                return True

                                            if self.mfg_bits is not None:
                                                return True

                                            if self.mfg_deviation is not None:
                                                return True

                                            if self.oem_string is not None:
                                                return True

                                            if self.part_number is not None:
                                                return True

                                            if self.part_revision is not None:
                                                return True

                                            if self.pca_num is not None:
                                                return True

                                            if self.pcavid is not None:
                                                return True

                                            if self.pcb_serial_num is not None:
                                                return True

                                            if self.pid is not None:
                                                return True

                                            if self.power_consumption is not None:
                                                return True

                                            if self.power_supply_type is not None:
                                                return True

                                            if self.product_id is not None:
                                                return True

                                            if self.rma is not None and self.rma._has_data():
                                                return True

                                            if self.rma_code is not None:
                                                return True

                                            if self.serial_number is not None:
                                                return True

                                            if self.snmpoid is not None:
                                                return True

                                            if self.top_assem_part_num is not None:
                                                return True

                                            if self.top_assem_vid is not None:
                                                return True

                                            if self.udi_description is not None:
                                                return True

                                            if self.udi_name is not None:
                                                return True

                                            if self.vid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.eeprom is not None and self.eeprom._has_data():
                                            return True

                                        if self.has_eeprom is not None:
                                            return True

                                        if self.inv_card_type is not None:
                                            return True

                                        if self.opaque_data is not None:
                                            return True

                                        if self.opaque_data_size is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                        return True

                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                        return True

                                    if self.fru_info is not None and self.fru_info._has_data():
                                        return True

                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                        return True

                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                        return True

                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                        return True

                                    if self.module_done is not None:
                                        return True

                                    if self.node_id is not None:
                                        return True

                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                        return True

                                    if self.threshold is not None and self.threshold._has_data():
                                        return True

                                    if self.vm_done is not None:
                                        return True

                                    if self.vm_node_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1.Attributes']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.name is None:
                                    raise YPYModelError('Key property name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi1[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.name is not None:
                                    return True

                                if self.attributes is not None and self.attributes._has_data():
                                    return True

                                if self.tsi2s is not None and self.tsi2s._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S.Tsi1']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi1s'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tsi1 is not None:
                                for child_ref in self.tsi1:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Tsi1S']['meta_info']


                    class Attributes(object):
                        """
                        Attributes
                        
                        .. attribute:: env_sensor_info
                        
                        	Environment sensor info
                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfo>`
                        
                        .. attribute:: env_sensor_info_xml
                        
                        	Environment sensor info XML
                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfoXml>`
                        
                        .. attribute:: fru_info
                        
                        	Inventory EDM FRU info
                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.FruInfo>`
                        
                        .. attribute:: inv_asset_bag
                        
                        	Inventory Asset Bag
                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvAssetBag>`
                        
                        .. attribute:: inv_basic_bag
                        
                        	Inventory Basic Bag
                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvBasicBag>`
                        
                        .. attribute:: inv_eeprom_info
                        
                        	Inventory EDM EEPROM Information Bag
                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvEepromInfo>`
                        
                        .. attribute:: module_done
                        
                        	Inventory EDM Module Done Tuple
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**default value**\: 1
                        
                        .. attribute:: node_id
                        
                        	Node ID Tuple
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwg_info
                        
                        	Inventory EDM PWG info
                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.PwgInfo>`
                        
                        .. attribute:: threshold
                        
                        	Threshold
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold>`
                        
                        .. attribute:: vm_done
                        
                        	VM Done Tuple
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: vm_node_id
                        
                        	VM Node ID Tuple
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.env_sensor_info = Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfo()
                            self.env_sensor_info.parent = self
                            self.env_sensor_info_xml = Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfoXml()
                            self.env_sensor_info_xml.parent = self
                            self.fru_info = Inventory.Racks.Rack.Powershelf.Slot.Attributes.FruInfo()
                            self.fru_info.parent = self
                            self.inv_asset_bag = Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvAssetBag()
                            self.inv_asset_bag.parent = self
                            self.inv_basic_bag = Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvBasicBag()
                            self.inv_basic_bag.parent = self
                            self.inv_eeprom_info = Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvEepromInfo()
                            self.inv_eeprom_info.parent = self
                            self.module_done = None
                            self.node_id = None
                            self.pwg_info = Inventory.Racks.Rack.Powershelf.Slot.Attributes.PwgInfo()
                            self.pwg_info.parent = self
                            self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold()
                            self.threshold.parent = self
                            self.vm_done = None
                            self.vm_node_id = None


                        class EnvSensorInfo(object):
                            """
                            Environment sensor info
                            
                            .. attribute:: age_time_stamp
                            
                            	Age of the sensor value; set to the current time if directly access the value from sensor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: alarm_type
                            
                            	Indicates threshold violation
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: data_type
                            
                            	Sensor data type enums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: device_description
                            
                            	Device Name
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: device_id
                            
                            	Identifier for this device
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: field_validity_bitmap
                            
                            	Sensor valid bitmap
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: precision
                            
                            	Sensor precision range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: scale
                            
                            	Sensor scale enums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status
                            
                            	Sensor operation state enums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: units
                            
                            	Units of variable being read
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: update_rate
                            
                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: value
                            
                            	Current reading of sensor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.age_time_stamp = None
                                self.alarm_type = None
                                self.data_type = None
                                self.device_description = None
                                self.device_id = None
                                self.field_validity_bitmap = None
                                self.precision = None
                                self.scale = None
                                self.status = None
                                self.units = None
                                self.update_rate = None
                                self.value = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.age_time_stamp is not None:
                                    return True

                                if self.alarm_type is not None:
                                    return True

                                if self.data_type is not None:
                                    return True

                                if self.device_description is not None:
                                    return True

                                if self.device_id is not None:
                                    return True

                                if self.field_validity_bitmap is not None:
                                    return True

                                if self.precision is not None:
                                    return True

                                if self.scale is not None:
                                    return True

                                if self.status is not None:
                                    return True

                                if self.units is not None:
                                    return True

                                if self.update_rate is not None:
                                    return True

                                if self.value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfo']['meta_info']


                        class PwgInfo(object):
                            """
                            Inventory EDM PWG info
                            
                            .. attribute:: power_group_available_current
                            
                            	available current
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_group_drawn_current
                            
                            	drawn current
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_group_power_units
                            
                            	power units
                            	**type**\:  str
                            
                            .. attribute:: power_group_redundancy_mode
                            
                            	redundancy mode
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.power_group_available_current = None
                                self.power_group_drawn_current = None
                                self.power_group_power_units = None
                                self.power_group_redundancy_mode = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.power_group_available_current is not None:
                                    return True

                                if self.power_group_drawn_current is not None:
                                    return True

                                if self.power_group_power_units is not None:
                                    return True

                                if self.power_group_redundancy_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.PwgInfo']['meta_info']


                        class EnvSensorInfoXml(object):
                            """
                            Environment sensor info XML
                            
                            .. attribute:: data_type
                            
                            	Sensor data type
                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                            
                            .. attribute:: description
                            
                            	Device Name
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: status
                            
                            	Sensor operation state
                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                            
                            .. attribute:: threshold
                            
                            	Threshold information
                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfoXml.Threshold>`
                            
                            .. attribute:: units
                            
                            	Units of variable being read
                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                            
                            .. attribute:: update_rate
                            
                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: value
                            
                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.data_type = None
                                self.description = None
                                self.status = None
                                self.threshold = Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfoXml.Threshold()
                                self.threshold.parent = self
                                self.units = None
                                self.update_rate = None
                                self.value = None


                            class Threshold(object):
                                """
                                Threshold information
                                
                                .. attribute:: threshold_array
                                
                                	Array of threshold
                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.threshold_array = YList()
                                    self.threshold_array.parent = self
                                    self.threshold_array.name = 'threshold_array'


                                class ThresholdArray(object):
                                    """
                                    Array of threshold
                                    
                                    .. attribute:: threshold_name
                                    
                                    	Threshold name
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_name = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_name is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.threshold_array is not None:
                                        for child_ref in self.threshold_array:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.data_type is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.status is not None:
                                    return True

                                if self.threshold is not None and self.threshold._has_data():
                                    return True

                                if self.units is not None:
                                    return True

                                if self.update_rate is not None:
                                    return True

                                if self.value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.EnvSensorInfoXml']['meta_info']


                        class InvAssetBag(object):
                            """
                            Inventory Asset Bag
                            
                            .. attribute:: manufacturer_assembly_number
                            
                            	Manufacture Assembly number
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_assembly_revision
                            
                            	Manufacture assembly revision
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_common_language_equipment_identifier
                            
                            	Common Language Equipment           Identifier number
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_firmware_identifier
                            
                            	
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_software_identifier
                            
                            	
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: original_equipment_manufacturer_string
                            
                            	String containing OEM information           if applicable
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: part_number
                            
                            	
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.manufacturer_assembly_number = None
                                self.manufacturer_assembly_revision = None
                                self.manufacturer_common_language_equipment_identifier = None
                                self.manufacturer_firmware_identifier = None
                                self.manufacturer_software_identifier = None
                                self.original_equipment_manufacturer_string = None
                                self.part_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.manufacturer_assembly_number is not None:
                                    return True

                                if self.manufacturer_assembly_revision is not None:
                                    return True

                                if self.manufacturer_common_language_equipment_identifier is not None:
                                    return True

                                if self.manufacturer_firmware_identifier is not None:
                                    return True

                                if self.manufacturer_software_identifier is not None:
                                    return True

                                if self.original_equipment_manufacturer_string is not None:
                                    return True

                                if self.part_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvAssetBag']['meta_info']


                        class Threshold(object):
                            """
                            Threshold
                            
                            .. attribute:: critical_hi
                            
                            	Critical High
                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalHi>`
                            
                            .. attribute:: critical_lo
                            
                            	Critical Low
                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalLo>`
                            
                            .. attribute:: major_hi
                            
                            	Major High
                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorHi>`
                            
                            .. attribute:: major_lo
                            
                            	Major Low
                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorLo>`
                            
                            .. attribute:: minor_hi
                            
                            	Minor High
                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorHi>`
                            
                            .. attribute:: minor_lo
                            
                            	Minor Low
                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorLo>`
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.critical_hi = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalHi()
                                self.critical_hi.parent = self
                                self.critical_lo = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalLo()
                                self.critical_lo.parent = self
                                self.major_hi = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorHi()
                                self.major_hi.parent = self
                                self.major_lo = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorLo()
                                self.major_lo.parent = self
                                self.minor_hi = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorHi()
                                self.minor_hi.parent = self
                                self.minor_lo = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorLo()
                                self.minor_lo.parent = self


                            class MajorLo(object):
                                """
                                Major Low
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorLo.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorLo.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorLo']['meta_info']


                            class CriticalHi(object):
                                """
                                Critical High
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalHi.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalHi.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalHi']['meta_info']


                            class MinorHi(object):
                                """
                                Minor High
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorHi.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorHi.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorHi']['meta_info']


                            class MajorHi(object):
                                """
                                Major High
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorHi.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorHi.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MajorHi']['meta_info']


                            class CriticalLo(object):
                                """
                                Critical Low
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalLo.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalLo.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.CriticalLo']['meta_info']


                            class MinorLo(object):
                                """
                                Minor Low
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorLo.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorLo.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold.MinorLo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.critical_hi is not None and self.critical_hi._has_data():
                                    return True

                                if self.critical_lo is not None and self.critical_lo._has_data():
                                    return True

                                if self.major_hi is not None and self.major_hi._has_data():
                                    return True

                                if self.major_lo is not None and self.major_lo._has_data():
                                    return True

                                if self.minor_hi is not None and self.minor_hi._has_data():
                                    return True

                                if self.minor_lo is not None and self.minor_lo._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.Threshold']['meta_info']


                        class FruInfo(object):
                            """
                            Inventory EDM FRU info
                            
                            .. attribute:: card_administrative_state
                            
                            	card admin state\: shutdown or not
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: card_monitor_state
                            
                            	card is monitored by a manager or left unmonitored
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: card_operational_state
                            
                            	card operation state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: card_reset_reason
                            
                            	card reset reason enum
                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                            
                            .. attribute:: card_up_time
                            
                            	card up time
                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.FruInfo.CardUpTime>`
                            
                            .. attribute:: last_operational_state_change
                            
                            	last card oper change state
                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.FruInfo.LastOperationalStateChange>`
                            
                            .. attribute:: power_administrative_state
                            
                            	power admin state\: up or down
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_current_measurement
                            
                            	power current\: not implemented
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_operational_state
                            
                            	Power operation state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.card_administrative_state = None
                                self.card_monitor_state = None
                                self.card_operational_state = None
                                self.card_reset_reason = None
                                self.card_up_time = Inventory.Racks.Rack.Powershelf.Slot.Attributes.FruInfo.CardUpTime()
                                self.card_up_time.parent = self
                                self.last_operational_state_change = Inventory.Racks.Rack.Powershelf.Slot.Attributes.FruInfo.LastOperationalStateChange()
                                self.last_operational_state_change.parent = self
                                self.power_administrative_state = None
                                self.power_current_measurement = None
                                self.power_operational_state = None


                            class LastOperationalStateChange(object):
                                """
                                last card oper change state
                                
                                .. attribute:: time_in_nano_seconds
                                
                                	Time Value in Nano\-seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: time_in_seconds
                                
                                	Time Value in Seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.time_in_nano_seconds = None
                                    self.time_in_seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.time_in_nano_seconds is not None:
                                        return True

                                    if self.time_in_seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                            class CardUpTime(object):
                                """
                                card up time
                                
                                .. attribute:: time_in_nano_seconds
                                
                                	Time Value in Nano\-seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: time_in_seconds
                                
                                	Time Value in Seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.time_in_nano_seconds = None
                                    self.time_in_seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.time_in_nano_seconds is not None:
                                        return True

                                    if self.time_in_seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.FruInfo.CardUpTime']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.card_administrative_state is not None:
                                    return True

                                if self.card_monitor_state is not None:
                                    return True

                                if self.card_operational_state is not None:
                                    return True

                                if self.card_reset_reason is not None:
                                    return True

                                if self.card_up_time is not None and self.card_up_time._has_data():
                                    return True

                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                    return True

                                if self.power_administrative_state is not None:
                                    return True

                                if self.power_current_measurement is not None:
                                    return True

                                if self.power_operational_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.FruInfo']['meta_info']


                        class InvBasicBag(object):
                            """
                            Inventory Basic Bag
                            
                            .. attribute:: alias
                            
                            	useful for storing an entity alias 
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: asset_id_str
                            
                            	asset Identification string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: asset_identification
                            
                            	asset Identification
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ceport
                            
                            	1 if ce port found, 0 if not
                            	**type**\:  bool
                            
                            .. attribute:: chip_hardware_revision
                            
                            	chip module hw revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: composite_class_code
                            
                            	Major&minor class of the entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: description
                            
                            	describes in user\-readable terms       what the entity in question does
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: environmental_monitor_path
                            
                            	sysdb name of sensor in the envmon EDM
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: firmware_revision
                            
                            	firmware revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: group_flag
                            
                            	indicates if this entity is group       or not
                            	**type**\:  bool
                            
                            .. attribute:: hardware_revision
                            
                            	hw revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: is_field_replaceable_unit
                            
                            	1 if Field Replaceable Unit 0, if not
                            	**type**\:  bool
                            
                            .. attribute:: manufacturer_asset_tags
                            
                            	Manufacture Asset Tags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: manufacturer_name
                            
                            	manufacturer's name
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: memory_size
                            
                            	Size of memory associated with       the entity where applicable
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: model_name
                            
                            	model name
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: name
                            
                            	name string for the entity
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: new_deviation_number
                            
                            	integer value for New Deviation Number 0x88
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: physical_layer_interface_module_type
                            
                            	integer value for plim type if     applicable to this entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: redundancystate
                            
                            	integer value for Redundancy State if     applicable to this entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: serial_number
                            
                            	serial number
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: software_revision
                            
                            	software revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: unique_id
                            
                            	Unique id for an entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: unrecognized_fru
                            
                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                            	**type**\:  bool
                            
                            .. attribute:: vendor_type
                            
                            	maps to the vendor OID string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: xr_scoped
                            
                            	1 if xr scoped, 0 if not
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.alias = None
                                self.asset_id_str = None
                                self.asset_identification = None
                                self.ceport = None
                                self.chip_hardware_revision = None
                                self.composite_class_code = None
                                self.description = None
                                self.environmental_monitor_path = None
                                self.firmware_revision = None
                                self.group_flag = None
                                self.hardware_revision = None
                                self.is_field_replaceable_unit = None
                                self.manufacturer_asset_tags = None
                                self.manufacturer_name = None
                                self.memory_size = None
                                self.model_name = None
                                self.name = None
                                self.new_deviation_number = None
                                self.physical_layer_interface_module_type = None
                                self.redundancystate = None
                                self.serial_number = None
                                self.software_revision = None
                                self.unique_id = None
                                self.unrecognized_fru = None
                                self.vendor_type = None
                                self.xr_scoped = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.alias is not None:
                                    return True

                                if self.asset_id_str is not None:
                                    return True

                                if self.asset_identification is not None:
                                    return True

                                if self.ceport is not None:
                                    return True

                                if self.chip_hardware_revision is not None:
                                    return True

                                if self.composite_class_code is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.environmental_monitor_path is not None:
                                    return True

                                if self.firmware_revision is not None:
                                    return True

                                if self.group_flag is not None:
                                    return True

                                if self.hardware_revision is not None:
                                    return True

                                if self.is_field_replaceable_unit is not None:
                                    return True

                                if self.manufacturer_asset_tags is not None:
                                    return True

                                if self.manufacturer_name is not None:
                                    return True

                                if self.memory_size is not None:
                                    return True

                                if self.model_name is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.new_deviation_number is not None:
                                    return True

                                if self.physical_layer_interface_module_type is not None:
                                    return True

                                if self.redundancystate is not None:
                                    return True

                                if self.serial_number is not None:
                                    return True

                                if self.software_revision is not None:
                                    return True

                                if self.unique_id is not None:
                                    return True

                                if self.unrecognized_fru is not None:
                                    return True

                                if self.vendor_type is not None:
                                    return True

                                if self.xr_scoped is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvBasicBag']['meta_info']


                        class InvEepromInfo(object):
                            """
                            Inventory EDM EEPROM Information Bag
                            
                            .. attribute:: description
                            
                            	A textual description of physical entity
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: eeprom
                            
                            	EEPROM data not from hex data
                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvEepromInfo.Eeprom>`
                            
                            .. attribute:: has_eeprom
                            
                            	use eeprom instead of opaque data
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inv_card_type
                            
                            	Inventory card type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: opaque_data
                            
                            	EEPROM hex data
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: opaque_data_size
                            
                            	size of the EEPROM hex data
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.eeprom = Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvEepromInfo.Eeprom()
                                self.eeprom.parent = self
                                self.has_eeprom = None
                                self.inv_card_type = None
                                self.opaque_data = None
                                self.opaque_data_size = None


                            class Eeprom(object):
                                """
                                EEPROM data not from hex data
                                
                                .. attribute:: asset_alias
                                
                                	Asset Alias
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: asset_id
                                
                                	Asset ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address1
                                
                                	Base Mac Address #1
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address2
                                
                                	Base Mac Address #2
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address3
                                
                                	Base Mac Address #3
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address4
                                
                                	Base Mac Address #4
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_checksum
                                
                                	Block Checksum
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_count
                                
                                	Block Count
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_length
                                
                                	Block Length
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_signature
                                
                                	Block Signature
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_version
                                
                                	Block Version
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: chassis_sid
                                
                                	Chassis serial number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: clei
                                
                                	Common Language Equipment Identifier (CLEI) code
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: controller_family
                                
                                	Controller family
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: controller_type
                                
                                	Controller type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: description
                                
                                	A textual description of physical entity
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num1
                                
                                	Deviation Number # 1
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num2
                                
                                	Deviation Number # 2
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num3
                                
                                	Deviation Number # 3
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num4
                                
                                	Deviation Number # 4
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num5
                                
                                	Deviation Number # 5
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num6
                                
                                	Deviation Number # 6
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num7
                                
                                	Deviation Number # 7
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: eci
                                
                                	Equipment Catalog Item (ECI) number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: eeprom_size
                                
                                	EEPROM Size
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: engineer_use
                                
                                	Engineer Use
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: fru_major_type
                                
                                	FRU Major Type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: fru_minor_type
                                
                                	FRU Minor Type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: hw_version
                                
                                	Hardware Version
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: hwid
                                
                                	Hardware Revision
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: idprom_format_rev
                                
                                	IDPROM Format Revision
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size1
                                
                                	Mac Address Block Size #1
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size2
                                
                                	Mac Address Block Size #2
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size3
                                
                                	Mac Address Block Size #3
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size4
                                
                                	Mac Address Block Size #4
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: manu_test_data
                                
                                	Manufacturing Test Data
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mfg_bits
                                
                                	MFG Bits
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mfg_deviation
                                
                                	MFG Deviation
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: oem_string
                                
                                	OEM String
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: part_number
                                
                                	Part Number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: part_revision
                                
                                	Part Revision
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pca_num
                                
                                	PCA number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pcavid
                                
                                	PCA revision ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pcb_serial_num
                                
                                	PCB Serial Number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pid
                                
                                	Product ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: power_consumption
                                
                                	Power Consumption
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: power_supply_type
                                
                                	Power Supply Type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: product_id
                                
                                	Product ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: rma
                                
                                	RMA Data
                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvEepromInfo.Eeprom.Rma>`
                                
                                .. attribute:: rma_code
                                
                                	RMA Code
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: serial_number
                                
                                	Serial Number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: snmpoid
                                
                                	SNMP OID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: top_assem_part_num
                                
                                	Top assembly part number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: top_assem_vid
                                
                                	Top assembly revision number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: udi_description
                                
                                	UDI description
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: udi_name
                                
                                	UDI name
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: vid
                                
                                	Version ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.asset_alias = None
                                    self.asset_id = None
                                    self.base_mac_address1 = None
                                    self.base_mac_address2 = None
                                    self.base_mac_address3 = None
                                    self.base_mac_address4 = None
                                    self.block_checksum = None
                                    self.block_count = None
                                    self.block_length = None
                                    self.block_signature = None
                                    self.block_version = None
                                    self.chassis_sid = None
                                    self.clei = None
                                    self.controller_family = None
                                    self.controller_type = None
                                    self.description = None
                                    self.dev_num1 = None
                                    self.dev_num2 = None
                                    self.dev_num3 = None
                                    self.dev_num4 = None
                                    self.dev_num5 = None
                                    self.dev_num6 = None
                                    self.dev_num7 = None
                                    self.eci = None
                                    self.eeprom_size = None
                                    self.engineer_use = None
                                    self.fru_major_type = None
                                    self.fru_minor_type = None
                                    self.hw_version = None
                                    self.hwid = None
                                    self.idprom_format_rev = None
                                    self.mac_add_blk_size1 = None
                                    self.mac_add_blk_size2 = None
                                    self.mac_add_blk_size3 = None
                                    self.mac_add_blk_size4 = None
                                    self.manu_test_data = None
                                    self.mfg_bits = None
                                    self.mfg_deviation = None
                                    self.oem_string = None
                                    self.part_number = None
                                    self.part_revision = None
                                    self.pca_num = None
                                    self.pcavid = None
                                    self.pcb_serial_num = None
                                    self.pid = None
                                    self.power_consumption = None
                                    self.power_supply_type = None
                                    self.product_id = None
                                    self.rma = Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvEepromInfo.Eeprom.Rma()
                                    self.rma.parent = self
                                    self.rma_code = None
                                    self.serial_number = None
                                    self.snmpoid = None
                                    self.top_assem_part_num = None
                                    self.top_assem_vid = None
                                    self.udi_description = None
                                    self.udi_name = None
                                    self.vid = None


                                class Rma(object):
                                    """
                                    RMA Data
                                    
                                    .. attribute:: rma_history
                                    
                                    	RMA history
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: rma_number
                                    
                                    	RMA tracking number format is N\-N\-N
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: test_history
                                    
                                    	Test history
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.rma_history = None
                                        self.rma_number = None
                                        self.test_history = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rma_history is not None:
                                            return True

                                        if self.rma_number is not None:
                                            return True

                                        if self.test_history is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.asset_alias is not None:
                                        return True

                                    if self.asset_id is not None:
                                        return True

                                    if self.base_mac_address1 is not None:
                                        return True

                                    if self.base_mac_address2 is not None:
                                        return True

                                    if self.base_mac_address3 is not None:
                                        return True

                                    if self.base_mac_address4 is not None:
                                        return True

                                    if self.block_checksum is not None:
                                        return True

                                    if self.block_count is not None:
                                        return True

                                    if self.block_length is not None:
                                        return True

                                    if self.block_signature is not None:
                                        return True

                                    if self.block_version is not None:
                                        return True

                                    if self.chassis_sid is not None:
                                        return True

                                    if self.clei is not None:
                                        return True

                                    if self.controller_family is not None:
                                        return True

                                    if self.controller_type is not None:
                                        return True

                                    if self.description is not None:
                                        return True

                                    if self.dev_num1 is not None:
                                        return True

                                    if self.dev_num2 is not None:
                                        return True

                                    if self.dev_num3 is not None:
                                        return True

                                    if self.dev_num4 is not None:
                                        return True

                                    if self.dev_num5 is not None:
                                        return True

                                    if self.dev_num6 is not None:
                                        return True

                                    if self.dev_num7 is not None:
                                        return True

                                    if self.eci is not None:
                                        return True

                                    if self.eeprom_size is not None:
                                        return True

                                    if self.engineer_use is not None:
                                        return True

                                    if self.fru_major_type is not None:
                                        return True

                                    if self.fru_minor_type is not None:
                                        return True

                                    if self.hw_version is not None:
                                        return True

                                    if self.hwid is not None:
                                        return True

                                    if self.idprom_format_rev is not None:
                                        return True

                                    if self.mac_add_blk_size1 is not None:
                                        return True

                                    if self.mac_add_blk_size2 is not None:
                                        return True

                                    if self.mac_add_blk_size3 is not None:
                                        return True

                                    if self.mac_add_blk_size4 is not None:
                                        return True

                                    if self.manu_test_data is not None:
                                        return True

                                    if self.mfg_bits is not None:
                                        return True

                                    if self.mfg_deviation is not None:
                                        return True

                                    if self.oem_string is not None:
                                        return True

                                    if self.part_number is not None:
                                        return True

                                    if self.part_revision is not None:
                                        return True

                                    if self.pca_num is not None:
                                        return True

                                    if self.pcavid is not None:
                                        return True

                                    if self.pcb_serial_num is not None:
                                        return True

                                    if self.pid is not None:
                                        return True

                                    if self.power_consumption is not None:
                                        return True

                                    if self.power_supply_type is not None:
                                        return True

                                    if self.product_id is not None:
                                        return True

                                    if self.rma is not None and self.rma._has_data():
                                        return True

                                    if self.rma_code is not None:
                                        return True

                                    if self.serial_number is not None:
                                        return True

                                    if self.snmpoid is not None:
                                        return True

                                    if self.top_assem_part_num is not None:
                                        return True

                                    if self.top_assem_vid is not None:
                                        return True

                                    if self.udi_description is not None:
                                        return True

                                    if self.udi_name is not None:
                                        return True

                                    if self.vid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvEepromInfo.Eeprom']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.eeprom is not None and self.eeprom._has_data():
                                    return True

                                if self.has_eeprom is not None:
                                    return True

                                if self.inv_card_type is not None:
                                    return True

                                if self.opaque_data is not None:
                                    return True

                                if self.opaque_data_size is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes.InvEepromInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                return True

                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                return True

                            if self.fru_info is not None and self.fru_info._has_data():
                                return True

                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                return True

                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                return True

                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                return True

                            if self.module_done is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.pwg_info is not None and self.pwg_info._has_data():
                                return True

                            if self.threshold is not None and self.threshold._has_data():
                                return True

                            if self.vm_done is not None:
                                return True

                            if self.vm_node_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot.Attributes']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.name is None:
                            raise YPYModelError('Key property name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:slot[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.name is not None:
                            return True

                        if self.attributes is not None and self.attributes._has_data():
                            return True

                        if self.tsi1s is not None and self.tsi1s._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Powershelf.Slot']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:powershelf'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.slot is not None:
                        for child_ref in self.slot:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                    return meta._meta_table['Inventory.Racks.Rack.Powershelf']['meta_info']


            class Fantray(object):
                """
                Fantray information
                
                .. attribute:: slot
                
                	Slot number
                	**type**\: list of    :py:class:`Slot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot>`
                
                

                """

                _prefix = 'invmgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.slot = YList()
                    self.slot.parent = self
                    self.slot.name = 'slot'


                class Slot(object):
                    """
                    Slot number
                    
                    .. attribute:: name  <key>
                    
                    	Slot name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: attributes
                    
                    	Attributes
                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes>`
                    
                    .. attribute:: tsi1s
                    
                    	Entity Level 1
                    	**type**\:   :py:class:`Tsi1S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S>`
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.name = None
                        self.attributes = Inventory.Racks.Rack.Fantray.Slot.Attributes()
                        self.attributes.parent = self
                        self.tsi1s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S()
                        self.tsi1s.parent = self


                    class Tsi1S(object):
                        """
                        Entity Level 1
                        
                        .. attribute:: tsi1
                        
                        	TSI1
                        	**type**\: list of    :py:class:`Tsi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1>`
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.tsi1 = YList()
                            self.tsi1.parent = self
                            self.tsi1.name = 'tsi1'


                        class Tsi1(object):
                            """
                            TSI1
                            
                            .. attribute:: name  <key>
                            
                            	TSI1
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: attributes
                            
                            	Attributes
                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes>`
                            
                            .. attribute:: tsi2s
                            
                            	Entity Level 2
                            	**type**\:   :py:class:`Tsi2S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S>`
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.name = None
                                self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes()
                                self.attributes.parent = self
                                self.tsi2s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S()
                                self.tsi2s.parent = self


                            class Tsi2S(object):
                                """
                                Entity Level 2
                                
                                .. attribute:: tsi2
                                
                                	TSI2
                                	**type**\: list of    :py:class:`Tsi2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tsi2 = YList()
                                    self.tsi2.parent = self
                                    self.tsi2.name = 'tsi2'


                                class Tsi2(object):
                                    """
                                    TSI2
                                    
                                    .. attribute:: name  <key>
                                    
                                    	TSI2
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: attributes
                                    
                                    	Attributes
                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes>`
                                    
                                    .. attribute:: tsi3s
                                    
                                    	Entity Level 3
                                    	**type**\:   :py:class:`Tsi3S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S>`
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.name = None
                                        self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes()
                                        self.attributes.parent = self
                                        self.tsi3s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S()
                                        self.tsi3s.parent = self


                                    class Tsi3S(object):
                                        """
                                        Entity Level 3
                                        
                                        .. attribute:: tsi3
                                        
                                        	TSI3
                                        	**type**\: list of    :py:class:`Tsi3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tsi3 = YList()
                                            self.tsi3.parent = self
                                            self.tsi3.name = 'tsi3'


                                        class Tsi3(object):
                                            """
                                            TSI3
                                            
                                            .. attribute:: name  <key>
                                            
                                            	TSI3
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: attributes
                                            
                                            	Attributes
                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes>`
                                            
                                            .. attribute:: tsi4s
                                            
                                            	Entity Level 4
                                            	**type**\:   :py:class:`Tsi4S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S>`
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.name = None
                                                self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes()
                                                self.attributes.parent = self
                                                self.tsi4s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S()
                                                self.tsi4s.parent = self


                                            class Tsi4S(object):
                                                """
                                                Entity Level 4
                                                
                                                .. attribute:: tsi4
                                                
                                                	TSI4
                                                	**type**\: list of    :py:class:`Tsi4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.tsi4 = YList()
                                                    self.tsi4.parent = self
                                                    self.tsi4.name = 'tsi4'


                                                class Tsi4(object):
                                                    """
                                                    TSI4
                                                    
                                                    .. attribute:: name  <key>
                                                    
                                                    	TSI4
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: attributes
                                                    
                                                    	Attributes
                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes>`
                                                    
                                                    .. attribute:: tsi5s
                                                    
                                                    	Entity Level 5
                                                    	**type**\:   :py:class:`Tsi5S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.name = None
                                                        self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes()
                                                        self.attributes.parent = self
                                                        self.tsi5s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S()
                                                        self.tsi5s.parent = self


                                                    class Tsi5S(object):
                                                        """
                                                        Entity Level 5
                                                        
                                                        .. attribute:: tsi5
                                                        
                                                        	TSI5
                                                        	**type**\: list of    :py:class:`Tsi5 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.tsi5 = YList()
                                                            self.tsi5.parent = self
                                                            self.tsi5.name = 'tsi5'


                                                        class Tsi5(object):
                                                            """
                                                            TSI5
                                                            
                                                            .. attribute:: name  <key>
                                                            
                                                            	TSI5
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                            
                                                            .. attribute:: attributes
                                                            
                                                            	Attributes
                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes>`
                                                            
                                                            .. attribute:: tsi6s
                                                            
                                                            	Entity Level 6
                                                            	**type**\:   :py:class:`Tsi6S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.name = None
                                                                self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes()
                                                                self.attributes.parent = self
                                                                self.tsi6s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S()
                                                                self.tsi6s.parent = self


                                                            class Tsi6S(object):
                                                                """
                                                                Entity Level 6
                                                                
                                                                .. attribute:: tsi6
                                                                
                                                                	TSI6
                                                                	**type**\: list of    :py:class:`Tsi6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.tsi6 = YList()
                                                                    self.tsi6.parent = self
                                                                    self.tsi6.name = 'tsi6'


                                                                class Tsi6(object):
                                                                    """
                                                                    TSI6
                                                                    
                                                                    .. attribute:: name  <key>
                                                                    
                                                                    	TSI6
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                    
                                                                    .. attribute:: attributes
                                                                    
                                                                    	Attributes
                                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes>`
                                                                    
                                                                    .. attribute:: tsi7s
                                                                    
                                                                    	Entity Level 7
                                                                    	**type**\:   :py:class:`Tsi7S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.name = None
                                                                        self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes()
                                                                        self.attributes.parent = self
                                                                        self.tsi7s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S()
                                                                        self.tsi7s.parent = self


                                                                    class Tsi7S(object):
                                                                        """
                                                                        Entity Level 7
                                                                        
                                                                        .. attribute:: tsi7
                                                                        
                                                                        	TSI7
                                                                        	**type**\: list of    :py:class:`Tsi7 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.tsi7 = YList()
                                                                            self.tsi7.parent = self
                                                                            self.tsi7.name = 'tsi7'


                                                                        class Tsi7(object):
                                                                            """
                                                                            TSI7
                                                                            
                                                                            .. attribute:: name  <key>
                                                                            
                                                                            	TSI7
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                            
                                                                            .. attribute:: attributes
                                                                            
                                                                            	Attributes
                                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes>`
                                                                            
                                                                            .. attribute:: tsi8s
                                                                            
                                                                            	Entity Level 8
                                                                            	**type**\:   :py:class:`Tsi8S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.name = None
                                                                                self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes()
                                                                                self.attributes.parent = self
                                                                                self.tsi8s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S()
                                                                                self.tsi8s.parent = self


                                                                            class Tsi8S(object):
                                                                                """
                                                                                Entity Level 8
                                                                                
                                                                                .. attribute:: tsi8
                                                                                
                                                                                	TSI8
                                                                                	**type**\: list of    :py:class:`Tsi8 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.tsi8 = YList()
                                                                                    self.tsi8.parent = self
                                                                                    self.tsi8.name = 'tsi8'


                                                                                class Tsi8(object):
                                                                                    """
                                                                                    TSI8
                                                                                    
                                                                                    .. attribute:: name  <key>
                                                                                    
                                                                                    	TSI8
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                    
                                                                                    .. attribute:: attributes
                                                                                    
                                                                                    	Attributes
                                                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes>`
                                                                                    
                                                                                    .. attribute:: tsi9s
                                                                                    
                                                                                    	Entity Level 9
                                                                                    	**type**\:   :py:class:`Tsi9S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S>`
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.name = None
                                                                                        self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes()
                                                                                        self.attributes.parent = self
                                                                                        self.tsi9s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S()
                                                                                        self.tsi9s.parent = self


                                                                                    class Tsi9S(object):
                                                                                        """
                                                                                        Entity Level 9
                                                                                        
                                                                                        .. attribute:: tsi9
                                                                                        
                                                                                        	TSI9
                                                                                        	**type**\: list of    :py:class:`Tsi9 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.tsi9 = YList()
                                                                                            self.tsi9.parent = self
                                                                                            self.tsi9.name = 'tsi9'


                                                                                        class Tsi9(object):
                                                                                            """
                                                                                            TSI9
                                                                                            
                                                                                            .. attribute:: name  <key>
                                                                                            
                                                                                            	TSI9
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                            
                                                                                            .. attribute:: attributes
                                                                                            
                                                                                            	Attributes
                                                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes>`
                                                                                            
                                                                                            .. attribute:: tsi10s
                                                                                            
                                                                                            	Entity Level 10
                                                                                            	**type**\:   :py:class:`Tsi10S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S>`
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.name = None
                                                                                                self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes()
                                                                                                self.attributes.parent = self
                                                                                                self.tsi10s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S()
                                                                                                self.tsi10s.parent = self


                                                                                            class Tsi10S(object):
                                                                                                """
                                                                                                Entity Level 10
                                                                                                
                                                                                                .. attribute:: tsi10
                                                                                                
                                                                                                	TSI10
                                                                                                	**type**\: list of    :py:class:`Tsi10 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.tsi10 = YList()
                                                                                                    self.tsi10.parent = self
                                                                                                    self.tsi10.name = 'tsi10'


                                                                                                class Tsi10(object):
                                                                                                    """
                                                                                                    TSI10
                                                                                                    
                                                                                                    .. attribute:: name  <key>
                                                                                                    
                                                                                                    	TSI10
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                                    
                                                                                                    .. attribute:: attributes
                                                                                                    
                                                                                                    	Attributes
                                                                                                    	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes>`
                                                                                                    
                                                                                                    .. attribute:: tsi11s
                                                                                                    
                                                                                                    	Entity Level 11
                                                                                                    	**type**\:   :py:class:`Tsi11S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S>`
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.name = None
                                                                                                        self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes()
                                                                                                        self.attributes.parent = self
                                                                                                        self.tsi11s = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S()
                                                                                                        self.tsi11s.parent = self


                                                                                                    class Tsi11S(object):
                                                                                                        """
                                                                                                        Entity Level 11
                                                                                                        
                                                                                                        .. attribute:: tsi11
                                                                                                        
                                                                                                        	TSI11
                                                                                                        	**type**\: list of    :py:class:`Tsi11 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.tsi11 = YList()
                                                                                                            self.tsi11.parent = self
                                                                                                            self.tsi11.name = 'tsi11'


                                                                                                        class Tsi11(object):
                                                                                                            """
                                                                                                            TSI11
                                                                                                            
                                                                                                            .. attribute:: name  <key>
                                                                                                            
                                                                                                            	TSI11
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                                                                            
                                                                                                            .. attribute:: attributes
                                                                                                            
                                                                                                            	Attributes
                                                                                                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes>`
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.name = None
                                                                                                                self.attributes = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes()
                                                                                                                self.attributes.parent = self


                                                                                                            class Attributes(object):
                                                                                                                """
                                                                                                                Attributes
                                                                                                                
                                                                                                                .. attribute:: env_sensor_info
                                                                                                                
                                                                                                                	Environment sensor info
                                                                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfo>`
                                                                                                                
                                                                                                                .. attribute:: env_sensor_info_xml
                                                                                                                
                                                                                                                	Environment sensor info XML
                                                                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml>`
                                                                                                                
                                                                                                                .. attribute:: fru_info
                                                                                                                
                                                                                                                	Inventory EDM FRU info
                                                                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo>`
                                                                                                                
                                                                                                                .. attribute:: inv_asset_bag
                                                                                                                
                                                                                                                	Inventory Asset Bag
                                                                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvAssetBag>`
                                                                                                                
                                                                                                                .. attribute:: inv_basic_bag
                                                                                                                
                                                                                                                	Inventory Basic Bag
                                                                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvBasicBag>`
                                                                                                                
                                                                                                                .. attribute:: inv_eeprom_info
                                                                                                                
                                                                                                                	Inventory EDM EEPROM Information Bag
                                                                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo>`
                                                                                                                
                                                                                                                .. attribute:: module_done
                                                                                                                
                                                                                                                	Inventory EDM Module Done Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**default value**\: 1
                                                                                                                
                                                                                                                .. attribute:: node_id
                                                                                                                
                                                                                                                	Node ID Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** 0..4294967295
                                                                                                                
                                                                                                                .. attribute:: pwg_info
                                                                                                                
                                                                                                                	Inventory EDM PWG info
                                                                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.PwgInfo>`
                                                                                                                
                                                                                                                .. attribute:: threshold
                                                                                                                
                                                                                                                	Threshold
                                                                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold>`
                                                                                                                
                                                                                                                .. attribute:: vm_done
                                                                                                                
                                                                                                                	VM Done Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                .. attribute:: vm_node_id
                                                                                                                
                                                                                                                	VM Node ID Tuple
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** 0..4294967295
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfo()
                                                                                                                    self.env_sensor_info.parent = self
                                                                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml()
                                                                                                                    self.env_sensor_info_xml.parent = self
                                                                                                                    self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo()
                                                                                                                    self.fru_info.parent = self
                                                                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvAssetBag()
                                                                                                                    self.inv_asset_bag.parent = self
                                                                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvBasicBag()
                                                                                                                    self.inv_basic_bag.parent = self
                                                                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo()
                                                                                                                    self.inv_eeprom_info.parent = self
                                                                                                                    self.module_done = None
                                                                                                                    self.node_id = None
                                                                                                                    self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.PwgInfo()
                                                                                                                    self.pwg_info.parent = self
                                                                                                                    self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold()
                                                                                                                    self.threshold.parent = self
                                                                                                                    self.vm_done = None
                                                                                                                    self.vm_node_id = None


                                                                                                                class EnvSensorInfo(object):
                                                                                                                    """
                                                                                                                    Environment sensor info
                                                                                                                    
                                                                                                                    .. attribute:: age_time_stamp
                                                                                                                    
                                                                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: alarm_type
                                                                                                                    
                                                                                                                    	Indicates threshold violation
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: data_type
                                                                                                                    
                                                                                                                    	Sensor data type enums
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: device_description
                                                                                                                    
                                                                                                                    	Device Name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: device_id
                                                                                                                    
                                                                                                                    	Identifier for this device
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: field_validity_bitmap
                                                                                                                    
                                                                                                                    	Sensor valid bitmap
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: precision
                                                                                                                    
                                                                                                                    	Sensor precision range
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: scale
                                                                                                                    
                                                                                                                    	Sensor scale enums
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: status
                                                                                                                    
                                                                                                                    	Sensor operation state enums
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: units
                                                                                                                    
                                                                                                                    	Units of variable being read
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: update_rate
                                                                                                                    
                                                                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: value
                                                                                                                    
                                                                                                                    	Current reading of sensor
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.age_time_stamp = None
                                                                                                                        self.alarm_type = None
                                                                                                                        self.data_type = None
                                                                                                                        self.device_description = None
                                                                                                                        self.device_id = None
                                                                                                                        self.field_validity_bitmap = None
                                                                                                                        self.precision = None
                                                                                                                        self.scale = None
                                                                                                                        self.status = None
                                                                                                                        self.units = None
                                                                                                                        self.update_rate = None
                                                                                                                        self.value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.age_time_stamp is not None:
                                                                                                                            return True

                                                                                                                        if self.alarm_type is not None:
                                                                                                                            return True

                                                                                                                        if self.data_type is not None:
                                                                                                                            return True

                                                                                                                        if self.device_description is not None:
                                                                                                                            return True

                                                                                                                        if self.device_id is not None:
                                                                                                                            return True

                                                                                                                        if self.field_validity_bitmap is not None:
                                                                                                                            return True

                                                                                                                        if self.precision is not None:
                                                                                                                            return True

                                                                                                                        if self.scale is not None:
                                                                                                                            return True

                                                                                                                        if self.status is not None:
                                                                                                                            return True

                                                                                                                        if self.units is not None:
                                                                                                                            return True

                                                                                                                        if self.update_rate is not None:
                                                                                                                            return True

                                                                                                                        if self.value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfo']['meta_info']


                                                                                                                class PwgInfo(object):
                                                                                                                    """
                                                                                                                    Inventory EDM PWG info
                                                                                                                    
                                                                                                                    .. attribute:: power_group_available_current
                                                                                                                    
                                                                                                                    	available current
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_group_drawn_current
                                                                                                                    
                                                                                                                    	drawn current
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_group_power_units
                                                                                                                    
                                                                                                                    	power units
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    .. attribute:: power_group_redundancy_mode
                                                                                                                    
                                                                                                                    	redundancy mode
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.power_group_available_current = None
                                                                                                                        self.power_group_drawn_current = None
                                                                                                                        self.power_group_power_units = None
                                                                                                                        self.power_group_redundancy_mode = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.power_group_available_current is not None:
                                                                                                                            return True

                                                                                                                        if self.power_group_drawn_current is not None:
                                                                                                                            return True

                                                                                                                        if self.power_group_power_units is not None:
                                                                                                                            return True

                                                                                                                        if self.power_group_redundancy_mode is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.PwgInfo']['meta_info']


                                                                                                                class EnvSensorInfoXml(object):
                                                                                                                    """
                                                                                                                    Environment sensor info XML
                                                                                                                    
                                                                                                                    .. attribute:: data_type
                                                                                                                    
                                                                                                                    	Sensor data type
                                                                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: description
                                                                                                                    
                                                                                                                    	Device Name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: status
                                                                                                                    
                                                                                                                    	Sensor operation state
                                                                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: threshold
                                                                                                                    
                                                                                                                    	Threshold information
                                                                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                                                    
                                                                                                                    .. attribute:: units
                                                                                                                    
                                                                                                                    	Units of variable being read
                                                                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: update_rate
                                                                                                                    
                                                                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: value
                                                                                                                    
                                                                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.data_type = None
                                                                                                                        self.description = None
                                                                                                                        self.status = None
                                                                                                                        self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                                        self.threshold.parent = self
                                                                                                                        self.units = None
                                                                                                                        self.update_rate = None
                                                                                                                        self.value = None


                                                                                                                    class Threshold(object):
                                                                                                                        """
                                                                                                                        Threshold information
                                                                                                                        
                                                                                                                        .. attribute:: threshold_array
                                                                                                                        
                                                                                                                        	Array of threshold
                                                                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.threshold_array = YList()
                                                                                                                            self.threshold_array.parent = self
                                                                                                                            self.threshold_array.name = 'threshold_array'


                                                                                                                        class ThresholdArray(object):
                                                                                                                            """
                                                                                                                            Array of threshold
                                                                                                                            
                                                                                                                            .. attribute:: threshold_name
                                                                                                                            
                                                                                                                            	Threshold name
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..50
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_name = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_name is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.threshold_array is not None:
                                                                                                                                for child_ref in self.threshold_array:
                                                                                                                                    if child_ref._has_data():
                                                                                                                                        return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.data_type is not None:
                                                                                                                            return True

                                                                                                                        if self.description is not None:
                                                                                                                            return True

                                                                                                                        if self.status is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                                                                            return True

                                                                                                                        if self.units is not None:
                                                                                                                            return True

                                                                                                                        if self.update_rate is not None:
                                                                                                                            return True

                                                                                                                        if self.value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                                                class InvAssetBag(object):
                                                                                                                    """
                                                                                                                    Inventory Asset Bag
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_assembly_number
                                                                                                                    
                                                                                                                    	Manufacture Assembly number
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_assembly_revision
                                                                                                                    
                                                                                                                    	Manufacture assembly revision
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                                                    
                                                                                                                    	Common Language Equipment           Identifier number
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                                                                    
                                                                                                                    	
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_software_identifier
                                                                                                                    
                                                                                                                    	
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                                                                    
                                                                                                                    	String containing OEM information           if applicable
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: part_number
                                                                                                                    
                                                                                                                    	
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.manufacturer_assembly_number = None
                                                                                                                        self.manufacturer_assembly_revision = None
                                                                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                                                                        self.manufacturer_firmware_identifier = None
                                                                                                                        self.manufacturer_software_identifier = None
                                                                                                                        self.original_equipment_manufacturer_string = None
                                                                                                                        self.part_number = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.manufacturer_assembly_number is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_assembly_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_software_identifier is not None:
                                                                                                                            return True

                                                                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                                                                            return True

                                                                                                                        if self.part_number is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvAssetBag']['meta_info']


                                                                                                                class Threshold(object):
                                                                                                                    """
                                                                                                                    Threshold
                                                                                                                    
                                                                                                                    .. attribute:: critical_hi
                                                                                                                    
                                                                                                                    	Critical High
                                                                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi>`
                                                                                                                    
                                                                                                                    .. attribute:: critical_lo
                                                                                                                    
                                                                                                                    	Critical Low
                                                                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo>`
                                                                                                                    
                                                                                                                    .. attribute:: major_hi
                                                                                                                    
                                                                                                                    	Major High
                                                                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi>`
                                                                                                                    
                                                                                                                    .. attribute:: major_lo
                                                                                                                    
                                                                                                                    	Major Low
                                                                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo>`
                                                                                                                    
                                                                                                                    .. attribute:: minor_hi
                                                                                                                    
                                                                                                                    	Minor High
                                                                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi>`
                                                                                                                    
                                                                                                                    .. attribute:: minor_lo
                                                                                                                    
                                                                                                                    	Minor Low
                                                                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo>`
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi()
                                                                                                                        self.critical_hi.parent = self
                                                                                                                        self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo()
                                                                                                                        self.critical_lo.parent = self
                                                                                                                        self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi()
                                                                                                                        self.major_hi.parent = self
                                                                                                                        self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo()
                                                                                                                        self.major_lo.parent = self
                                                                                                                        self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi()
                                                                                                                        self.minor_hi.parent = self
                                                                                                                        self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo()
                                                                                                                        self.minor_lo.parent = self


                                                                                                                    class MajorLo(object):
                                                                                                                        """
                                                                                                                        Major Low
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorLo']['meta_info']


                                                                                                                    class CriticalHi(object):
                                                                                                                        """
                                                                                                                        Critical High
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                                                    class MinorHi(object):
                                                                                                                        """
                                                                                                                        Minor High
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorHi']['meta_info']


                                                                                                                    class MajorHi(object):
                                                                                                                        """
                                                                                                                        Major High
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MajorHi']['meta_info']


                                                                                                                    class CriticalLo(object):
                                                                                                                        """
                                                                                                                        Critical Low
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                                                    class MinorLo(object):
                                                                                                                        """
                                                                                                                        Minor Low
                                                                                                                        
                                                                                                                        .. attribute:: thresh_bag
                                                                                                                        
                                                                                                                        	Environment threshold info
                                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                                            self.thresh_bag.parent = self


                                                                                                                        class ThreshBag(object):
                                                                                                                            """
                                                                                                                            Environment threshold info
                                                                                                                            
                                                                                                                            .. attribute:: threshold_evaluation
                                                                                                                            
                                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                                            
                                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                            	**type**\:  bool
                                                                                                                            
                                                                                                                            .. attribute:: threshold_relation
                                                                                                                            
                                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_severity
                                                                                                                            
                                                                                                                            	Indicates minor, major, critical severities
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            .. attribute:: threshold_value
                                                                                                                            
                                                                                                                            	Value of the configured threshold
                                                                                                                            	**type**\:  int
                                                                                                                            
                                                                                                                            	**range:** 0..4294967295
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.threshold_evaluation = None
                                                                                                                                self.threshold_notification_enabled = None
                                                                                                                                self.threshold_relation = None
                                                                                                                                self.threshold_severity = None
                                                                                                                                self.threshold_value = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_relation is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_severity is not None:
                                                                                                                                    return True

                                                                                                                                if self.threshold_value is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold.MinorLo']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                                            return True

                                                                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                                            return True

                                                                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                                                                            return True

                                                                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                                                                            return True

                                                                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                                            return True

                                                                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.Threshold']['meta_info']


                                                                                                                class FruInfo(object):
                                                                                                                    """
                                                                                                                    Inventory EDM FRU info
                                                                                                                    
                                                                                                                    .. attribute:: card_administrative_state
                                                                                                                    
                                                                                                                    	card admin state\: shutdown or not
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: card_monitor_state
                                                                                                                    
                                                                                                                    	card is monitored by a manager or left unmonitored
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: card_operational_state
                                                                                                                    
                                                                                                                    	card operation state
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: card_reset_reason
                                                                                                                    
                                                                                                                    	card reset reason enum
                                                                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: card_up_time
                                                                                                                    
                                                                                                                    	card up time
                                                                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.CardUpTime>`
                                                                                                                    
                                                                                                                    .. attribute:: last_operational_state_change
                                                                                                                    
                                                                                                                    	last card oper change state
                                                                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                                                    
                                                                                                                    .. attribute:: power_administrative_state
                                                                                                                    
                                                                                                                    	power admin state\: up or down
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_current_measurement
                                                                                                                    
                                                                                                                    	power current\: not implemented
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: power_operational_state
                                                                                                                    
                                                                                                                    	Power operation state
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.card_administrative_state = None
                                                                                                                        self.card_monitor_state = None
                                                                                                                        self.card_operational_state = None
                                                                                                                        self.card_reset_reason = None
                                                                                                                        self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.CardUpTime()
                                                                                                                        self.card_up_time.parent = self
                                                                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                                        self.last_operational_state_change.parent = self
                                                                                                                        self.power_administrative_state = None
                                                                                                                        self.power_current_measurement = None
                                                                                                                        self.power_operational_state = None


                                                                                                                    class LastOperationalStateChange(object):
                                                                                                                        """
                                                                                                                        last card oper change state
                                                                                                                        
                                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                                        
                                                                                                                        	Time Value in Nano\-seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: nanosecond
                                                                                                                        
                                                                                                                        .. attribute:: time_in_seconds
                                                                                                                        
                                                                                                                        	Time Value in Seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: second
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.time_in_nano_seconds = None
                                                                                                                            self.time_in_seconds = None

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                                return True

                                                                                                                            if self.time_in_seconds is not None:
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                                                    class CardUpTime(object):
                                                                                                                        """
                                                                                                                        card up time
                                                                                                                        
                                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                                        
                                                                                                                        	Time Value in Nano\-seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: nanosecond
                                                                                                                        
                                                                                                                        .. attribute:: time_in_seconds
                                                                                                                        
                                                                                                                        	Time Value in Seconds
                                                                                                                        	**type**\:  int
                                                                                                                        
                                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                                        
                                                                                                                        	**units**\: second
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.time_in_nano_seconds = None
                                                                                                                            self.time_in_seconds = None

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                                return True

                                                                                                                            if self.time_in_seconds is not None:
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.card_administrative_state is not None:
                                                                                                                            return True

                                                                                                                        if self.card_monitor_state is not None:
                                                                                                                            return True

                                                                                                                        if self.card_operational_state is not None:
                                                                                                                            return True

                                                                                                                        if self.card_reset_reason is not None:
                                                                                                                            return True

                                                                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                                            return True

                                                                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                                            return True

                                                                                                                        if self.power_administrative_state is not None:
                                                                                                                            return True

                                                                                                                        if self.power_current_measurement is not None:
                                                                                                                            return True

                                                                                                                        if self.power_operational_state is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.FruInfo']['meta_info']


                                                                                                                class InvBasicBag(object):
                                                                                                                    """
                                                                                                                    Inventory Basic Bag
                                                                                                                    
                                                                                                                    .. attribute:: alias
                                                                                                                    
                                                                                                                    	useful for storing an entity alias 
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: asset_id_str
                                                                                                                    
                                                                                                                    	asset Identification string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: asset_identification
                                                                                                                    
                                                                                                                    	asset Identification
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: ceport
                                                                                                                    
                                                                                                                    	1 if ce port found, 0 if not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: chip_hardware_revision
                                                                                                                    
                                                                                                                    	chip module hw revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: composite_class_code
                                                                                                                    
                                                                                                                    	Major&minor class of the entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: description
                                                                                                                    
                                                                                                                    	describes in user\-readable terms       what the entity in question does
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: environmental_monitor_path
                                                                                                                    
                                                                                                                    	sysdb name of sensor in the envmon EDM
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: firmware_revision
                                                                                                                    
                                                                                                                    	firmware revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: group_flag
                                                                                                                    
                                                                                                                    	indicates if this entity is group       or not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: hardware_revision
                                                                                                                    
                                                                                                                    	hw revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: is_field_replaceable_unit
                                                                                                                    
                                                                                                                    	1 if Field Replaceable Unit 0, if not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_asset_tags
                                                                                                                    
                                                                                                                    	Manufacture Asset Tags
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: manufacturer_name
                                                                                                                    
                                                                                                                    	manufacturer's name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: memory_size
                                                                                                                    
                                                                                                                    	Size of memory associated with       the entity where applicable
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: model_name
                                                                                                                    
                                                                                                                    	model name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: name
                                                                                                                    
                                                                                                                    	name string for the entity
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: new_deviation_number
                                                                                                                    
                                                                                                                    	integer value for New Deviation Number 0x88
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: physical_layer_interface_module_type
                                                                                                                    
                                                                                                                    	integer value for plim type if     applicable to this entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: redundancystate
                                                                                                                    
                                                                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: serial_number
                                                                                                                    
                                                                                                                    	serial number
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: software_revision
                                                                                                                    
                                                                                                                    	software revision string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: unique_id
                                                                                                                    
                                                                                                                    	Unique id for an entity
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    .. attribute:: unrecognized_fru
                                                                                                                    
                                                                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: vendor_type
                                                                                                                    
                                                                                                                    	maps to the vendor OID string
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: xr_scoped
                                                                                                                    
                                                                                                                    	1 if xr scoped, 0 if not
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.alias = None
                                                                                                                        self.asset_id_str = None
                                                                                                                        self.asset_identification = None
                                                                                                                        self.ceport = None
                                                                                                                        self.chip_hardware_revision = None
                                                                                                                        self.composite_class_code = None
                                                                                                                        self.description = None
                                                                                                                        self.environmental_monitor_path = None
                                                                                                                        self.firmware_revision = None
                                                                                                                        self.group_flag = None
                                                                                                                        self.hardware_revision = None
                                                                                                                        self.is_field_replaceable_unit = None
                                                                                                                        self.manufacturer_asset_tags = None
                                                                                                                        self.manufacturer_name = None
                                                                                                                        self.memory_size = None
                                                                                                                        self.model_name = None
                                                                                                                        self.name = None
                                                                                                                        self.new_deviation_number = None
                                                                                                                        self.physical_layer_interface_module_type = None
                                                                                                                        self.redundancystate = None
                                                                                                                        self.serial_number = None
                                                                                                                        self.software_revision = None
                                                                                                                        self.unique_id = None
                                                                                                                        self.unrecognized_fru = None
                                                                                                                        self.vendor_type = None
                                                                                                                        self.xr_scoped = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.alias is not None:
                                                                                                                            return True

                                                                                                                        if self.asset_id_str is not None:
                                                                                                                            return True

                                                                                                                        if self.asset_identification is not None:
                                                                                                                            return True

                                                                                                                        if self.ceport is not None:
                                                                                                                            return True

                                                                                                                        if self.chip_hardware_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.composite_class_code is not None:
                                                                                                                            return True

                                                                                                                        if self.description is not None:
                                                                                                                            return True

                                                                                                                        if self.environmental_monitor_path is not None:
                                                                                                                            return True

                                                                                                                        if self.firmware_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.group_flag is not None:
                                                                                                                            return True

                                                                                                                        if self.hardware_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.is_field_replaceable_unit is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_asset_tags is not None:
                                                                                                                            return True

                                                                                                                        if self.manufacturer_name is not None:
                                                                                                                            return True

                                                                                                                        if self.memory_size is not None:
                                                                                                                            return True

                                                                                                                        if self.model_name is not None:
                                                                                                                            return True

                                                                                                                        if self.name is not None:
                                                                                                                            return True

                                                                                                                        if self.new_deviation_number is not None:
                                                                                                                            return True

                                                                                                                        if self.physical_layer_interface_module_type is not None:
                                                                                                                            return True

                                                                                                                        if self.redundancystate is not None:
                                                                                                                            return True

                                                                                                                        if self.serial_number is not None:
                                                                                                                            return True

                                                                                                                        if self.software_revision is not None:
                                                                                                                            return True

                                                                                                                        if self.unique_id is not None:
                                                                                                                            return True

                                                                                                                        if self.unrecognized_fru is not None:
                                                                                                                            return True

                                                                                                                        if self.vendor_type is not None:
                                                                                                                            return True

                                                                                                                        if self.xr_scoped is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvBasicBag']['meta_info']


                                                                                                                class InvEepromInfo(object):
                                                                                                                    """
                                                                                                                    Inventory EDM EEPROM Information Bag
                                                                                                                    
                                                                                                                    .. attribute:: description
                                                                                                                    
                                                                                                                    	A textual description of physical entity
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: eeprom
                                                                                                                    
                                                                                                                    	EEPROM data not from hex data
                                                                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom>`
                                                                                                                    
                                                                                                                    .. attribute:: has_eeprom
                                                                                                                    
                                                                                                                    	use eeprom instead of opaque data
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: inv_card_type
                                                                                                                    
                                                                                                                    	Inventory card type
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: opaque_data
                                                                                                                    
                                                                                                                    	EEPROM hex data
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                                                    
                                                                                                                    .. attribute:: opaque_data_size
                                                                                                                    
                                                                                                                    	size of the EEPROM hex data
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.description = None
                                                                                                                        self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom()
                                                                                                                        self.eeprom.parent = self
                                                                                                                        self.has_eeprom = None
                                                                                                                        self.inv_card_type = None
                                                                                                                        self.opaque_data = None
                                                                                                                        self.opaque_data_size = None


                                                                                                                    class Eeprom(object):
                                                                                                                        """
                                                                                                                        EEPROM data not from hex data
                                                                                                                        
                                                                                                                        .. attribute:: asset_alias
                                                                                                                        
                                                                                                                        	Asset Alias
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: asset_id
                                                                                                                        
                                                                                                                        	Asset ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address1
                                                                                                                        
                                                                                                                        	Base Mac Address #1
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address2
                                                                                                                        
                                                                                                                        	Base Mac Address #2
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address3
                                                                                                                        
                                                                                                                        	Base Mac Address #3
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: base_mac_address4
                                                                                                                        
                                                                                                                        	Base Mac Address #4
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_checksum
                                                                                                                        
                                                                                                                        	Block Checksum
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_count
                                                                                                                        
                                                                                                                        	Block Count
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_length
                                                                                                                        
                                                                                                                        	Block Length
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_signature
                                                                                                                        
                                                                                                                        	Block Signature
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: block_version
                                                                                                                        
                                                                                                                        	Block Version
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: chassis_sid
                                                                                                                        
                                                                                                                        	Chassis serial number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: clei
                                                                                                                        
                                                                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: controller_family
                                                                                                                        
                                                                                                                        	Controller family
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: controller_type
                                                                                                                        
                                                                                                                        	Controller type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: description
                                                                                                                        
                                                                                                                        	A textual description of physical entity
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num1
                                                                                                                        
                                                                                                                        	Deviation Number # 1
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num2
                                                                                                                        
                                                                                                                        	Deviation Number # 2
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num3
                                                                                                                        
                                                                                                                        	Deviation Number # 3
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num4
                                                                                                                        
                                                                                                                        	Deviation Number # 4
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num5
                                                                                                                        
                                                                                                                        	Deviation Number # 5
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num6
                                                                                                                        
                                                                                                                        	Deviation Number # 6
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: dev_num7
                                                                                                                        
                                                                                                                        	Deviation Number # 7
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: eci
                                                                                                                        
                                                                                                                        	Equipment Catalog Item (ECI) number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: eeprom_size
                                                                                                                        
                                                                                                                        	EEPROM Size
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: engineer_use
                                                                                                                        
                                                                                                                        	Engineer Use
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: fru_major_type
                                                                                                                        
                                                                                                                        	FRU Major Type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: fru_minor_type
                                                                                                                        
                                                                                                                        	FRU Minor Type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: hw_version
                                                                                                                        
                                                                                                                        	Hardware Version
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: hwid
                                                                                                                        
                                                                                                                        	Hardware Revision
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: idprom_format_rev
                                                                                                                        
                                                                                                                        	IDPROM Format Revision
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size1
                                                                                                                        
                                                                                                                        	Mac Address Block Size #1
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size2
                                                                                                                        
                                                                                                                        	Mac Address Block Size #2
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size3
                                                                                                                        
                                                                                                                        	Mac Address Block Size #3
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mac_add_blk_size4
                                                                                                                        
                                                                                                                        	Mac Address Block Size #4
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: manu_test_data
                                                                                                                        
                                                                                                                        	Manufacturing Test Data
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mfg_bits
                                                                                                                        
                                                                                                                        	MFG Bits
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: mfg_deviation
                                                                                                                        
                                                                                                                        	MFG Deviation
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: oem_string
                                                                                                                        
                                                                                                                        	OEM String
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: part_number
                                                                                                                        
                                                                                                                        	Part Number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: part_revision
                                                                                                                        
                                                                                                                        	Part Revision
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pca_num
                                                                                                                        
                                                                                                                        	PCA number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pcavid
                                                                                                                        
                                                                                                                        	PCA revision ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pcb_serial_num
                                                                                                                        
                                                                                                                        	PCB Serial Number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: pid
                                                                                                                        
                                                                                                                        	Product ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: power_consumption
                                                                                                                        
                                                                                                                        	Power Consumption
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: power_supply_type
                                                                                                                        
                                                                                                                        	Power Supply Type
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: product_id
                                                                                                                        
                                                                                                                        	Product ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: rma
                                                                                                                        
                                                                                                                        	RMA Data
                                                                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                                        
                                                                                                                        .. attribute:: rma_code
                                                                                                                        
                                                                                                                        	RMA Code
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: serial_number
                                                                                                                        
                                                                                                                        	Serial Number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: snmpoid
                                                                                                                        
                                                                                                                        	SNMP OID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: top_assem_part_num
                                                                                                                        
                                                                                                                        	Top assembly part number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: top_assem_vid
                                                                                                                        
                                                                                                                        	Top assembly revision number
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: udi_description
                                                                                                                        
                                                                                                                        	UDI description
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: udi_name
                                                                                                                        
                                                                                                                        	UDI name
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        .. attribute:: vid
                                                                                                                        
                                                                                                                        	Version ID
                                                                                                                        	**type**\:  str
                                                                                                                        
                                                                                                                        	**length:** 0..255
                                                                                                                        
                                                                                                                        

                                                                                                                        """

                                                                                                                        _prefix = 'invmgr-oper'
                                                                                                                        _revision = '2015-11-09'

                                                                                                                        def __init__(self):
                                                                                                                            self.parent = None
                                                                                                                            self.asset_alias = None
                                                                                                                            self.asset_id = None
                                                                                                                            self.base_mac_address1 = None
                                                                                                                            self.base_mac_address2 = None
                                                                                                                            self.base_mac_address3 = None
                                                                                                                            self.base_mac_address4 = None
                                                                                                                            self.block_checksum = None
                                                                                                                            self.block_count = None
                                                                                                                            self.block_length = None
                                                                                                                            self.block_signature = None
                                                                                                                            self.block_version = None
                                                                                                                            self.chassis_sid = None
                                                                                                                            self.clei = None
                                                                                                                            self.controller_family = None
                                                                                                                            self.controller_type = None
                                                                                                                            self.description = None
                                                                                                                            self.dev_num1 = None
                                                                                                                            self.dev_num2 = None
                                                                                                                            self.dev_num3 = None
                                                                                                                            self.dev_num4 = None
                                                                                                                            self.dev_num5 = None
                                                                                                                            self.dev_num6 = None
                                                                                                                            self.dev_num7 = None
                                                                                                                            self.eci = None
                                                                                                                            self.eeprom_size = None
                                                                                                                            self.engineer_use = None
                                                                                                                            self.fru_major_type = None
                                                                                                                            self.fru_minor_type = None
                                                                                                                            self.hw_version = None
                                                                                                                            self.hwid = None
                                                                                                                            self.idprom_format_rev = None
                                                                                                                            self.mac_add_blk_size1 = None
                                                                                                                            self.mac_add_blk_size2 = None
                                                                                                                            self.mac_add_blk_size3 = None
                                                                                                                            self.mac_add_blk_size4 = None
                                                                                                                            self.manu_test_data = None
                                                                                                                            self.mfg_bits = None
                                                                                                                            self.mfg_deviation = None
                                                                                                                            self.oem_string = None
                                                                                                                            self.part_number = None
                                                                                                                            self.part_revision = None
                                                                                                                            self.pca_num = None
                                                                                                                            self.pcavid = None
                                                                                                                            self.pcb_serial_num = None
                                                                                                                            self.pid = None
                                                                                                                            self.power_consumption = None
                                                                                                                            self.power_supply_type = None
                                                                                                                            self.product_id = None
                                                                                                                            self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                                            self.rma.parent = self
                                                                                                                            self.rma_code = None
                                                                                                                            self.serial_number = None
                                                                                                                            self.snmpoid = None
                                                                                                                            self.top_assem_part_num = None
                                                                                                                            self.top_assem_vid = None
                                                                                                                            self.udi_description = None
                                                                                                                            self.udi_name = None
                                                                                                                            self.vid = None


                                                                                                                        class Rma(object):
                                                                                                                            """
                                                                                                                            RMA Data
                                                                                                                            
                                                                                                                            .. attribute:: rma_history
                                                                                                                            
                                                                                                                            	RMA history
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..255
                                                                                                                            
                                                                                                                            .. attribute:: rma_number
                                                                                                                            
                                                                                                                            	RMA tracking number format is N\-N\-N
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..255
                                                                                                                            
                                                                                                                            .. attribute:: test_history
                                                                                                                            
                                                                                                                            	Test history
                                                                                                                            	**type**\:  str
                                                                                                                            
                                                                                                                            	**length:** 0..255
                                                                                                                            
                                                                                                                            

                                                                                                                            """

                                                                                                                            _prefix = 'invmgr-oper'
                                                                                                                            _revision = '2015-11-09'

                                                                                                                            def __init__(self):
                                                                                                                                self.parent = None
                                                                                                                                self.rma_history = None
                                                                                                                                self.rma_number = None
                                                                                                                                self.test_history = None

                                                                                                                            @property
                                                                                                                            def _common_path(self):
                                                                                                                                if self.parent is None:
                                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                                            def is_config(self):
                                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                                return False

                                                                                                                            def _has_data(self):
                                                                                                                                if not self.is_config():
                                                                                                                                    return False
                                                                                                                                if self.rma_history is not None:
                                                                                                                                    return True

                                                                                                                                if self.rma_number is not None:
                                                                                                                                    return True

                                                                                                                                if self.test_history is not None:
                                                                                                                                    return True

                                                                                                                                return False

                                                                                                                            @staticmethod
                                                                                                                            def _meta_info():
                                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                                        @property
                                                                                                                        def _common_path(self):
                                                                                                                            if self.parent is None:
                                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                                        def is_config(self):
                                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                                            return False

                                                                                                                        def _has_data(self):
                                                                                                                            if not self.is_config():
                                                                                                                                return False
                                                                                                                            if self.asset_alias is not None:
                                                                                                                                return True

                                                                                                                            if self.asset_id is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address1 is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address2 is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address3 is not None:
                                                                                                                                return True

                                                                                                                            if self.base_mac_address4 is not None:
                                                                                                                                return True

                                                                                                                            if self.block_checksum is not None:
                                                                                                                                return True

                                                                                                                            if self.block_count is not None:
                                                                                                                                return True

                                                                                                                            if self.block_length is not None:
                                                                                                                                return True

                                                                                                                            if self.block_signature is not None:
                                                                                                                                return True

                                                                                                                            if self.block_version is not None:
                                                                                                                                return True

                                                                                                                            if self.chassis_sid is not None:
                                                                                                                                return True

                                                                                                                            if self.clei is not None:
                                                                                                                                return True

                                                                                                                            if self.controller_family is not None:
                                                                                                                                return True

                                                                                                                            if self.controller_type is not None:
                                                                                                                                return True

                                                                                                                            if self.description is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num1 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num2 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num3 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num4 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num5 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num6 is not None:
                                                                                                                                return True

                                                                                                                            if self.dev_num7 is not None:
                                                                                                                                return True

                                                                                                                            if self.eci is not None:
                                                                                                                                return True

                                                                                                                            if self.eeprom_size is not None:
                                                                                                                                return True

                                                                                                                            if self.engineer_use is not None:
                                                                                                                                return True

                                                                                                                            if self.fru_major_type is not None:
                                                                                                                                return True

                                                                                                                            if self.fru_minor_type is not None:
                                                                                                                                return True

                                                                                                                            if self.hw_version is not None:
                                                                                                                                return True

                                                                                                                            if self.hwid is not None:
                                                                                                                                return True

                                                                                                                            if self.idprom_format_rev is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size1 is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size2 is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size3 is not None:
                                                                                                                                return True

                                                                                                                            if self.mac_add_blk_size4 is not None:
                                                                                                                                return True

                                                                                                                            if self.manu_test_data is not None:
                                                                                                                                return True

                                                                                                                            if self.mfg_bits is not None:
                                                                                                                                return True

                                                                                                                            if self.mfg_deviation is not None:
                                                                                                                                return True

                                                                                                                            if self.oem_string is not None:
                                                                                                                                return True

                                                                                                                            if self.part_number is not None:
                                                                                                                                return True

                                                                                                                            if self.part_revision is not None:
                                                                                                                                return True

                                                                                                                            if self.pca_num is not None:
                                                                                                                                return True

                                                                                                                            if self.pcavid is not None:
                                                                                                                                return True

                                                                                                                            if self.pcb_serial_num is not None:
                                                                                                                                return True

                                                                                                                            if self.pid is not None:
                                                                                                                                return True

                                                                                                                            if self.power_consumption is not None:
                                                                                                                                return True

                                                                                                                            if self.power_supply_type is not None:
                                                                                                                                return True

                                                                                                                            if self.product_id is not None:
                                                                                                                                return True

                                                                                                                            if self.rma is not None and self.rma._has_data():
                                                                                                                                return True

                                                                                                                            if self.rma_code is not None:
                                                                                                                                return True

                                                                                                                            if self.serial_number is not None:
                                                                                                                                return True

                                                                                                                            if self.snmpoid is not None:
                                                                                                                                return True

                                                                                                                            if self.top_assem_part_num is not None:
                                                                                                                                return True

                                                                                                                            if self.top_assem_vid is not None:
                                                                                                                                return True

                                                                                                                            if self.udi_description is not None:
                                                                                                                                return True

                                                                                                                            if self.udi_name is not None:
                                                                                                                                return True

                                                                                                                            if self.vid is not None:
                                                                                                                                return True

                                                                                                                            return False

                                                                                                                        @staticmethod
                                                                                                                        def _meta_info():
                                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.description is not None:
                                                                                                                            return True

                                                                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                                                                            return True

                                                                                                                        if self.has_eeprom is not None:
                                                                                                                            return True

                                                                                                                        if self.inv_card_type is not None:
                                                                                                                            return True

                                                                                                                        if self.opaque_data is not None:
                                                                                                                            return True

                                                                                                                        if self.opaque_data_size is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes.InvEepromInfo']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                                        return True

                                                                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                                        return True

                                                                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                                        return True

                                                                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.module_done is not None:
                                                                                                                        return True

                                                                                                                    if self.node_id is not None:
                                                                                                                        return True

                                                                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                                        return True

                                                                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                                                                        return True

                                                                                                                    if self.vm_done is not None:
                                                                                                                        return True

                                                                                                                    if self.vm_node_id is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11.Attributes']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                                                if self.name is None:
                                                                                                                    raise YPYModelError('Key property name is None')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi11[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.name is not None:
                                                                                                                    return True

                                                                                                                if self.attributes is not None and self.attributes._has_data():
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S.Tsi11']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi11s'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.tsi11 is not None:
                                                                                                                for child_ref in self.tsi11:
                                                                                                                    if child_ref._has_data():
                                                                                                                        return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Tsi11S']['meta_info']


                                                                                                    class Attributes(object):
                                                                                                        """
                                                                                                        Attributes
                                                                                                        
                                                                                                        .. attribute:: env_sensor_info
                                                                                                        
                                                                                                        	Environment sensor info
                                                                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfo>`
                                                                                                        
                                                                                                        .. attribute:: env_sensor_info_xml
                                                                                                        
                                                                                                        	Environment sensor info XML
                                                                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml>`
                                                                                                        
                                                                                                        .. attribute:: fru_info
                                                                                                        
                                                                                                        	Inventory EDM FRU info
                                                                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo>`
                                                                                                        
                                                                                                        .. attribute:: inv_asset_bag
                                                                                                        
                                                                                                        	Inventory Asset Bag
                                                                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvAssetBag>`
                                                                                                        
                                                                                                        .. attribute:: inv_basic_bag
                                                                                                        
                                                                                                        	Inventory Basic Bag
                                                                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvBasicBag>`
                                                                                                        
                                                                                                        .. attribute:: inv_eeprom_info
                                                                                                        
                                                                                                        	Inventory EDM EEPROM Information Bag
                                                                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo>`
                                                                                                        
                                                                                                        .. attribute:: module_done
                                                                                                        
                                                                                                        	Inventory EDM Module Done Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**default value**\: 1
                                                                                                        
                                                                                                        .. attribute:: node_id
                                                                                                        
                                                                                                        	Node ID Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** 0..4294967295
                                                                                                        
                                                                                                        .. attribute:: pwg_info
                                                                                                        
                                                                                                        	Inventory EDM PWG info
                                                                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.PwgInfo>`
                                                                                                        
                                                                                                        .. attribute:: threshold
                                                                                                        
                                                                                                        	Threshold
                                                                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold>`
                                                                                                        
                                                                                                        .. attribute:: vm_done
                                                                                                        
                                                                                                        	VM Done Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        .. attribute:: vm_node_id
                                                                                                        
                                                                                                        	VM Node ID Tuple
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** 0..4294967295
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfo()
                                                                                                            self.env_sensor_info.parent = self
                                                                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml()
                                                                                                            self.env_sensor_info_xml.parent = self
                                                                                                            self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo()
                                                                                                            self.fru_info.parent = self
                                                                                                            self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvAssetBag()
                                                                                                            self.inv_asset_bag.parent = self
                                                                                                            self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvBasicBag()
                                                                                                            self.inv_basic_bag.parent = self
                                                                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo()
                                                                                                            self.inv_eeprom_info.parent = self
                                                                                                            self.module_done = None
                                                                                                            self.node_id = None
                                                                                                            self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.PwgInfo()
                                                                                                            self.pwg_info.parent = self
                                                                                                            self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold()
                                                                                                            self.threshold.parent = self
                                                                                                            self.vm_done = None
                                                                                                            self.vm_node_id = None


                                                                                                        class EnvSensorInfo(object):
                                                                                                            """
                                                                                                            Environment sensor info
                                                                                                            
                                                                                                            .. attribute:: age_time_stamp
                                                                                                            
                                                                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: alarm_type
                                                                                                            
                                                                                                            	Indicates threshold violation
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: data_type
                                                                                                            
                                                                                                            	Sensor data type enums
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: device_description
                                                                                                            
                                                                                                            	Device Name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: device_id
                                                                                                            
                                                                                                            	Identifier for this device
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: field_validity_bitmap
                                                                                                            
                                                                                                            	Sensor valid bitmap
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: precision
                                                                                                            
                                                                                                            	Sensor precision range
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: scale
                                                                                                            
                                                                                                            	Sensor scale enums
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: status
                                                                                                            
                                                                                                            	Sensor operation state enums
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: units
                                                                                                            
                                                                                                            	Units of variable being read
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: update_rate
                                                                                                            
                                                                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: value
                                                                                                            
                                                                                                            	Current reading of sensor
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.age_time_stamp = None
                                                                                                                self.alarm_type = None
                                                                                                                self.data_type = None
                                                                                                                self.device_description = None
                                                                                                                self.device_id = None
                                                                                                                self.field_validity_bitmap = None
                                                                                                                self.precision = None
                                                                                                                self.scale = None
                                                                                                                self.status = None
                                                                                                                self.units = None
                                                                                                                self.update_rate = None
                                                                                                                self.value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.age_time_stamp is not None:
                                                                                                                    return True

                                                                                                                if self.alarm_type is not None:
                                                                                                                    return True

                                                                                                                if self.data_type is not None:
                                                                                                                    return True

                                                                                                                if self.device_description is not None:
                                                                                                                    return True

                                                                                                                if self.device_id is not None:
                                                                                                                    return True

                                                                                                                if self.field_validity_bitmap is not None:
                                                                                                                    return True

                                                                                                                if self.precision is not None:
                                                                                                                    return True

                                                                                                                if self.scale is not None:
                                                                                                                    return True

                                                                                                                if self.status is not None:
                                                                                                                    return True

                                                                                                                if self.units is not None:
                                                                                                                    return True

                                                                                                                if self.update_rate is not None:
                                                                                                                    return True

                                                                                                                if self.value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfo']['meta_info']


                                                                                                        class PwgInfo(object):
                                                                                                            """
                                                                                                            Inventory EDM PWG info
                                                                                                            
                                                                                                            .. attribute:: power_group_available_current
                                                                                                            
                                                                                                            	available current
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_group_drawn_current
                                                                                                            
                                                                                                            	drawn current
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_group_power_units
                                                                                                            
                                                                                                            	power units
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            .. attribute:: power_group_redundancy_mode
                                                                                                            
                                                                                                            	redundancy mode
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.power_group_available_current = None
                                                                                                                self.power_group_drawn_current = None
                                                                                                                self.power_group_power_units = None
                                                                                                                self.power_group_redundancy_mode = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.power_group_available_current is not None:
                                                                                                                    return True

                                                                                                                if self.power_group_drawn_current is not None:
                                                                                                                    return True

                                                                                                                if self.power_group_power_units is not None:
                                                                                                                    return True

                                                                                                                if self.power_group_redundancy_mode is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.PwgInfo']['meta_info']


                                                                                                        class EnvSensorInfoXml(object):
                                                                                                            """
                                                                                                            Environment sensor info XML
                                                                                                            
                                                                                                            .. attribute:: data_type
                                                                                                            
                                                                                                            	Sensor data type
                                                                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                                            
                                                                                                            .. attribute:: description
                                                                                                            
                                                                                                            	Device Name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: status
                                                                                                            
                                                                                                            	Sensor operation state
                                                                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                                            
                                                                                                            .. attribute:: threshold
                                                                                                            
                                                                                                            	Threshold information
                                                                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                                            
                                                                                                            .. attribute:: units
                                                                                                            
                                                                                                            	Units of variable being read
                                                                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                                            
                                                                                                            .. attribute:: update_rate
                                                                                                            
                                                                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: value
                                                                                                            
                                                                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.data_type = None
                                                                                                                self.description = None
                                                                                                                self.status = None
                                                                                                                self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                                self.threshold.parent = self
                                                                                                                self.units = None
                                                                                                                self.update_rate = None
                                                                                                                self.value = None


                                                                                                            class Threshold(object):
                                                                                                                """
                                                                                                                Threshold information
                                                                                                                
                                                                                                                .. attribute:: threshold_array
                                                                                                                
                                                                                                                	Array of threshold
                                                                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.threshold_array = YList()
                                                                                                                    self.threshold_array.parent = self
                                                                                                                    self.threshold_array.name = 'threshold_array'


                                                                                                                class ThresholdArray(object):
                                                                                                                    """
                                                                                                                    Array of threshold
                                                                                                                    
                                                                                                                    .. attribute:: threshold_name
                                                                                                                    
                                                                                                                    	Threshold name
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..50
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_name = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_name is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.threshold_array is not None:
                                                                                                                        for child_ref in self.threshold_array:
                                                                                                                            if child_ref._has_data():
                                                                                                                                return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.data_type is not None:
                                                                                                                    return True

                                                                                                                if self.description is not None:
                                                                                                                    return True

                                                                                                                if self.status is not None:
                                                                                                                    return True

                                                                                                                if self.threshold is not None and self.threshold._has_data():
                                                                                                                    return True

                                                                                                                if self.units is not None:
                                                                                                                    return True

                                                                                                                if self.update_rate is not None:
                                                                                                                    return True

                                                                                                                if self.value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                                        class InvAssetBag(object):
                                                                                                            """
                                                                                                            Inventory Asset Bag
                                                                                                            
                                                                                                            .. attribute:: manufacturer_assembly_number
                                                                                                            
                                                                                                            	Manufacture Assembly number
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_assembly_revision
                                                                                                            
                                                                                                            	Manufacture assembly revision
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                                            
                                                                                                            	Common Language Equipment           Identifier number
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_firmware_identifier
                                                                                                            
                                                                                                            	
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: manufacturer_software_identifier
                                                                                                            
                                                                                                            	
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: original_equipment_manufacturer_string
                                                                                                            
                                                                                                            	String containing OEM information           if applicable
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: part_number
                                                                                                            
                                                                                                            	
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.manufacturer_assembly_number = None
                                                                                                                self.manufacturer_assembly_revision = None
                                                                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                                                                self.manufacturer_firmware_identifier = None
                                                                                                                self.manufacturer_software_identifier = None
                                                                                                                self.original_equipment_manufacturer_string = None
                                                                                                                self.part_number = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.manufacturer_assembly_number is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_assembly_revision is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_firmware_identifier is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_software_identifier is not None:
                                                                                                                    return True

                                                                                                                if self.original_equipment_manufacturer_string is not None:
                                                                                                                    return True

                                                                                                                if self.part_number is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvAssetBag']['meta_info']


                                                                                                        class Threshold(object):
                                                                                                            """
                                                                                                            Threshold
                                                                                                            
                                                                                                            .. attribute:: critical_hi
                                                                                                            
                                                                                                            	Critical High
                                                                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi>`
                                                                                                            
                                                                                                            .. attribute:: critical_lo
                                                                                                            
                                                                                                            	Critical Low
                                                                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo>`
                                                                                                            
                                                                                                            .. attribute:: major_hi
                                                                                                            
                                                                                                            	Major High
                                                                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi>`
                                                                                                            
                                                                                                            .. attribute:: major_lo
                                                                                                            
                                                                                                            	Major Low
                                                                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo>`
                                                                                                            
                                                                                                            .. attribute:: minor_hi
                                                                                                            
                                                                                                            	Minor High
                                                                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi>`
                                                                                                            
                                                                                                            .. attribute:: minor_lo
                                                                                                            
                                                                                                            	Minor Low
                                                                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo>`
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi()
                                                                                                                self.critical_hi.parent = self
                                                                                                                self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo()
                                                                                                                self.critical_lo.parent = self
                                                                                                                self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi()
                                                                                                                self.major_hi.parent = self
                                                                                                                self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo()
                                                                                                                self.major_lo.parent = self
                                                                                                                self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi()
                                                                                                                self.minor_hi.parent = self
                                                                                                                self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo()
                                                                                                                self.minor_lo.parent = self


                                                                                                            class MajorLo(object):
                                                                                                                """
                                                                                                                Major Low
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorLo']['meta_info']


                                                                                                            class CriticalHi(object):
                                                                                                                """
                                                                                                                Critical High
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                                            class MinorHi(object):
                                                                                                                """
                                                                                                                Minor High
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorHi']['meta_info']


                                                                                                            class MajorHi(object):
                                                                                                                """
                                                                                                                Major High
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MajorHi']['meta_info']


                                                                                                            class CriticalLo(object):
                                                                                                                """
                                                                                                                Critical Low
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                                            class MinorLo(object):
                                                                                                                """
                                                                                                                Minor Low
                                                                                                                
                                                                                                                .. attribute:: thresh_bag
                                                                                                                
                                                                                                                	Environment threshold info
                                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                                    self.thresh_bag.parent = self


                                                                                                                class ThreshBag(object):
                                                                                                                    """
                                                                                                                    Environment threshold info
                                                                                                                    
                                                                                                                    .. attribute:: threshold_evaluation
                                                                                                                    
                                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                                    
                                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                                    	**type**\:  bool
                                                                                                                    
                                                                                                                    .. attribute:: threshold_relation
                                                                                                                    
                                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_severity
                                                                                                                    
                                                                                                                    	Indicates minor, major, critical severities
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    .. attribute:: threshold_value
                                                                                                                    
                                                                                                                    	Value of the configured threshold
                                                                                                                    	**type**\:  int
                                                                                                                    
                                                                                                                    	**range:** 0..4294967295
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.threshold_evaluation = None
                                                                                                                        self.threshold_notification_enabled = None
                                                                                                                        self.threshold_relation = None
                                                                                                                        self.threshold_severity = None
                                                                                                                        self.threshold_value = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.threshold_evaluation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_relation is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_severity is not None:
                                                                                                                            return True

                                                                                                                        if self.threshold_value is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold.MinorLo']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                                    return True

                                                                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                                    return True

                                                                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                                                                    return True

                                                                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                                                                    return True

                                                                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                                    return True

                                                                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.Threshold']['meta_info']


                                                                                                        class FruInfo(object):
                                                                                                            """
                                                                                                            Inventory EDM FRU info
                                                                                                            
                                                                                                            .. attribute:: card_administrative_state
                                                                                                            
                                                                                                            	card admin state\: shutdown or not
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: card_monitor_state
                                                                                                            
                                                                                                            	card is monitored by a manager or left unmonitored
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: card_operational_state
                                                                                                            
                                                                                                            	card operation state
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: card_reset_reason
                                                                                                            
                                                                                                            	card reset reason enum
                                                                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                                            
                                                                                                            .. attribute:: card_up_time
                                                                                                            
                                                                                                            	card up time
                                                                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.CardUpTime>`
                                                                                                            
                                                                                                            .. attribute:: last_operational_state_change
                                                                                                            
                                                                                                            	last card oper change state
                                                                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                                            
                                                                                                            .. attribute:: power_administrative_state
                                                                                                            
                                                                                                            	power admin state\: up or down
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_current_measurement
                                                                                                            
                                                                                                            	power current\: not implemented
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: power_operational_state
                                                                                                            
                                                                                                            	Power operation state
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.card_administrative_state = None
                                                                                                                self.card_monitor_state = None
                                                                                                                self.card_operational_state = None
                                                                                                                self.card_reset_reason = None
                                                                                                                self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.CardUpTime()
                                                                                                                self.card_up_time.parent = self
                                                                                                                self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                                self.last_operational_state_change.parent = self
                                                                                                                self.power_administrative_state = None
                                                                                                                self.power_current_measurement = None
                                                                                                                self.power_operational_state = None


                                                                                                            class LastOperationalStateChange(object):
                                                                                                                """
                                                                                                                last card oper change state
                                                                                                                
                                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                                
                                                                                                                	Time Value in Nano\-seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: nanosecond
                                                                                                                
                                                                                                                .. attribute:: time_in_seconds
                                                                                                                
                                                                                                                	Time Value in Seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: second
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.time_in_nano_seconds = None
                                                                                                                    self.time_in_seconds = None

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                                        return True

                                                                                                                    if self.time_in_seconds is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                                            class CardUpTime(object):
                                                                                                                """
                                                                                                                card up time
                                                                                                                
                                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                                
                                                                                                                	Time Value in Nano\-seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: nanosecond
                                                                                                                
                                                                                                                .. attribute:: time_in_seconds
                                                                                                                
                                                                                                                	Time Value in Seconds
                                                                                                                	**type**\:  int
                                                                                                                
                                                                                                                	**range:** \-2147483648..2147483647
                                                                                                                
                                                                                                                	**units**\: second
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.time_in_nano_seconds = None
                                                                                                                    self.time_in_seconds = None

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                                        return True

                                                                                                                    if self.time_in_seconds is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.card_administrative_state is not None:
                                                                                                                    return True

                                                                                                                if self.card_monitor_state is not None:
                                                                                                                    return True

                                                                                                                if self.card_operational_state is not None:
                                                                                                                    return True

                                                                                                                if self.card_reset_reason is not None:
                                                                                                                    return True

                                                                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                                    return True

                                                                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                                    return True

                                                                                                                if self.power_administrative_state is not None:
                                                                                                                    return True

                                                                                                                if self.power_current_measurement is not None:
                                                                                                                    return True

                                                                                                                if self.power_operational_state is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.FruInfo']['meta_info']


                                                                                                        class InvBasicBag(object):
                                                                                                            """
                                                                                                            Inventory Basic Bag
                                                                                                            
                                                                                                            .. attribute:: alias
                                                                                                            
                                                                                                            	useful for storing an entity alias 
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: asset_id_str
                                                                                                            
                                                                                                            	asset Identification string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: asset_identification
                                                                                                            
                                                                                                            	asset Identification
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: ceport
                                                                                                            
                                                                                                            	1 if ce port found, 0 if not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: chip_hardware_revision
                                                                                                            
                                                                                                            	chip module hw revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: composite_class_code
                                                                                                            
                                                                                                            	Major&minor class of the entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: description
                                                                                                            
                                                                                                            	describes in user\-readable terms       what the entity in question does
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: environmental_monitor_path
                                                                                                            
                                                                                                            	sysdb name of sensor in the envmon EDM
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: firmware_revision
                                                                                                            
                                                                                                            	firmware revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: group_flag
                                                                                                            
                                                                                                            	indicates if this entity is group       or not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: hardware_revision
                                                                                                            
                                                                                                            	hw revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: is_field_replaceable_unit
                                                                                                            
                                                                                                            	1 if Field Replaceable Unit 0, if not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: manufacturer_asset_tags
                                                                                                            
                                                                                                            	Manufacture Asset Tags
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: manufacturer_name
                                                                                                            
                                                                                                            	manufacturer's name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: memory_size
                                                                                                            
                                                                                                            	Size of memory associated with       the entity where applicable
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: model_name
                                                                                                            
                                                                                                            	model name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: name
                                                                                                            
                                                                                                            	name string for the entity
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: new_deviation_number
                                                                                                            
                                                                                                            	integer value for New Deviation Number 0x88
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: physical_layer_interface_module_type
                                                                                                            
                                                                                                            	integer value for plim type if     applicable to this entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: redundancystate
                                                                                                            
                                                                                                            	integer value for Redundancy State if     applicable to this entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: serial_number
                                                                                                            
                                                                                                            	serial number
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: software_revision
                                                                                                            
                                                                                                            	software revision string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: unique_id
                                                                                                            
                                                                                                            	Unique id for an entity
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            .. attribute:: unrecognized_fru
                                                                                                            
                                                                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: vendor_type
                                                                                                            
                                                                                                            	maps to the vendor OID string
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: xr_scoped
                                                                                                            
                                                                                                            	1 if xr scoped, 0 if not
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.alias = None
                                                                                                                self.asset_id_str = None
                                                                                                                self.asset_identification = None
                                                                                                                self.ceport = None
                                                                                                                self.chip_hardware_revision = None
                                                                                                                self.composite_class_code = None
                                                                                                                self.description = None
                                                                                                                self.environmental_monitor_path = None
                                                                                                                self.firmware_revision = None
                                                                                                                self.group_flag = None
                                                                                                                self.hardware_revision = None
                                                                                                                self.is_field_replaceable_unit = None
                                                                                                                self.manufacturer_asset_tags = None
                                                                                                                self.manufacturer_name = None
                                                                                                                self.memory_size = None
                                                                                                                self.model_name = None
                                                                                                                self.name = None
                                                                                                                self.new_deviation_number = None
                                                                                                                self.physical_layer_interface_module_type = None
                                                                                                                self.redundancystate = None
                                                                                                                self.serial_number = None
                                                                                                                self.software_revision = None
                                                                                                                self.unique_id = None
                                                                                                                self.unrecognized_fru = None
                                                                                                                self.vendor_type = None
                                                                                                                self.xr_scoped = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.alias is not None:
                                                                                                                    return True

                                                                                                                if self.asset_id_str is not None:
                                                                                                                    return True

                                                                                                                if self.asset_identification is not None:
                                                                                                                    return True

                                                                                                                if self.ceport is not None:
                                                                                                                    return True

                                                                                                                if self.chip_hardware_revision is not None:
                                                                                                                    return True

                                                                                                                if self.composite_class_code is not None:
                                                                                                                    return True

                                                                                                                if self.description is not None:
                                                                                                                    return True

                                                                                                                if self.environmental_monitor_path is not None:
                                                                                                                    return True

                                                                                                                if self.firmware_revision is not None:
                                                                                                                    return True

                                                                                                                if self.group_flag is not None:
                                                                                                                    return True

                                                                                                                if self.hardware_revision is not None:
                                                                                                                    return True

                                                                                                                if self.is_field_replaceable_unit is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_asset_tags is not None:
                                                                                                                    return True

                                                                                                                if self.manufacturer_name is not None:
                                                                                                                    return True

                                                                                                                if self.memory_size is not None:
                                                                                                                    return True

                                                                                                                if self.model_name is not None:
                                                                                                                    return True

                                                                                                                if self.name is not None:
                                                                                                                    return True

                                                                                                                if self.new_deviation_number is not None:
                                                                                                                    return True

                                                                                                                if self.physical_layer_interface_module_type is not None:
                                                                                                                    return True

                                                                                                                if self.redundancystate is not None:
                                                                                                                    return True

                                                                                                                if self.serial_number is not None:
                                                                                                                    return True

                                                                                                                if self.software_revision is not None:
                                                                                                                    return True

                                                                                                                if self.unique_id is not None:
                                                                                                                    return True

                                                                                                                if self.unrecognized_fru is not None:
                                                                                                                    return True

                                                                                                                if self.vendor_type is not None:
                                                                                                                    return True

                                                                                                                if self.xr_scoped is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvBasicBag']['meta_info']


                                                                                                        class InvEepromInfo(object):
                                                                                                            """
                                                                                                            Inventory EDM EEPROM Information Bag
                                                                                                            
                                                                                                            .. attribute:: description
                                                                                                            
                                                                                                            	A textual description of physical entity
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: eeprom
                                                                                                            
                                                                                                            	EEPROM data not from hex data
                                                                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom>`
                                                                                                            
                                                                                                            .. attribute:: has_eeprom
                                                                                                            
                                                                                                            	use eeprom instead of opaque data
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: inv_card_type
                                                                                                            
                                                                                                            	Inventory card type
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..255
                                                                                                            
                                                                                                            .. attribute:: opaque_data
                                                                                                            
                                                                                                            	EEPROM hex data
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                                            
                                                                                                            .. attribute:: opaque_data_size
                                                                                                            
                                                                                                            	size of the EEPROM hex data
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.description = None
                                                                                                                self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom()
                                                                                                                self.eeprom.parent = self
                                                                                                                self.has_eeprom = None
                                                                                                                self.inv_card_type = None
                                                                                                                self.opaque_data = None
                                                                                                                self.opaque_data_size = None


                                                                                                            class Eeprom(object):
                                                                                                                """
                                                                                                                EEPROM data not from hex data
                                                                                                                
                                                                                                                .. attribute:: asset_alias
                                                                                                                
                                                                                                                	Asset Alias
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: asset_id
                                                                                                                
                                                                                                                	Asset ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address1
                                                                                                                
                                                                                                                	Base Mac Address #1
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address2
                                                                                                                
                                                                                                                	Base Mac Address #2
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address3
                                                                                                                
                                                                                                                	Base Mac Address #3
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: base_mac_address4
                                                                                                                
                                                                                                                	Base Mac Address #4
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_checksum
                                                                                                                
                                                                                                                	Block Checksum
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_count
                                                                                                                
                                                                                                                	Block Count
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_length
                                                                                                                
                                                                                                                	Block Length
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_signature
                                                                                                                
                                                                                                                	Block Signature
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: block_version
                                                                                                                
                                                                                                                	Block Version
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: chassis_sid
                                                                                                                
                                                                                                                	Chassis serial number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: clei
                                                                                                                
                                                                                                                	Common Language Equipment Identifier (CLEI) code
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: controller_family
                                                                                                                
                                                                                                                	Controller family
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: controller_type
                                                                                                                
                                                                                                                	Controller type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: description
                                                                                                                
                                                                                                                	A textual description of physical entity
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num1
                                                                                                                
                                                                                                                	Deviation Number # 1
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num2
                                                                                                                
                                                                                                                	Deviation Number # 2
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num3
                                                                                                                
                                                                                                                	Deviation Number # 3
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num4
                                                                                                                
                                                                                                                	Deviation Number # 4
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num5
                                                                                                                
                                                                                                                	Deviation Number # 5
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num6
                                                                                                                
                                                                                                                	Deviation Number # 6
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: dev_num7
                                                                                                                
                                                                                                                	Deviation Number # 7
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: eci
                                                                                                                
                                                                                                                	Equipment Catalog Item (ECI) number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: eeprom_size
                                                                                                                
                                                                                                                	EEPROM Size
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: engineer_use
                                                                                                                
                                                                                                                	Engineer Use
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: fru_major_type
                                                                                                                
                                                                                                                	FRU Major Type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: fru_minor_type
                                                                                                                
                                                                                                                	FRU Minor Type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: hw_version
                                                                                                                
                                                                                                                	Hardware Version
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: hwid
                                                                                                                
                                                                                                                	Hardware Revision
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: idprom_format_rev
                                                                                                                
                                                                                                                	IDPROM Format Revision
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size1
                                                                                                                
                                                                                                                	Mac Address Block Size #1
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size2
                                                                                                                
                                                                                                                	Mac Address Block Size #2
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size3
                                                                                                                
                                                                                                                	Mac Address Block Size #3
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mac_add_blk_size4
                                                                                                                
                                                                                                                	Mac Address Block Size #4
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: manu_test_data
                                                                                                                
                                                                                                                	Manufacturing Test Data
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mfg_bits
                                                                                                                
                                                                                                                	MFG Bits
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: mfg_deviation
                                                                                                                
                                                                                                                	MFG Deviation
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: oem_string
                                                                                                                
                                                                                                                	OEM String
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: part_number
                                                                                                                
                                                                                                                	Part Number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: part_revision
                                                                                                                
                                                                                                                	Part Revision
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pca_num
                                                                                                                
                                                                                                                	PCA number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pcavid
                                                                                                                
                                                                                                                	PCA revision ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pcb_serial_num
                                                                                                                
                                                                                                                	PCB Serial Number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: pid
                                                                                                                
                                                                                                                	Product ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: power_consumption
                                                                                                                
                                                                                                                	Power Consumption
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: power_supply_type
                                                                                                                
                                                                                                                	Power Supply Type
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: product_id
                                                                                                                
                                                                                                                	Product ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: rma
                                                                                                                
                                                                                                                	RMA Data
                                                                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                                
                                                                                                                .. attribute:: rma_code
                                                                                                                
                                                                                                                	RMA Code
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: serial_number
                                                                                                                
                                                                                                                	Serial Number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: snmpoid
                                                                                                                
                                                                                                                	SNMP OID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: top_assem_part_num
                                                                                                                
                                                                                                                	Top assembly part number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: top_assem_vid
                                                                                                                
                                                                                                                	Top assembly revision number
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: udi_description
                                                                                                                
                                                                                                                	UDI description
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: udi_name
                                                                                                                
                                                                                                                	UDI name
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                .. attribute:: vid
                                                                                                                
                                                                                                                	Version ID
                                                                                                                	**type**\:  str
                                                                                                                
                                                                                                                	**length:** 0..255
                                                                                                                
                                                                                                                

                                                                                                                """

                                                                                                                _prefix = 'invmgr-oper'
                                                                                                                _revision = '2015-11-09'

                                                                                                                def __init__(self):
                                                                                                                    self.parent = None
                                                                                                                    self.asset_alias = None
                                                                                                                    self.asset_id = None
                                                                                                                    self.base_mac_address1 = None
                                                                                                                    self.base_mac_address2 = None
                                                                                                                    self.base_mac_address3 = None
                                                                                                                    self.base_mac_address4 = None
                                                                                                                    self.block_checksum = None
                                                                                                                    self.block_count = None
                                                                                                                    self.block_length = None
                                                                                                                    self.block_signature = None
                                                                                                                    self.block_version = None
                                                                                                                    self.chassis_sid = None
                                                                                                                    self.clei = None
                                                                                                                    self.controller_family = None
                                                                                                                    self.controller_type = None
                                                                                                                    self.description = None
                                                                                                                    self.dev_num1 = None
                                                                                                                    self.dev_num2 = None
                                                                                                                    self.dev_num3 = None
                                                                                                                    self.dev_num4 = None
                                                                                                                    self.dev_num5 = None
                                                                                                                    self.dev_num6 = None
                                                                                                                    self.dev_num7 = None
                                                                                                                    self.eci = None
                                                                                                                    self.eeprom_size = None
                                                                                                                    self.engineer_use = None
                                                                                                                    self.fru_major_type = None
                                                                                                                    self.fru_minor_type = None
                                                                                                                    self.hw_version = None
                                                                                                                    self.hwid = None
                                                                                                                    self.idprom_format_rev = None
                                                                                                                    self.mac_add_blk_size1 = None
                                                                                                                    self.mac_add_blk_size2 = None
                                                                                                                    self.mac_add_blk_size3 = None
                                                                                                                    self.mac_add_blk_size4 = None
                                                                                                                    self.manu_test_data = None
                                                                                                                    self.mfg_bits = None
                                                                                                                    self.mfg_deviation = None
                                                                                                                    self.oem_string = None
                                                                                                                    self.part_number = None
                                                                                                                    self.part_revision = None
                                                                                                                    self.pca_num = None
                                                                                                                    self.pcavid = None
                                                                                                                    self.pcb_serial_num = None
                                                                                                                    self.pid = None
                                                                                                                    self.power_consumption = None
                                                                                                                    self.power_supply_type = None
                                                                                                                    self.product_id = None
                                                                                                                    self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                                    self.rma.parent = self
                                                                                                                    self.rma_code = None
                                                                                                                    self.serial_number = None
                                                                                                                    self.snmpoid = None
                                                                                                                    self.top_assem_part_num = None
                                                                                                                    self.top_assem_vid = None
                                                                                                                    self.udi_description = None
                                                                                                                    self.udi_name = None
                                                                                                                    self.vid = None


                                                                                                                class Rma(object):
                                                                                                                    """
                                                                                                                    RMA Data
                                                                                                                    
                                                                                                                    .. attribute:: rma_history
                                                                                                                    
                                                                                                                    	RMA history
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: rma_number
                                                                                                                    
                                                                                                                    	RMA tracking number format is N\-N\-N
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    .. attribute:: test_history
                                                                                                                    
                                                                                                                    	Test history
                                                                                                                    	**type**\:  str
                                                                                                                    
                                                                                                                    	**length:** 0..255
                                                                                                                    
                                                                                                                    

                                                                                                                    """

                                                                                                                    _prefix = 'invmgr-oper'
                                                                                                                    _revision = '2015-11-09'

                                                                                                                    def __init__(self):
                                                                                                                        self.parent = None
                                                                                                                        self.rma_history = None
                                                                                                                        self.rma_number = None
                                                                                                                        self.test_history = None

                                                                                                                    @property
                                                                                                                    def _common_path(self):
                                                                                                                        if self.parent is None:
                                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                                    def is_config(self):
                                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                                        return False

                                                                                                                    def _has_data(self):
                                                                                                                        if not self.is_config():
                                                                                                                            return False
                                                                                                                        if self.rma_history is not None:
                                                                                                                            return True

                                                                                                                        if self.rma_number is not None:
                                                                                                                            return True

                                                                                                                        if self.test_history is not None:
                                                                                                                            return True

                                                                                                                        return False

                                                                                                                    @staticmethod
                                                                                                                    def _meta_info():
                                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                                @property
                                                                                                                def _common_path(self):
                                                                                                                    if self.parent is None:
                                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                                def is_config(self):
                                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                                    return False

                                                                                                                def _has_data(self):
                                                                                                                    if not self.is_config():
                                                                                                                        return False
                                                                                                                    if self.asset_alias is not None:
                                                                                                                        return True

                                                                                                                    if self.asset_id is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address1 is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address2 is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address3 is not None:
                                                                                                                        return True

                                                                                                                    if self.base_mac_address4 is not None:
                                                                                                                        return True

                                                                                                                    if self.block_checksum is not None:
                                                                                                                        return True

                                                                                                                    if self.block_count is not None:
                                                                                                                        return True

                                                                                                                    if self.block_length is not None:
                                                                                                                        return True

                                                                                                                    if self.block_signature is not None:
                                                                                                                        return True

                                                                                                                    if self.block_version is not None:
                                                                                                                        return True

                                                                                                                    if self.chassis_sid is not None:
                                                                                                                        return True

                                                                                                                    if self.clei is not None:
                                                                                                                        return True

                                                                                                                    if self.controller_family is not None:
                                                                                                                        return True

                                                                                                                    if self.controller_type is not None:
                                                                                                                        return True

                                                                                                                    if self.description is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num1 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num2 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num3 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num4 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num5 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num6 is not None:
                                                                                                                        return True

                                                                                                                    if self.dev_num7 is not None:
                                                                                                                        return True

                                                                                                                    if self.eci is not None:
                                                                                                                        return True

                                                                                                                    if self.eeprom_size is not None:
                                                                                                                        return True

                                                                                                                    if self.engineer_use is not None:
                                                                                                                        return True

                                                                                                                    if self.fru_major_type is not None:
                                                                                                                        return True

                                                                                                                    if self.fru_minor_type is not None:
                                                                                                                        return True

                                                                                                                    if self.hw_version is not None:
                                                                                                                        return True

                                                                                                                    if self.hwid is not None:
                                                                                                                        return True

                                                                                                                    if self.idprom_format_rev is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size1 is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size2 is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size3 is not None:
                                                                                                                        return True

                                                                                                                    if self.mac_add_blk_size4 is not None:
                                                                                                                        return True

                                                                                                                    if self.manu_test_data is not None:
                                                                                                                        return True

                                                                                                                    if self.mfg_bits is not None:
                                                                                                                        return True

                                                                                                                    if self.mfg_deviation is not None:
                                                                                                                        return True

                                                                                                                    if self.oem_string is not None:
                                                                                                                        return True

                                                                                                                    if self.part_number is not None:
                                                                                                                        return True

                                                                                                                    if self.part_revision is not None:
                                                                                                                        return True

                                                                                                                    if self.pca_num is not None:
                                                                                                                        return True

                                                                                                                    if self.pcavid is not None:
                                                                                                                        return True

                                                                                                                    if self.pcb_serial_num is not None:
                                                                                                                        return True

                                                                                                                    if self.pid is not None:
                                                                                                                        return True

                                                                                                                    if self.power_consumption is not None:
                                                                                                                        return True

                                                                                                                    if self.power_supply_type is not None:
                                                                                                                        return True

                                                                                                                    if self.product_id is not None:
                                                                                                                        return True

                                                                                                                    if self.rma is not None and self.rma._has_data():
                                                                                                                        return True

                                                                                                                    if self.rma_code is not None:
                                                                                                                        return True

                                                                                                                    if self.serial_number is not None:
                                                                                                                        return True

                                                                                                                    if self.snmpoid is not None:
                                                                                                                        return True

                                                                                                                    if self.top_assem_part_num is not None:
                                                                                                                        return True

                                                                                                                    if self.top_assem_vid is not None:
                                                                                                                        return True

                                                                                                                    if self.udi_description is not None:
                                                                                                                        return True

                                                                                                                    if self.udi_name is not None:
                                                                                                                        return True

                                                                                                                    if self.vid is not None:
                                                                                                                        return True

                                                                                                                    return False

                                                                                                                @staticmethod
                                                                                                                def _meta_info():
                                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.description is not None:
                                                                                                                    return True

                                                                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                                                                    return True

                                                                                                                if self.has_eeprom is not None:
                                                                                                                    return True

                                                                                                                if self.inv_card_type is not None:
                                                                                                                    return True

                                                                                                                if self.opaque_data is not None:
                                                                                                                    return True

                                                                                                                if self.opaque_data_size is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes.InvEepromInfo']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                                return True

                                                                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                                return True

                                                                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                                                                return True

                                                                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                                return True

                                                                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                                return True

                                                                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                                return True

                                                                                                            if self.module_done is not None:
                                                                                                                return True

                                                                                                            if self.node_id is not None:
                                                                                                                return True

                                                                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                                return True

                                                                                                            if self.threshold is not None and self.threshold._has_data():
                                                                                                                return True

                                                                                                            if self.vm_done is not None:
                                                                                                                return True

                                                                                                            if self.vm_node_id is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10.Attributes']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                                        if self.name is None:
                                                                                                            raise YPYModelError('Key property name is None')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi10[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.name is not None:
                                                                                                            return True

                                                                                                        if self.attributes is not None and self.attributes._has_data():
                                                                                                            return True

                                                                                                        if self.tsi11s is not None and self.tsi11s._has_data():
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S.Tsi10']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi10s'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.tsi10 is not None:
                                                                                                        for child_ref in self.tsi10:
                                                                                                            if child_ref._has_data():
                                                                                                                return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Tsi10S']['meta_info']


                                                                                            class Attributes(object):
                                                                                                """
                                                                                                Attributes
                                                                                                
                                                                                                .. attribute:: env_sensor_info
                                                                                                
                                                                                                	Environment sensor info
                                                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfo>`
                                                                                                
                                                                                                .. attribute:: env_sensor_info_xml
                                                                                                
                                                                                                	Environment sensor info XML
                                                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml>`
                                                                                                
                                                                                                .. attribute:: fru_info
                                                                                                
                                                                                                	Inventory EDM FRU info
                                                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo>`
                                                                                                
                                                                                                .. attribute:: inv_asset_bag
                                                                                                
                                                                                                	Inventory Asset Bag
                                                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvAssetBag>`
                                                                                                
                                                                                                .. attribute:: inv_basic_bag
                                                                                                
                                                                                                	Inventory Basic Bag
                                                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvBasicBag>`
                                                                                                
                                                                                                .. attribute:: inv_eeprom_info
                                                                                                
                                                                                                	Inventory EDM EEPROM Information Bag
                                                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo>`
                                                                                                
                                                                                                .. attribute:: module_done
                                                                                                
                                                                                                	Inventory EDM Module Done Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**default value**\: 1
                                                                                                
                                                                                                .. attribute:: node_id
                                                                                                
                                                                                                	Node ID Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** 0..4294967295
                                                                                                
                                                                                                .. attribute:: pwg_info
                                                                                                
                                                                                                	Inventory EDM PWG info
                                                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.PwgInfo>`
                                                                                                
                                                                                                .. attribute:: threshold
                                                                                                
                                                                                                	Threshold
                                                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold>`
                                                                                                
                                                                                                .. attribute:: vm_done
                                                                                                
                                                                                                	VM Done Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                .. attribute:: vm_node_id
                                                                                                
                                                                                                	VM Node ID Tuple
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** 0..4294967295
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfo()
                                                                                                    self.env_sensor_info.parent = self
                                                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml()
                                                                                                    self.env_sensor_info_xml.parent = self
                                                                                                    self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo()
                                                                                                    self.fru_info.parent = self
                                                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvAssetBag()
                                                                                                    self.inv_asset_bag.parent = self
                                                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvBasicBag()
                                                                                                    self.inv_basic_bag.parent = self
                                                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo()
                                                                                                    self.inv_eeprom_info.parent = self
                                                                                                    self.module_done = None
                                                                                                    self.node_id = None
                                                                                                    self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.PwgInfo()
                                                                                                    self.pwg_info.parent = self
                                                                                                    self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold()
                                                                                                    self.threshold.parent = self
                                                                                                    self.vm_done = None
                                                                                                    self.vm_node_id = None


                                                                                                class EnvSensorInfo(object):
                                                                                                    """
                                                                                                    Environment sensor info
                                                                                                    
                                                                                                    .. attribute:: age_time_stamp
                                                                                                    
                                                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: alarm_type
                                                                                                    
                                                                                                    	Indicates threshold violation
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: data_type
                                                                                                    
                                                                                                    	Sensor data type enums
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: device_description
                                                                                                    
                                                                                                    	Device Name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: device_id
                                                                                                    
                                                                                                    	Identifier for this device
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: field_validity_bitmap
                                                                                                    
                                                                                                    	Sensor valid bitmap
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: precision
                                                                                                    
                                                                                                    	Sensor precision range
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: scale
                                                                                                    
                                                                                                    	Sensor scale enums
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: status
                                                                                                    
                                                                                                    	Sensor operation state enums
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: units
                                                                                                    
                                                                                                    	Units of variable being read
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: update_rate
                                                                                                    
                                                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: value
                                                                                                    
                                                                                                    	Current reading of sensor
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.age_time_stamp = None
                                                                                                        self.alarm_type = None
                                                                                                        self.data_type = None
                                                                                                        self.device_description = None
                                                                                                        self.device_id = None
                                                                                                        self.field_validity_bitmap = None
                                                                                                        self.precision = None
                                                                                                        self.scale = None
                                                                                                        self.status = None
                                                                                                        self.units = None
                                                                                                        self.update_rate = None
                                                                                                        self.value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.age_time_stamp is not None:
                                                                                                            return True

                                                                                                        if self.alarm_type is not None:
                                                                                                            return True

                                                                                                        if self.data_type is not None:
                                                                                                            return True

                                                                                                        if self.device_description is not None:
                                                                                                            return True

                                                                                                        if self.device_id is not None:
                                                                                                            return True

                                                                                                        if self.field_validity_bitmap is not None:
                                                                                                            return True

                                                                                                        if self.precision is not None:
                                                                                                            return True

                                                                                                        if self.scale is not None:
                                                                                                            return True

                                                                                                        if self.status is not None:
                                                                                                            return True

                                                                                                        if self.units is not None:
                                                                                                            return True

                                                                                                        if self.update_rate is not None:
                                                                                                            return True

                                                                                                        if self.value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfo']['meta_info']


                                                                                                class PwgInfo(object):
                                                                                                    """
                                                                                                    Inventory EDM PWG info
                                                                                                    
                                                                                                    .. attribute:: power_group_available_current
                                                                                                    
                                                                                                    	available current
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_group_drawn_current
                                                                                                    
                                                                                                    	drawn current
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_group_power_units
                                                                                                    
                                                                                                    	power units
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    .. attribute:: power_group_redundancy_mode
                                                                                                    
                                                                                                    	redundancy mode
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.power_group_available_current = None
                                                                                                        self.power_group_drawn_current = None
                                                                                                        self.power_group_power_units = None
                                                                                                        self.power_group_redundancy_mode = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.power_group_available_current is not None:
                                                                                                            return True

                                                                                                        if self.power_group_drawn_current is not None:
                                                                                                            return True

                                                                                                        if self.power_group_power_units is not None:
                                                                                                            return True

                                                                                                        if self.power_group_redundancy_mode is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.PwgInfo']['meta_info']


                                                                                                class EnvSensorInfoXml(object):
                                                                                                    """
                                                                                                    Environment sensor info XML
                                                                                                    
                                                                                                    .. attribute:: data_type
                                                                                                    
                                                                                                    	Sensor data type
                                                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                                    
                                                                                                    .. attribute:: description
                                                                                                    
                                                                                                    	Device Name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: status
                                                                                                    
                                                                                                    	Sensor operation state
                                                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                                    
                                                                                                    .. attribute:: threshold
                                                                                                    
                                                                                                    	Threshold information
                                                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                                    
                                                                                                    .. attribute:: units
                                                                                                    
                                                                                                    	Units of variable being read
                                                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                                    
                                                                                                    .. attribute:: update_rate
                                                                                                    
                                                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: value
                                                                                                    
                                                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.data_type = None
                                                                                                        self.description = None
                                                                                                        self.status = None
                                                                                                        self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                        self.threshold.parent = self
                                                                                                        self.units = None
                                                                                                        self.update_rate = None
                                                                                                        self.value = None


                                                                                                    class Threshold(object):
                                                                                                        """
                                                                                                        Threshold information
                                                                                                        
                                                                                                        .. attribute:: threshold_array
                                                                                                        
                                                                                                        	Array of threshold
                                                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.threshold_array = YList()
                                                                                                            self.threshold_array.parent = self
                                                                                                            self.threshold_array.name = 'threshold_array'


                                                                                                        class ThresholdArray(object):
                                                                                                            """
                                                                                                            Array of threshold
                                                                                                            
                                                                                                            .. attribute:: threshold_name
                                                                                                            
                                                                                                            	Threshold name
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..50
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** \-2147483648..2147483647
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_name = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_name is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.threshold_array is not None:
                                                                                                                for child_ref in self.threshold_array:
                                                                                                                    if child_ref._has_data():
                                                                                                                        return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.data_type is not None:
                                                                                                            return True

                                                                                                        if self.description is not None:
                                                                                                            return True

                                                                                                        if self.status is not None:
                                                                                                            return True

                                                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                                                            return True

                                                                                                        if self.units is not None:
                                                                                                            return True

                                                                                                        if self.update_rate is not None:
                                                                                                            return True

                                                                                                        if self.value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                                class InvAssetBag(object):
                                                                                                    """
                                                                                                    Inventory Asset Bag
                                                                                                    
                                                                                                    .. attribute:: manufacturer_assembly_number
                                                                                                    
                                                                                                    	Manufacture Assembly number
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_assembly_revision
                                                                                                    
                                                                                                    	Manufacture assembly revision
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                                    
                                                                                                    	Common Language Equipment           Identifier number
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                                                    
                                                                                                    	
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: manufacturer_software_identifier
                                                                                                    
                                                                                                    	
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                                                    
                                                                                                    	String containing OEM information           if applicable
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: part_number
                                                                                                    
                                                                                                    	
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.manufacturer_assembly_number = None
                                                                                                        self.manufacturer_assembly_revision = None
                                                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                                                        self.manufacturer_firmware_identifier = None
                                                                                                        self.manufacturer_software_identifier = None
                                                                                                        self.original_equipment_manufacturer_string = None
                                                                                                        self.part_number = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.manufacturer_assembly_number is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_assembly_revision is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_software_identifier is not None:
                                                                                                            return True

                                                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                                                            return True

                                                                                                        if self.part_number is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvAssetBag']['meta_info']


                                                                                                class Threshold(object):
                                                                                                    """
                                                                                                    Threshold
                                                                                                    
                                                                                                    .. attribute:: critical_hi
                                                                                                    
                                                                                                    	Critical High
                                                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi>`
                                                                                                    
                                                                                                    .. attribute:: critical_lo
                                                                                                    
                                                                                                    	Critical Low
                                                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo>`
                                                                                                    
                                                                                                    .. attribute:: major_hi
                                                                                                    
                                                                                                    	Major High
                                                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi>`
                                                                                                    
                                                                                                    .. attribute:: major_lo
                                                                                                    
                                                                                                    	Major Low
                                                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo>`
                                                                                                    
                                                                                                    .. attribute:: minor_hi
                                                                                                    
                                                                                                    	Minor High
                                                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi>`
                                                                                                    
                                                                                                    .. attribute:: minor_lo
                                                                                                    
                                                                                                    	Minor Low
                                                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo>`
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi()
                                                                                                        self.critical_hi.parent = self
                                                                                                        self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo()
                                                                                                        self.critical_lo.parent = self
                                                                                                        self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi()
                                                                                                        self.major_hi.parent = self
                                                                                                        self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo()
                                                                                                        self.major_lo.parent = self
                                                                                                        self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi()
                                                                                                        self.minor_hi.parent = self
                                                                                                        self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo()
                                                                                                        self.minor_lo.parent = self


                                                                                                    class MajorLo(object):
                                                                                                        """
                                                                                                        Major Low
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorLo']['meta_info']


                                                                                                    class CriticalHi(object):
                                                                                                        """
                                                                                                        Critical High
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                                    class MinorHi(object):
                                                                                                        """
                                                                                                        Minor High
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorHi']['meta_info']


                                                                                                    class MajorHi(object):
                                                                                                        """
                                                                                                        Major High
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MajorHi']['meta_info']


                                                                                                    class CriticalLo(object):
                                                                                                        """
                                                                                                        Critical Low
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                                    class MinorLo(object):
                                                                                                        """
                                                                                                        Minor Low
                                                                                                        
                                                                                                        .. attribute:: thresh_bag
                                                                                                        
                                                                                                        	Environment threshold info
                                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                            self.thresh_bag.parent = self


                                                                                                        class ThreshBag(object):
                                                                                                            """
                                                                                                            Environment threshold info
                                                                                                            
                                                                                                            .. attribute:: threshold_evaluation
                                                                                                            
                                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_notification_enabled
                                                                                                            
                                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                            	**type**\:  bool
                                                                                                            
                                                                                                            .. attribute:: threshold_relation
                                                                                                            
                                                                                                            	Indicates relation between sensor value and threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_severity
                                                                                                            
                                                                                                            	Indicates minor, major, critical severities
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            .. attribute:: threshold_value
                                                                                                            
                                                                                                            	Value of the configured threshold
                                                                                                            	**type**\:  int
                                                                                                            
                                                                                                            	**range:** 0..4294967295
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.threshold_evaluation = None
                                                                                                                self.threshold_notification_enabled = None
                                                                                                                self.threshold_relation = None
                                                                                                                self.threshold_severity = None
                                                                                                                self.threshold_value = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.threshold_evaluation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_relation is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_severity is not None:
                                                                                                                    return True

                                                                                                                if self.threshold_value is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold.MinorLo']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                            return True

                                                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                            return True

                                                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                                                            return True

                                                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                                                            return True

                                                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                            return True

                                                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.Threshold']['meta_info']


                                                                                                class FruInfo(object):
                                                                                                    """
                                                                                                    Inventory EDM FRU info
                                                                                                    
                                                                                                    .. attribute:: card_administrative_state
                                                                                                    
                                                                                                    	card admin state\: shutdown or not
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: card_monitor_state
                                                                                                    
                                                                                                    	card is monitored by a manager or left unmonitored
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: card_operational_state
                                                                                                    
                                                                                                    	card operation state
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: card_reset_reason
                                                                                                    
                                                                                                    	card reset reason enum
                                                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                                    
                                                                                                    .. attribute:: card_up_time
                                                                                                    
                                                                                                    	card up time
                                                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.CardUpTime>`
                                                                                                    
                                                                                                    .. attribute:: last_operational_state_change
                                                                                                    
                                                                                                    	last card oper change state
                                                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                                    
                                                                                                    .. attribute:: power_administrative_state
                                                                                                    
                                                                                                    	power admin state\: up or down
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_current_measurement
                                                                                                    
                                                                                                    	power current\: not implemented
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: power_operational_state
                                                                                                    
                                                                                                    	Power operation state
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.card_administrative_state = None
                                                                                                        self.card_monitor_state = None
                                                                                                        self.card_operational_state = None
                                                                                                        self.card_reset_reason = None
                                                                                                        self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.CardUpTime()
                                                                                                        self.card_up_time.parent = self
                                                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                        self.last_operational_state_change.parent = self
                                                                                                        self.power_administrative_state = None
                                                                                                        self.power_current_measurement = None
                                                                                                        self.power_operational_state = None


                                                                                                    class LastOperationalStateChange(object):
                                                                                                        """
                                                                                                        last card oper change state
                                                                                                        
                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                        
                                                                                                        	Time Value in Nano\-seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: nanosecond
                                                                                                        
                                                                                                        .. attribute:: time_in_seconds
                                                                                                        
                                                                                                        	Time Value in Seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: second
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.time_in_nano_seconds = None
                                                                                                            self.time_in_seconds = None

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                return True

                                                                                                            if self.time_in_seconds is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                                    class CardUpTime(object):
                                                                                                        """
                                                                                                        card up time
                                                                                                        
                                                                                                        .. attribute:: time_in_nano_seconds
                                                                                                        
                                                                                                        	Time Value in Nano\-seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: nanosecond
                                                                                                        
                                                                                                        .. attribute:: time_in_seconds
                                                                                                        
                                                                                                        	Time Value in Seconds
                                                                                                        	**type**\:  int
                                                                                                        
                                                                                                        	**range:** \-2147483648..2147483647
                                                                                                        
                                                                                                        	**units**\: second
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.time_in_nano_seconds = None
                                                                                                            self.time_in_seconds = None

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                                return True

                                                                                                            if self.time_in_seconds is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.card_administrative_state is not None:
                                                                                                            return True

                                                                                                        if self.card_monitor_state is not None:
                                                                                                            return True

                                                                                                        if self.card_operational_state is not None:
                                                                                                            return True

                                                                                                        if self.card_reset_reason is not None:
                                                                                                            return True

                                                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                            return True

                                                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                            return True

                                                                                                        if self.power_administrative_state is not None:
                                                                                                            return True

                                                                                                        if self.power_current_measurement is not None:
                                                                                                            return True

                                                                                                        if self.power_operational_state is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.FruInfo']['meta_info']


                                                                                                class InvBasicBag(object):
                                                                                                    """
                                                                                                    Inventory Basic Bag
                                                                                                    
                                                                                                    .. attribute:: alias
                                                                                                    
                                                                                                    	useful for storing an entity alias 
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: asset_id_str
                                                                                                    
                                                                                                    	asset Identification string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: asset_identification
                                                                                                    
                                                                                                    	asset Identification
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: ceport
                                                                                                    
                                                                                                    	1 if ce port found, 0 if not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: chip_hardware_revision
                                                                                                    
                                                                                                    	chip module hw revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: composite_class_code
                                                                                                    
                                                                                                    	Major&minor class of the entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: description
                                                                                                    
                                                                                                    	describes in user\-readable terms       what the entity in question does
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: environmental_monitor_path
                                                                                                    
                                                                                                    	sysdb name of sensor in the envmon EDM
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: firmware_revision
                                                                                                    
                                                                                                    	firmware revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: group_flag
                                                                                                    
                                                                                                    	indicates if this entity is group       or not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: hardware_revision
                                                                                                    
                                                                                                    	hw revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: is_field_replaceable_unit
                                                                                                    
                                                                                                    	1 if Field Replaceable Unit 0, if not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: manufacturer_asset_tags
                                                                                                    
                                                                                                    	Manufacture Asset Tags
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: manufacturer_name
                                                                                                    
                                                                                                    	manufacturer's name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: memory_size
                                                                                                    
                                                                                                    	Size of memory associated with       the entity where applicable
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: model_name
                                                                                                    
                                                                                                    	model name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: name
                                                                                                    
                                                                                                    	name string for the entity
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: new_deviation_number
                                                                                                    
                                                                                                    	integer value for New Deviation Number 0x88
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: physical_layer_interface_module_type
                                                                                                    
                                                                                                    	integer value for plim type if     applicable to this entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: redundancystate
                                                                                                    
                                                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: serial_number
                                                                                                    
                                                                                                    	serial number
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: software_revision
                                                                                                    
                                                                                                    	software revision string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: unique_id
                                                                                                    
                                                                                                    	Unique id for an entity
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    .. attribute:: unrecognized_fru
                                                                                                    
                                                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: vendor_type
                                                                                                    
                                                                                                    	maps to the vendor OID string
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: xr_scoped
                                                                                                    
                                                                                                    	1 if xr scoped, 0 if not
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.alias = None
                                                                                                        self.asset_id_str = None
                                                                                                        self.asset_identification = None
                                                                                                        self.ceport = None
                                                                                                        self.chip_hardware_revision = None
                                                                                                        self.composite_class_code = None
                                                                                                        self.description = None
                                                                                                        self.environmental_monitor_path = None
                                                                                                        self.firmware_revision = None
                                                                                                        self.group_flag = None
                                                                                                        self.hardware_revision = None
                                                                                                        self.is_field_replaceable_unit = None
                                                                                                        self.manufacturer_asset_tags = None
                                                                                                        self.manufacturer_name = None
                                                                                                        self.memory_size = None
                                                                                                        self.model_name = None
                                                                                                        self.name = None
                                                                                                        self.new_deviation_number = None
                                                                                                        self.physical_layer_interface_module_type = None
                                                                                                        self.redundancystate = None
                                                                                                        self.serial_number = None
                                                                                                        self.software_revision = None
                                                                                                        self.unique_id = None
                                                                                                        self.unrecognized_fru = None
                                                                                                        self.vendor_type = None
                                                                                                        self.xr_scoped = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.alias is not None:
                                                                                                            return True

                                                                                                        if self.asset_id_str is not None:
                                                                                                            return True

                                                                                                        if self.asset_identification is not None:
                                                                                                            return True

                                                                                                        if self.ceport is not None:
                                                                                                            return True

                                                                                                        if self.chip_hardware_revision is not None:
                                                                                                            return True

                                                                                                        if self.composite_class_code is not None:
                                                                                                            return True

                                                                                                        if self.description is not None:
                                                                                                            return True

                                                                                                        if self.environmental_monitor_path is not None:
                                                                                                            return True

                                                                                                        if self.firmware_revision is not None:
                                                                                                            return True

                                                                                                        if self.group_flag is not None:
                                                                                                            return True

                                                                                                        if self.hardware_revision is not None:
                                                                                                            return True

                                                                                                        if self.is_field_replaceable_unit is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_asset_tags is not None:
                                                                                                            return True

                                                                                                        if self.manufacturer_name is not None:
                                                                                                            return True

                                                                                                        if self.memory_size is not None:
                                                                                                            return True

                                                                                                        if self.model_name is not None:
                                                                                                            return True

                                                                                                        if self.name is not None:
                                                                                                            return True

                                                                                                        if self.new_deviation_number is not None:
                                                                                                            return True

                                                                                                        if self.physical_layer_interface_module_type is not None:
                                                                                                            return True

                                                                                                        if self.redundancystate is not None:
                                                                                                            return True

                                                                                                        if self.serial_number is not None:
                                                                                                            return True

                                                                                                        if self.software_revision is not None:
                                                                                                            return True

                                                                                                        if self.unique_id is not None:
                                                                                                            return True

                                                                                                        if self.unrecognized_fru is not None:
                                                                                                            return True

                                                                                                        if self.vendor_type is not None:
                                                                                                            return True

                                                                                                        if self.xr_scoped is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvBasicBag']['meta_info']


                                                                                                class InvEepromInfo(object):
                                                                                                    """
                                                                                                    Inventory EDM EEPROM Information Bag
                                                                                                    
                                                                                                    .. attribute:: description
                                                                                                    
                                                                                                    	A textual description of physical entity
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: eeprom
                                                                                                    
                                                                                                    	EEPROM data not from hex data
                                                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom>`
                                                                                                    
                                                                                                    .. attribute:: has_eeprom
                                                                                                    
                                                                                                    	use eeprom instead of opaque data
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: inv_card_type
                                                                                                    
                                                                                                    	Inventory card type
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..255
                                                                                                    
                                                                                                    .. attribute:: opaque_data
                                                                                                    
                                                                                                    	EEPROM hex data
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                                    
                                                                                                    .. attribute:: opaque_data_size
                                                                                                    
                                                                                                    	size of the EEPROM hex data
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.description = None
                                                                                                        self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom()
                                                                                                        self.eeprom.parent = self
                                                                                                        self.has_eeprom = None
                                                                                                        self.inv_card_type = None
                                                                                                        self.opaque_data = None
                                                                                                        self.opaque_data_size = None


                                                                                                    class Eeprom(object):
                                                                                                        """
                                                                                                        EEPROM data not from hex data
                                                                                                        
                                                                                                        .. attribute:: asset_alias
                                                                                                        
                                                                                                        	Asset Alias
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: asset_id
                                                                                                        
                                                                                                        	Asset ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address1
                                                                                                        
                                                                                                        	Base Mac Address #1
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address2
                                                                                                        
                                                                                                        	Base Mac Address #2
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address3
                                                                                                        
                                                                                                        	Base Mac Address #3
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: base_mac_address4
                                                                                                        
                                                                                                        	Base Mac Address #4
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_checksum
                                                                                                        
                                                                                                        	Block Checksum
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_count
                                                                                                        
                                                                                                        	Block Count
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_length
                                                                                                        
                                                                                                        	Block Length
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_signature
                                                                                                        
                                                                                                        	Block Signature
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: block_version
                                                                                                        
                                                                                                        	Block Version
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: chassis_sid
                                                                                                        
                                                                                                        	Chassis serial number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: clei
                                                                                                        
                                                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: controller_family
                                                                                                        
                                                                                                        	Controller family
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: controller_type
                                                                                                        
                                                                                                        	Controller type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: description
                                                                                                        
                                                                                                        	A textual description of physical entity
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num1
                                                                                                        
                                                                                                        	Deviation Number # 1
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num2
                                                                                                        
                                                                                                        	Deviation Number # 2
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num3
                                                                                                        
                                                                                                        	Deviation Number # 3
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num4
                                                                                                        
                                                                                                        	Deviation Number # 4
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num5
                                                                                                        
                                                                                                        	Deviation Number # 5
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num6
                                                                                                        
                                                                                                        	Deviation Number # 6
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: dev_num7
                                                                                                        
                                                                                                        	Deviation Number # 7
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: eci
                                                                                                        
                                                                                                        	Equipment Catalog Item (ECI) number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: eeprom_size
                                                                                                        
                                                                                                        	EEPROM Size
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: engineer_use
                                                                                                        
                                                                                                        	Engineer Use
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: fru_major_type
                                                                                                        
                                                                                                        	FRU Major Type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: fru_minor_type
                                                                                                        
                                                                                                        	FRU Minor Type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: hw_version
                                                                                                        
                                                                                                        	Hardware Version
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: hwid
                                                                                                        
                                                                                                        	Hardware Revision
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: idprom_format_rev
                                                                                                        
                                                                                                        	IDPROM Format Revision
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size1
                                                                                                        
                                                                                                        	Mac Address Block Size #1
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size2
                                                                                                        
                                                                                                        	Mac Address Block Size #2
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size3
                                                                                                        
                                                                                                        	Mac Address Block Size #3
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mac_add_blk_size4
                                                                                                        
                                                                                                        	Mac Address Block Size #4
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: manu_test_data
                                                                                                        
                                                                                                        	Manufacturing Test Data
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mfg_bits
                                                                                                        
                                                                                                        	MFG Bits
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: mfg_deviation
                                                                                                        
                                                                                                        	MFG Deviation
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: oem_string
                                                                                                        
                                                                                                        	OEM String
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: part_number
                                                                                                        
                                                                                                        	Part Number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: part_revision
                                                                                                        
                                                                                                        	Part Revision
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pca_num
                                                                                                        
                                                                                                        	PCA number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pcavid
                                                                                                        
                                                                                                        	PCA revision ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pcb_serial_num
                                                                                                        
                                                                                                        	PCB Serial Number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: pid
                                                                                                        
                                                                                                        	Product ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: power_consumption
                                                                                                        
                                                                                                        	Power Consumption
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: power_supply_type
                                                                                                        
                                                                                                        	Power Supply Type
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: product_id
                                                                                                        
                                                                                                        	Product ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: rma
                                                                                                        
                                                                                                        	RMA Data
                                                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                        
                                                                                                        .. attribute:: rma_code
                                                                                                        
                                                                                                        	RMA Code
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: serial_number
                                                                                                        
                                                                                                        	Serial Number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: snmpoid
                                                                                                        
                                                                                                        	SNMP OID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: top_assem_part_num
                                                                                                        
                                                                                                        	Top assembly part number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: top_assem_vid
                                                                                                        
                                                                                                        	Top assembly revision number
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: udi_description
                                                                                                        
                                                                                                        	UDI description
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: udi_name
                                                                                                        
                                                                                                        	UDI name
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        .. attribute:: vid
                                                                                                        
                                                                                                        	Version ID
                                                                                                        	**type**\:  str
                                                                                                        
                                                                                                        	**length:** 0..255
                                                                                                        
                                                                                                        

                                                                                                        """

                                                                                                        _prefix = 'invmgr-oper'
                                                                                                        _revision = '2015-11-09'

                                                                                                        def __init__(self):
                                                                                                            self.parent = None
                                                                                                            self.asset_alias = None
                                                                                                            self.asset_id = None
                                                                                                            self.base_mac_address1 = None
                                                                                                            self.base_mac_address2 = None
                                                                                                            self.base_mac_address3 = None
                                                                                                            self.base_mac_address4 = None
                                                                                                            self.block_checksum = None
                                                                                                            self.block_count = None
                                                                                                            self.block_length = None
                                                                                                            self.block_signature = None
                                                                                                            self.block_version = None
                                                                                                            self.chassis_sid = None
                                                                                                            self.clei = None
                                                                                                            self.controller_family = None
                                                                                                            self.controller_type = None
                                                                                                            self.description = None
                                                                                                            self.dev_num1 = None
                                                                                                            self.dev_num2 = None
                                                                                                            self.dev_num3 = None
                                                                                                            self.dev_num4 = None
                                                                                                            self.dev_num5 = None
                                                                                                            self.dev_num6 = None
                                                                                                            self.dev_num7 = None
                                                                                                            self.eci = None
                                                                                                            self.eeprom_size = None
                                                                                                            self.engineer_use = None
                                                                                                            self.fru_major_type = None
                                                                                                            self.fru_minor_type = None
                                                                                                            self.hw_version = None
                                                                                                            self.hwid = None
                                                                                                            self.idprom_format_rev = None
                                                                                                            self.mac_add_blk_size1 = None
                                                                                                            self.mac_add_blk_size2 = None
                                                                                                            self.mac_add_blk_size3 = None
                                                                                                            self.mac_add_blk_size4 = None
                                                                                                            self.manu_test_data = None
                                                                                                            self.mfg_bits = None
                                                                                                            self.mfg_deviation = None
                                                                                                            self.oem_string = None
                                                                                                            self.part_number = None
                                                                                                            self.part_revision = None
                                                                                                            self.pca_num = None
                                                                                                            self.pcavid = None
                                                                                                            self.pcb_serial_num = None
                                                                                                            self.pid = None
                                                                                                            self.power_consumption = None
                                                                                                            self.power_supply_type = None
                                                                                                            self.product_id = None
                                                                                                            self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                            self.rma.parent = self
                                                                                                            self.rma_code = None
                                                                                                            self.serial_number = None
                                                                                                            self.snmpoid = None
                                                                                                            self.top_assem_part_num = None
                                                                                                            self.top_assem_vid = None
                                                                                                            self.udi_description = None
                                                                                                            self.udi_name = None
                                                                                                            self.vid = None


                                                                                                        class Rma(object):
                                                                                                            """
                                                                                                            RMA Data
                                                                                                            
                                                                                                            .. attribute:: rma_history
                                                                                                            
                                                                                                            	RMA history
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: rma_number
                                                                                                            
                                                                                                            	RMA tracking number format is N\-N\-N
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            .. attribute:: test_history
                                                                                                            
                                                                                                            	Test history
                                                                                                            	**type**\:  str
                                                                                                            
                                                                                                            	**length:** 0..255
                                                                                                            
                                                                                                            

                                                                                                            """

                                                                                                            _prefix = 'invmgr-oper'
                                                                                                            _revision = '2015-11-09'

                                                                                                            def __init__(self):
                                                                                                                self.parent = None
                                                                                                                self.rma_history = None
                                                                                                                self.rma_number = None
                                                                                                                self.test_history = None

                                                                                                            @property
                                                                                                            def _common_path(self):
                                                                                                                if self.parent is None:
                                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                            def is_config(self):
                                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                                return False

                                                                                                            def _has_data(self):
                                                                                                                if not self.is_config():
                                                                                                                    return False
                                                                                                                if self.rma_history is not None:
                                                                                                                    return True

                                                                                                                if self.rma_number is not None:
                                                                                                                    return True

                                                                                                                if self.test_history is not None:
                                                                                                                    return True

                                                                                                                return False

                                                                                                            @staticmethod
                                                                                                            def _meta_info():
                                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                        @property
                                                                                                        def _common_path(self):
                                                                                                            if self.parent is None:
                                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                        def is_config(self):
                                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                                            return False

                                                                                                        def _has_data(self):
                                                                                                            if not self.is_config():
                                                                                                                return False
                                                                                                            if self.asset_alias is not None:
                                                                                                                return True

                                                                                                            if self.asset_id is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address1 is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address2 is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address3 is not None:
                                                                                                                return True

                                                                                                            if self.base_mac_address4 is not None:
                                                                                                                return True

                                                                                                            if self.block_checksum is not None:
                                                                                                                return True

                                                                                                            if self.block_count is not None:
                                                                                                                return True

                                                                                                            if self.block_length is not None:
                                                                                                                return True

                                                                                                            if self.block_signature is not None:
                                                                                                                return True

                                                                                                            if self.block_version is not None:
                                                                                                                return True

                                                                                                            if self.chassis_sid is not None:
                                                                                                                return True

                                                                                                            if self.clei is not None:
                                                                                                                return True

                                                                                                            if self.controller_family is not None:
                                                                                                                return True

                                                                                                            if self.controller_type is not None:
                                                                                                                return True

                                                                                                            if self.description is not None:
                                                                                                                return True

                                                                                                            if self.dev_num1 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num2 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num3 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num4 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num5 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num6 is not None:
                                                                                                                return True

                                                                                                            if self.dev_num7 is not None:
                                                                                                                return True

                                                                                                            if self.eci is not None:
                                                                                                                return True

                                                                                                            if self.eeprom_size is not None:
                                                                                                                return True

                                                                                                            if self.engineer_use is not None:
                                                                                                                return True

                                                                                                            if self.fru_major_type is not None:
                                                                                                                return True

                                                                                                            if self.fru_minor_type is not None:
                                                                                                                return True

                                                                                                            if self.hw_version is not None:
                                                                                                                return True

                                                                                                            if self.hwid is not None:
                                                                                                                return True

                                                                                                            if self.idprom_format_rev is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size1 is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size2 is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size3 is not None:
                                                                                                                return True

                                                                                                            if self.mac_add_blk_size4 is not None:
                                                                                                                return True

                                                                                                            if self.manu_test_data is not None:
                                                                                                                return True

                                                                                                            if self.mfg_bits is not None:
                                                                                                                return True

                                                                                                            if self.mfg_deviation is not None:
                                                                                                                return True

                                                                                                            if self.oem_string is not None:
                                                                                                                return True

                                                                                                            if self.part_number is not None:
                                                                                                                return True

                                                                                                            if self.part_revision is not None:
                                                                                                                return True

                                                                                                            if self.pca_num is not None:
                                                                                                                return True

                                                                                                            if self.pcavid is not None:
                                                                                                                return True

                                                                                                            if self.pcb_serial_num is not None:
                                                                                                                return True

                                                                                                            if self.pid is not None:
                                                                                                                return True

                                                                                                            if self.power_consumption is not None:
                                                                                                                return True

                                                                                                            if self.power_supply_type is not None:
                                                                                                                return True

                                                                                                            if self.product_id is not None:
                                                                                                                return True

                                                                                                            if self.rma is not None and self.rma._has_data():
                                                                                                                return True

                                                                                                            if self.rma_code is not None:
                                                                                                                return True

                                                                                                            if self.serial_number is not None:
                                                                                                                return True

                                                                                                            if self.snmpoid is not None:
                                                                                                                return True

                                                                                                            if self.top_assem_part_num is not None:
                                                                                                                return True

                                                                                                            if self.top_assem_vid is not None:
                                                                                                                return True

                                                                                                            if self.udi_description is not None:
                                                                                                                return True

                                                                                                            if self.udi_name is not None:
                                                                                                                return True

                                                                                                            if self.vid is not None:
                                                                                                                return True

                                                                                                            return False

                                                                                                        @staticmethod
                                                                                                        def _meta_info():
                                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.description is not None:
                                                                                                            return True

                                                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                                                            return True

                                                                                                        if self.has_eeprom is not None:
                                                                                                            return True

                                                                                                        if self.inv_card_type is not None:
                                                                                                            return True

                                                                                                        if self.opaque_data is not None:
                                                                                                            return True

                                                                                                        if self.opaque_data_size is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes.InvEepromInfo']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                        return True

                                                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                        return True

                                                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                                                        return True

                                                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                        return True

                                                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                        return True

                                                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                        return True

                                                                                                    if self.module_done is not None:
                                                                                                        return True

                                                                                                    if self.node_id is not None:
                                                                                                        return True

                                                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                        return True

                                                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                                                        return True

                                                                                                    if self.vm_done is not None:
                                                                                                        return True

                                                                                                    if self.vm_node_id is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9.Attributes']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                                if self.name is None:
                                                                                                    raise YPYModelError('Key property name is None')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi9[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.name is not None:
                                                                                                    return True

                                                                                                if self.attributes is not None and self.attributes._has_data():
                                                                                                    return True

                                                                                                if self.tsi10s is not None and self.tsi10s._has_data():
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S.Tsi9']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi9s'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.tsi9 is not None:
                                                                                                for child_ref in self.tsi9:
                                                                                                    if child_ref._has_data():
                                                                                                        return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Tsi9S']['meta_info']


                                                                                    class Attributes(object):
                                                                                        """
                                                                                        Attributes
                                                                                        
                                                                                        .. attribute:: env_sensor_info
                                                                                        
                                                                                        	Environment sensor info
                                                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfo>`
                                                                                        
                                                                                        .. attribute:: env_sensor_info_xml
                                                                                        
                                                                                        	Environment sensor info XML
                                                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml>`
                                                                                        
                                                                                        .. attribute:: fru_info
                                                                                        
                                                                                        	Inventory EDM FRU info
                                                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo>`
                                                                                        
                                                                                        .. attribute:: inv_asset_bag
                                                                                        
                                                                                        	Inventory Asset Bag
                                                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvAssetBag>`
                                                                                        
                                                                                        .. attribute:: inv_basic_bag
                                                                                        
                                                                                        	Inventory Basic Bag
                                                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvBasicBag>`
                                                                                        
                                                                                        .. attribute:: inv_eeprom_info
                                                                                        
                                                                                        	Inventory EDM EEPROM Information Bag
                                                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo>`
                                                                                        
                                                                                        .. attribute:: module_done
                                                                                        
                                                                                        	Inventory EDM Module Done Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**default value**\: 1
                                                                                        
                                                                                        .. attribute:: node_id
                                                                                        
                                                                                        	Node ID Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** 0..4294967295
                                                                                        
                                                                                        .. attribute:: pwg_info
                                                                                        
                                                                                        	Inventory EDM PWG info
                                                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.PwgInfo>`
                                                                                        
                                                                                        .. attribute:: threshold
                                                                                        
                                                                                        	Threshold
                                                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold>`
                                                                                        
                                                                                        .. attribute:: vm_done
                                                                                        
                                                                                        	VM Done Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        .. attribute:: vm_node_id
                                                                                        
                                                                                        	VM Node ID Tuple
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** 0..4294967295
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfo()
                                                                                            self.env_sensor_info.parent = self
                                                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml()
                                                                                            self.env_sensor_info_xml.parent = self
                                                                                            self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo()
                                                                                            self.fru_info.parent = self
                                                                                            self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvAssetBag()
                                                                                            self.inv_asset_bag.parent = self
                                                                                            self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvBasicBag()
                                                                                            self.inv_basic_bag.parent = self
                                                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo()
                                                                                            self.inv_eeprom_info.parent = self
                                                                                            self.module_done = None
                                                                                            self.node_id = None
                                                                                            self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.PwgInfo()
                                                                                            self.pwg_info.parent = self
                                                                                            self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold()
                                                                                            self.threshold.parent = self
                                                                                            self.vm_done = None
                                                                                            self.vm_node_id = None


                                                                                        class EnvSensorInfo(object):
                                                                                            """
                                                                                            Environment sensor info
                                                                                            
                                                                                            .. attribute:: age_time_stamp
                                                                                            
                                                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: alarm_type
                                                                                            
                                                                                            	Indicates threshold violation
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: data_type
                                                                                            
                                                                                            	Sensor data type enums
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: device_description
                                                                                            
                                                                                            	Device Name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: device_id
                                                                                            
                                                                                            	Identifier for this device
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: field_validity_bitmap
                                                                                            
                                                                                            	Sensor valid bitmap
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: precision
                                                                                            
                                                                                            	Sensor precision range
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: scale
                                                                                            
                                                                                            	Sensor scale enums
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: status
                                                                                            
                                                                                            	Sensor operation state enums
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: units
                                                                                            
                                                                                            	Units of variable being read
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: update_rate
                                                                                            
                                                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: value
                                                                                            
                                                                                            	Current reading of sensor
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.age_time_stamp = None
                                                                                                self.alarm_type = None
                                                                                                self.data_type = None
                                                                                                self.device_description = None
                                                                                                self.device_id = None
                                                                                                self.field_validity_bitmap = None
                                                                                                self.precision = None
                                                                                                self.scale = None
                                                                                                self.status = None
                                                                                                self.units = None
                                                                                                self.update_rate = None
                                                                                                self.value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.age_time_stamp is not None:
                                                                                                    return True

                                                                                                if self.alarm_type is not None:
                                                                                                    return True

                                                                                                if self.data_type is not None:
                                                                                                    return True

                                                                                                if self.device_description is not None:
                                                                                                    return True

                                                                                                if self.device_id is not None:
                                                                                                    return True

                                                                                                if self.field_validity_bitmap is not None:
                                                                                                    return True

                                                                                                if self.precision is not None:
                                                                                                    return True

                                                                                                if self.scale is not None:
                                                                                                    return True

                                                                                                if self.status is not None:
                                                                                                    return True

                                                                                                if self.units is not None:
                                                                                                    return True

                                                                                                if self.update_rate is not None:
                                                                                                    return True

                                                                                                if self.value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfo']['meta_info']


                                                                                        class PwgInfo(object):
                                                                                            """
                                                                                            Inventory EDM PWG info
                                                                                            
                                                                                            .. attribute:: power_group_available_current
                                                                                            
                                                                                            	available current
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_group_drawn_current
                                                                                            
                                                                                            	drawn current
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_group_power_units
                                                                                            
                                                                                            	power units
                                                                                            	**type**\:  str
                                                                                            
                                                                                            .. attribute:: power_group_redundancy_mode
                                                                                            
                                                                                            	redundancy mode
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.power_group_available_current = None
                                                                                                self.power_group_drawn_current = None
                                                                                                self.power_group_power_units = None
                                                                                                self.power_group_redundancy_mode = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.power_group_available_current is not None:
                                                                                                    return True

                                                                                                if self.power_group_drawn_current is not None:
                                                                                                    return True

                                                                                                if self.power_group_power_units is not None:
                                                                                                    return True

                                                                                                if self.power_group_redundancy_mode is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.PwgInfo']['meta_info']


                                                                                        class EnvSensorInfoXml(object):
                                                                                            """
                                                                                            Environment sensor info XML
                                                                                            
                                                                                            .. attribute:: data_type
                                                                                            
                                                                                            	Sensor data type
                                                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                            
                                                                                            .. attribute:: description
                                                                                            
                                                                                            	Device Name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: status
                                                                                            
                                                                                            	Sensor operation state
                                                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                            
                                                                                            .. attribute:: threshold
                                                                                            
                                                                                            	Threshold information
                                                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                            
                                                                                            .. attribute:: units
                                                                                            
                                                                                            	Units of variable being read
                                                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                            
                                                                                            .. attribute:: update_rate
                                                                                            
                                                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: value
                                                                                            
                                                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.data_type = None
                                                                                                self.description = None
                                                                                                self.status = None
                                                                                                self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold()
                                                                                                self.threshold.parent = self
                                                                                                self.units = None
                                                                                                self.update_rate = None
                                                                                                self.value = None


                                                                                            class Threshold(object):
                                                                                                """
                                                                                                Threshold information
                                                                                                
                                                                                                .. attribute:: threshold_array
                                                                                                
                                                                                                	Array of threshold
                                                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.threshold_array = YList()
                                                                                                    self.threshold_array.parent = self
                                                                                                    self.threshold_array.name = 'threshold_array'


                                                                                                class ThresholdArray(object):
                                                                                                    """
                                                                                                    Array of threshold
                                                                                                    
                                                                                                    .. attribute:: threshold_name
                                                                                                    
                                                                                                    	Threshold name
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..50
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** \-2147483648..2147483647
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_name = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_name is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.threshold_array is not None:
                                                                                                        for child_ref in self.threshold_array:
                                                                                                            if child_ref._has_data():
                                                                                                                return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.data_type is not None:
                                                                                                    return True

                                                                                                if self.description is not None:
                                                                                                    return True

                                                                                                if self.status is not None:
                                                                                                    return True

                                                                                                if self.threshold is not None and self.threshold._has_data():
                                                                                                    return True

                                                                                                if self.units is not None:
                                                                                                    return True

                                                                                                if self.update_rate is not None:
                                                                                                    return True

                                                                                                if self.value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                        class InvAssetBag(object):
                                                                                            """
                                                                                            Inventory Asset Bag
                                                                                            
                                                                                            .. attribute:: manufacturer_assembly_number
                                                                                            
                                                                                            	Manufacture Assembly number
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_assembly_revision
                                                                                            
                                                                                            	Manufacture assembly revision
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                            
                                                                                            	Common Language Equipment           Identifier number
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_firmware_identifier
                                                                                            
                                                                                            	
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: manufacturer_software_identifier
                                                                                            
                                                                                            	
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: original_equipment_manufacturer_string
                                                                                            
                                                                                            	String containing OEM information           if applicable
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: part_number
                                                                                            
                                                                                            	
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.manufacturer_assembly_number = None
                                                                                                self.manufacturer_assembly_revision = None
                                                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                                                self.manufacturer_firmware_identifier = None
                                                                                                self.manufacturer_software_identifier = None
                                                                                                self.original_equipment_manufacturer_string = None
                                                                                                self.part_number = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.manufacturer_assembly_number is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_assembly_revision is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_firmware_identifier is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_software_identifier is not None:
                                                                                                    return True

                                                                                                if self.original_equipment_manufacturer_string is not None:
                                                                                                    return True

                                                                                                if self.part_number is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvAssetBag']['meta_info']


                                                                                        class Threshold(object):
                                                                                            """
                                                                                            Threshold
                                                                                            
                                                                                            .. attribute:: critical_hi
                                                                                            
                                                                                            	Critical High
                                                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi>`
                                                                                            
                                                                                            .. attribute:: critical_lo
                                                                                            
                                                                                            	Critical Low
                                                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo>`
                                                                                            
                                                                                            .. attribute:: major_hi
                                                                                            
                                                                                            	Major High
                                                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi>`
                                                                                            
                                                                                            .. attribute:: major_lo
                                                                                            
                                                                                            	Major Low
                                                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo>`
                                                                                            
                                                                                            .. attribute:: minor_hi
                                                                                            
                                                                                            	Minor High
                                                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi>`
                                                                                            
                                                                                            .. attribute:: minor_lo
                                                                                            
                                                                                            	Minor Low
                                                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo>`
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi()
                                                                                                self.critical_hi.parent = self
                                                                                                self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo()
                                                                                                self.critical_lo.parent = self
                                                                                                self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi()
                                                                                                self.major_hi.parent = self
                                                                                                self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo()
                                                                                                self.major_lo.parent = self
                                                                                                self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi()
                                                                                                self.minor_hi.parent = self
                                                                                                self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo()
                                                                                                self.minor_lo.parent = self


                                                                                            class MajorLo(object):
                                                                                                """
                                                                                                Major Low
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorLo']['meta_info']


                                                                                            class CriticalHi(object):
                                                                                                """
                                                                                                Critical High
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                            class MinorHi(object):
                                                                                                """
                                                                                                Minor High
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorHi']['meta_info']


                                                                                            class MajorHi(object):
                                                                                                """
                                                                                                Major High
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MajorHi']['meta_info']


                                                                                            class CriticalLo(object):
                                                                                                """
                                                                                                Critical Low
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                            class MinorLo(object):
                                                                                                """
                                                                                                Minor Low
                                                                                                
                                                                                                .. attribute:: thresh_bag
                                                                                                
                                                                                                	Environment threshold info
                                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                                    self.thresh_bag.parent = self


                                                                                                class ThreshBag(object):
                                                                                                    """
                                                                                                    Environment threshold info
                                                                                                    
                                                                                                    .. attribute:: threshold_evaluation
                                                                                                    
                                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_notification_enabled
                                                                                                    
                                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                                    	**type**\:  bool
                                                                                                    
                                                                                                    .. attribute:: threshold_relation
                                                                                                    
                                                                                                    	Indicates relation between sensor value and threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_severity
                                                                                                    
                                                                                                    	Indicates minor, major, critical severities
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    .. attribute:: threshold_value
                                                                                                    
                                                                                                    	Value of the configured threshold
                                                                                                    	**type**\:  int
                                                                                                    
                                                                                                    	**range:** 0..4294967295
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.threshold_evaluation = None
                                                                                                        self.threshold_notification_enabled = None
                                                                                                        self.threshold_relation = None
                                                                                                        self.threshold_severity = None
                                                                                                        self.threshold_value = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.threshold_evaluation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_notification_enabled is not None:
                                                                                                            return True

                                                                                                        if self.threshold_relation is not None:
                                                                                                            return True

                                                                                                        if self.threshold_severity is not None:
                                                                                                            return True

                                                                                                        if self.threshold_value is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold.MinorLo']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                                    return True

                                                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                                    return True

                                                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                                                    return True

                                                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                                                    return True

                                                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                                    return True

                                                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.Threshold']['meta_info']


                                                                                        class FruInfo(object):
                                                                                            """
                                                                                            Inventory EDM FRU info
                                                                                            
                                                                                            .. attribute:: card_administrative_state
                                                                                            
                                                                                            	card admin state\: shutdown or not
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: card_monitor_state
                                                                                            
                                                                                            	card is monitored by a manager or left unmonitored
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: card_operational_state
                                                                                            
                                                                                            	card operation state
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: card_reset_reason
                                                                                            
                                                                                            	card reset reason enum
                                                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                            
                                                                                            .. attribute:: card_up_time
                                                                                            
                                                                                            	card up time
                                                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.CardUpTime>`
                                                                                            
                                                                                            .. attribute:: last_operational_state_change
                                                                                            
                                                                                            	last card oper change state
                                                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                            
                                                                                            .. attribute:: power_administrative_state
                                                                                            
                                                                                            	power admin state\: up or down
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_current_measurement
                                                                                            
                                                                                            	power current\: not implemented
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: power_operational_state
                                                                                            
                                                                                            	Power operation state
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.card_administrative_state = None
                                                                                                self.card_monitor_state = None
                                                                                                self.card_operational_state = None
                                                                                                self.card_reset_reason = None
                                                                                                self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.CardUpTime()
                                                                                                self.card_up_time.parent = self
                                                                                                self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.LastOperationalStateChange()
                                                                                                self.last_operational_state_change.parent = self
                                                                                                self.power_administrative_state = None
                                                                                                self.power_current_measurement = None
                                                                                                self.power_operational_state = None


                                                                                            class LastOperationalStateChange(object):
                                                                                                """
                                                                                                last card oper change state
                                                                                                
                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                
                                                                                                	Time Value in Nano\-seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: nanosecond
                                                                                                
                                                                                                .. attribute:: time_in_seconds
                                                                                                
                                                                                                	Time Value in Seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: second
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.time_in_nano_seconds = None
                                                                                                    self.time_in_seconds = None

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                        return True

                                                                                                    if self.time_in_seconds is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                            class CardUpTime(object):
                                                                                                """
                                                                                                card up time
                                                                                                
                                                                                                .. attribute:: time_in_nano_seconds
                                                                                                
                                                                                                	Time Value in Nano\-seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: nanosecond
                                                                                                
                                                                                                .. attribute:: time_in_seconds
                                                                                                
                                                                                                	Time Value in Seconds
                                                                                                	**type**\:  int
                                                                                                
                                                                                                	**range:** \-2147483648..2147483647
                                                                                                
                                                                                                	**units**\: second
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.time_in_nano_seconds = None
                                                                                                    self.time_in_seconds = None

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.time_in_nano_seconds is not None:
                                                                                                        return True

                                                                                                    if self.time_in_seconds is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.card_administrative_state is not None:
                                                                                                    return True

                                                                                                if self.card_monitor_state is not None:
                                                                                                    return True

                                                                                                if self.card_operational_state is not None:
                                                                                                    return True

                                                                                                if self.card_reset_reason is not None:
                                                                                                    return True

                                                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                                    return True

                                                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                                    return True

                                                                                                if self.power_administrative_state is not None:
                                                                                                    return True

                                                                                                if self.power_current_measurement is not None:
                                                                                                    return True

                                                                                                if self.power_operational_state is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.FruInfo']['meta_info']


                                                                                        class InvBasicBag(object):
                                                                                            """
                                                                                            Inventory Basic Bag
                                                                                            
                                                                                            .. attribute:: alias
                                                                                            
                                                                                            	useful for storing an entity alias 
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: asset_id_str
                                                                                            
                                                                                            	asset Identification string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: asset_identification
                                                                                            
                                                                                            	asset Identification
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: ceport
                                                                                            
                                                                                            	1 if ce port found, 0 if not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: chip_hardware_revision
                                                                                            
                                                                                            	chip module hw revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: composite_class_code
                                                                                            
                                                                                            	Major&minor class of the entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: description
                                                                                            
                                                                                            	describes in user\-readable terms       what the entity in question does
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: environmental_monitor_path
                                                                                            
                                                                                            	sysdb name of sensor in the envmon EDM
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: firmware_revision
                                                                                            
                                                                                            	firmware revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: group_flag
                                                                                            
                                                                                            	indicates if this entity is group       or not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: hardware_revision
                                                                                            
                                                                                            	hw revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: is_field_replaceable_unit
                                                                                            
                                                                                            	1 if Field Replaceable Unit 0, if not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: manufacturer_asset_tags
                                                                                            
                                                                                            	Manufacture Asset Tags
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: manufacturer_name
                                                                                            
                                                                                            	manufacturer's name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: memory_size
                                                                                            
                                                                                            	Size of memory associated with       the entity where applicable
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: model_name
                                                                                            
                                                                                            	model name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: name
                                                                                            
                                                                                            	name string for the entity
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: new_deviation_number
                                                                                            
                                                                                            	integer value for New Deviation Number 0x88
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: physical_layer_interface_module_type
                                                                                            
                                                                                            	integer value for plim type if     applicable to this entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: redundancystate
                                                                                            
                                                                                            	integer value for Redundancy State if     applicable to this entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: serial_number
                                                                                            
                                                                                            	serial number
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: software_revision
                                                                                            
                                                                                            	software revision string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: unique_id
                                                                                            
                                                                                            	Unique id for an entity
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            .. attribute:: unrecognized_fru
                                                                                            
                                                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: vendor_type
                                                                                            
                                                                                            	maps to the vendor OID string
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: xr_scoped
                                                                                            
                                                                                            	1 if xr scoped, 0 if not
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.alias = None
                                                                                                self.asset_id_str = None
                                                                                                self.asset_identification = None
                                                                                                self.ceport = None
                                                                                                self.chip_hardware_revision = None
                                                                                                self.composite_class_code = None
                                                                                                self.description = None
                                                                                                self.environmental_monitor_path = None
                                                                                                self.firmware_revision = None
                                                                                                self.group_flag = None
                                                                                                self.hardware_revision = None
                                                                                                self.is_field_replaceable_unit = None
                                                                                                self.manufacturer_asset_tags = None
                                                                                                self.manufacturer_name = None
                                                                                                self.memory_size = None
                                                                                                self.model_name = None
                                                                                                self.name = None
                                                                                                self.new_deviation_number = None
                                                                                                self.physical_layer_interface_module_type = None
                                                                                                self.redundancystate = None
                                                                                                self.serial_number = None
                                                                                                self.software_revision = None
                                                                                                self.unique_id = None
                                                                                                self.unrecognized_fru = None
                                                                                                self.vendor_type = None
                                                                                                self.xr_scoped = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.alias is not None:
                                                                                                    return True

                                                                                                if self.asset_id_str is not None:
                                                                                                    return True

                                                                                                if self.asset_identification is not None:
                                                                                                    return True

                                                                                                if self.ceport is not None:
                                                                                                    return True

                                                                                                if self.chip_hardware_revision is not None:
                                                                                                    return True

                                                                                                if self.composite_class_code is not None:
                                                                                                    return True

                                                                                                if self.description is not None:
                                                                                                    return True

                                                                                                if self.environmental_monitor_path is not None:
                                                                                                    return True

                                                                                                if self.firmware_revision is not None:
                                                                                                    return True

                                                                                                if self.group_flag is not None:
                                                                                                    return True

                                                                                                if self.hardware_revision is not None:
                                                                                                    return True

                                                                                                if self.is_field_replaceable_unit is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_asset_tags is not None:
                                                                                                    return True

                                                                                                if self.manufacturer_name is not None:
                                                                                                    return True

                                                                                                if self.memory_size is not None:
                                                                                                    return True

                                                                                                if self.model_name is not None:
                                                                                                    return True

                                                                                                if self.name is not None:
                                                                                                    return True

                                                                                                if self.new_deviation_number is not None:
                                                                                                    return True

                                                                                                if self.physical_layer_interface_module_type is not None:
                                                                                                    return True

                                                                                                if self.redundancystate is not None:
                                                                                                    return True

                                                                                                if self.serial_number is not None:
                                                                                                    return True

                                                                                                if self.software_revision is not None:
                                                                                                    return True

                                                                                                if self.unique_id is not None:
                                                                                                    return True

                                                                                                if self.unrecognized_fru is not None:
                                                                                                    return True

                                                                                                if self.vendor_type is not None:
                                                                                                    return True

                                                                                                if self.xr_scoped is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvBasicBag']['meta_info']


                                                                                        class InvEepromInfo(object):
                                                                                            """
                                                                                            Inventory EDM EEPROM Information Bag
                                                                                            
                                                                                            .. attribute:: description
                                                                                            
                                                                                            	A textual description of physical entity
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: eeprom
                                                                                            
                                                                                            	EEPROM data not from hex data
                                                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom>`
                                                                                            
                                                                                            .. attribute:: has_eeprom
                                                                                            
                                                                                            	use eeprom instead of opaque data
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: inv_card_type
                                                                                            
                                                                                            	Inventory card type
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..255
                                                                                            
                                                                                            .. attribute:: opaque_data
                                                                                            
                                                                                            	EEPROM hex data
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                            
                                                                                            .. attribute:: opaque_data_size
                                                                                            
                                                                                            	size of the EEPROM hex data
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.description = None
                                                                                                self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom()
                                                                                                self.eeprom.parent = self
                                                                                                self.has_eeprom = None
                                                                                                self.inv_card_type = None
                                                                                                self.opaque_data = None
                                                                                                self.opaque_data_size = None


                                                                                            class Eeprom(object):
                                                                                                """
                                                                                                EEPROM data not from hex data
                                                                                                
                                                                                                .. attribute:: asset_alias
                                                                                                
                                                                                                	Asset Alias
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: asset_id
                                                                                                
                                                                                                	Asset ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address1
                                                                                                
                                                                                                	Base Mac Address #1
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address2
                                                                                                
                                                                                                	Base Mac Address #2
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address3
                                                                                                
                                                                                                	Base Mac Address #3
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: base_mac_address4
                                                                                                
                                                                                                	Base Mac Address #4
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_checksum
                                                                                                
                                                                                                	Block Checksum
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_count
                                                                                                
                                                                                                	Block Count
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_length
                                                                                                
                                                                                                	Block Length
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_signature
                                                                                                
                                                                                                	Block Signature
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: block_version
                                                                                                
                                                                                                	Block Version
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: chassis_sid
                                                                                                
                                                                                                	Chassis serial number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: clei
                                                                                                
                                                                                                	Common Language Equipment Identifier (CLEI) code
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: controller_family
                                                                                                
                                                                                                	Controller family
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: controller_type
                                                                                                
                                                                                                	Controller type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: description
                                                                                                
                                                                                                	A textual description of physical entity
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num1
                                                                                                
                                                                                                	Deviation Number # 1
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num2
                                                                                                
                                                                                                	Deviation Number # 2
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num3
                                                                                                
                                                                                                	Deviation Number # 3
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num4
                                                                                                
                                                                                                	Deviation Number # 4
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num5
                                                                                                
                                                                                                	Deviation Number # 5
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num6
                                                                                                
                                                                                                	Deviation Number # 6
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: dev_num7
                                                                                                
                                                                                                	Deviation Number # 7
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: eci
                                                                                                
                                                                                                	Equipment Catalog Item (ECI) number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: eeprom_size
                                                                                                
                                                                                                	EEPROM Size
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: engineer_use
                                                                                                
                                                                                                	Engineer Use
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: fru_major_type
                                                                                                
                                                                                                	FRU Major Type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: fru_minor_type
                                                                                                
                                                                                                	FRU Minor Type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: hw_version
                                                                                                
                                                                                                	Hardware Version
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: hwid
                                                                                                
                                                                                                	Hardware Revision
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: idprom_format_rev
                                                                                                
                                                                                                	IDPROM Format Revision
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size1
                                                                                                
                                                                                                	Mac Address Block Size #1
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size2
                                                                                                
                                                                                                	Mac Address Block Size #2
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size3
                                                                                                
                                                                                                	Mac Address Block Size #3
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mac_add_blk_size4
                                                                                                
                                                                                                	Mac Address Block Size #4
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: manu_test_data
                                                                                                
                                                                                                	Manufacturing Test Data
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mfg_bits
                                                                                                
                                                                                                	MFG Bits
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: mfg_deviation
                                                                                                
                                                                                                	MFG Deviation
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: oem_string
                                                                                                
                                                                                                	OEM String
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: part_number
                                                                                                
                                                                                                	Part Number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: part_revision
                                                                                                
                                                                                                	Part Revision
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pca_num
                                                                                                
                                                                                                	PCA number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pcavid
                                                                                                
                                                                                                	PCA revision ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pcb_serial_num
                                                                                                
                                                                                                	PCB Serial Number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: pid
                                                                                                
                                                                                                	Product ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: power_consumption
                                                                                                
                                                                                                	Power Consumption
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: power_supply_type
                                                                                                
                                                                                                	Power Supply Type
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: product_id
                                                                                                
                                                                                                	Product ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: rma
                                                                                                
                                                                                                	RMA Data
                                                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                                
                                                                                                .. attribute:: rma_code
                                                                                                
                                                                                                	RMA Code
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: serial_number
                                                                                                
                                                                                                	Serial Number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: snmpoid
                                                                                                
                                                                                                	SNMP OID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: top_assem_part_num
                                                                                                
                                                                                                	Top assembly part number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: top_assem_vid
                                                                                                
                                                                                                	Top assembly revision number
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: udi_description
                                                                                                
                                                                                                	UDI description
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: udi_name
                                                                                                
                                                                                                	UDI name
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                .. attribute:: vid
                                                                                                
                                                                                                	Version ID
                                                                                                	**type**\:  str
                                                                                                
                                                                                                	**length:** 0..255
                                                                                                
                                                                                                

                                                                                                """

                                                                                                _prefix = 'invmgr-oper'
                                                                                                _revision = '2015-11-09'

                                                                                                def __init__(self):
                                                                                                    self.parent = None
                                                                                                    self.asset_alias = None
                                                                                                    self.asset_id = None
                                                                                                    self.base_mac_address1 = None
                                                                                                    self.base_mac_address2 = None
                                                                                                    self.base_mac_address3 = None
                                                                                                    self.base_mac_address4 = None
                                                                                                    self.block_checksum = None
                                                                                                    self.block_count = None
                                                                                                    self.block_length = None
                                                                                                    self.block_signature = None
                                                                                                    self.block_version = None
                                                                                                    self.chassis_sid = None
                                                                                                    self.clei = None
                                                                                                    self.controller_family = None
                                                                                                    self.controller_type = None
                                                                                                    self.description = None
                                                                                                    self.dev_num1 = None
                                                                                                    self.dev_num2 = None
                                                                                                    self.dev_num3 = None
                                                                                                    self.dev_num4 = None
                                                                                                    self.dev_num5 = None
                                                                                                    self.dev_num6 = None
                                                                                                    self.dev_num7 = None
                                                                                                    self.eci = None
                                                                                                    self.eeprom_size = None
                                                                                                    self.engineer_use = None
                                                                                                    self.fru_major_type = None
                                                                                                    self.fru_minor_type = None
                                                                                                    self.hw_version = None
                                                                                                    self.hwid = None
                                                                                                    self.idprom_format_rev = None
                                                                                                    self.mac_add_blk_size1 = None
                                                                                                    self.mac_add_blk_size2 = None
                                                                                                    self.mac_add_blk_size3 = None
                                                                                                    self.mac_add_blk_size4 = None
                                                                                                    self.manu_test_data = None
                                                                                                    self.mfg_bits = None
                                                                                                    self.mfg_deviation = None
                                                                                                    self.oem_string = None
                                                                                                    self.part_number = None
                                                                                                    self.part_revision = None
                                                                                                    self.pca_num = None
                                                                                                    self.pcavid = None
                                                                                                    self.pcb_serial_num = None
                                                                                                    self.pid = None
                                                                                                    self.power_consumption = None
                                                                                                    self.power_supply_type = None
                                                                                                    self.product_id = None
                                                                                                    self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                                    self.rma.parent = self
                                                                                                    self.rma_code = None
                                                                                                    self.serial_number = None
                                                                                                    self.snmpoid = None
                                                                                                    self.top_assem_part_num = None
                                                                                                    self.top_assem_vid = None
                                                                                                    self.udi_description = None
                                                                                                    self.udi_name = None
                                                                                                    self.vid = None


                                                                                                class Rma(object):
                                                                                                    """
                                                                                                    RMA Data
                                                                                                    
                                                                                                    .. attribute:: rma_history
                                                                                                    
                                                                                                    	RMA history
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: rma_number
                                                                                                    
                                                                                                    	RMA tracking number format is N\-N\-N
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    .. attribute:: test_history
                                                                                                    
                                                                                                    	Test history
                                                                                                    	**type**\:  str
                                                                                                    
                                                                                                    	**length:** 0..255
                                                                                                    
                                                                                                    

                                                                                                    """

                                                                                                    _prefix = 'invmgr-oper'
                                                                                                    _revision = '2015-11-09'

                                                                                                    def __init__(self):
                                                                                                        self.parent = None
                                                                                                        self.rma_history = None
                                                                                                        self.rma_number = None
                                                                                                        self.test_history = None

                                                                                                    @property
                                                                                                    def _common_path(self):
                                                                                                        if self.parent is None:
                                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                                    def is_config(self):
                                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                                        return False

                                                                                                    def _has_data(self):
                                                                                                        if not self.is_config():
                                                                                                            return False
                                                                                                        if self.rma_history is not None:
                                                                                                            return True

                                                                                                        if self.rma_number is not None:
                                                                                                            return True

                                                                                                        if self.test_history is not None:
                                                                                                            return True

                                                                                                        return False

                                                                                                    @staticmethod
                                                                                                    def _meta_info():
                                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                                @property
                                                                                                def _common_path(self):
                                                                                                    if self.parent is None:
                                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                                def is_config(self):
                                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                                    return False

                                                                                                def _has_data(self):
                                                                                                    if not self.is_config():
                                                                                                        return False
                                                                                                    if self.asset_alias is not None:
                                                                                                        return True

                                                                                                    if self.asset_id is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address1 is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address2 is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address3 is not None:
                                                                                                        return True

                                                                                                    if self.base_mac_address4 is not None:
                                                                                                        return True

                                                                                                    if self.block_checksum is not None:
                                                                                                        return True

                                                                                                    if self.block_count is not None:
                                                                                                        return True

                                                                                                    if self.block_length is not None:
                                                                                                        return True

                                                                                                    if self.block_signature is not None:
                                                                                                        return True

                                                                                                    if self.block_version is not None:
                                                                                                        return True

                                                                                                    if self.chassis_sid is not None:
                                                                                                        return True

                                                                                                    if self.clei is not None:
                                                                                                        return True

                                                                                                    if self.controller_family is not None:
                                                                                                        return True

                                                                                                    if self.controller_type is not None:
                                                                                                        return True

                                                                                                    if self.description is not None:
                                                                                                        return True

                                                                                                    if self.dev_num1 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num2 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num3 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num4 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num5 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num6 is not None:
                                                                                                        return True

                                                                                                    if self.dev_num7 is not None:
                                                                                                        return True

                                                                                                    if self.eci is not None:
                                                                                                        return True

                                                                                                    if self.eeprom_size is not None:
                                                                                                        return True

                                                                                                    if self.engineer_use is not None:
                                                                                                        return True

                                                                                                    if self.fru_major_type is not None:
                                                                                                        return True

                                                                                                    if self.fru_minor_type is not None:
                                                                                                        return True

                                                                                                    if self.hw_version is not None:
                                                                                                        return True

                                                                                                    if self.hwid is not None:
                                                                                                        return True

                                                                                                    if self.idprom_format_rev is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size1 is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size2 is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size3 is not None:
                                                                                                        return True

                                                                                                    if self.mac_add_blk_size4 is not None:
                                                                                                        return True

                                                                                                    if self.manu_test_data is not None:
                                                                                                        return True

                                                                                                    if self.mfg_bits is not None:
                                                                                                        return True

                                                                                                    if self.mfg_deviation is not None:
                                                                                                        return True

                                                                                                    if self.oem_string is not None:
                                                                                                        return True

                                                                                                    if self.part_number is not None:
                                                                                                        return True

                                                                                                    if self.part_revision is not None:
                                                                                                        return True

                                                                                                    if self.pca_num is not None:
                                                                                                        return True

                                                                                                    if self.pcavid is not None:
                                                                                                        return True

                                                                                                    if self.pcb_serial_num is not None:
                                                                                                        return True

                                                                                                    if self.pid is not None:
                                                                                                        return True

                                                                                                    if self.power_consumption is not None:
                                                                                                        return True

                                                                                                    if self.power_supply_type is not None:
                                                                                                        return True

                                                                                                    if self.product_id is not None:
                                                                                                        return True

                                                                                                    if self.rma is not None and self.rma._has_data():
                                                                                                        return True

                                                                                                    if self.rma_code is not None:
                                                                                                        return True

                                                                                                    if self.serial_number is not None:
                                                                                                        return True

                                                                                                    if self.snmpoid is not None:
                                                                                                        return True

                                                                                                    if self.top_assem_part_num is not None:
                                                                                                        return True

                                                                                                    if self.top_assem_vid is not None:
                                                                                                        return True

                                                                                                    if self.udi_description is not None:
                                                                                                        return True

                                                                                                    if self.udi_name is not None:
                                                                                                        return True

                                                                                                    if self.vid is not None:
                                                                                                        return True

                                                                                                    return False

                                                                                                @staticmethod
                                                                                                def _meta_info():
                                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.description is not None:
                                                                                                    return True

                                                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                                                    return True

                                                                                                if self.has_eeprom is not None:
                                                                                                    return True

                                                                                                if self.inv_card_type is not None:
                                                                                                    return True

                                                                                                if self.opaque_data is not None:
                                                                                                    return True

                                                                                                if self.opaque_data_size is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes.InvEepromInfo']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                                return True

                                                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                                return True

                                                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                                                return True

                                                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                                return True

                                                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                                return True

                                                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                                return True

                                                                                            if self.module_done is not None:
                                                                                                return True

                                                                                            if self.node_id is not None:
                                                                                                return True

                                                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                                return True

                                                                                            if self.threshold is not None and self.threshold._has_data():
                                                                                                return True

                                                                                            if self.vm_done is not None:
                                                                                                return True

                                                                                            if self.vm_node_id is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8.Attributes']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                        if self.name is None:
                                                                                            raise YPYModelError('Key property name is None')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi8[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.name is not None:
                                                                                            return True

                                                                                        if self.attributes is not None and self.attributes._has_data():
                                                                                            return True

                                                                                        if self.tsi9s is not None and self.tsi9s._has_data():
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S.Tsi8']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi8s'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.tsi8 is not None:
                                                                                        for child_ref in self.tsi8:
                                                                                            if child_ref._has_data():
                                                                                                return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Tsi8S']['meta_info']


                                                                            class Attributes(object):
                                                                                """
                                                                                Attributes
                                                                                
                                                                                .. attribute:: env_sensor_info
                                                                                
                                                                                	Environment sensor info
                                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfo>`
                                                                                
                                                                                .. attribute:: env_sensor_info_xml
                                                                                
                                                                                	Environment sensor info XML
                                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml>`
                                                                                
                                                                                .. attribute:: fru_info
                                                                                
                                                                                	Inventory EDM FRU info
                                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo>`
                                                                                
                                                                                .. attribute:: inv_asset_bag
                                                                                
                                                                                	Inventory Asset Bag
                                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvAssetBag>`
                                                                                
                                                                                .. attribute:: inv_basic_bag
                                                                                
                                                                                	Inventory Basic Bag
                                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvBasicBag>`
                                                                                
                                                                                .. attribute:: inv_eeprom_info
                                                                                
                                                                                	Inventory EDM EEPROM Information Bag
                                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo>`
                                                                                
                                                                                .. attribute:: module_done
                                                                                
                                                                                	Inventory EDM Module Done Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**default value**\: 1
                                                                                
                                                                                .. attribute:: node_id
                                                                                
                                                                                	Node ID Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: pwg_info
                                                                                
                                                                                	Inventory EDM PWG info
                                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.PwgInfo>`
                                                                                
                                                                                .. attribute:: threshold
                                                                                
                                                                                	Threshold
                                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold>`
                                                                                
                                                                                .. attribute:: vm_done
                                                                                
                                                                                	VM Done Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                .. attribute:: vm_node_id
                                                                                
                                                                                	VM Node ID Tuple
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfo()
                                                                                    self.env_sensor_info.parent = self
                                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml()
                                                                                    self.env_sensor_info_xml.parent = self
                                                                                    self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo()
                                                                                    self.fru_info.parent = self
                                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvAssetBag()
                                                                                    self.inv_asset_bag.parent = self
                                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvBasicBag()
                                                                                    self.inv_basic_bag.parent = self
                                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo()
                                                                                    self.inv_eeprom_info.parent = self
                                                                                    self.module_done = None
                                                                                    self.node_id = None
                                                                                    self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.PwgInfo()
                                                                                    self.pwg_info.parent = self
                                                                                    self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold()
                                                                                    self.threshold.parent = self
                                                                                    self.vm_done = None
                                                                                    self.vm_node_id = None


                                                                                class EnvSensorInfo(object):
                                                                                    """
                                                                                    Environment sensor info
                                                                                    
                                                                                    .. attribute:: age_time_stamp
                                                                                    
                                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: alarm_type
                                                                                    
                                                                                    	Indicates threshold violation
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: data_type
                                                                                    
                                                                                    	Sensor data type enums
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: device_description
                                                                                    
                                                                                    	Device Name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: device_id
                                                                                    
                                                                                    	Identifier for this device
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: field_validity_bitmap
                                                                                    
                                                                                    	Sensor valid bitmap
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: precision
                                                                                    
                                                                                    	Sensor precision range
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: scale
                                                                                    
                                                                                    	Sensor scale enums
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: status
                                                                                    
                                                                                    	Sensor operation state enums
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: units
                                                                                    
                                                                                    	Units of variable being read
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: update_rate
                                                                                    
                                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                    	Current reading of sensor
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.age_time_stamp = None
                                                                                        self.alarm_type = None
                                                                                        self.data_type = None
                                                                                        self.device_description = None
                                                                                        self.device_id = None
                                                                                        self.field_validity_bitmap = None
                                                                                        self.precision = None
                                                                                        self.scale = None
                                                                                        self.status = None
                                                                                        self.units = None
                                                                                        self.update_rate = None
                                                                                        self.value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.age_time_stamp is not None:
                                                                                            return True

                                                                                        if self.alarm_type is not None:
                                                                                            return True

                                                                                        if self.data_type is not None:
                                                                                            return True

                                                                                        if self.device_description is not None:
                                                                                            return True

                                                                                        if self.device_id is not None:
                                                                                            return True

                                                                                        if self.field_validity_bitmap is not None:
                                                                                            return True

                                                                                        if self.precision is not None:
                                                                                            return True

                                                                                        if self.scale is not None:
                                                                                            return True

                                                                                        if self.status is not None:
                                                                                            return True

                                                                                        if self.units is not None:
                                                                                            return True

                                                                                        if self.update_rate is not None:
                                                                                            return True

                                                                                        if self.value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfo']['meta_info']


                                                                                class PwgInfo(object):
                                                                                    """
                                                                                    Inventory EDM PWG info
                                                                                    
                                                                                    .. attribute:: power_group_available_current
                                                                                    
                                                                                    	available current
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_group_drawn_current
                                                                                    
                                                                                    	drawn current
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_group_power_units
                                                                                    
                                                                                    	power units
                                                                                    	**type**\:  str
                                                                                    
                                                                                    .. attribute:: power_group_redundancy_mode
                                                                                    
                                                                                    	redundancy mode
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.power_group_available_current = None
                                                                                        self.power_group_drawn_current = None
                                                                                        self.power_group_power_units = None
                                                                                        self.power_group_redundancy_mode = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.power_group_available_current is not None:
                                                                                            return True

                                                                                        if self.power_group_drawn_current is not None:
                                                                                            return True

                                                                                        if self.power_group_power_units is not None:
                                                                                            return True

                                                                                        if self.power_group_redundancy_mode is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.PwgInfo']['meta_info']


                                                                                class EnvSensorInfoXml(object):
                                                                                    """
                                                                                    Environment sensor info XML
                                                                                    
                                                                                    .. attribute:: data_type
                                                                                    
                                                                                    	Sensor data type
                                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                                    
                                                                                    .. attribute:: description
                                                                                    
                                                                                    	Device Name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: status
                                                                                    
                                                                                    	Sensor operation state
                                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                                    
                                                                                    .. attribute:: threshold
                                                                                    
                                                                                    	Threshold information
                                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold>`
                                                                                    
                                                                                    .. attribute:: units
                                                                                    
                                                                                    	Units of variable being read
                                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                                    
                                                                                    .. attribute:: update_rate
                                                                                    
                                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.data_type = None
                                                                                        self.description = None
                                                                                        self.status = None
                                                                                        self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold()
                                                                                        self.threshold.parent = self
                                                                                        self.units = None
                                                                                        self.update_rate = None
                                                                                        self.value = None


                                                                                    class Threshold(object):
                                                                                        """
                                                                                        Threshold information
                                                                                        
                                                                                        .. attribute:: threshold_array
                                                                                        
                                                                                        	Array of threshold
                                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.threshold_array = YList()
                                                                                            self.threshold_array.parent = self
                                                                                            self.threshold_array.name = 'threshold_array'


                                                                                        class ThresholdArray(object):
                                                                                            """
                                                                                            Array of threshold
                                                                                            
                                                                                            .. attribute:: threshold_name
                                                                                            
                                                                                            	Threshold name
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..50
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** \-2147483648..2147483647
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_name = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_name is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.threshold_array is not None:
                                                                                                for child_ref in self.threshold_array:
                                                                                                    if child_ref._has_data():
                                                                                                        return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.data_type is not None:
                                                                                            return True

                                                                                        if self.description is not None:
                                                                                            return True

                                                                                        if self.status is not None:
                                                                                            return True

                                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                                            return True

                                                                                        if self.units is not None:
                                                                                            return True

                                                                                        if self.update_rate is not None:
                                                                                            return True

                                                                                        if self.value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.EnvSensorInfoXml']['meta_info']


                                                                                class InvAssetBag(object):
                                                                                    """
                                                                                    Inventory Asset Bag
                                                                                    
                                                                                    .. attribute:: manufacturer_assembly_number
                                                                                    
                                                                                    	Manufacture Assembly number
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_assembly_revision
                                                                                    
                                                                                    	Manufacture assembly revision
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                                    
                                                                                    	Common Language Equipment           Identifier number
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                                    
                                                                                    	
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: manufacturer_software_identifier
                                                                                    
                                                                                    	
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                                    
                                                                                    	String containing OEM information           if applicable
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: part_number
                                                                                    
                                                                                    	
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.manufacturer_assembly_number = None
                                                                                        self.manufacturer_assembly_revision = None
                                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                                        self.manufacturer_firmware_identifier = None
                                                                                        self.manufacturer_software_identifier = None
                                                                                        self.original_equipment_manufacturer_string = None
                                                                                        self.part_number = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.manufacturer_assembly_number is not None:
                                                                                            return True

                                                                                        if self.manufacturer_assembly_revision is not None:
                                                                                            return True

                                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                            return True

                                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                                            return True

                                                                                        if self.manufacturer_software_identifier is not None:
                                                                                            return True

                                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                                            return True

                                                                                        if self.part_number is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvAssetBag']['meta_info']


                                                                                class Threshold(object):
                                                                                    """
                                                                                    Threshold
                                                                                    
                                                                                    .. attribute:: critical_hi
                                                                                    
                                                                                    	Critical High
                                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi>`
                                                                                    
                                                                                    .. attribute:: critical_lo
                                                                                    
                                                                                    	Critical Low
                                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo>`
                                                                                    
                                                                                    .. attribute:: major_hi
                                                                                    
                                                                                    	Major High
                                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi>`
                                                                                    
                                                                                    .. attribute:: major_lo
                                                                                    
                                                                                    	Major Low
                                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo>`
                                                                                    
                                                                                    .. attribute:: minor_hi
                                                                                    
                                                                                    	Minor High
                                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi>`
                                                                                    
                                                                                    .. attribute:: minor_lo
                                                                                    
                                                                                    	Minor Low
                                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo>`
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi()
                                                                                        self.critical_hi.parent = self
                                                                                        self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo()
                                                                                        self.critical_lo.parent = self
                                                                                        self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi()
                                                                                        self.major_hi.parent = self
                                                                                        self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo()
                                                                                        self.major_lo.parent = self
                                                                                        self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi()
                                                                                        self.minor_hi.parent = self
                                                                                        self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo()
                                                                                        self.minor_lo.parent = self


                                                                                    class MajorLo(object):
                                                                                        """
                                                                                        Major Low
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorLo']['meta_info']


                                                                                    class CriticalHi(object):
                                                                                        """
                                                                                        Critical High
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalHi']['meta_info']


                                                                                    class MinorHi(object):
                                                                                        """
                                                                                        Minor High
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorHi']['meta_info']


                                                                                    class MajorHi(object):
                                                                                        """
                                                                                        Major High
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MajorHi']['meta_info']


                                                                                    class CriticalLo(object):
                                                                                        """
                                                                                        Critical Low
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.CriticalLo']['meta_info']


                                                                                    class MinorLo(object):
                                                                                        """
                                                                                        Minor Low
                                                                                        
                                                                                        .. attribute:: thresh_bag
                                                                                        
                                                                                        	Environment threshold info
                                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                            self.thresh_bag.parent = self


                                                                                        class ThreshBag(object):
                                                                                            """
                                                                                            Environment threshold info
                                                                                            
                                                                                            .. attribute:: threshold_evaluation
                                                                                            
                                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_notification_enabled
                                                                                            
                                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                                            	**type**\:  bool
                                                                                            
                                                                                            .. attribute:: threshold_relation
                                                                                            
                                                                                            	Indicates relation between sensor value and threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_severity
                                                                                            
                                                                                            	Indicates minor, major, critical severities
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            .. attribute:: threshold_value
                                                                                            
                                                                                            	Value of the configured threshold
                                                                                            	**type**\:  int
                                                                                            
                                                                                            	**range:** 0..4294967295
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.threshold_evaluation = None
                                                                                                self.threshold_notification_enabled = None
                                                                                                self.threshold_relation = None
                                                                                                self.threshold_severity = None
                                                                                                self.threshold_value = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.threshold_evaluation is not None:
                                                                                                    return True

                                                                                                if self.threshold_notification_enabled is not None:
                                                                                                    return True

                                                                                                if self.threshold_relation is not None:
                                                                                                    return True

                                                                                                if self.threshold_severity is not None:
                                                                                                    return True

                                                                                                if self.threshold_value is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold.MinorLo']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                            return True

                                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                            return True

                                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                                            return True

                                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                                            return True

                                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                            return True

                                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.Threshold']['meta_info']


                                                                                class FruInfo(object):
                                                                                    """
                                                                                    Inventory EDM FRU info
                                                                                    
                                                                                    .. attribute:: card_administrative_state
                                                                                    
                                                                                    	card admin state\: shutdown or not
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: card_monitor_state
                                                                                    
                                                                                    	card is monitored by a manager or left unmonitored
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: card_operational_state
                                                                                    
                                                                                    	card operation state
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: card_reset_reason
                                                                                    
                                                                                    	card reset reason enum
                                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                                    
                                                                                    .. attribute:: card_up_time
                                                                                    
                                                                                    	card up time
                                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.CardUpTime>`
                                                                                    
                                                                                    .. attribute:: last_operational_state_change
                                                                                    
                                                                                    	last card oper change state
                                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.LastOperationalStateChange>`
                                                                                    
                                                                                    .. attribute:: power_administrative_state
                                                                                    
                                                                                    	power admin state\: up or down
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_current_measurement
                                                                                    
                                                                                    	power current\: not implemented
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: power_operational_state
                                                                                    
                                                                                    	Power operation state
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.card_administrative_state = None
                                                                                        self.card_monitor_state = None
                                                                                        self.card_operational_state = None
                                                                                        self.card_reset_reason = None
                                                                                        self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.CardUpTime()
                                                                                        self.card_up_time.parent = self
                                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.LastOperationalStateChange()
                                                                                        self.last_operational_state_change.parent = self
                                                                                        self.power_administrative_state = None
                                                                                        self.power_current_measurement = None
                                                                                        self.power_operational_state = None


                                                                                    class LastOperationalStateChange(object):
                                                                                        """
                                                                                        last card oper change state
                                                                                        
                                                                                        .. attribute:: time_in_nano_seconds
                                                                                        
                                                                                        	Time Value in Nano\-seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: nanosecond
                                                                                        
                                                                                        .. attribute:: time_in_seconds
                                                                                        
                                                                                        	Time Value in Seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: second
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.time_in_nano_seconds = None
                                                                                            self.time_in_seconds = None

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                return True

                                                                                            if self.time_in_seconds is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                                    class CardUpTime(object):
                                                                                        """
                                                                                        card up time
                                                                                        
                                                                                        .. attribute:: time_in_nano_seconds
                                                                                        
                                                                                        	Time Value in Nano\-seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: nanosecond
                                                                                        
                                                                                        .. attribute:: time_in_seconds
                                                                                        
                                                                                        	Time Value in Seconds
                                                                                        	**type**\:  int
                                                                                        
                                                                                        	**range:** \-2147483648..2147483647
                                                                                        
                                                                                        	**units**\: second
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.time_in_nano_seconds = None
                                                                                            self.time_in_seconds = None

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.time_in_nano_seconds is not None:
                                                                                                return True

                                                                                            if self.time_in_seconds is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.card_administrative_state is not None:
                                                                                            return True

                                                                                        if self.card_monitor_state is not None:
                                                                                            return True

                                                                                        if self.card_operational_state is not None:
                                                                                            return True

                                                                                        if self.card_reset_reason is not None:
                                                                                            return True

                                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                            return True

                                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                            return True

                                                                                        if self.power_administrative_state is not None:
                                                                                            return True

                                                                                        if self.power_current_measurement is not None:
                                                                                            return True

                                                                                        if self.power_operational_state is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.FruInfo']['meta_info']


                                                                                class InvBasicBag(object):
                                                                                    """
                                                                                    Inventory Basic Bag
                                                                                    
                                                                                    .. attribute:: alias
                                                                                    
                                                                                    	useful for storing an entity alias 
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: asset_id_str
                                                                                    
                                                                                    	asset Identification string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: asset_identification
                                                                                    
                                                                                    	asset Identification
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: ceport
                                                                                    
                                                                                    	1 if ce port found, 0 if not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: chip_hardware_revision
                                                                                    
                                                                                    	chip module hw revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: composite_class_code
                                                                                    
                                                                                    	Major&minor class of the entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: description
                                                                                    
                                                                                    	describes in user\-readable terms       what the entity in question does
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: environmental_monitor_path
                                                                                    
                                                                                    	sysdb name of sensor in the envmon EDM
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: firmware_revision
                                                                                    
                                                                                    	firmware revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: group_flag
                                                                                    
                                                                                    	indicates if this entity is group       or not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: hardware_revision
                                                                                    
                                                                                    	hw revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: is_field_replaceable_unit
                                                                                    
                                                                                    	1 if Field Replaceable Unit 0, if not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: manufacturer_asset_tags
                                                                                    
                                                                                    	Manufacture Asset Tags
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: manufacturer_name
                                                                                    
                                                                                    	manufacturer's name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: memory_size
                                                                                    
                                                                                    	Size of memory associated with       the entity where applicable
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: model_name
                                                                                    
                                                                                    	model name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: name
                                                                                    
                                                                                    	name string for the entity
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: new_deviation_number
                                                                                    
                                                                                    	integer value for New Deviation Number 0x88
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: physical_layer_interface_module_type
                                                                                    
                                                                                    	integer value for plim type if     applicable to this entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: redundancystate
                                                                                    
                                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: serial_number
                                                                                    
                                                                                    	serial number
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: software_revision
                                                                                    
                                                                                    	software revision string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: unique_id
                                                                                    
                                                                                    	Unique id for an entity
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    .. attribute:: unrecognized_fru
                                                                                    
                                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: vendor_type
                                                                                    
                                                                                    	maps to the vendor OID string
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: xr_scoped
                                                                                    
                                                                                    	1 if xr scoped, 0 if not
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.alias = None
                                                                                        self.asset_id_str = None
                                                                                        self.asset_identification = None
                                                                                        self.ceport = None
                                                                                        self.chip_hardware_revision = None
                                                                                        self.composite_class_code = None
                                                                                        self.description = None
                                                                                        self.environmental_monitor_path = None
                                                                                        self.firmware_revision = None
                                                                                        self.group_flag = None
                                                                                        self.hardware_revision = None
                                                                                        self.is_field_replaceable_unit = None
                                                                                        self.manufacturer_asset_tags = None
                                                                                        self.manufacturer_name = None
                                                                                        self.memory_size = None
                                                                                        self.model_name = None
                                                                                        self.name = None
                                                                                        self.new_deviation_number = None
                                                                                        self.physical_layer_interface_module_type = None
                                                                                        self.redundancystate = None
                                                                                        self.serial_number = None
                                                                                        self.software_revision = None
                                                                                        self.unique_id = None
                                                                                        self.unrecognized_fru = None
                                                                                        self.vendor_type = None
                                                                                        self.xr_scoped = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.alias is not None:
                                                                                            return True

                                                                                        if self.asset_id_str is not None:
                                                                                            return True

                                                                                        if self.asset_identification is not None:
                                                                                            return True

                                                                                        if self.ceport is not None:
                                                                                            return True

                                                                                        if self.chip_hardware_revision is not None:
                                                                                            return True

                                                                                        if self.composite_class_code is not None:
                                                                                            return True

                                                                                        if self.description is not None:
                                                                                            return True

                                                                                        if self.environmental_monitor_path is not None:
                                                                                            return True

                                                                                        if self.firmware_revision is not None:
                                                                                            return True

                                                                                        if self.group_flag is not None:
                                                                                            return True

                                                                                        if self.hardware_revision is not None:
                                                                                            return True

                                                                                        if self.is_field_replaceable_unit is not None:
                                                                                            return True

                                                                                        if self.manufacturer_asset_tags is not None:
                                                                                            return True

                                                                                        if self.manufacturer_name is not None:
                                                                                            return True

                                                                                        if self.memory_size is not None:
                                                                                            return True

                                                                                        if self.model_name is not None:
                                                                                            return True

                                                                                        if self.name is not None:
                                                                                            return True

                                                                                        if self.new_deviation_number is not None:
                                                                                            return True

                                                                                        if self.physical_layer_interface_module_type is not None:
                                                                                            return True

                                                                                        if self.redundancystate is not None:
                                                                                            return True

                                                                                        if self.serial_number is not None:
                                                                                            return True

                                                                                        if self.software_revision is not None:
                                                                                            return True

                                                                                        if self.unique_id is not None:
                                                                                            return True

                                                                                        if self.unrecognized_fru is not None:
                                                                                            return True

                                                                                        if self.vendor_type is not None:
                                                                                            return True

                                                                                        if self.xr_scoped is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvBasicBag']['meta_info']


                                                                                class InvEepromInfo(object):
                                                                                    """
                                                                                    Inventory EDM EEPROM Information Bag
                                                                                    
                                                                                    .. attribute:: description
                                                                                    
                                                                                    	A textual description of physical entity
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: eeprom
                                                                                    
                                                                                    	EEPROM data not from hex data
                                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom>`
                                                                                    
                                                                                    .. attribute:: has_eeprom
                                                                                    
                                                                                    	use eeprom instead of opaque data
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: inv_card_type
                                                                                    
                                                                                    	Inventory card type
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..255
                                                                                    
                                                                                    .. attribute:: opaque_data
                                                                                    
                                                                                    	EEPROM hex data
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                                    
                                                                                    .. attribute:: opaque_data_size
                                                                                    
                                                                                    	size of the EEPROM hex data
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.description = None
                                                                                        self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom()
                                                                                        self.eeprom.parent = self
                                                                                        self.has_eeprom = None
                                                                                        self.inv_card_type = None
                                                                                        self.opaque_data = None
                                                                                        self.opaque_data_size = None


                                                                                    class Eeprom(object):
                                                                                        """
                                                                                        EEPROM data not from hex data
                                                                                        
                                                                                        .. attribute:: asset_alias
                                                                                        
                                                                                        	Asset Alias
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: asset_id
                                                                                        
                                                                                        	Asset ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address1
                                                                                        
                                                                                        	Base Mac Address #1
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address2
                                                                                        
                                                                                        	Base Mac Address #2
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address3
                                                                                        
                                                                                        	Base Mac Address #3
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: base_mac_address4
                                                                                        
                                                                                        	Base Mac Address #4
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_checksum
                                                                                        
                                                                                        	Block Checksum
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_count
                                                                                        
                                                                                        	Block Count
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_length
                                                                                        
                                                                                        	Block Length
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_signature
                                                                                        
                                                                                        	Block Signature
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: block_version
                                                                                        
                                                                                        	Block Version
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: chassis_sid
                                                                                        
                                                                                        	Chassis serial number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: clei
                                                                                        
                                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: controller_family
                                                                                        
                                                                                        	Controller family
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: controller_type
                                                                                        
                                                                                        	Controller type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: description
                                                                                        
                                                                                        	A textual description of physical entity
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num1
                                                                                        
                                                                                        	Deviation Number # 1
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num2
                                                                                        
                                                                                        	Deviation Number # 2
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num3
                                                                                        
                                                                                        	Deviation Number # 3
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num4
                                                                                        
                                                                                        	Deviation Number # 4
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num5
                                                                                        
                                                                                        	Deviation Number # 5
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num6
                                                                                        
                                                                                        	Deviation Number # 6
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: dev_num7
                                                                                        
                                                                                        	Deviation Number # 7
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: eci
                                                                                        
                                                                                        	Equipment Catalog Item (ECI) number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: eeprom_size
                                                                                        
                                                                                        	EEPROM Size
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: engineer_use
                                                                                        
                                                                                        	Engineer Use
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: fru_major_type
                                                                                        
                                                                                        	FRU Major Type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: fru_minor_type
                                                                                        
                                                                                        	FRU Minor Type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: hw_version
                                                                                        
                                                                                        	Hardware Version
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: hwid
                                                                                        
                                                                                        	Hardware Revision
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: idprom_format_rev
                                                                                        
                                                                                        	IDPROM Format Revision
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size1
                                                                                        
                                                                                        	Mac Address Block Size #1
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size2
                                                                                        
                                                                                        	Mac Address Block Size #2
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size3
                                                                                        
                                                                                        	Mac Address Block Size #3
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mac_add_blk_size4
                                                                                        
                                                                                        	Mac Address Block Size #4
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: manu_test_data
                                                                                        
                                                                                        	Manufacturing Test Data
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mfg_bits
                                                                                        
                                                                                        	MFG Bits
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: mfg_deviation
                                                                                        
                                                                                        	MFG Deviation
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: oem_string
                                                                                        
                                                                                        	OEM String
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: part_number
                                                                                        
                                                                                        	Part Number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: part_revision
                                                                                        
                                                                                        	Part Revision
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pca_num
                                                                                        
                                                                                        	PCA number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pcavid
                                                                                        
                                                                                        	PCA revision ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pcb_serial_num
                                                                                        
                                                                                        	PCB Serial Number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: pid
                                                                                        
                                                                                        	Product ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: power_consumption
                                                                                        
                                                                                        	Power Consumption
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: power_supply_type
                                                                                        
                                                                                        	Power Supply Type
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: product_id
                                                                                        
                                                                                        	Product ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: rma
                                                                                        
                                                                                        	RMA Data
                                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                        
                                                                                        .. attribute:: rma_code
                                                                                        
                                                                                        	RMA Code
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: serial_number
                                                                                        
                                                                                        	Serial Number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: snmpoid
                                                                                        
                                                                                        	SNMP OID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: top_assem_part_num
                                                                                        
                                                                                        	Top assembly part number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: top_assem_vid
                                                                                        
                                                                                        	Top assembly revision number
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: udi_description
                                                                                        
                                                                                        	UDI description
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: udi_name
                                                                                        
                                                                                        	UDI name
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        .. attribute:: vid
                                                                                        
                                                                                        	Version ID
                                                                                        	**type**\:  str
                                                                                        
                                                                                        	**length:** 0..255
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'invmgr-oper'
                                                                                        _revision = '2015-11-09'

                                                                                        def __init__(self):
                                                                                            self.parent = None
                                                                                            self.asset_alias = None
                                                                                            self.asset_id = None
                                                                                            self.base_mac_address1 = None
                                                                                            self.base_mac_address2 = None
                                                                                            self.base_mac_address3 = None
                                                                                            self.base_mac_address4 = None
                                                                                            self.block_checksum = None
                                                                                            self.block_count = None
                                                                                            self.block_length = None
                                                                                            self.block_signature = None
                                                                                            self.block_version = None
                                                                                            self.chassis_sid = None
                                                                                            self.clei = None
                                                                                            self.controller_family = None
                                                                                            self.controller_type = None
                                                                                            self.description = None
                                                                                            self.dev_num1 = None
                                                                                            self.dev_num2 = None
                                                                                            self.dev_num3 = None
                                                                                            self.dev_num4 = None
                                                                                            self.dev_num5 = None
                                                                                            self.dev_num6 = None
                                                                                            self.dev_num7 = None
                                                                                            self.eci = None
                                                                                            self.eeprom_size = None
                                                                                            self.engineer_use = None
                                                                                            self.fru_major_type = None
                                                                                            self.fru_minor_type = None
                                                                                            self.hw_version = None
                                                                                            self.hwid = None
                                                                                            self.idprom_format_rev = None
                                                                                            self.mac_add_blk_size1 = None
                                                                                            self.mac_add_blk_size2 = None
                                                                                            self.mac_add_blk_size3 = None
                                                                                            self.mac_add_blk_size4 = None
                                                                                            self.manu_test_data = None
                                                                                            self.mfg_bits = None
                                                                                            self.mfg_deviation = None
                                                                                            self.oem_string = None
                                                                                            self.part_number = None
                                                                                            self.part_revision = None
                                                                                            self.pca_num = None
                                                                                            self.pcavid = None
                                                                                            self.pcb_serial_num = None
                                                                                            self.pid = None
                                                                                            self.power_consumption = None
                                                                                            self.power_supply_type = None
                                                                                            self.product_id = None
                                                                                            self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                            self.rma.parent = self
                                                                                            self.rma_code = None
                                                                                            self.serial_number = None
                                                                                            self.snmpoid = None
                                                                                            self.top_assem_part_num = None
                                                                                            self.top_assem_vid = None
                                                                                            self.udi_description = None
                                                                                            self.udi_name = None
                                                                                            self.vid = None


                                                                                        class Rma(object):
                                                                                            """
                                                                                            RMA Data
                                                                                            
                                                                                            .. attribute:: rma_history
                                                                                            
                                                                                            	RMA history
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: rma_number
                                                                                            
                                                                                            	RMA tracking number format is N\-N\-N
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            .. attribute:: test_history
                                                                                            
                                                                                            	Test history
                                                                                            	**type**\:  str
                                                                                            
                                                                                            	**length:** 0..255
                                                                                            
                                                                                            

                                                                                            """

                                                                                            _prefix = 'invmgr-oper'
                                                                                            _revision = '2015-11-09'

                                                                                            def __init__(self):
                                                                                                self.parent = None
                                                                                                self.rma_history = None
                                                                                                self.rma_number = None
                                                                                                self.test_history = None

                                                                                            @property
                                                                                            def _common_path(self):
                                                                                                if self.parent is None:
                                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                            def is_config(self):
                                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                                return False

                                                                                            def _has_data(self):
                                                                                                if not self.is_config():
                                                                                                    return False
                                                                                                if self.rma_history is not None:
                                                                                                    return True

                                                                                                if self.rma_number is not None:
                                                                                                    return True

                                                                                                if self.test_history is not None:
                                                                                                    return True

                                                                                                return False

                                                                                            @staticmethod
                                                                                            def _meta_info():
                                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                        @property
                                                                                        def _common_path(self):
                                                                                            if self.parent is None:
                                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                        def is_config(self):
                                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                                            return False

                                                                                        def _has_data(self):
                                                                                            if not self.is_config():
                                                                                                return False
                                                                                            if self.asset_alias is not None:
                                                                                                return True

                                                                                            if self.asset_id is not None:
                                                                                                return True

                                                                                            if self.base_mac_address1 is not None:
                                                                                                return True

                                                                                            if self.base_mac_address2 is not None:
                                                                                                return True

                                                                                            if self.base_mac_address3 is not None:
                                                                                                return True

                                                                                            if self.base_mac_address4 is not None:
                                                                                                return True

                                                                                            if self.block_checksum is not None:
                                                                                                return True

                                                                                            if self.block_count is not None:
                                                                                                return True

                                                                                            if self.block_length is not None:
                                                                                                return True

                                                                                            if self.block_signature is not None:
                                                                                                return True

                                                                                            if self.block_version is not None:
                                                                                                return True

                                                                                            if self.chassis_sid is not None:
                                                                                                return True

                                                                                            if self.clei is not None:
                                                                                                return True

                                                                                            if self.controller_family is not None:
                                                                                                return True

                                                                                            if self.controller_type is not None:
                                                                                                return True

                                                                                            if self.description is not None:
                                                                                                return True

                                                                                            if self.dev_num1 is not None:
                                                                                                return True

                                                                                            if self.dev_num2 is not None:
                                                                                                return True

                                                                                            if self.dev_num3 is not None:
                                                                                                return True

                                                                                            if self.dev_num4 is not None:
                                                                                                return True

                                                                                            if self.dev_num5 is not None:
                                                                                                return True

                                                                                            if self.dev_num6 is not None:
                                                                                                return True

                                                                                            if self.dev_num7 is not None:
                                                                                                return True

                                                                                            if self.eci is not None:
                                                                                                return True

                                                                                            if self.eeprom_size is not None:
                                                                                                return True

                                                                                            if self.engineer_use is not None:
                                                                                                return True

                                                                                            if self.fru_major_type is not None:
                                                                                                return True

                                                                                            if self.fru_minor_type is not None:
                                                                                                return True

                                                                                            if self.hw_version is not None:
                                                                                                return True

                                                                                            if self.hwid is not None:
                                                                                                return True

                                                                                            if self.idprom_format_rev is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size1 is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size2 is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size3 is not None:
                                                                                                return True

                                                                                            if self.mac_add_blk_size4 is not None:
                                                                                                return True

                                                                                            if self.manu_test_data is not None:
                                                                                                return True

                                                                                            if self.mfg_bits is not None:
                                                                                                return True

                                                                                            if self.mfg_deviation is not None:
                                                                                                return True

                                                                                            if self.oem_string is not None:
                                                                                                return True

                                                                                            if self.part_number is not None:
                                                                                                return True

                                                                                            if self.part_revision is not None:
                                                                                                return True

                                                                                            if self.pca_num is not None:
                                                                                                return True

                                                                                            if self.pcavid is not None:
                                                                                                return True

                                                                                            if self.pcb_serial_num is not None:
                                                                                                return True

                                                                                            if self.pid is not None:
                                                                                                return True

                                                                                            if self.power_consumption is not None:
                                                                                                return True

                                                                                            if self.power_supply_type is not None:
                                                                                                return True

                                                                                            if self.product_id is not None:
                                                                                                return True

                                                                                            if self.rma is not None and self.rma._has_data():
                                                                                                return True

                                                                                            if self.rma_code is not None:
                                                                                                return True

                                                                                            if self.serial_number is not None:
                                                                                                return True

                                                                                            if self.snmpoid is not None:
                                                                                                return True

                                                                                            if self.top_assem_part_num is not None:
                                                                                                return True

                                                                                            if self.top_assem_vid is not None:
                                                                                                return True

                                                                                            if self.udi_description is not None:
                                                                                                return True

                                                                                            if self.udi_name is not None:
                                                                                                return True

                                                                                            if self.vid is not None:
                                                                                                return True

                                                                                            return False

                                                                                        @staticmethod
                                                                                        def _meta_info():
                                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.description is not None:
                                                                                            return True

                                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                                            return True

                                                                                        if self.has_eeprom is not None:
                                                                                            return True

                                                                                        if self.inv_card_type is not None:
                                                                                            return True

                                                                                        if self.opaque_data is not None:
                                                                                            return True

                                                                                        if self.opaque_data_size is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes.InvEepromInfo']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                        return True

                                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                        return True

                                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                                        return True

                                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                        return True

                                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                        return True

                                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                        return True

                                                                                    if self.module_done is not None:
                                                                                        return True

                                                                                    if self.node_id is not None:
                                                                                        return True

                                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                        return True

                                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                                        return True

                                                                                    if self.vm_done is not None:
                                                                                        return True

                                                                                    if self.vm_node_id is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7.Attributes']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                                if self.name is None:
                                                                                    raise YPYModelError('Key property name is None')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi7[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.name is not None:
                                                                                    return True

                                                                                if self.attributes is not None and self.attributes._has_data():
                                                                                    return True

                                                                                if self.tsi8s is not None and self.tsi8s._has_data():
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S.Tsi7']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi7s'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.tsi7 is not None:
                                                                                for child_ref in self.tsi7:
                                                                                    if child_ref._has_data():
                                                                                        return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Tsi7S']['meta_info']


                                                                    class Attributes(object):
                                                                        """
                                                                        Attributes
                                                                        
                                                                        .. attribute:: env_sensor_info
                                                                        
                                                                        	Environment sensor info
                                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfo>`
                                                                        
                                                                        .. attribute:: env_sensor_info_xml
                                                                        
                                                                        	Environment sensor info XML
                                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml>`
                                                                        
                                                                        .. attribute:: fru_info
                                                                        
                                                                        	Inventory EDM FRU info
                                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo>`
                                                                        
                                                                        .. attribute:: inv_asset_bag
                                                                        
                                                                        	Inventory Asset Bag
                                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvAssetBag>`
                                                                        
                                                                        .. attribute:: inv_basic_bag
                                                                        
                                                                        	Inventory Basic Bag
                                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvBasicBag>`
                                                                        
                                                                        .. attribute:: inv_eeprom_info
                                                                        
                                                                        	Inventory EDM EEPROM Information Bag
                                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo>`
                                                                        
                                                                        .. attribute:: module_done
                                                                        
                                                                        	Inventory EDM Module Done Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**default value**\: 1
                                                                        
                                                                        .. attribute:: node_id
                                                                        
                                                                        	Node ID Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: pwg_info
                                                                        
                                                                        	Inventory EDM PWG info
                                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.PwgInfo>`
                                                                        
                                                                        .. attribute:: threshold
                                                                        
                                                                        	Threshold
                                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold>`
                                                                        
                                                                        .. attribute:: vm_done
                                                                        
                                                                        	VM Done Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        .. attribute:: vm_node_id
                                                                        
                                                                        	VM Node ID Tuple
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfo()
                                                                            self.env_sensor_info.parent = self
                                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml()
                                                                            self.env_sensor_info_xml.parent = self
                                                                            self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo()
                                                                            self.fru_info.parent = self
                                                                            self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvAssetBag()
                                                                            self.inv_asset_bag.parent = self
                                                                            self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvBasicBag()
                                                                            self.inv_basic_bag.parent = self
                                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo()
                                                                            self.inv_eeprom_info.parent = self
                                                                            self.module_done = None
                                                                            self.node_id = None
                                                                            self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.PwgInfo()
                                                                            self.pwg_info.parent = self
                                                                            self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold()
                                                                            self.threshold.parent = self
                                                                            self.vm_done = None
                                                                            self.vm_node_id = None


                                                                        class EnvSensorInfo(object):
                                                                            """
                                                                            Environment sensor info
                                                                            
                                                                            .. attribute:: age_time_stamp
                                                                            
                                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: alarm_type
                                                                            
                                                                            	Indicates threshold violation
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: data_type
                                                                            
                                                                            	Sensor data type enums
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: device_description
                                                                            
                                                                            	Device Name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: device_id
                                                                            
                                                                            	Identifier for this device
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: field_validity_bitmap
                                                                            
                                                                            	Sensor valid bitmap
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: precision
                                                                            
                                                                            	Sensor precision range
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: scale
                                                                            
                                                                            	Sensor scale enums
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: status
                                                                            
                                                                            	Sensor operation state enums
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: units
                                                                            
                                                                            	Units of variable being read
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: update_rate
                                                                            
                                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	Current reading of sensor
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.age_time_stamp = None
                                                                                self.alarm_type = None
                                                                                self.data_type = None
                                                                                self.device_description = None
                                                                                self.device_id = None
                                                                                self.field_validity_bitmap = None
                                                                                self.precision = None
                                                                                self.scale = None
                                                                                self.status = None
                                                                                self.units = None
                                                                                self.update_rate = None
                                                                                self.value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.age_time_stamp is not None:
                                                                                    return True

                                                                                if self.alarm_type is not None:
                                                                                    return True

                                                                                if self.data_type is not None:
                                                                                    return True

                                                                                if self.device_description is not None:
                                                                                    return True

                                                                                if self.device_id is not None:
                                                                                    return True

                                                                                if self.field_validity_bitmap is not None:
                                                                                    return True

                                                                                if self.precision is not None:
                                                                                    return True

                                                                                if self.scale is not None:
                                                                                    return True

                                                                                if self.status is not None:
                                                                                    return True

                                                                                if self.units is not None:
                                                                                    return True

                                                                                if self.update_rate is not None:
                                                                                    return True

                                                                                if self.value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfo']['meta_info']


                                                                        class PwgInfo(object):
                                                                            """
                                                                            Inventory EDM PWG info
                                                                            
                                                                            .. attribute:: power_group_available_current
                                                                            
                                                                            	available current
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_group_drawn_current
                                                                            
                                                                            	drawn current
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_group_power_units
                                                                            
                                                                            	power units
                                                                            	**type**\:  str
                                                                            
                                                                            .. attribute:: power_group_redundancy_mode
                                                                            
                                                                            	redundancy mode
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.power_group_available_current = None
                                                                                self.power_group_drawn_current = None
                                                                                self.power_group_power_units = None
                                                                                self.power_group_redundancy_mode = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.power_group_available_current is not None:
                                                                                    return True

                                                                                if self.power_group_drawn_current is not None:
                                                                                    return True

                                                                                if self.power_group_power_units is not None:
                                                                                    return True

                                                                                if self.power_group_redundancy_mode is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.PwgInfo']['meta_info']


                                                                        class EnvSensorInfoXml(object):
                                                                            """
                                                                            Environment sensor info XML
                                                                            
                                                                            .. attribute:: data_type
                                                                            
                                                                            	Sensor data type
                                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                            
                                                                            .. attribute:: description
                                                                            
                                                                            	Device Name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: status
                                                                            
                                                                            	Sensor operation state
                                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                            
                                                                            .. attribute:: threshold
                                                                            
                                                                            	Threshold information
                                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold>`
                                                                            
                                                                            .. attribute:: units
                                                                            
                                                                            	Units of variable being read
                                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                            
                                                                            .. attribute:: update_rate
                                                                            
                                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.data_type = None
                                                                                self.description = None
                                                                                self.status = None
                                                                                self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold()
                                                                                self.threshold.parent = self
                                                                                self.units = None
                                                                                self.update_rate = None
                                                                                self.value = None


                                                                            class Threshold(object):
                                                                                """
                                                                                Threshold information
                                                                                
                                                                                .. attribute:: threshold_array
                                                                                
                                                                                	Array of threshold
                                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.threshold_array = YList()
                                                                                    self.threshold_array.parent = self
                                                                                    self.threshold_array.name = 'threshold_array'


                                                                                class ThresholdArray(object):
                                                                                    """
                                                                                    Array of threshold
                                                                                    
                                                                                    .. attribute:: threshold_name
                                                                                    
                                                                                    	Threshold name
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..50
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** \-2147483648..2147483647
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_name = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_name is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.threshold_array is not None:
                                                                                        for child_ref in self.threshold_array:
                                                                                            if child_ref._has_data():
                                                                                                return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.data_type is not None:
                                                                                    return True

                                                                                if self.description is not None:
                                                                                    return True

                                                                                if self.status is not None:
                                                                                    return True

                                                                                if self.threshold is not None and self.threshold._has_data():
                                                                                    return True

                                                                                if self.units is not None:
                                                                                    return True

                                                                                if self.update_rate is not None:
                                                                                    return True

                                                                                if self.value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.EnvSensorInfoXml']['meta_info']


                                                                        class InvAssetBag(object):
                                                                            """
                                                                            Inventory Asset Bag
                                                                            
                                                                            .. attribute:: manufacturer_assembly_number
                                                                            
                                                                            	Manufacture Assembly number
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_assembly_revision
                                                                            
                                                                            	Manufacture assembly revision
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                                            
                                                                            	Common Language Equipment           Identifier number
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_firmware_identifier
                                                                            
                                                                            	
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: manufacturer_software_identifier
                                                                            
                                                                            	
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: original_equipment_manufacturer_string
                                                                            
                                                                            	String containing OEM information           if applicable
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: part_number
                                                                            
                                                                            	
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.manufacturer_assembly_number = None
                                                                                self.manufacturer_assembly_revision = None
                                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                                self.manufacturer_firmware_identifier = None
                                                                                self.manufacturer_software_identifier = None
                                                                                self.original_equipment_manufacturer_string = None
                                                                                self.part_number = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.manufacturer_assembly_number is not None:
                                                                                    return True

                                                                                if self.manufacturer_assembly_revision is not None:
                                                                                    return True

                                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                                    return True

                                                                                if self.manufacturer_firmware_identifier is not None:
                                                                                    return True

                                                                                if self.manufacturer_software_identifier is not None:
                                                                                    return True

                                                                                if self.original_equipment_manufacturer_string is not None:
                                                                                    return True

                                                                                if self.part_number is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvAssetBag']['meta_info']


                                                                        class Threshold(object):
                                                                            """
                                                                            Threshold
                                                                            
                                                                            .. attribute:: critical_hi
                                                                            
                                                                            	Critical High
                                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi>`
                                                                            
                                                                            .. attribute:: critical_lo
                                                                            
                                                                            	Critical Low
                                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo>`
                                                                            
                                                                            .. attribute:: major_hi
                                                                            
                                                                            	Major High
                                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi>`
                                                                            
                                                                            .. attribute:: major_lo
                                                                            
                                                                            	Major Low
                                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo>`
                                                                            
                                                                            .. attribute:: minor_hi
                                                                            
                                                                            	Minor High
                                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi>`
                                                                            
                                                                            .. attribute:: minor_lo
                                                                            
                                                                            	Minor Low
                                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi()
                                                                                self.critical_hi.parent = self
                                                                                self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo()
                                                                                self.critical_lo.parent = self
                                                                                self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi()
                                                                                self.major_hi.parent = self
                                                                                self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo()
                                                                                self.major_lo.parent = self
                                                                                self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi()
                                                                                self.minor_hi.parent = self
                                                                                self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo()
                                                                                self.minor_lo.parent = self


                                                                            class MajorLo(object):
                                                                                """
                                                                                Major Low
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorLo']['meta_info']


                                                                            class CriticalHi(object):
                                                                                """
                                                                                Critical High
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalHi']['meta_info']


                                                                            class MinorHi(object):
                                                                                """
                                                                                Minor High
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorHi']['meta_info']


                                                                            class MajorHi(object):
                                                                                """
                                                                                Major High
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MajorHi']['meta_info']


                                                                            class CriticalLo(object):
                                                                                """
                                                                                Critical Low
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.CriticalLo']['meta_info']


                                                                            class MinorLo(object):
                                                                                """
                                                                                Minor Low
                                                                                
                                                                                .. attribute:: thresh_bag
                                                                                
                                                                                	Environment threshold info
                                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo.ThreshBag()
                                                                                    self.thresh_bag.parent = self


                                                                                class ThreshBag(object):
                                                                                    """
                                                                                    Environment threshold info
                                                                                    
                                                                                    .. attribute:: threshold_evaluation
                                                                                    
                                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_notification_enabled
                                                                                    
                                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                                    	**type**\:  bool
                                                                                    
                                                                                    .. attribute:: threshold_relation
                                                                                    
                                                                                    	Indicates relation between sensor value and threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_severity
                                                                                    
                                                                                    	Indicates minor, major, critical severities
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: threshold_value
                                                                                    
                                                                                    	Value of the configured threshold
                                                                                    	**type**\:  int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.threshold_evaluation = None
                                                                                        self.threshold_notification_enabled = None
                                                                                        self.threshold_relation = None
                                                                                        self.threshold_severity = None
                                                                                        self.threshold_value = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.threshold_evaluation is not None:
                                                                                            return True

                                                                                        if self.threshold_notification_enabled is not None:
                                                                                            return True

                                                                                        if self.threshold_relation is not None:
                                                                                            return True

                                                                                        if self.threshold_severity is not None:
                                                                                            return True

                                                                                        if self.threshold_value is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold.MinorLo']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                                    return True

                                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                                    return True

                                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                                    return True

                                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                                    return True

                                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                                    return True

                                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.Threshold']['meta_info']


                                                                        class FruInfo(object):
                                                                            """
                                                                            Inventory EDM FRU info
                                                                            
                                                                            .. attribute:: card_administrative_state
                                                                            
                                                                            	card admin state\: shutdown or not
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: card_monitor_state
                                                                            
                                                                            	card is monitored by a manager or left unmonitored
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: card_operational_state
                                                                            
                                                                            	card operation state
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: card_reset_reason
                                                                            
                                                                            	card reset reason enum
                                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                            
                                                                            .. attribute:: card_up_time
                                                                            
                                                                            	card up time
                                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.CardUpTime>`
                                                                            
                                                                            .. attribute:: last_operational_state_change
                                                                            
                                                                            	last card oper change state
                                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.LastOperationalStateChange>`
                                                                            
                                                                            .. attribute:: power_administrative_state
                                                                            
                                                                            	power admin state\: up or down
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_current_measurement
                                                                            
                                                                            	power current\: not implemented
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: power_operational_state
                                                                            
                                                                            	Power operation state
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.card_administrative_state = None
                                                                                self.card_monitor_state = None
                                                                                self.card_operational_state = None
                                                                                self.card_reset_reason = None
                                                                                self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.CardUpTime()
                                                                                self.card_up_time.parent = self
                                                                                self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.LastOperationalStateChange()
                                                                                self.last_operational_state_change.parent = self
                                                                                self.power_administrative_state = None
                                                                                self.power_current_measurement = None
                                                                                self.power_operational_state = None


                                                                            class LastOperationalStateChange(object):
                                                                                """
                                                                                last card oper change state
                                                                                
                                                                                .. attribute:: time_in_nano_seconds
                                                                                
                                                                                	Time Value in Nano\-seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: nanosecond
                                                                                
                                                                                .. attribute:: time_in_seconds
                                                                                
                                                                                	Time Value in Seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: second
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.time_in_nano_seconds = None
                                                                                    self.time_in_seconds = None

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.time_in_nano_seconds is not None:
                                                                                        return True

                                                                                    if self.time_in_seconds is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                            class CardUpTime(object):
                                                                                """
                                                                                card up time
                                                                                
                                                                                .. attribute:: time_in_nano_seconds
                                                                                
                                                                                	Time Value in Nano\-seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: nanosecond
                                                                                
                                                                                .. attribute:: time_in_seconds
                                                                                
                                                                                	Time Value in Seconds
                                                                                	**type**\:  int
                                                                                
                                                                                	**range:** \-2147483648..2147483647
                                                                                
                                                                                	**units**\: second
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.time_in_nano_seconds = None
                                                                                    self.time_in_seconds = None

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.time_in_nano_seconds is not None:
                                                                                        return True

                                                                                    if self.time_in_seconds is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.card_administrative_state is not None:
                                                                                    return True

                                                                                if self.card_monitor_state is not None:
                                                                                    return True

                                                                                if self.card_operational_state is not None:
                                                                                    return True

                                                                                if self.card_reset_reason is not None:
                                                                                    return True

                                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                                    return True

                                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                                    return True

                                                                                if self.power_administrative_state is not None:
                                                                                    return True

                                                                                if self.power_current_measurement is not None:
                                                                                    return True

                                                                                if self.power_operational_state is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.FruInfo']['meta_info']


                                                                        class InvBasicBag(object):
                                                                            """
                                                                            Inventory Basic Bag
                                                                            
                                                                            .. attribute:: alias
                                                                            
                                                                            	useful for storing an entity alias 
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: asset_id_str
                                                                            
                                                                            	asset Identification string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: asset_identification
                                                                            
                                                                            	asset Identification
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: ceport
                                                                            
                                                                            	1 if ce port found, 0 if not
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: chip_hardware_revision
                                                                            
                                                                            	chip module hw revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: composite_class_code
                                                                            
                                                                            	Major&minor class of the entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: description
                                                                            
                                                                            	describes in user\-readable terms       what the entity in question does
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: environmental_monitor_path
                                                                            
                                                                            	sysdb name of sensor in the envmon EDM
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: firmware_revision
                                                                            
                                                                            	firmware revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: group_flag
                                                                            
                                                                            	indicates if this entity is group       or not
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: hardware_revision
                                                                            
                                                                            	hw revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: is_field_replaceable_unit
                                                                            
                                                                            	1 if Field Replaceable Unit 0, if not
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: manufacturer_asset_tags
                                                                            
                                                                            	Manufacture Asset Tags
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: manufacturer_name
                                                                            
                                                                            	manufacturer's name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: memory_size
                                                                            
                                                                            	Size of memory associated with       the entity where applicable
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: model_name
                                                                            
                                                                            	model name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: name
                                                                            
                                                                            	name string for the entity
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: new_deviation_number
                                                                            
                                                                            	integer value for New Deviation Number 0x88
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: physical_layer_interface_module_type
                                                                            
                                                                            	integer value for plim type if     applicable to this entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: redundancystate
                                                                            
                                                                            	integer value for Redundancy State if     applicable to this entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: serial_number
                                                                            
                                                                            	serial number
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: software_revision
                                                                            
                                                                            	software revision string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: unique_id
                                                                            
                                                                            	Unique id for an entity
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            .. attribute:: unrecognized_fru
                                                                            
                                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: vendor_type
                                                                            
                                                                            	maps to the vendor OID string
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: xr_scoped
                                                                            
                                                                            	1 if xr scoped, 0 if not
                                                                            	**type**\:  bool
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.alias = None
                                                                                self.asset_id_str = None
                                                                                self.asset_identification = None
                                                                                self.ceport = None
                                                                                self.chip_hardware_revision = None
                                                                                self.composite_class_code = None
                                                                                self.description = None
                                                                                self.environmental_monitor_path = None
                                                                                self.firmware_revision = None
                                                                                self.group_flag = None
                                                                                self.hardware_revision = None
                                                                                self.is_field_replaceable_unit = None
                                                                                self.manufacturer_asset_tags = None
                                                                                self.manufacturer_name = None
                                                                                self.memory_size = None
                                                                                self.model_name = None
                                                                                self.name = None
                                                                                self.new_deviation_number = None
                                                                                self.physical_layer_interface_module_type = None
                                                                                self.redundancystate = None
                                                                                self.serial_number = None
                                                                                self.software_revision = None
                                                                                self.unique_id = None
                                                                                self.unrecognized_fru = None
                                                                                self.vendor_type = None
                                                                                self.xr_scoped = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.alias is not None:
                                                                                    return True

                                                                                if self.asset_id_str is not None:
                                                                                    return True

                                                                                if self.asset_identification is not None:
                                                                                    return True

                                                                                if self.ceport is not None:
                                                                                    return True

                                                                                if self.chip_hardware_revision is not None:
                                                                                    return True

                                                                                if self.composite_class_code is not None:
                                                                                    return True

                                                                                if self.description is not None:
                                                                                    return True

                                                                                if self.environmental_monitor_path is not None:
                                                                                    return True

                                                                                if self.firmware_revision is not None:
                                                                                    return True

                                                                                if self.group_flag is not None:
                                                                                    return True

                                                                                if self.hardware_revision is not None:
                                                                                    return True

                                                                                if self.is_field_replaceable_unit is not None:
                                                                                    return True

                                                                                if self.manufacturer_asset_tags is not None:
                                                                                    return True

                                                                                if self.manufacturer_name is not None:
                                                                                    return True

                                                                                if self.memory_size is not None:
                                                                                    return True

                                                                                if self.model_name is not None:
                                                                                    return True

                                                                                if self.name is not None:
                                                                                    return True

                                                                                if self.new_deviation_number is not None:
                                                                                    return True

                                                                                if self.physical_layer_interface_module_type is not None:
                                                                                    return True

                                                                                if self.redundancystate is not None:
                                                                                    return True

                                                                                if self.serial_number is not None:
                                                                                    return True

                                                                                if self.software_revision is not None:
                                                                                    return True

                                                                                if self.unique_id is not None:
                                                                                    return True

                                                                                if self.unrecognized_fru is not None:
                                                                                    return True

                                                                                if self.vendor_type is not None:
                                                                                    return True

                                                                                if self.xr_scoped is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvBasicBag']['meta_info']


                                                                        class InvEepromInfo(object):
                                                                            """
                                                                            Inventory EDM EEPROM Information Bag
                                                                            
                                                                            .. attribute:: description
                                                                            
                                                                            	A textual description of physical entity
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: eeprom
                                                                            
                                                                            	EEPROM data not from hex data
                                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom>`
                                                                            
                                                                            .. attribute:: has_eeprom
                                                                            
                                                                            	use eeprom instead of opaque data
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: inv_card_type
                                                                            
                                                                            	Inventory card type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: opaque_data
                                                                            
                                                                            	EEPROM hex data
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: opaque_data_size
                                                                            
                                                                            	size of the EEPROM hex data
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.description = None
                                                                                self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom()
                                                                                self.eeprom.parent = self
                                                                                self.has_eeprom = None
                                                                                self.inv_card_type = None
                                                                                self.opaque_data = None
                                                                                self.opaque_data_size = None


                                                                            class Eeprom(object):
                                                                                """
                                                                                EEPROM data not from hex data
                                                                                
                                                                                .. attribute:: asset_alias
                                                                                
                                                                                	Asset Alias
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: asset_id
                                                                                
                                                                                	Asset ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address1
                                                                                
                                                                                	Base Mac Address #1
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address2
                                                                                
                                                                                	Base Mac Address #2
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address3
                                                                                
                                                                                	Base Mac Address #3
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: base_mac_address4
                                                                                
                                                                                	Base Mac Address #4
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_checksum
                                                                                
                                                                                	Block Checksum
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_count
                                                                                
                                                                                	Block Count
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_length
                                                                                
                                                                                	Block Length
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_signature
                                                                                
                                                                                	Block Signature
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: block_version
                                                                                
                                                                                	Block Version
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: chassis_sid
                                                                                
                                                                                	Chassis serial number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: clei
                                                                                
                                                                                	Common Language Equipment Identifier (CLEI) code
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: controller_family
                                                                                
                                                                                	Controller family
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: controller_type
                                                                                
                                                                                	Controller type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: description
                                                                                
                                                                                	A textual description of physical entity
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num1
                                                                                
                                                                                	Deviation Number # 1
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num2
                                                                                
                                                                                	Deviation Number # 2
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num3
                                                                                
                                                                                	Deviation Number # 3
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num4
                                                                                
                                                                                	Deviation Number # 4
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num5
                                                                                
                                                                                	Deviation Number # 5
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num6
                                                                                
                                                                                	Deviation Number # 6
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: dev_num7
                                                                                
                                                                                	Deviation Number # 7
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: eci
                                                                                
                                                                                	Equipment Catalog Item (ECI) number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: eeprom_size
                                                                                
                                                                                	EEPROM Size
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: engineer_use
                                                                                
                                                                                	Engineer Use
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: fru_major_type
                                                                                
                                                                                	FRU Major Type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: fru_minor_type
                                                                                
                                                                                	FRU Minor Type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: hw_version
                                                                                
                                                                                	Hardware Version
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: hwid
                                                                                
                                                                                	Hardware Revision
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: idprom_format_rev
                                                                                
                                                                                	IDPROM Format Revision
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size1
                                                                                
                                                                                	Mac Address Block Size #1
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size2
                                                                                
                                                                                	Mac Address Block Size #2
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size3
                                                                                
                                                                                	Mac Address Block Size #3
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mac_add_blk_size4
                                                                                
                                                                                	Mac Address Block Size #4
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: manu_test_data
                                                                                
                                                                                	Manufacturing Test Data
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mfg_bits
                                                                                
                                                                                	MFG Bits
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: mfg_deviation
                                                                                
                                                                                	MFG Deviation
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: oem_string
                                                                                
                                                                                	OEM String
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: part_number
                                                                                
                                                                                	Part Number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: part_revision
                                                                                
                                                                                	Part Revision
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pca_num
                                                                                
                                                                                	PCA number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pcavid
                                                                                
                                                                                	PCA revision ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pcb_serial_num
                                                                                
                                                                                	PCB Serial Number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: pid
                                                                                
                                                                                	Product ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: power_consumption
                                                                                
                                                                                	Power Consumption
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: power_supply_type
                                                                                
                                                                                	Power Supply Type
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: product_id
                                                                                
                                                                                	Product ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: rma
                                                                                
                                                                                	RMA Data
                                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                                
                                                                                .. attribute:: rma_code
                                                                                
                                                                                	RMA Code
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: serial_number
                                                                                
                                                                                	Serial Number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: snmpoid
                                                                                
                                                                                	SNMP OID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: top_assem_part_num
                                                                                
                                                                                	Top assembly part number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: top_assem_vid
                                                                                
                                                                                	Top assembly revision number
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: udi_description
                                                                                
                                                                                	UDI description
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: udi_name
                                                                                
                                                                                	UDI name
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                .. attribute:: vid
                                                                                
                                                                                	Version ID
                                                                                	**type**\:  str
                                                                                
                                                                                	**length:** 0..255
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'invmgr-oper'
                                                                                _revision = '2015-11-09'

                                                                                def __init__(self):
                                                                                    self.parent = None
                                                                                    self.asset_alias = None
                                                                                    self.asset_id = None
                                                                                    self.base_mac_address1 = None
                                                                                    self.base_mac_address2 = None
                                                                                    self.base_mac_address3 = None
                                                                                    self.base_mac_address4 = None
                                                                                    self.block_checksum = None
                                                                                    self.block_count = None
                                                                                    self.block_length = None
                                                                                    self.block_signature = None
                                                                                    self.block_version = None
                                                                                    self.chassis_sid = None
                                                                                    self.clei = None
                                                                                    self.controller_family = None
                                                                                    self.controller_type = None
                                                                                    self.description = None
                                                                                    self.dev_num1 = None
                                                                                    self.dev_num2 = None
                                                                                    self.dev_num3 = None
                                                                                    self.dev_num4 = None
                                                                                    self.dev_num5 = None
                                                                                    self.dev_num6 = None
                                                                                    self.dev_num7 = None
                                                                                    self.eci = None
                                                                                    self.eeprom_size = None
                                                                                    self.engineer_use = None
                                                                                    self.fru_major_type = None
                                                                                    self.fru_minor_type = None
                                                                                    self.hw_version = None
                                                                                    self.hwid = None
                                                                                    self.idprom_format_rev = None
                                                                                    self.mac_add_blk_size1 = None
                                                                                    self.mac_add_blk_size2 = None
                                                                                    self.mac_add_blk_size3 = None
                                                                                    self.mac_add_blk_size4 = None
                                                                                    self.manu_test_data = None
                                                                                    self.mfg_bits = None
                                                                                    self.mfg_deviation = None
                                                                                    self.oem_string = None
                                                                                    self.part_number = None
                                                                                    self.part_revision = None
                                                                                    self.pca_num = None
                                                                                    self.pcavid = None
                                                                                    self.pcb_serial_num = None
                                                                                    self.pid = None
                                                                                    self.power_consumption = None
                                                                                    self.power_supply_type = None
                                                                                    self.product_id = None
                                                                                    self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                                    self.rma.parent = self
                                                                                    self.rma_code = None
                                                                                    self.serial_number = None
                                                                                    self.snmpoid = None
                                                                                    self.top_assem_part_num = None
                                                                                    self.top_assem_vid = None
                                                                                    self.udi_description = None
                                                                                    self.udi_name = None
                                                                                    self.vid = None


                                                                                class Rma(object):
                                                                                    """
                                                                                    RMA Data
                                                                                    
                                                                                    .. attribute:: rma_history
                                                                                    
                                                                                    	RMA history
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: rma_number
                                                                                    
                                                                                    	RMA tracking number format is N\-N\-N
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    .. attribute:: test_history
                                                                                    
                                                                                    	Test history
                                                                                    	**type**\:  str
                                                                                    
                                                                                    	**length:** 0..255
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'invmgr-oper'
                                                                                    _revision = '2015-11-09'

                                                                                    def __init__(self):
                                                                                        self.parent = None
                                                                                        self.rma_history = None
                                                                                        self.rma_number = None
                                                                                        self.test_history = None

                                                                                    @property
                                                                                    def _common_path(self):
                                                                                        if self.parent is None:
                                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                                    def is_config(self):
                                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                                        return False

                                                                                    def _has_data(self):
                                                                                        if not self.is_config():
                                                                                            return False
                                                                                        if self.rma_history is not None:
                                                                                            return True

                                                                                        if self.rma_number is not None:
                                                                                            return True

                                                                                        if self.test_history is not None:
                                                                                            return True

                                                                                        return False

                                                                                    @staticmethod
                                                                                    def _meta_info():
                                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                                @property
                                                                                def _common_path(self):
                                                                                    if self.parent is None:
                                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                                def is_config(self):
                                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                                    return False

                                                                                def _has_data(self):
                                                                                    if not self.is_config():
                                                                                        return False
                                                                                    if self.asset_alias is not None:
                                                                                        return True

                                                                                    if self.asset_id is not None:
                                                                                        return True

                                                                                    if self.base_mac_address1 is not None:
                                                                                        return True

                                                                                    if self.base_mac_address2 is not None:
                                                                                        return True

                                                                                    if self.base_mac_address3 is not None:
                                                                                        return True

                                                                                    if self.base_mac_address4 is not None:
                                                                                        return True

                                                                                    if self.block_checksum is not None:
                                                                                        return True

                                                                                    if self.block_count is not None:
                                                                                        return True

                                                                                    if self.block_length is not None:
                                                                                        return True

                                                                                    if self.block_signature is not None:
                                                                                        return True

                                                                                    if self.block_version is not None:
                                                                                        return True

                                                                                    if self.chassis_sid is not None:
                                                                                        return True

                                                                                    if self.clei is not None:
                                                                                        return True

                                                                                    if self.controller_family is not None:
                                                                                        return True

                                                                                    if self.controller_type is not None:
                                                                                        return True

                                                                                    if self.description is not None:
                                                                                        return True

                                                                                    if self.dev_num1 is not None:
                                                                                        return True

                                                                                    if self.dev_num2 is not None:
                                                                                        return True

                                                                                    if self.dev_num3 is not None:
                                                                                        return True

                                                                                    if self.dev_num4 is not None:
                                                                                        return True

                                                                                    if self.dev_num5 is not None:
                                                                                        return True

                                                                                    if self.dev_num6 is not None:
                                                                                        return True

                                                                                    if self.dev_num7 is not None:
                                                                                        return True

                                                                                    if self.eci is not None:
                                                                                        return True

                                                                                    if self.eeprom_size is not None:
                                                                                        return True

                                                                                    if self.engineer_use is not None:
                                                                                        return True

                                                                                    if self.fru_major_type is not None:
                                                                                        return True

                                                                                    if self.fru_minor_type is not None:
                                                                                        return True

                                                                                    if self.hw_version is not None:
                                                                                        return True

                                                                                    if self.hwid is not None:
                                                                                        return True

                                                                                    if self.idprom_format_rev is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size1 is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size2 is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size3 is not None:
                                                                                        return True

                                                                                    if self.mac_add_blk_size4 is not None:
                                                                                        return True

                                                                                    if self.manu_test_data is not None:
                                                                                        return True

                                                                                    if self.mfg_bits is not None:
                                                                                        return True

                                                                                    if self.mfg_deviation is not None:
                                                                                        return True

                                                                                    if self.oem_string is not None:
                                                                                        return True

                                                                                    if self.part_number is not None:
                                                                                        return True

                                                                                    if self.part_revision is not None:
                                                                                        return True

                                                                                    if self.pca_num is not None:
                                                                                        return True

                                                                                    if self.pcavid is not None:
                                                                                        return True

                                                                                    if self.pcb_serial_num is not None:
                                                                                        return True

                                                                                    if self.pid is not None:
                                                                                        return True

                                                                                    if self.power_consumption is not None:
                                                                                        return True

                                                                                    if self.power_supply_type is not None:
                                                                                        return True

                                                                                    if self.product_id is not None:
                                                                                        return True

                                                                                    if self.rma is not None and self.rma._has_data():
                                                                                        return True

                                                                                    if self.rma_code is not None:
                                                                                        return True

                                                                                    if self.serial_number is not None:
                                                                                        return True

                                                                                    if self.snmpoid is not None:
                                                                                        return True

                                                                                    if self.top_assem_part_num is not None:
                                                                                        return True

                                                                                    if self.top_assem_vid is not None:
                                                                                        return True

                                                                                    if self.udi_description is not None:
                                                                                        return True

                                                                                    if self.udi_name is not None:
                                                                                        return True

                                                                                    if self.vid is not None:
                                                                                        return True

                                                                                    return False

                                                                                @staticmethod
                                                                                def _meta_info():
                                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.description is not None:
                                                                                    return True

                                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                                    return True

                                                                                if self.has_eeprom is not None:
                                                                                    return True

                                                                                if self.inv_card_type is not None:
                                                                                    return True

                                                                                if self.opaque_data is not None:
                                                                                    return True

                                                                                if self.opaque_data_size is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes.InvEepromInfo']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                                return True

                                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                                return True

                                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                                return True

                                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                                return True

                                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                                return True

                                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                                return True

                                                                            if self.module_done is not None:
                                                                                return True

                                                                            if self.node_id is not None:
                                                                                return True

                                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                                return True

                                                                            if self.threshold is not None and self.threshold._has_data():
                                                                                return True

                                                                            if self.vm_done is not None:
                                                                                return True

                                                                            if self.vm_node_id is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6.Attributes']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                                        if self.name is None:
                                                                            raise YPYModelError('Key property name is None')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi6[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.name is not None:
                                                                            return True

                                                                        if self.attributes is not None and self.attributes._has_data():
                                                                            return True

                                                                        if self.tsi7s is not None and self.tsi7s._has_data():
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S.Tsi6']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi6s'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.tsi6 is not None:
                                                                        for child_ref in self.tsi6:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Tsi6S']['meta_info']


                                                            class Attributes(object):
                                                                """
                                                                Attributes
                                                                
                                                                .. attribute:: env_sensor_info
                                                                
                                                                	Environment sensor info
                                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfo>`
                                                                
                                                                .. attribute:: env_sensor_info_xml
                                                                
                                                                	Environment sensor info XML
                                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml>`
                                                                
                                                                .. attribute:: fru_info
                                                                
                                                                	Inventory EDM FRU info
                                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo>`
                                                                
                                                                .. attribute:: inv_asset_bag
                                                                
                                                                	Inventory Asset Bag
                                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvAssetBag>`
                                                                
                                                                .. attribute:: inv_basic_bag
                                                                
                                                                	Inventory Basic Bag
                                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvBasicBag>`
                                                                
                                                                .. attribute:: inv_eeprom_info
                                                                
                                                                	Inventory EDM EEPROM Information Bag
                                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo>`
                                                                
                                                                .. attribute:: module_done
                                                                
                                                                	Inventory EDM Module Done Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**default value**\: 1
                                                                
                                                                .. attribute:: node_id
                                                                
                                                                	Node ID Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pwg_info
                                                                
                                                                	Inventory EDM PWG info
                                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.PwgInfo>`
                                                                
                                                                .. attribute:: threshold
                                                                
                                                                	Threshold
                                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold>`
                                                                
                                                                .. attribute:: vm_done
                                                                
                                                                	VM Done Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                .. attribute:: vm_node_id
                                                                
                                                                	VM Node ID Tuple
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfo()
                                                                    self.env_sensor_info.parent = self
                                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml()
                                                                    self.env_sensor_info_xml.parent = self
                                                                    self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo()
                                                                    self.fru_info.parent = self
                                                                    self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvAssetBag()
                                                                    self.inv_asset_bag.parent = self
                                                                    self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvBasicBag()
                                                                    self.inv_basic_bag.parent = self
                                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo()
                                                                    self.inv_eeprom_info.parent = self
                                                                    self.module_done = None
                                                                    self.node_id = None
                                                                    self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.PwgInfo()
                                                                    self.pwg_info.parent = self
                                                                    self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold()
                                                                    self.threshold.parent = self
                                                                    self.vm_done = None
                                                                    self.vm_node_id = None


                                                                class EnvSensorInfo(object):
                                                                    """
                                                                    Environment sensor info
                                                                    
                                                                    .. attribute:: age_time_stamp
                                                                    
                                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: alarm_type
                                                                    
                                                                    	Indicates threshold violation
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: data_type
                                                                    
                                                                    	Sensor data type enums
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: device_description
                                                                    
                                                                    	Device Name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: device_id
                                                                    
                                                                    	Identifier for this device
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: field_validity_bitmap
                                                                    
                                                                    	Sensor valid bitmap
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: precision
                                                                    
                                                                    	Sensor precision range
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: scale
                                                                    
                                                                    	Sensor scale enums
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: status
                                                                    
                                                                    	Sensor operation state enums
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: units
                                                                    
                                                                    	Units of variable being read
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: update_rate
                                                                    
                                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	Current reading of sensor
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.age_time_stamp = None
                                                                        self.alarm_type = None
                                                                        self.data_type = None
                                                                        self.device_description = None
                                                                        self.device_id = None
                                                                        self.field_validity_bitmap = None
                                                                        self.precision = None
                                                                        self.scale = None
                                                                        self.status = None
                                                                        self.units = None
                                                                        self.update_rate = None
                                                                        self.value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.age_time_stamp is not None:
                                                                            return True

                                                                        if self.alarm_type is not None:
                                                                            return True

                                                                        if self.data_type is not None:
                                                                            return True

                                                                        if self.device_description is not None:
                                                                            return True

                                                                        if self.device_id is not None:
                                                                            return True

                                                                        if self.field_validity_bitmap is not None:
                                                                            return True

                                                                        if self.precision is not None:
                                                                            return True

                                                                        if self.scale is not None:
                                                                            return True

                                                                        if self.status is not None:
                                                                            return True

                                                                        if self.units is not None:
                                                                            return True

                                                                        if self.update_rate is not None:
                                                                            return True

                                                                        if self.value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfo']['meta_info']


                                                                class PwgInfo(object):
                                                                    """
                                                                    Inventory EDM PWG info
                                                                    
                                                                    .. attribute:: power_group_available_current
                                                                    
                                                                    	available current
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_group_drawn_current
                                                                    
                                                                    	drawn current
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_group_power_units
                                                                    
                                                                    	power units
                                                                    	**type**\:  str
                                                                    
                                                                    .. attribute:: power_group_redundancy_mode
                                                                    
                                                                    	redundancy mode
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.power_group_available_current = None
                                                                        self.power_group_drawn_current = None
                                                                        self.power_group_power_units = None
                                                                        self.power_group_redundancy_mode = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.power_group_available_current is not None:
                                                                            return True

                                                                        if self.power_group_drawn_current is not None:
                                                                            return True

                                                                        if self.power_group_power_units is not None:
                                                                            return True

                                                                        if self.power_group_redundancy_mode is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.PwgInfo']['meta_info']


                                                                class EnvSensorInfoXml(object):
                                                                    """
                                                                    Environment sensor info XML
                                                                    
                                                                    .. attribute:: data_type
                                                                    
                                                                    	Sensor data type
                                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                                    
                                                                    .. attribute:: description
                                                                    
                                                                    	Device Name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: status
                                                                    
                                                                    	Sensor operation state
                                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                                    
                                                                    .. attribute:: threshold
                                                                    
                                                                    	Threshold information
                                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold>`
                                                                    
                                                                    .. attribute:: units
                                                                    
                                                                    	Units of variable being read
                                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                                    
                                                                    .. attribute:: update_rate
                                                                    
                                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.data_type = None
                                                                        self.description = None
                                                                        self.status = None
                                                                        self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold()
                                                                        self.threshold.parent = self
                                                                        self.units = None
                                                                        self.update_rate = None
                                                                        self.value = None


                                                                    class Threshold(object):
                                                                        """
                                                                        Threshold information
                                                                        
                                                                        .. attribute:: threshold_array
                                                                        
                                                                        	Array of threshold
                                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.threshold_array = YList()
                                                                            self.threshold_array.parent = self
                                                                            self.threshold_array.name = 'threshold_array'


                                                                        class ThresholdArray(object):
                                                                            """
                                                                            Array of threshold
                                                                            
                                                                            .. attribute:: threshold_name
                                                                            
                                                                            	Threshold name
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..50
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** \-2147483648..2147483647
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_name = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_name is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.threshold_array is not None:
                                                                                for child_ref in self.threshold_array:
                                                                                    if child_ref._has_data():
                                                                                        return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.data_type is not None:
                                                                            return True

                                                                        if self.description is not None:
                                                                            return True

                                                                        if self.status is not None:
                                                                            return True

                                                                        if self.threshold is not None and self.threshold._has_data():
                                                                            return True

                                                                        if self.units is not None:
                                                                            return True

                                                                        if self.update_rate is not None:
                                                                            return True

                                                                        if self.value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.EnvSensorInfoXml']['meta_info']


                                                                class InvAssetBag(object):
                                                                    """
                                                                    Inventory Asset Bag
                                                                    
                                                                    .. attribute:: manufacturer_assembly_number
                                                                    
                                                                    	Manufacture Assembly number
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_assembly_revision
                                                                    
                                                                    	Manufacture assembly revision
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                                    
                                                                    	Common Language Equipment           Identifier number
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_firmware_identifier
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: manufacturer_software_identifier
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: original_equipment_manufacturer_string
                                                                    
                                                                    	String containing OEM information           if applicable
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: part_number
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.manufacturer_assembly_number = None
                                                                        self.manufacturer_assembly_revision = None
                                                                        self.manufacturer_common_language_equipment_identifier = None
                                                                        self.manufacturer_firmware_identifier = None
                                                                        self.manufacturer_software_identifier = None
                                                                        self.original_equipment_manufacturer_string = None
                                                                        self.part_number = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.manufacturer_assembly_number is not None:
                                                                            return True

                                                                        if self.manufacturer_assembly_revision is not None:
                                                                            return True

                                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                                            return True

                                                                        if self.manufacturer_firmware_identifier is not None:
                                                                            return True

                                                                        if self.manufacturer_software_identifier is not None:
                                                                            return True

                                                                        if self.original_equipment_manufacturer_string is not None:
                                                                            return True

                                                                        if self.part_number is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvAssetBag']['meta_info']


                                                                class Threshold(object):
                                                                    """
                                                                    Threshold
                                                                    
                                                                    .. attribute:: critical_hi
                                                                    
                                                                    	Critical High
                                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi>`
                                                                    
                                                                    .. attribute:: critical_lo
                                                                    
                                                                    	Critical Low
                                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo>`
                                                                    
                                                                    .. attribute:: major_hi
                                                                    
                                                                    	Major High
                                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi>`
                                                                    
                                                                    .. attribute:: major_lo
                                                                    
                                                                    	Major Low
                                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo>`
                                                                    
                                                                    .. attribute:: minor_hi
                                                                    
                                                                    	Minor High
                                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi>`
                                                                    
                                                                    .. attribute:: minor_lo
                                                                    
                                                                    	Minor Low
                                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi()
                                                                        self.critical_hi.parent = self
                                                                        self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo()
                                                                        self.critical_lo.parent = self
                                                                        self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi()
                                                                        self.major_hi.parent = self
                                                                        self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo()
                                                                        self.major_lo.parent = self
                                                                        self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi()
                                                                        self.minor_hi.parent = self
                                                                        self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo()
                                                                        self.minor_lo.parent = self


                                                                    class MajorLo(object):
                                                                        """
                                                                        Major Low
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorLo']['meta_info']


                                                                    class CriticalHi(object):
                                                                        """
                                                                        Critical High
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalHi']['meta_info']


                                                                    class MinorHi(object):
                                                                        """
                                                                        Minor High
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorHi']['meta_info']


                                                                    class MajorHi(object):
                                                                        """
                                                                        Major High
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MajorHi']['meta_info']


                                                                    class CriticalLo(object):
                                                                        """
                                                                        Critical Low
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.CriticalLo']['meta_info']


                                                                    class MinorLo(object):
                                                                        """
                                                                        Minor Low
                                                                        
                                                                        .. attribute:: thresh_bag
                                                                        
                                                                        	Environment threshold info
                                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo.ThreshBag()
                                                                            self.thresh_bag.parent = self


                                                                        class ThreshBag(object):
                                                                            """
                                                                            Environment threshold info
                                                                            
                                                                            .. attribute:: threshold_evaluation
                                                                            
                                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_notification_enabled
                                                                            
                                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                                            	**type**\:  bool
                                                                            
                                                                            .. attribute:: threshold_relation
                                                                            
                                                                            	Indicates relation between sensor value and threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_severity
                                                                            
                                                                            	Indicates minor, major, critical severities
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: threshold_value
                                                                            
                                                                            	Value of the configured threshold
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.threshold_evaluation = None
                                                                                self.threshold_notification_enabled = None
                                                                                self.threshold_relation = None
                                                                                self.threshold_severity = None
                                                                                self.threshold_value = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.threshold_evaluation is not None:
                                                                                    return True

                                                                                if self.threshold_notification_enabled is not None:
                                                                                    return True

                                                                                if self.threshold_relation is not None:
                                                                                    return True

                                                                                if self.threshold_severity is not None:
                                                                                    return True

                                                                                if self.threshold_value is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold.MinorLo']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                                            return True

                                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                                            return True

                                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                                            return True

                                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                                            return True

                                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                                            return True

                                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.Threshold']['meta_info']


                                                                class FruInfo(object):
                                                                    """
                                                                    Inventory EDM FRU info
                                                                    
                                                                    .. attribute:: card_administrative_state
                                                                    
                                                                    	card admin state\: shutdown or not
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: card_monitor_state
                                                                    
                                                                    	card is monitored by a manager or left unmonitored
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: card_operational_state
                                                                    
                                                                    	card operation state
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: card_reset_reason
                                                                    
                                                                    	card reset reason enum
                                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                                    
                                                                    .. attribute:: card_up_time
                                                                    
                                                                    	card up time
                                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.CardUpTime>`
                                                                    
                                                                    .. attribute:: last_operational_state_change
                                                                    
                                                                    	last card oper change state
                                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.LastOperationalStateChange>`
                                                                    
                                                                    .. attribute:: power_administrative_state
                                                                    
                                                                    	power admin state\: up or down
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_current_measurement
                                                                    
                                                                    	power current\: not implemented
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: power_operational_state
                                                                    
                                                                    	Power operation state
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.card_administrative_state = None
                                                                        self.card_monitor_state = None
                                                                        self.card_operational_state = None
                                                                        self.card_reset_reason = None
                                                                        self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.CardUpTime()
                                                                        self.card_up_time.parent = self
                                                                        self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.LastOperationalStateChange()
                                                                        self.last_operational_state_change.parent = self
                                                                        self.power_administrative_state = None
                                                                        self.power_current_measurement = None
                                                                        self.power_operational_state = None


                                                                    class LastOperationalStateChange(object):
                                                                        """
                                                                        last card oper change state
                                                                        
                                                                        .. attribute:: time_in_nano_seconds
                                                                        
                                                                        	Time Value in Nano\-seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: nanosecond
                                                                        
                                                                        .. attribute:: time_in_seconds
                                                                        
                                                                        	Time Value in Seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.time_in_nano_seconds = None
                                                                            self.time_in_seconds = None

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.time_in_nano_seconds is not None:
                                                                                return True

                                                                            if self.time_in_seconds is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                                    class CardUpTime(object):
                                                                        """
                                                                        card up time
                                                                        
                                                                        .. attribute:: time_in_nano_seconds
                                                                        
                                                                        	Time Value in Nano\-seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: nanosecond
                                                                        
                                                                        .. attribute:: time_in_seconds
                                                                        
                                                                        	Time Value in Seconds
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** \-2147483648..2147483647
                                                                        
                                                                        	**units**\: second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.time_in_nano_seconds = None
                                                                            self.time_in_seconds = None

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.time_in_nano_seconds is not None:
                                                                                return True

                                                                            if self.time_in_seconds is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo.CardUpTime']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.card_administrative_state is not None:
                                                                            return True

                                                                        if self.card_monitor_state is not None:
                                                                            return True

                                                                        if self.card_operational_state is not None:
                                                                            return True

                                                                        if self.card_reset_reason is not None:
                                                                            return True

                                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                                            return True

                                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                            return True

                                                                        if self.power_administrative_state is not None:
                                                                            return True

                                                                        if self.power_current_measurement is not None:
                                                                            return True

                                                                        if self.power_operational_state is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.FruInfo']['meta_info']


                                                                class InvBasicBag(object):
                                                                    """
                                                                    Inventory Basic Bag
                                                                    
                                                                    .. attribute:: alias
                                                                    
                                                                    	useful for storing an entity alias 
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: asset_id_str
                                                                    
                                                                    	asset Identification string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: asset_identification
                                                                    
                                                                    	asset Identification
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: ceport
                                                                    
                                                                    	1 if ce port found, 0 if not
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: chip_hardware_revision
                                                                    
                                                                    	chip module hw revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: composite_class_code
                                                                    
                                                                    	Major&minor class of the entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: description
                                                                    
                                                                    	describes in user\-readable terms       what the entity in question does
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: environmental_monitor_path
                                                                    
                                                                    	sysdb name of sensor in the envmon EDM
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: firmware_revision
                                                                    
                                                                    	firmware revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: group_flag
                                                                    
                                                                    	indicates if this entity is group       or not
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: hardware_revision
                                                                    
                                                                    	hw revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: is_field_replaceable_unit
                                                                    
                                                                    	1 if Field Replaceable Unit 0, if not
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: manufacturer_asset_tags
                                                                    
                                                                    	Manufacture Asset Tags
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: manufacturer_name
                                                                    
                                                                    	manufacturer's name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: memory_size
                                                                    
                                                                    	Size of memory associated with       the entity where applicable
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: model_name
                                                                    
                                                                    	model name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: name
                                                                    
                                                                    	name string for the entity
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: new_deviation_number
                                                                    
                                                                    	integer value for New Deviation Number 0x88
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: physical_layer_interface_module_type
                                                                    
                                                                    	integer value for plim type if     applicable to this entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: redundancystate
                                                                    
                                                                    	integer value for Redundancy State if     applicable to this entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: serial_number
                                                                    
                                                                    	serial number
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: software_revision
                                                                    
                                                                    	software revision string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: unique_id
                                                                    
                                                                    	Unique id for an entity
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    .. attribute:: unrecognized_fru
                                                                    
                                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: vendor_type
                                                                    
                                                                    	maps to the vendor OID string
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: xr_scoped
                                                                    
                                                                    	1 if xr scoped, 0 if not
                                                                    	**type**\:  bool
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.alias = None
                                                                        self.asset_id_str = None
                                                                        self.asset_identification = None
                                                                        self.ceport = None
                                                                        self.chip_hardware_revision = None
                                                                        self.composite_class_code = None
                                                                        self.description = None
                                                                        self.environmental_monitor_path = None
                                                                        self.firmware_revision = None
                                                                        self.group_flag = None
                                                                        self.hardware_revision = None
                                                                        self.is_field_replaceable_unit = None
                                                                        self.manufacturer_asset_tags = None
                                                                        self.manufacturer_name = None
                                                                        self.memory_size = None
                                                                        self.model_name = None
                                                                        self.name = None
                                                                        self.new_deviation_number = None
                                                                        self.physical_layer_interface_module_type = None
                                                                        self.redundancystate = None
                                                                        self.serial_number = None
                                                                        self.software_revision = None
                                                                        self.unique_id = None
                                                                        self.unrecognized_fru = None
                                                                        self.vendor_type = None
                                                                        self.xr_scoped = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.alias is not None:
                                                                            return True

                                                                        if self.asset_id_str is not None:
                                                                            return True

                                                                        if self.asset_identification is not None:
                                                                            return True

                                                                        if self.ceport is not None:
                                                                            return True

                                                                        if self.chip_hardware_revision is not None:
                                                                            return True

                                                                        if self.composite_class_code is not None:
                                                                            return True

                                                                        if self.description is not None:
                                                                            return True

                                                                        if self.environmental_monitor_path is not None:
                                                                            return True

                                                                        if self.firmware_revision is not None:
                                                                            return True

                                                                        if self.group_flag is not None:
                                                                            return True

                                                                        if self.hardware_revision is not None:
                                                                            return True

                                                                        if self.is_field_replaceable_unit is not None:
                                                                            return True

                                                                        if self.manufacturer_asset_tags is not None:
                                                                            return True

                                                                        if self.manufacturer_name is not None:
                                                                            return True

                                                                        if self.memory_size is not None:
                                                                            return True

                                                                        if self.model_name is not None:
                                                                            return True

                                                                        if self.name is not None:
                                                                            return True

                                                                        if self.new_deviation_number is not None:
                                                                            return True

                                                                        if self.physical_layer_interface_module_type is not None:
                                                                            return True

                                                                        if self.redundancystate is not None:
                                                                            return True

                                                                        if self.serial_number is not None:
                                                                            return True

                                                                        if self.software_revision is not None:
                                                                            return True

                                                                        if self.unique_id is not None:
                                                                            return True

                                                                        if self.unrecognized_fru is not None:
                                                                            return True

                                                                        if self.vendor_type is not None:
                                                                            return True

                                                                        if self.xr_scoped is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvBasicBag']['meta_info']


                                                                class InvEepromInfo(object):
                                                                    """
                                                                    Inventory EDM EEPROM Information Bag
                                                                    
                                                                    .. attribute:: description
                                                                    
                                                                    	A textual description of physical entity
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: eeprom
                                                                    
                                                                    	EEPROM data not from hex data
                                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom>`
                                                                    
                                                                    .. attribute:: has_eeprom
                                                                    
                                                                    	use eeprom instead of opaque data
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: inv_card_type
                                                                    
                                                                    	Inventory card type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: opaque_data
                                                                    
                                                                    	EEPROM hex data
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: opaque_data_size
                                                                    
                                                                    	size of the EEPROM hex data
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.description = None
                                                                        self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom()
                                                                        self.eeprom.parent = self
                                                                        self.has_eeprom = None
                                                                        self.inv_card_type = None
                                                                        self.opaque_data = None
                                                                        self.opaque_data_size = None


                                                                    class Eeprom(object):
                                                                        """
                                                                        EEPROM data not from hex data
                                                                        
                                                                        .. attribute:: asset_alias
                                                                        
                                                                        	Asset Alias
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: asset_id
                                                                        
                                                                        	Asset ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address1
                                                                        
                                                                        	Base Mac Address #1
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address2
                                                                        
                                                                        	Base Mac Address #2
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address3
                                                                        
                                                                        	Base Mac Address #3
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: base_mac_address4
                                                                        
                                                                        	Base Mac Address #4
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_checksum
                                                                        
                                                                        	Block Checksum
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_count
                                                                        
                                                                        	Block Count
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_length
                                                                        
                                                                        	Block Length
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_signature
                                                                        
                                                                        	Block Signature
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: block_version
                                                                        
                                                                        	Block Version
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: chassis_sid
                                                                        
                                                                        	Chassis serial number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: clei
                                                                        
                                                                        	Common Language Equipment Identifier (CLEI) code
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: controller_family
                                                                        
                                                                        	Controller family
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: controller_type
                                                                        
                                                                        	Controller type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: description
                                                                        
                                                                        	A textual description of physical entity
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num1
                                                                        
                                                                        	Deviation Number # 1
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num2
                                                                        
                                                                        	Deviation Number # 2
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num3
                                                                        
                                                                        	Deviation Number # 3
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num4
                                                                        
                                                                        	Deviation Number # 4
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num5
                                                                        
                                                                        	Deviation Number # 5
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num6
                                                                        
                                                                        	Deviation Number # 6
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: dev_num7
                                                                        
                                                                        	Deviation Number # 7
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: eci
                                                                        
                                                                        	Equipment Catalog Item (ECI) number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: eeprom_size
                                                                        
                                                                        	EEPROM Size
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: engineer_use
                                                                        
                                                                        	Engineer Use
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: fru_major_type
                                                                        
                                                                        	FRU Major Type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: fru_minor_type
                                                                        
                                                                        	FRU Minor Type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: hw_version
                                                                        
                                                                        	Hardware Version
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: hwid
                                                                        
                                                                        	Hardware Revision
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: idprom_format_rev
                                                                        
                                                                        	IDPROM Format Revision
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size1
                                                                        
                                                                        	Mac Address Block Size #1
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size2
                                                                        
                                                                        	Mac Address Block Size #2
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size3
                                                                        
                                                                        	Mac Address Block Size #3
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mac_add_blk_size4
                                                                        
                                                                        	Mac Address Block Size #4
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: manu_test_data
                                                                        
                                                                        	Manufacturing Test Data
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mfg_bits
                                                                        
                                                                        	MFG Bits
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: mfg_deviation
                                                                        
                                                                        	MFG Deviation
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: oem_string
                                                                        
                                                                        	OEM String
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: part_number
                                                                        
                                                                        	Part Number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: part_revision
                                                                        
                                                                        	Part Revision
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pca_num
                                                                        
                                                                        	PCA number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pcavid
                                                                        
                                                                        	PCA revision ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pcb_serial_num
                                                                        
                                                                        	PCB Serial Number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: pid
                                                                        
                                                                        	Product ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: power_consumption
                                                                        
                                                                        	Power Consumption
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: power_supply_type
                                                                        
                                                                        	Power Supply Type
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: product_id
                                                                        
                                                                        	Product ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: rma
                                                                        
                                                                        	RMA Data
                                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                        
                                                                        .. attribute:: rma_code
                                                                        
                                                                        	RMA Code
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: serial_number
                                                                        
                                                                        	Serial Number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: snmpoid
                                                                        
                                                                        	SNMP OID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: top_assem_part_num
                                                                        
                                                                        	Top assembly part number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: top_assem_vid
                                                                        
                                                                        	Top assembly revision number
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: udi_description
                                                                        
                                                                        	UDI description
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: udi_name
                                                                        
                                                                        	UDI name
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        .. attribute:: vid
                                                                        
                                                                        	Version ID
                                                                        	**type**\:  str
                                                                        
                                                                        	**length:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'invmgr-oper'
                                                                        _revision = '2015-11-09'

                                                                        def __init__(self):
                                                                            self.parent = None
                                                                            self.asset_alias = None
                                                                            self.asset_id = None
                                                                            self.base_mac_address1 = None
                                                                            self.base_mac_address2 = None
                                                                            self.base_mac_address3 = None
                                                                            self.base_mac_address4 = None
                                                                            self.block_checksum = None
                                                                            self.block_count = None
                                                                            self.block_length = None
                                                                            self.block_signature = None
                                                                            self.block_version = None
                                                                            self.chassis_sid = None
                                                                            self.clei = None
                                                                            self.controller_family = None
                                                                            self.controller_type = None
                                                                            self.description = None
                                                                            self.dev_num1 = None
                                                                            self.dev_num2 = None
                                                                            self.dev_num3 = None
                                                                            self.dev_num4 = None
                                                                            self.dev_num5 = None
                                                                            self.dev_num6 = None
                                                                            self.dev_num7 = None
                                                                            self.eci = None
                                                                            self.eeprom_size = None
                                                                            self.engineer_use = None
                                                                            self.fru_major_type = None
                                                                            self.fru_minor_type = None
                                                                            self.hw_version = None
                                                                            self.hwid = None
                                                                            self.idprom_format_rev = None
                                                                            self.mac_add_blk_size1 = None
                                                                            self.mac_add_blk_size2 = None
                                                                            self.mac_add_blk_size3 = None
                                                                            self.mac_add_blk_size4 = None
                                                                            self.manu_test_data = None
                                                                            self.mfg_bits = None
                                                                            self.mfg_deviation = None
                                                                            self.oem_string = None
                                                                            self.part_number = None
                                                                            self.part_revision = None
                                                                            self.pca_num = None
                                                                            self.pcavid = None
                                                                            self.pcb_serial_num = None
                                                                            self.pid = None
                                                                            self.power_consumption = None
                                                                            self.power_supply_type = None
                                                                            self.product_id = None
                                                                            self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                            self.rma.parent = self
                                                                            self.rma_code = None
                                                                            self.serial_number = None
                                                                            self.snmpoid = None
                                                                            self.top_assem_part_num = None
                                                                            self.top_assem_vid = None
                                                                            self.udi_description = None
                                                                            self.udi_name = None
                                                                            self.vid = None


                                                                        class Rma(object):
                                                                            """
                                                                            RMA Data
                                                                            
                                                                            .. attribute:: rma_history
                                                                            
                                                                            	RMA history
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: rma_number
                                                                            
                                                                            	RMA tracking number format is N\-N\-N
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            .. attribute:: test_history
                                                                            
                                                                            	Test history
                                                                            	**type**\:  str
                                                                            
                                                                            	**length:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'invmgr-oper'
                                                                            _revision = '2015-11-09'

                                                                            def __init__(self):
                                                                                self.parent = None
                                                                                self.rma_history = None
                                                                                self.rma_number = None
                                                                                self.test_history = None

                                                                            @property
                                                                            def _common_path(self):
                                                                                if self.parent is None:
                                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                            def is_config(self):
                                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                                return False

                                                                            def _has_data(self):
                                                                                if not self.is_config():
                                                                                    return False
                                                                                if self.rma_history is not None:
                                                                                    return True

                                                                                if self.rma_number is not None:
                                                                                    return True

                                                                                if self.test_history is not None:
                                                                                    return True

                                                                                return False

                                                                            @staticmethod
                                                                            def _meta_info():
                                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                        @property
                                                                        def _common_path(self):
                                                                            if self.parent is None:
                                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                        def is_config(self):
                                                                            ''' Returns True if this instance represents config data else returns False '''
                                                                            return False

                                                                        def _has_data(self):
                                                                            if not self.is_config():
                                                                                return False
                                                                            if self.asset_alias is not None:
                                                                                return True

                                                                            if self.asset_id is not None:
                                                                                return True

                                                                            if self.base_mac_address1 is not None:
                                                                                return True

                                                                            if self.base_mac_address2 is not None:
                                                                                return True

                                                                            if self.base_mac_address3 is not None:
                                                                                return True

                                                                            if self.base_mac_address4 is not None:
                                                                                return True

                                                                            if self.block_checksum is not None:
                                                                                return True

                                                                            if self.block_count is not None:
                                                                                return True

                                                                            if self.block_length is not None:
                                                                                return True

                                                                            if self.block_signature is not None:
                                                                                return True

                                                                            if self.block_version is not None:
                                                                                return True

                                                                            if self.chassis_sid is not None:
                                                                                return True

                                                                            if self.clei is not None:
                                                                                return True

                                                                            if self.controller_family is not None:
                                                                                return True

                                                                            if self.controller_type is not None:
                                                                                return True

                                                                            if self.description is not None:
                                                                                return True

                                                                            if self.dev_num1 is not None:
                                                                                return True

                                                                            if self.dev_num2 is not None:
                                                                                return True

                                                                            if self.dev_num3 is not None:
                                                                                return True

                                                                            if self.dev_num4 is not None:
                                                                                return True

                                                                            if self.dev_num5 is not None:
                                                                                return True

                                                                            if self.dev_num6 is not None:
                                                                                return True

                                                                            if self.dev_num7 is not None:
                                                                                return True

                                                                            if self.eci is not None:
                                                                                return True

                                                                            if self.eeprom_size is not None:
                                                                                return True

                                                                            if self.engineer_use is not None:
                                                                                return True

                                                                            if self.fru_major_type is not None:
                                                                                return True

                                                                            if self.fru_minor_type is not None:
                                                                                return True

                                                                            if self.hw_version is not None:
                                                                                return True

                                                                            if self.hwid is not None:
                                                                                return True

                                                                            if self.idprom_format_rev is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size1 is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size2 is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size3 is not None:
                                                                                return True

                                                                            if self.mac_add_blk_size4 is not None:
                                                                                return True

                                                                            if self.manu_test_data is not None:
                                                                                return True

                                                                            if self.mfg_bits is not None:
                                                                                return True

                                                                            if self.mfg_deviation is not None:
                                                                                return True

                                                                            if self.oem_string is not None:
                                                                                return True

                                                                            if self.part_number is not None:
                                                                                return True

                                                                            if self.part_revision is not None:
                                                                                return True

                                                                            if self.pca_num is not None:
                                                                                return True

                                                                            if self.pcavid is not None:
                                                                                return True

                                                                            if self.pcb_serial_num is not None:
                                                                                return True

                                                                            if self.pid is not None:
                                                                                return True

                                                                            if self.power_consumption is not None:
                                                                                return True

                                                                            if self.power_supply_type is not None:
                                                                                return True

                                                                            if self.product_id is not None:
                                                                                return True

                                                                            if self.rma is not None and self.rma._has_data():
                                                                                return True

                                                                            if self.rma_code is not None:
                                                                                return True

                                                                            if self.serial_number is not None:
                                                                                return True

                                                                            if self.snmpoid is not None:
                                                                                return True

                                                                            if self.top_assem_part_num is not None:
                                                                                return True

                                                                            if self.top_assem_vid is not None:
                                                                                return True

                                                                            if self.udi_description is not None:
                                                                                return True

                                                                            if self.udi_name is not None:
                                                                                return True

                                                                            if self.vid is not None:
                                                                                return True

                                                                            return False

                                                                        @staticmethod
                                                                        def _meta_info():
                                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.description is not None:
                                                                            return True

                                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                                            return True

                                                                        if self.has_eeprom is not None:
                                                                            return True

                                                                        if self.inv_card_type is not None:
                                                                            return True

                                                                        if self.opaque_data is not None:
                                                                            return True

                                                                        if self.opaque_data_size is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes.InvEepromInfo']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                        return True

                                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                        return True

                                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                                        return True

                                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                        return True

                                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                        return True

                                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                        return True

                                                                    if self.module_done is not None:
                                                                        return True

                                                                    if self.node_id is not None:
                                                                        return True

                                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                                        return True

                                                                    if self.threshold is not None and self.threshold._has_data():
                                                                        return True

                                                                    if self.vm_done is not None:
                                                                        return True

                                                                    if self.vm_node_id is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5.Attributes']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                                if self.name is None:
                                                                    raise YPYModelError('Key property name is None')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi5[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.name is not None:
                                                                    return True

                                                                if self.attributes is not None and self.attributes._has_data():
                                                                    return True

                                                                if self.tsi6s is not None and self.tsi6s._has_data():
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S.Tsi5']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi5s'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.tsi5 is not None:
                                                                for child_ref in self.tsi5:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Tsi5S']['meta_info']


                                                    class Attributes(object):
                                                        """
                                                        Attributes
                                                        
                                                        .. attribute:: env_sensor_info
                                                        
                                                        	Environment sensor info
                                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfo>`
                                                        
                                                        .. attribute:: env_sensor_info_xml
                                                        
                                                        	Environment sensor info XML
                                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml>`
                                                        
                                                        .. attribute:: fru_info
                                                        
                                                        	Inventory EDM FRU info
                                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo>`
                                                        
                                                        .. attribute:: inv_asset_bag
                                                        
                                                        	Inventory Asset Bag
                                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvAssetBag>`
                                                        
                                                        .. attribute:: inv_basic_bag
                                                        
                                                        	Inventory Basic Bag
                                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvBasicBag>`
                                                        
                                                        .. attribute:: inv_eeprom_info
                                                        
                                                        	Inventory EDM EEPROM Information Bag
                                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo>`
                                                        
                                                        .. attribute:: module_done
                                                        
                                                        	Inventory EDM Module Done Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: node_id
                                                        
                                                        	Node ID Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pwg_info
                                                        
                                                        	Inventory EDM PWG info
                                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.PwgInfo>`
                                                        
                                                        .. attribute:: threshold
                                                        
                                                        	Threshold
                                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold>`
                                                        
                                                        .. attribute:: vm_done
                                                        
                                                        	VM Done Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        .. attribute:: vm_node_id
                                                        
                                                        	VM Node ID Tuple
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfo()
                                                            self.env_sensor_info.parent = self
                                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml()
                                                            self.env_sensor_info_xml.parent = self
                                                            self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo()
                                                            self.fru_info.parent = self
                                                            self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvAssetBag()
                                                            self.inv_asset_bag.parent = self
                                                            self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvBasicBag()
                                                            self.inv_basic_bag.parent = self
                                                            self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo()
                                                            self.inv_eeprom_info.parent = self
                                                            self.module_done = None
                                                            self.node_id = None
                                                            self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.PwgInfo()
                                                            self.pwg_info.parent = self
                                                            self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold()
                                                            self.threshold.parent = self
                                                            self.vm_done = None
                                                            self.vm_node_id = None


                                                        class EnvSensorInfo(object):
                                                            """
                                                            Environment sensor info
                                                            
                                                            .. attribute:: age_time_stamp
                                                            
                                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: alarm_type
                                                            
                                                            	Indicates threshold violation
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: data_type
                                                            
                                                            	Sensor data type enums
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: device_description
                                                            
                                                            	Device Name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: device_id
                                                            
                                                            	Identifier for this device
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: field_validity_bitmap
                                                            
                                                            	Sensor valid bitmap
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: precision
                                                            
                                                            	Sensor precision range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: scale
                                                            
                                                            	Sensor scale enums
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: status
                                                            
                                                            	Sensor operation state enums
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: units
                                                            
                                                            	Units of variable being read
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: update_rate
                                                            
                                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: value
                                                            
                                                            	Current reading of sensor
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.age_time_stamp = None
                                                                self.alarm_type = None
                                                                self.data_type = None
                                                                self.device_description = None
                                                                self.device_id = None
                                                                self.field_validity_bitmap = None
                                                                self.precision = None
                                                                self.scale = None
                                                                self.status = None
                                                                self.units = None
                                                                self.update_rate = None
                                                                self.value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.age_time_stamp is not None:
                                                                    return True

                                                                if self.alarm_type is not None:
                                                                    return True

                                                                if self.data_type is not None:
                                                                    return True

                                                                if self.device_description is not None:
                                                                    return True

                                                                if self.device_id is not None:
                                                                    return True

                                                                if self.field_validity_bitmap is not None:
                                                                    return True

                                                                if self.precision is not None:
                                                                    return True

                                                                if self.scale is not None:
                                                                    return True

                                                                if self.status is not None:
                                                                    return True

                                                                if self.units is not None:
                                                                    return True

                                                                if self.update_rate is not None:
                                                                    return True

                                                                if self.value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfo']['meta_info']


                                                        class PwgInfo(object):
                                                            """
                                                            Inventory EDM PWG info
                                                            
                                                            .. attribute:: power_group_available_current
                                                            
                                                            	available current
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_group_drawn_current
                                                            
                                                            	drawn current
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_group_power_units
                                                            
                                                            	power units
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: power_group_redundancy_mode
                                                            
                                                            	redundancy mode
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.power_group_available_current = None
                                                                self.power_group_drawn_current = None
                                                                self.power_group_power_units = None
                                                                self.power_group_redundancy_mode = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.power_group_available_current is not None:
                                                                    return True

                                                                if self.power_group_drawn_current is not None:
                                                                    return True

                                                                if self.power_group_power_units is not None:
                                                                    return True

                                                                if self.power_group_redundancy_mode is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.PwgInfo']['meta_info']


                                                        class EnvSensorInfoXml(object):
                                                            """
                                                            Environment sensor info XML
                                                            
                                                            .. attribute:: data_type
                                                            
                                                            	Sensor data type
                                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                            
                                                            .. attribute:: description
                                                            
                                                            	Device Name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: status
                                                            
                                                            	Sensor operation state
                                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                            
                                                            .. attribute:: threshold
                                                            
                                                            	Threshold information
                                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold>`
                                                            
                                                            .. attribute:: units
                                                            
                                                            	Units of variable being read
                                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                            
                                                            .. attribute:: update_rate
                                                            
                                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: value
                                                            
                                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.data_type = None
                                                                self.description = None
                                                                self.status = None
                                                                self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold()
                                                                self.threshold.parent = self
                                                                self.units = None
                                                                self.update_rate = None
                                                                self.value = None


                                                            class Threshold(object):
                                                                """
                                                                Threshold information
                                                                
                                                                .. attribute:: threshold_array
                                                                
                                                                	Array of threshold
                                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.threshold_array = YList()
                                                                    self.threshold_array.parent = self
                                                                    self.threshold_array.name = 'threshold_array'


                                                                class ThresholdArray(object):
                                                                    """
                                                                    Array of threshold
                                                                    
                                                                    .. attribute:: threshold_name
                                                                    
                                                                    	Threshold name
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..50
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** \-2147483648..2147483647
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_name = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_name is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.threshold_array is not None:
                                                                        for child_ref in self.threshold_array:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.data_type is not None:
                                                                    return True

                                                                if self.description is not None:
                                                                    return True

                                                                if self.status is not None:
                                                                    return True

                                                                if self.threshold is not None and self.threshold._has_data():
                                                                    return True

                                                                if self.units is not None:
                                                                    return True

                                                                if self.update_rate is not None:
                                                                    return True

                                                                if self.value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.EnvSensorInfoXml']['meta_info']


                                                        class InvAssetBag(object):
                                                            """
                                                            Inventory Asset Bag
                                                            
                                                            .. attribute:: manufacturer_assembly_number
                                                            
                                                            	Manufacture Assembly number
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_assembly_revision
                                                            
                                                            	Manufacture assembly revision
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                                            
                                                            	Common Language Equipment           Identifier number
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_firmware_identifier
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: manufacturer_software_identifier
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: original_equipment_manufacturer_string
                                                            
                                                            	String containing OEM information           if applicable
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: part_number
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.manufacturer_assembly_number = None
                                                                self.manufacturer_assembly_revision = None
                                                                self.manufacturer_common_language_equipment_identifier = None
                                                                self.manufacturer_firmware_identifier = None
                                                                self.manufacturer_software_identifier = None
                                                                self.original_equipment_manufacturer_string = None
                                                                self.part_number = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.manufacturer_assembly_number is not None:
                                                                    return True

                                                                if self.manufacturer_assembly_revision is not None:
                                                                    return True

                                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                                    return True

                                                                if self.manufacturer_firmware_identifier is not None:
                                                                    return True

                                                                if self.manufacturer_software_identifier is not None:
                                                                    return True

                                                                if self.original_equipment_manufacturer_string is not None:
                                                                    return True

                                                                if self.part_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvAssetBag']['meta_info']


                                                        class Threshold(object):
                                                            """
                                                            Threshold
                                                            
                                                            .. attribute:: critical_hi
                                                            
                                                            	Critical High
                                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi>`
                                                            
                                                            .. attribute:: critical_lo
                                                            
                                                            	Critical Low
                                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo>`
                                                            
                                                            .. attribute:: major_hi
                                                            
                                                            	Major High
                                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi>`
                                                            
                                                            .. attribute:: major_lo
                                                            
                                                            	Major Low
                                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo>`
                                                            
                                                            .. attribute:: minor_hi
                                                            
                                                            	Minor High
                                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi>`
                                                            
                                                            .. attribute:: minor_lo
                                                            
                                                            	Minor Low
                                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi()
                                                                self.critical_hi.parent = self
                                                                self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo()
                                                                self.critical_lo.parent = self
                                                                self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi()
                                                                self.major_hi.parent = self
                                                                self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo()
                                                                self.major_lo.parent = self
                                                                self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi()
                                                                self.minor_hi.parent = self
                                                                self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo()
                                                                self.minor_lo.parent = self


                                                            class MajorLo(object):
                                                                """
                                                                Major Low
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorLo']['meta_info']


                                                            class CriticalHi(object):
                                                                """
                                                                Critical High
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalHi']['meta_info']


                                                            class MinorHi(object):
                                                                """
                                                                Minor High
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorHi']['meta_info']


                                                            class MajorHi(object):
                                                                """
                                                                Major High
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MajorHi']['meta_info']


                                                            class CriticalLo(object):
                                                                """
                                                                Critical Low
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.CriticalLo']['meta_info']


                                                            class MinorLo(object):
                                                                """
                                                                Minor Low
                                                                
                                                                .. attribute:: thresh_bag
                                                                
                                                                	Environment threshold info
                                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo.ThreshBag>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo.ThreshBag()
                                                                    self.thresh_bag.parent = self


                                                                class ThreshBag(object):
                                                                    """
                                                                    Environment threshold info
                                                                    
                                                                    .. attribute:: threshold_evaluation
                                                                    
                                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_notification_enabled
                                                                    
                                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: threshold_relation
                                                                    
                                                                    	Indicates relation between sensor value and threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_severity
                                                                    
                                                                    	Indicates minor, major, critical severities
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: threshold_value
                                                                    
                                                                    	Value of the configured threshold
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.threshold_evaluation = None
                                                                        self.threshold_notification_enabled = None
                                                                        self.threshold_relation = None
                                                                        self.threshold_severity = None
                                                                        self.threshold_value = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.threshold_evaluation is not None:
                                                                            return True

                                                                        if self.threshold_notification_enabled is not None:
                                                                            return True

                                                                        if self.threshold_relation is not None:
                                                                            return True

                                                                        if self.threshold_severity is not None:
                                                                            return True

                                                                        if self.threshold_value is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold.MinorLo']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                                    return True

                                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                                    return True

                                                                if self.major_hi is not None and self.major_hi._has_data():
                                                                    return True

                                                                if self.major_lo is not None and self.major_lo._has_data():
                                                                    return True

                                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                                    return True

                                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.Threshold']['meta_info']


                                                        class FruInfo(object):
                                                            """
                                                            Inventory EDM FRU info
                                                            
                                                            .. attribute:: card_administrative_state
                                                            
                                                            	card admin state\: shutdown or not
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: card_monitor_state
                                                            
                                                            	card is monitored by a manager or left unmonitored
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: card_operational_state
                                                            
                                                            	card operation state
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: card_reset_reason
                                                            
                                                            	card reset reason enum
                                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                            
                                                            .. attribute:: card_up_time
                                                            
                                                            	card up time
                                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.CardUpTime>`
                                                            
                                                            .. attribute:: last_operational_state_change
                                                            
                                                            	last card oper change state
                                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.LastOperationalStateChange>`
                                                            
                                                            .. attribute:: power_administrative_state
                                                            
                                                            	power admin state\: up or down
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_current_measurement
                                                            
                                                            	power current\: not implemented
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: power_operational_state
                                                            
                                                            	Power operation state
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.card_administrative_state = None
                                                                self.card_monitor_state = None
                                                                self.card_operational_state = None
                                                                self.card_reset_reason = None
                                                                self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.CardUpTime()
                                                                self.card_up_time.parent = self
                                                                self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.LastOperationalStateChange()
                                                                self.last_operational_state_change.parent = self
                                                                self.power_administrative_state = None
                                                                self.power_current_measurement = None
                                                                self.power_operational_state = None


                                                            class LastOperationalStateChange(object):
                                                                """
                                                                last card oper change state
                                                                
                                                                .. attribute:: time_in_nano_seconds
                                                                
                                                                	Time Value in Nano\-seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: nanosecond
                                                                
                                                                .. attribute:: time_in_seconds
                                                                
                                                                	Time Value in Seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: second
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.time_in_nano_seconds = None
                                                                    self.time_in_seconds = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.time_in_nano_seconds is not None:
                                                                        return True

                                                                    if self.time_in_seconds is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                            class CardUpTime(object):
                                                                """
                                                                card up time
                                                                
                                                                .. attribute:: time_in_nano_seconds
                                                                
                                                                	Time Value in Nano\-seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: nanosecond
                                                                
                                                                .. attribute:: time_in_seconds
                                                                
                                                                	Time Value in Seconds
                                                                	**type**\:  int
                                                                
                                                                	**range:** \-2147483648..2147483647
                                                                
                                                                	**units**\: second
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.time_in_nano_seconds = None
                                                                    self.time_in_seconds = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.time_in_nano_seconds is not None:
                                                                        return True

                                                                    if self.time_in_seconds is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo.CardUpTime']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.card_administrative_state is not None:
                                                                    return True

                                                                if self.card_monitor_state is not None:
                                                                    return True

                                                                if self.card_operational_state is not None:
                                                                    return True

                                                                if self.card_reset_reason is not None:
                                                                    return True

                                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                                    return True

                                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                                    return True

                                                                if self.power_administrative_state is not None:
                                                                    return True

                                                                if self.power_current_measurement is not None:
                                                                    return True

                                                                if self.power_operational_state is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.FruInfo']['meta_info']


                                                        class InvBasicBag(object):
                                                            """
                                                            Inventory Basic Bag
                                                            
                                                            .. attribute:: alias
                                                            
                                                            	useful for storing an entity alias 
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: asset_id_str
                                                            
                                                            	asset Identification string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: asset_identification
                                                            
                                                            	asset Identification
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: ceport
                                                            
                                                            	1 if ce port found, 0 if not
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: chip_hardware_revision
                                                            
                                                            	chip module hw revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: composite_class_code
                                                            
                                                            	Major&minor class of the entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: description
                                                            
                                                            	describes in user\-readable terms       what the entity in question does
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: environmental_monitor_path
                                                            
                                                            	sysdb name of sensor in the envmon EDM
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: firmware_revision
                                                            
                                                            	firmware revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: group_flag
                                                            
                                                            	indicates if this entity is group       or not
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: hardware_revision
                                                            
                                                            	hw revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: is_field_replaceable_unit
                                                            
                                                            	1 if Field Replaceable Unit 0, if not
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: manufacturer_asset_tags
                                                            
                                                            	Manufacture Asset Tags
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: manufacturer_name
                                                            
                                                            	manufacturer's name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: memory_size
                                                            
                                                            	Size of memory associated with       the entity where applicable
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: model_name
                                                            
                                                            	model name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: name
                                                            
                                                            	name string for the entity
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: new_deviation_number
                                                            
                                                            	integer value for New Deviation Number 0x88
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: physical_layer_interface_module_type
                                                            
                                                            	integer value for plim type if     applicable to this entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: redundancystate
                                                            
                                                            	integer value for Redundancy State if     applicable to this entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: serial_number
                                                            
                                                            	serial number
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: software_revision
                                                            
                                                            	software revision string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: unique_id
                                                            
                                                            	Unique id for an entity
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            .. attribute:: unrecognized_fru
                                                            
                                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: vendor_type
                                                            
                                                            	maps to the vendor OID string
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: xr_scoped
                                                            
                                                            	1 if xr scoped, 0 if not
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.alias = None
                                                                self.asset_id_str = None
                                                                self.asset_identification = None
                                                                self.ceport = None
                                                                self.chip_hardware_revision = None
                                                                self.composite_class_code = None
                                                                self.description = None
                                                                self.environmental_monitor_path = None
                                                                self.firmware_revision = None
                                                                self.group_flag = None
                                                                self.hardware_revision = None
                                                                self.is_field_replaceable_unit = None
                                                                self.manufacturer_asset_tags = None
                                                                self.manufacturer_name = None
                                                                self.memory_size = None
                                                                self.model_name = None
                                                                self.name = None
                                                                self.new_deviation_number = None
                                                                self.physical_layer_interface_module_type = None
                                                                self.redundancystate = None
                                                                self.serial_number = None
                                                                self.software_revision = None
                                                                self.unique_id = None
                                                                self.unrecognized_fru = None
                                                                self.vendor_type = None
                                                                self.xr_scoped = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.alias is not None:
                                                                    return True

                                                                if self.asset_id_str is not None:
                                                                    return True

                                                                if self.asset_identification is not None:
                                                                    return True

                                                                if self.ceport is not None:
                                                                    return True

                                                                if self.chip_hardware_revision is not None:
                                                                    return True

                                                                if self.composite_class_code is not None:
                                                                    return True

                                                                if self.description is not None:
                                                                    return True

                                                                if self.environmental_monitor_path is not None:
                                                                    return True

                                                                if self.firmware_revision is not None:
                                                                    return True

                                                                if self.group_flag is not None:
                                                                    return True

                                                                if self.hardware_revision is not None:
                                                                    return True

                                                                if self.is_field_replaceable_unit is not None:
                                                                    return True

                                                                if self.manufacturer_asset_tags is not None:
                                                                    return True

                                                                if self.manufacturer_name is not None:
                                                                    return True

                                                                if self.memory_size is not None:
                                                                    return True

                                                                if self.model_name is not None:
                                                                    return True

                                                                if self.name is not None:
                                                                    return True

                                                                if self.new_deviation_number is not None:
                                                                    return True

                                                                if self.physical_layer_interface_module_type is not None:
                                                                    return True

                                                                if self.redundancystate is not None:
                                                                    return True

                                                                if self.serial_number is not None:
                                                                    return True

                                                                if self.software_revision is not None:
                                                                    return True

                                                                if self.unique_id is not None:
                                                                    return True

                                                                if self.unrecognized_fru is not None:
                                                                    return True

                                                                if self.vendor_type is not None:
                                                                    return True

                                                                if self.xr_scoped is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvBasicBag']['meta_info']


                                                        class InvEepromInfo(object):
                                                            """
                                                            Inventory EDM EEPROM Information Bag
                                                            
                                                            .. attribute:: description
                                                            
                                                            	A textual description of physical entity
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: eeprom
                                                            
                                                            	EEPROM data not from hex data
                                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom>`
                                                            
                                                            .. attribute:: has_eeprom
                                                            
                                                            	use eeprom instead of opaque data
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: inv_card_type
                                                            
                                                            	Inventory card type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: opaque_data
                                                            
                                                            	EEPROM hex data
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: opaque_data_size
                                                            
                                                            	size of the EEPROM hex data
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.description = None
                                                                self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom()
                                                                self.eeprom.parent = self
                                                                self.has_eeprom = None
                                                                self.inv_card_type = None
                                                                self.opaque_data = None
                                                                self.opaque_data_size = None


                                                            class Eeprom(object):
                                                                """
                                                                EEPROM data not from hex data
                                                                
                                                                .. attribute:: asset_alias
                                                                
                                                                	Asset Alias
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: asset_id
                                                                
                                                                	Asset ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address1
                                                                
                                                                	Base Mac Address #1
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address2
                                                                
                                                                	Base Mac Address #2
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address3
                                                                
                                                                	Base Mac Address #3
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: base_mac_address4
                                                                
                                                                	Base Mac Address #4
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_checksum
                                                                
                                                                	Block Checksum
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_count
                                                                
                                                                	Block Count
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_length
                                                                
                                                                	Block Length
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_signature
                                                                
                                                                	Block Signature
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: block_version
                                                                
                                                                	Block Version
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: chassis_sid
                                                                
                                                                	Chassis serial number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: clei
                                                                
                                                                	Common Language Equipment Identifier (CLEI) code
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: controller_family
                                                                
                                                                	Controller family
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: controller_type
                                                                
                                                                	Controller type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: description
                                                                
                                                                	A textual description of physical entity
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num1
                                                                
                                                                	Deviation Number # 1
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num2
                                                                
                                                                	Deviation Number # 2
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num3
                                                                
                                                                	Deviation Number # 3
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num4
                                                                
                                                                	Deviation Number # 4
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num5
                                                                
                                                                	Deviation Number # 5
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num6
                                                                
                                                                	Deviation Number # 6
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: dev_num7
                                                                
                                                                	Deviation Number # 7
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: eci
                                                                
                                                                	Equipment Catalog Item (ECI) number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: eeprom_size
                                                                
                                                                	EEPROM Size
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: engineer_use
                                                                
                                                                	Engineer Use
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: fru_major_type
                                                                
                                                                	FRU Major Type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: fru_minor_type
                                                                
                                                                	FRU Minor Type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: hw_version
                                                                
                                                                	Hardware Version
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: hwid
                                                                
                                                                	Hardware Revision
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: idprom_format_rev
                                                                
                                                                	IDPROM Format Revision
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size1
                                                                
                                                                	Mac Address Block Size #1
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size2
                                                                
                                                                	Mac Address Block Size #2
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size3
                                                                
                                                                	Mac Address Block Size #3
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mac_add_blk_size4
                                                                
                                                                	Mac Address Block Size #4
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: manu_test_data
                                                                
                                                                	Manufacturing Test Data
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mfg_bits
                                                                
                                                                	MFG Bits
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: mfg_deviation
                                                                
                                                                	MFG Deviation
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: oem_string
                                                                
                                                                	OEM String
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: part_number
                                                                
                                                                	Part Number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: part_revision
                                                                
                                                                	Part Revision
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pca_num
                                                                
                                                                	PCA number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pcavid
                                                                
                                                                	PCA revision ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pcb_serial_num
                                                                
                                                                	PCB Serial Number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: pid
                                                                
                                                                	Product ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: power_consumption
                                                                
                                                                	Power Consumption
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: power_supply_type
                                                                
                                                                	Power Supply Type
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: product_id
                                                                
                                                                	Product ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: rma
                                                                
                                                                	RMA Data
                                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                                
                                                                .. attribute:: rma_code
                                                                
                                                                	RMA Code
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: serial_number
                                                                
                                                                	Serial Number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: snmpoid
                                                                
                                                                	SNMP OID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: top_assem_part_num
                                                                
                                                                	Top assembly part number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: top_assem_vid
                                                                
                                                                	Top assembly revision number
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: udi_description
                                                                
                                                                	UDI description
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: udi_name
                                                                
                                                                	UDI name
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                .. attribute:: vid
                                                                
                                                                	Version ID
                                                                	**type**\:  str
                                                                
                                                                	**length:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'invmgr-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.asset_alias = None
                                                                    self.asset_id = None
                                                                    self.base_mac_address1 = None
                                                                    self.base_mac_address2 = None
                                                                    self.base_mac_address3 = None
                                                                    self.base_mac_address4 = None
                                                                    self.block_checksum = None
                                                                    self.block_count = None
                                                                    self.block_length = None
                                                                    self.block_signature = None
                                                                    self.block_version = None
                                                                    self.chassis_sid = None
                                                                    self.clei = None
                                                                    self.controller_family = None
                                                                    self.controller_type = None
                                                                    self.description = None
                                                                    self.dev_num1 = None
                                                                    self.dev_num2 = None
                                                                    self.dev_num3 = None
                                                                    self.dev_num4 = None
                                                                    self.dev_num5 = None
                                                                    self.dev_num6 = None
                                                                    self.dev_num7 = None
                                                                    self.eci = None
                                                                    self.eeprom_size = None
                                                                    self.engineer_use = None
                                                                    self.fru_major_type = None
                                                                    self.fru_minor_type = None
                                                                    self.hw_version = None
                                                                    self.hwid = None
                                                                    self.idprom_format_rev = None
                                                                    self.mac_add_blk_size1 = None
                                                                    self.mac_add_blk_size2 = None
                                                                    self.mac_add_blk_size3 = None
                                                                    self.mac_add_blk_size4 = None
                                                                    self.manu_test_data = None
                                                                    self.mfg_bits = None
                                                                    self.mfg_deviation = None
                                                                    self.oem_string = None
                                                                    self.part_number = None
                                                                    self.part_revision = None
                                                                    self.pca_num = None
                                                                    self.pcavid = None
                                                                    self.pcb_serial_num = None
                                                                    self.pid = None
                                                                    self.power_consumption = None
                                                                    self.power_supply_type = None
                                                                    self.product_id = None
                                                                    self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom.Rma()
                                                                    self.rma.parent = self
                                                                    self.rma_code = None
                                                                    self.serial_number = None
                                                                    self.snmpoid = None
                                                                    self.top_assem_part_num = None
                                                                    self.top_assem_vid = None
                                                                    self.udi_description = None
                                                                    self.udi_name = None
                                                                    self.vid = None


                                                                class Rma(object):
                                                                    """
                                                                    RMA Data
                                                                    
                                                                    .. attribute:: rma_history
                                                                    
                                                                    	RMA history
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: rma_number
                                                                    
                                                                    	RMA tracking number format is N\-N\-N
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    .. attribute:: test_history
                                                                    
                                                                    	Test history
                                                                    	**type**\:  str
                                                                    
                                                                    	**length:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'invmgr-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.rma_history = None
                                                                        self.rma_number = None
                                                                        self.test_history = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.rma_history is not None:
                                                                            return True

                                                                        if self.rma_number is not None:
                                                                            return True

                                                                        if self.test_history is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.asset_alias is not None:
                                                                        return True

                                                                    if self.asset_id is not None:
                                                                        return True

                                                                    if self.base_mac_address1 is not None:
                                                                        return True

                                                                    if self.base_mac_address2 is not None:
                                                                        return True

                                                                    if self.base_mac_address3 is not None:
                                                                        return True

                                                                    if self.base_mac_address4 is not None:
                                                                        return True

                                                                    if self.block_checksum is not None:
                                                                        return True

                                                                    if self.block_count is not None:
                                                                        return True

                                                                    if self.block_length is not None:
                                                                        return True

                                                                    if self.block_signature is not None:
                                                                        return True

                                                                    if self.block_version is not None:
                                                                        return True

                                                                    if self.chassis_sid is not None:
                                                                        return True

                                                                    if self.clei is not None:
                                                                        return True

                                                                    if self.controller_family is not None:
                                                                        return True

                                                                    if self.controller_type is not None:
                                                                        return True

                                                                    if self.description is not None:
                                                                        return True

                                                                    if self.dev_num1 is not None:
                                                                        return True

                                                                    if self.dev_num2 is not None:
                                                                        return True

                                                                    if self.dev_num3 is not None:
                                                                        return True

                                                                    if self.dev_num4 is not None:
                                                                        return True

                                                                    if self.dev_num5 is not None:
                                                                        return True

                                                                    if self.dev_num6 is not None:
                                                                        return True

                                                                    if self.dev_num7 is not None:
                                                                        return True

                                                                    if self.eci is not None:
                                                                        return True

                                                                    if self.eeprom_size is not None:
                                                                        return True

                                                                    if self.engineer_use is not None:
                                                                        return True

                                                                    if self.fru_major_type is not None:
                                                                        return True

                                                                    if self.fru_minor_type is not None:
                                                                        return True

                                                                    if self.hw_version is not None:
                                                                        return True

                                                                    if self.hwid is not None:
                                                                        return True

                                                                    if self.idprom_format_rev is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size1 is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size2 is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size3 is not None:
                                                                        return True

                                                                    if self.mac_add_blk_size4 is not None:
                                                                        return True

                                                                    if self.manu_test_data is not None:
                                                                        return True

                                                                    if self.mfg_bits is not None:
                                                                        return True

                                                                    if self.mfg_deviation is not None:
                                                                        return True

                                                                    if self.oem_string is not None:
                                                                        return True

                                                                    if self.part_number is not None:
                                                                        return True

                                                                    if self.part_revision is not None:
                                                                        return True

                                                                    if self.pca_num is not None:
                                                                        return True

                                                                    if self.pcavid is not None:
                                                                        return True

                                                                    if self.pcb_serial_num is not None:
                                                                        return True

                                                                    if self.pid is not None:
                                                                        return True

                                                                    if self.power_consumption is not None:
                                                                        return True

                                                                    if self.power_supply_type is not None:
                                                                        return True

                                                                    if self.product_id is not None:
                                                                        return True

                                                                    if self.rma is not None and self.rma._has_data():
                                                                        return True

                                                                    if self.rma_code is not None:
                                                                        return True

                                                                    if self.serial_number is not None:
                                                                        return True

                                                                    if self.snmpoid is not None:
                                                                        return True

                                                                    if self.top_assem_part_num is not None:
                                                                        return True

                                                                    if self.top_assem_vid is not None:
                                                                        return True

                                                                    if self.udi_description is not None:
                                                                        return True

                                                                    if self.udi_name is not None:
                                                                        return True

                                                                    if self.vid is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.description is not None:
                                                                    return True

                                                                if self.eeprom is not None and self.eeprom._has_data():
                                                                    return True

                                                                if self.has_eeprom is not None:
                                                                    return True

                                                                if self.inv_card_type is not None:
                                                                    return True

                                                                if self.opaque_data is not None:
                                                                    return True

                                                                if self.opaque_data_size is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes.InvEepromInfo']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                                return True

                                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                                return True

                                                            if self.fru_info is not None and self.fru_info._has_data():
                                                                return True

                                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                                return True

                                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                                return True

                                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                                return True

                                                            if self.module_done is not None:
                                                                return True

                                                            if self.node_id is not None:
                                                                return True

                                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                                return True

                                                            if self.threshold is not None and self.threshold._has_data():
                                                                return True

                                                            if self.vm_done is not None:
                                                                return True

                                                            if self.vm_node_id is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4.Attributes']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                                        if self.name is None:
                                                            raise YPYModelError('Key property name is None')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi4[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.name is not None:
                                                            return True

                                                        if self.attributes is not None and self.attributes._has_data():
                                                            return True

                                                        if self.tsi5s is not None and self.tsi5s._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S.Tsi4']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi4s'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.tsi4 is not None:
                                                        for child_ref in self.tsi4:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Tsi4S']['meta_info']


                                            class Attributes(object):
                                                """
                                                Attributes
                                                
                                                .. attribute:: env_sensor_info
                                                
                                                	Environment sensor info
                                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfo>`
                                                
                                                .. attribute:: env_sensor_info_xml
                                                
                                                	Environment sensor info XML
                                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml>`
                                                
                                                .. attribute:: fru_info
                                                
                                                	Inventory EDM FRU info
                                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo>`
                                                
                                                .. attribute:: inv_asset_bag
                                                
                                                	Inventory Asset Bag
                                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvAssetBag>`
                                                
                                                .. attribute:: inv_basic_bag
                                                
                                                	Inventory Basic Bag
                                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvBasicBag>`
                                                
                                                .. attribute:: inv_eeprom_info
                                                
                                                	Inventory EDM EEPROM Information Bag
                                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo>`
                                                
                                                .. attribute:: module_done
                                                
                                                	Inventory EDM Module Done Tuple
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: node_id
                                                
                                                	Node ID Tuple
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pwg_info
                                                
                                                	Inventory EDM PWG info
                                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.PwgInfo>`
                                                
                                                .. attribute:: threshold
                                                
                                                	Threshold
                                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold>`
                                                
                                                .. attribute:: vm_done
                                                
                                                	VM Done Tuple
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: vm_node_id
                                                
                                                	VM Node ID Tuple
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfo()
                                                    self.env_sensor_info.parent = self
                                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml()
                                                    self.env_sensor_info_xml.parent = self
                                                    self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo()
                                                    self.fru_info.parent = self
                                                    self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvAssetBag()
                                                    self.inv_asset_bag.parent = self
                                                    self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvBasicBag()
                                                    self.inv_basic_bag.parent = self
                                                    self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo()
                                                    self.inv_eeprom_info.parent = self
                                                    self.module_done = None
                                                    self.node_id = None
                                                    self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.PwgInfo()
                                                    self.pwg_info.parent = self
                                                    self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold()
                                                    self.threshold.parent = self
                                                    self.vm_done = None
                                                    self.vm_node_id = None


                                                class EnvSensorInfo(object):
                                                    """
                                                    Environment sensor info
                                                    
                                                    .. attribute:: age_time_stamp
                                                    
                                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: alarm_type
                                                    
                                                    	Indicates threshold violation
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: data_type
                                                    
                                                    	Sensor data type enums
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: device_description
                                                    
                                                    	Device Name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: device_id
                                                    
                                                    	Identifier for this device
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: field_validity_bitmap
                                                    
                                                    	Sensor valid bitmap
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: precision
                                                    
                                                    	Sensor precision range
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: scale
                                                    
                                                    	Sensor scale enums
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: status
                                                    
                                                    	Sensor operation state enums
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: units
                                                    
                                                    	Units of variable being read
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: update_rate
                                                    
                                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Current reading of sensor
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.age_time_stamp = None
                                                        self.alarm_type = None
                                                        self.data_type = None
                                                        self.device_description = None
                                                        self.device_id = None
                                                        self.field_validity_bitmap = None
                                                        self.precision = None
                                                        self.scale = None
                                                        self.status = None
                                                        self.units = None
                                                        self.update_rate = None
                                                        self.value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.age_time_stamp is not None:
                                                            return True

                                                        if self.alarm_type is not None:
                                                            return True

                                                        if self.data_type is not None:
                                                            return True

                                                        if self.device_description is not None:
                                                            return True

                                                        if self.device_id is not None:
                                                            return True

                                                        if self.field_validity_bitmap is not None:
                                                            return True

                                                        if self.precision is not None:
                                                            return True

                                                        if self.scale is not None:
                                                            return True

                                                        if self.status is not None:
                                                            return True

                                                        if self.units is not None:
                                                            return True

                                                        if self.update_rate is not None:
                                                            return True

                                                        if self.value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfo']['meta_info']


                                                class PwgInfo(object):
                                                    """
                                                    Inventory EDM PWG info
                                                    
                                                    .. attribute:: power_group_available_current
                                                    
                                                    	available current
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_group_drawn_current
                                                    
                                                    	drawn current
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_group_power_units
                                                    
                                                    	power units
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: power_group_redundancy_mode
                                                    
                                                    	redundancy mode
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.power_group_available_current = None
                                                        self.power_group_drawn_current = None
                                                        self.power_group_power_units = None
                                                        self.power_group_redundancy_mode = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.power_group_available_current is not None:
                                                            return True

                                                        if self.power_group_drawn_current is not None:
                                                            return True

                                                        if self.power_group_power_units is not None:
                                                            return True

                                                        if self.power_group_redundancy_mode is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.PwgInfo']['meta_info']


                                                class EnvSensorInfoXml(object):
                                                    """
                                                    Environment sensor info XML
                                                    
                                                    .. attribute:: data_type
                                                    
                                                    	Sensor data type
                                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Device Name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: status
                                                    
                                                    	Sensor operation state
                                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	Threshold information
                                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold>`
                                                    
                                                    .. attribute:: units
                                                    
                                                    	Units of variable being read
                                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                                    
                                                    .. attribute:: update_rate
                                                    
                                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data_type = None
                                                        self.description = None
                                                        self.status = None
                                                        self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold()
                                                        self.threshold.parent = self
                                                        self.units = None
                                                        self.update_rate = None
                                                        self.value = None


                                                    class Threshold(object):
                                                        """
                                                        Threshold information
                                                        
                                                        .. attribute:: threshold_array
                                                        
                                                        	Array of threshold
                                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.threshold_array = YList()
                                                            self.threshold_array.parent = self
                                                            self.threshold_array.name = 'threshold_array'


                                                        class ThresholdArray(object):
                                                            """
                                                            Array of threshold
                                                            
                                                            .. attribute:: threshold_name
                                                            
                                                            	Threshold name
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..50
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** \-2147483648..2147483647
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_name = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_name is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.threshold_array is not None:
                                                                for child_ref in self.threshold_array:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data_type is not None:
                                                            return True

                                                        if self.description is not None:
                                                            return True

                                                        if self.status is not None:
                                                            return True

                                                        if self.threshold is not None and self.threshold._has_data():
                                                            return True

                                                        if self.units is not None:
                                                            return True

                                                        if self.update_rate is not None:
                                                            return True

                                                        if self.value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.EnvSensorInfoXml']['meta_info']


                                                class InvAssetBag(object):
                                                    """
                                                    Inventory Asset Bag
                                                    
                                                    .. attribute:: manufacturer_assembly_number
                                                    
                                                    	Manufacture Assembly number
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_assembly_revision
                                                    
                                                    	Manufacture assembly revision
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                                    
                                                    	Common Language Equipment           Identifier number
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_firmware_identifier
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: manufacturer_software_identifier
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: original_equipment_manufacturer_string
                                                    
                                                    	String containing OEM information           if applicable
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: part_number
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.manufacturer_assembly_number = None
                                                        self.manufacturer_assembly_revision = None
                                                        self.manufacturer_common_language_equipment_identifier = None
                                                        self.manufacturer_firmware_identifier = None
                                                        self.manufacturer_software_identifier = None
                                                        self.original_equipment_manufacturer_string = None
                                                        self.part_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.manufacturer_assembly_number is not None:
                                                            return True

                                                        if self.manufacturer_assembly_revision is not None:
                                                            return True

                                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                                            return True

                                                        if self.manufacturer_firmware_identifier is not None:
                                                            return True

                                                        if self.manufacturer_software_identifier is not None:
                                                            return True

                                                        if self.original_equipment_manufacturer_string is not None:
                                                            return True

                                                        if self.part_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvAssetBag']['meta_info']


                                                class Threshold(object):
                                                    """
                                                    Threshold
                                                    
                                                    .. attribute:: critical_hi
                                                    
                                                    	Critical High
                                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi>`
                                                    
                                                    .. attribute:: critical_lo
                                                    
                                                    	Critical Low
                                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo>`
                                                    
                                                    .. attribute:: major_hi
                                                    
                                                    	Major High
                                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi>`
                                                    
                                                    .. attribute:: major_lo
                                                    
                                                    	Major Low
                                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo>`
                                                    
                                                    .. attribute:: minor_hi
                                                    
                                                    	Minor High
                                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi>`
                                                    
                                                    .. attribute:: minor_lo
                                                    
                                                    	Minor Low
                                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi()
                                                        self.critical_hi.parent = self
                                                        self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo()
                                                        self.critical_lo.parent = self
                                                        self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi()
                                                        self.major_hi.parent = self
                                                        self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo()
                                                        self.major_lo.parent = self
                                                        self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi()
                                                        self.minor_hi.parent = self
                                                        self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo()
                                                        self.minor_lo.parent = self


                                                    class MajorLo(object):
                                                        """
                                                        Major Low
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorLo']['meta_info']


                                                    class CriticalHi(object):
                                                        """
                                                        Critical High
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalHi']['meta_info']


                                                    class MinorHi(object):
                                                        """
                                                        Minor High
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorHi']['meta_info']


                                                    class MajorHi(object):
                                                        """
                                                        Major High
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MajorHi']['meta_info']


                                                    class CriticalLo(object):
                                                        """
                                                        Critical Low
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.CriticalLo']['meta_info']


                                                    class MinorLo(object):
                                                        """
                                                        Minor Low
                                                        
                                                        .. attribute:: thresh_bag
                                                        
                                                        	Environment threshold info
                                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo.ThreshBag>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo.ThreshBag()
                                                            self.thresh_bag.parent = self


                                                        class ThreshBag(object):
                                                            """
                                                            Environment threshold info
                                                            
                                                            .. attribute:: threshold_evaluation
                                                            
                                                            	Indicates the result of the most recent evaluation of the thresholD
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_notification_enabled
                                                            
                                                            	Indicates whether or not a notification should result, in case of threshold violation
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: threshold_relation
                                                            
                                                            	Indicates relation between sensor value and threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_severity
                                                            
                                                            	Indicates minor, major, critical severities
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: threshold_value
                                                            
                                                            	Value of the configured threshold
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.threshold_evaluation = None
                                                                self.threshold_notification_enabled = None
                                                                self.threshold_relation = None
                                                                self.threshold_severity = None
                                                                self.threshold_value = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.threshold_evaluation is not None:
                                                                    return True

                                                                if self.threshold_notification_enabled is not None:
                                                                    return True

                                                                if self.threshold_relation is not None:
                                                                    return True

                                                                if self.threshold_severity is not None:
                                                                    return True

                                                                if self.threshold_value is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold.MinorLo']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                                            return True

                                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                                            return True

                                                        if self.major_hi is not None and self.major_hi._has_data():
                                                            return True

                                                        if self.major_lo is not None and self.major_lo._has_data():
                                                            return True

                                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                                            return True

                                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.Threshold']['meta_info']


                                                class FruInfo(object):
                                                    """
                                                    Inventory EDM FRU info
                                                    
                                                    .. attribute:: card_administrative_state
                                                    
                                                    	card admin state\: shutdown or not
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: card_monitor_state
                                                    
                                                    	card is monitored by a manager or left unmonitored
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: card_operational_state
                                                    
                                                    	card operation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: card_reset_reason
                                                    
                                                    	card reset reason enum
                                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                                    
                                                    .. attribute:: card_up_time
                                                    
                                                    	card up time
                                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.CardUpTime>`
                                                    
                                                    .. attribute:: last_operational_state_change
                                                    
                                                    	last card oper change state
                                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.LastOperationalStateChange>`
                                                    
                                                    .. attribute:: power_administrative_state
                                                    
                                                    	power admin state\: up or down
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_current_measurement
                                                    
                                                    	power current\: not implemented
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: power_operational_state
                                                    
                                                    	Power operation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.card_administrative_state = None
                                                        self.card_monitor_state = None
                                                        self.card_operational_state = None
                                                        self.card_reset_reason = None
                                                        self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.CardUpTime()
                                                        self.card_up_time.parent = self
                                                        self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.LastOperationalStateChange()
                                                        self.last_operational_state_change.parent = self
                                                        self.power_administrative_state = None
                                                        self.power_current_measurement = None
                                                        self.power_operational_state = None


                                                    class LastOperationalStateChange(object):
                                                        """
                                                        last card oper change state
                                                        
                                                        .. attribute:: time_in_nano_seconds
                                                        
                                                        	Time Value in Nano\-seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: time_in_seconds
                                                        
                                                        	Time Value in Seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.time_in_nano_seconds = None
                                                            self.time_in_seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.time_in_nano_seconds is not None:
                                                                return True

                                                            if self.time_in_seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                                    class CardUpTime(object):
                                                        """
                                                        card up time
                                                        
                                                        .. attribute:: time_in_nano_seconds
                                                        
                                                        	Time Value in Nano\-seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: time_in_seconds
                                                        
                                                        	Time Value in Seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-2147483648..2147483647
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.time_in_nano_seconds = None
                                                            self.time_in_seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.time_in_nano_seconds is not None:
                                                                return True

                                                            if self.time_in_seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo.CardUpTime']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.card_administrative_state is not None:
                                                            return True

                                                        if self.card_monitor_state is not None:
                                                            return True

                                                        if self.card_operational_state is not None:
                                                            return True

                                                        if self.card_reset_reason is not None:
                                                            return True

                                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                                            return True

                                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                            return True

                                                        if self.power_administrative_state is not None:
                                                            return True

                                                        if self.power_current_measurement is not None:
                                                            return True

                                                        if self.power_operational_state is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.FruInfo']['meta_info']


                                                class InvBasicBag(object):
                                                    """
                                                    Inventory Basic Bag
                                                    
                                                    .. attribute:: alias
                                                    
                                                    	useful for storing an entity alias 
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: asset_id_str
                                                    
                                                    	asset Identification string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: asset_identification
                                                    
                                                    	asset Identification
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: ceport
                                                    
                                                    	1 if ce port found, 0 if not
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: chip_hardware_revision
                                                    
                                                    	chip module hw revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: composite_class_code
                                                    
                                                    	Major&minor class of the entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: description
                                                    
                                                    	describes in user\-readable terms       what the entity in question does
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: environmental_monitor_path
                                                    
                                                    	sysdb name of sensor in the envmon EDM
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: firmware_revision
                                                    
                                                    	firmware revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: group_flag
                                                    
                                                    	indicates if this entity is group       or not
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: hardware_revision
                                                    
                                                    	hw revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: is_field_replaceable_unit
                                                    
                                                    	1 if Field Replaceable Unit 0, if not
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: manufacturer_asset_tags
                                                    
                                                    	Manufacture Asset Tags
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: manufacturer_name
                                                    
                                                    	manufacturer's name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: memory_size
                                                    
                                                    	Size of memory associated with       the entity where applicable
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: model_name
                                                    
                                                    	model name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: name
                                                    
                                                    	name string for the entity
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: new_deviation_number
                                                    
                                                    	integer value for New Deviation Number 0x88
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: physical_layer_interface_module_type
                                                    
                                                    	integer value for plim type if     applicable to this entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: redundancystate
                                                    
                                                    	integer value for Redundancy State if     applicable to this entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: serial_number
                                                    
                                                    	serial number
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: software_revision
                                                    
                                                    	software revision string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: unique_id
                                                    
                                                    	Unique id for an entity
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    .. attribute:: unrecognized_fru
                                                    
                                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vendor_type
                                                    
                                                    	maps to the vendor OID string
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: xr_scoped
                                                    
                                                    	1 if xr scoped, 0 if not
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.alias = None
                                                        self.asset_id_str = None
                                                        self.asset_identification = None
                                                        self.ceport = None
                                                        self.chip_hardware_revision = None
                                                        self.composite_class_code = None
                                                        self.description = None
                                                        self.environmental_monitor_path = None
                                                        self.firmware_revision = None
                                                        self.group_flag = None
                                                        self.hardware_revision = None
                                                        self.is_field_replaceable_unit = None
                                                        self.manufacturer_asset_tags = None
                                                        self.manufacturer_name = None
                                                        self.memory_size = None
                                                        self.model_name = None
                                                        self.name = None
                                                        self.new_deviation_number = None
                                                        self.physical_layer_interface_module_type = None
                                                        self.redundancystate = None
                                                        self.serial_number = None
                                                        self.software_revision = None
                                                        self.unique_id = None
                                                        self.unrecognized_fru = None
                                                        self.vendor_type = None
                                                        self.xr_scoped = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.alias is not None:
                                                            return True

                                                        if self.asset_id_str is not None:
                                                            return True

                                                        if self.asset_identification is not None:
                                                            return True

                                                        if self.ceport is not None:
                                                            return True

                                                        if self.chip_hardware_revision is not None:
                                                            return True

                                                        if self.composite_class_code is not None:
                                                            return True

                                                        if self.description is not None:
                                                            return True

                                                        if self.environmental_monitor_path is not None:
                                                            return True

                                                        if self.firmware_revision is not None:
                                                            return True

                                                        if self.group_flag is not None:
                                                            return True

                                                        if self.hardware_revision is not None:
                                                            return True

                                                        if self.is_field_replaceable_unit is not None:
                                                            return True

                                                        if self.manufacturer_asset_tags is not None:
                                                            return True

                                                        if self.manufacturer_name is not None:
                                                            return True

                                                        if self.memory_size is not None:
                                                            return True

                                                        if self.model_name is not None:
                                                            return True

                                                        if self.name is not None:
                                                            return True

                                                        if self.new_deviation_number is not None:
                                                            return True

                                                        if self.physical_layer_interface_module_type is not None:
                                                            return True

                                                        if self.redundancystate is not None:
                                                            return True

                                                        if self.serial_number is not None:
                                                            return True

                                                        if self.software_revision is not None:
                                                            return True

                                                        if self.unique_id is not None:
                                                            return True

                                                        if self.unrecognized_fru is not None:
                                                            return True

                                                        if self.vendor_type is not None:
                                                            return True

                                                        if self.xr_scoped is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvBasicBag']['meta_info']


                                                class InvEepromInfo(object):
                                                    """
                                                    Inventory EDM EEPROM Information Bag
                                                    
                                                    .. attribute:: description
                                                    
                                                    	A textual description of physical entity
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: eeprom
                                                    
                                                    	EEPROM data not from hex data
                                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom>`
                                                    
                                                    .. attribute:: has_eeprom
                                                    
                                                    	use eeprom instead of opaque data
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: inv_card_type
                                                    
                                                    	Inventory card type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: opaque_data
                                                    
                                                    	EEPROM hex data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: opaque_data_size
                                                    
                                                    	size of the EEPROM hex data
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.description = None
                                                        self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom()
                                                        self.eeprom.parent = self
                                                        self.has_eeprom = None
                                                        self.inv_card_type = None
                                                        self.opaque_data = None
                                                        self.opaque_data_size = None


                                                    class Eeprom(object):
                                                        """
                                                        EEPROM data not from hex data
                                                        
                                                        .. attribute:: asset_alias
                                                        
                                                        	Asset Alias
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: asset_id
                                                        
                                                        	Asset ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address1
                                                        
                                                        	Base Mac Address #1
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address2
                                                        
                                                        	Base Mac Address #2
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address3
                                                        
                                                        	Base Mac Address #3
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: base_mac_address4
                                                        
                                                        	Base Mac Address #4
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_checksum
                                                        
                                                        	Block Checksum
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_count
                                                        
                                                        	Block Count
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_length
                                                        
                                                        	Block Length
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_signature
                                                        
                                                        	Block Signature
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: block_version
                                                        
                                                        	Block Version
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: chassis_sid
                                                        
                                                        	Chassis serial number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: clei
                                                        
                                                        	Common Language Equipment Identifier (CLEI) code
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: controller_family
                                                        
                                                        	Controller family
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: controller_type
                                                        
                                                        	Controller type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: description
                                                        
                                                        	A textual description of physical entity
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num1
                                                        
                                                        	Deviation Number # 1
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num2
                                                        
                                                        	Deviation Number # 2
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num3
                                                        
                                                        	Deviation Number # 3
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num4
                                                        
                                                        	Deviation Number # 4
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num5
                                                        
                                                        	Deviation Number # 5
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num6
                                                        
                                                        	Deviation Number # 6
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: dev_num7
                                                        
                                                        	Deviation Number # 7
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: eci
                                                        
                                                        	Equipment Catalog Item (ECI) number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: eeprom_size
                                                        
                                                        	EEPROM Size
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: engineer_use
                                                        
                                                        	Engineer Use
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: fru_major_type
                                                        
                                                        	FRU Major Type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: fru_minor_type
                                                        
                                                        	FRU Minor Type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: hw_version
                                                        
                                                        	Hardware Version
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: hwid
                                                        
                                                        	Hardware Revision
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: idprom_format_rev
                                                        
                                                        	IDPROM Format Revision
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size1
                                                        
                                                        	Mac Address Block Size #1
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size2
                                                        
                                                        	Mac Address Block Size #2
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size3
                                                        
                                                        	Mac Address Block Size #3
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mac_add_blk_size4
                                                        
                                                        	Mac Address Block Size #4
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: manu_test_data
                                                        
                                                        	Manufacturing Test Data
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mfg_bits
                                                        
                                                        	MFG Bits
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: mfg_deviation
                                                        
                                                        	MFG Deviation
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: oem_string
                                                        
                                                        	OEM String
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: part_number
                                                        
                                                        	Part Number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: part_revision
                                                        
                                                        	Part Revision
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pca_num
                                                        
                                                        	PCA number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pcavid
                                                        
                                                        	PCA revision ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pcb_serial_num
                                                        
                                                        	PCB Serial Number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: pid
                                                        
                                                        	Product ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: power_consumption
                                                        
                                                        	Power Consumption
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: power_supply_type
                                                        
                                                        	Power Supply Type
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: product_id
                                                        
                                                        	Product ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: rma
                                                        
                                                        	RMA Data
                                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                        
                                                        .. attribute:: rma_code
                                                        
                                                        	RMA Code
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: serial_number
                                                        
                                                        	Serial Number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: snmpoid
                                                        
                                                        	SNMP OID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: top_assem_part_num
                                                        
                                                        	Top assembly part number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: top_assem_vid
                                                        
                                                        	Top assembly revision number
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: udi_description
                                                        
                                                        	UDI description
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: udi_name
                                                        
                                                        	UDI name
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        .. attribute:: vid
                                                        
                                                        	Version ID
                                                        	**type**\:  str
                                                        
                                                        	**length:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'invmgr-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.asset_alias = None
                                                            self.asset_id = None
                                                            self.base_mac_address1 = None
                                                            self.base_mac_address2 = None
                                                            self.base_mac_address3 = None
                                                            self.base_mac_address4 = None
                                                            self.block_checksum = None
                                                            self.block_count = None
                                                            self.block_length = None
                                                            self.block_signature = None
                                                            self.block_version = None
                                                            self.chassis_sid = None
                                                            self.clei = None
                                                            self.controller_family = None
                                                            self.controller_type = None
                                                            self.description = None
                                                            self.dev_num1 = None
                                                            self.dev_num2 = None
                                                            self.dev_num3 = None
                                                            self.dev_num4 = None
                                                            self.dev_num5 = None
                                                            self.dev_num6 = None
                                                            self.dev_num7 = None
                                                            self.eci = None
                                                            self.eeprom_size = None
                                                            self.engineer_use = None
                                                            self.fru_major_type = None
                                                            self.fru_minor_type = None
                                                            self.hw_version = None
                                                            self.hwid = None
                                                            self.idprom_format_rev = None
                                                            self.mac_add_blk_size1 = None
                                                            self.mac_add_blk_size2 = None
                                                            self.mac_add_blk_size3 = None
                                                            self.mac_add_blk_size4 = None
                                                            self.manu_test_data = None
                                                            self.mfg_bits = None
                                                            self.mfg_deviation = None
                                                            self.oem_string = None
                                                            self.part_number = None
                                                            self.part_revision = None
                                                            self.pca_num = None
                                                            self.pcavid = None
                                                            self.pcb_serial_num = None
                                                            self.pid = None
                                                            self.power_consumption = None
                                                            self.power_supply_type = None
                                                            self.product_id = None
                                                            self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom.Rma()
                                                            self.rma.parent = self
                                                            self.rma_code = None
                                                            self.serial_number = None
                                                            self.snmpoid = None
                                                            self.top_assem_part_num = None
                                                            self.top_assem_vid = None
                                                            self.udi_description = None
                                                            self.udi_name = None
                                                            self.vid = None


                                                        class Rma(object):
                                                            """
                                                            RMA Data
                                                            
                                                            .. attribute:: rma_history
                                                            
                                                            	RMA history
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: rma_number
                                                            
                                                            	RMA tracking number format is N\-N\-N
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            .. attribute:: test_history
                                                            
                                                            	Test history
                                                            	**type**\:  str
                                                            
                                                            	**length:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'invmgr-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.rma_history = None
                                                                self.rma_number = None
                                                                self.test_history = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.rma_history is not None:
                                                                    return True

                                                                if self.rma_number is not None:
                                                                    return True

                                                                if self.test_history is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.asset_alias is not None:
                                                                return True

                                                            if self.asset_id is not None:
                                                                return True

                                                            if self.base_mac_address1 is not None:
                                                                return True

                                                            if self.base_mac_address2 is not None:
                                                                return True

                                                            if self.base_mac_address3 is not None:
                                                                return True

                                                            if self.base_mac_address4 is not None:
                                                                return True

                                                            if self.block_checksum is not None:
                                                                return True

                                                            if self.block_count is not None:
                                                                return True

                                                            if self.block_length is not None:
                                                                return True

                                                            if self.block_signature is not None:
                                                                return True

                                                            if self.block_version is not None:
                                                                return True

                                                            if self.chassis_sid is not None:
                                                                return True

                                                            if self.clei is not None:
                                                                return True

                                                            if self.controller_family is not None:
                                                                return True

                                                            if self.controller_type is not None:
                                                                return True

                                                            if self.description is not None:
                                                                return True

                                                            if self.dev_num1 is not None:
                                                                return True

                                                            if self.dev_num2 is not None:
                                                                return True

                                                            if self.dev_num3 is not None:
                                                                return True

                                                            if self.dev_num4 is not None:
                                                                return True

                                                            if self.dev_num5 is not None:
                                                                return True

                                                            if self.dev_num6 is not None:
                                                                return True

                                                            if self.dev_num7 is not None:
                                                                return True

                                                            if self.eci is not None:
                                                                return True

                                                            if self.eeprom_size is not None:
                                                                return True

                                                            if self.engineer_use is not None:
                                                                return True

                                                            if self.fru_major_type is not None:
                                                                return True

                                                            if self.fru_minor_type is not None:
                                                                return True

                                                            if self.hw_version is not None:
                                                                return True

                                                            if self.hwid is not None:
                                                                return True

                                                            if self.idprom_format_rev is not None:
                                                                return True

                                                            if self.mac_add_blk_size1 is not None:
                                                                return True

                                                            if self.mac_add_blk_size2 is not None:
                                                                return True

                                                            if self.mac_add_blk_size3 is not None:
                                                                return True

                                                            if self.mac_add_blk_size4 is not None:
                                                                return True

                                                            if self.manu_test_data is not None:
                                                                return True

                                                            if self.mfg_bits is not None:
                                                                return True

                                                            if self.mfg_deviation is not None:
                                                                return True

                                                            if self.oem_string is not None:
                                                                return True

                                                            if self.part_number is not None:
                                                                return True

                                                            if self.part_revision is not None:
                                                                return True

                                                            if self.pca_num is not None:
                                                                return True

                                                            if self.pcavid is not None:
                                                                return True

                                                            if self.pcb_serial_num is not None:
                                                                return True

                                                            if self.pid is not None:
                                                                return True

                                                            if self.power_consumption is not None:
                                                                return True

                                                            if self.power_supply_type is not None:
                                                                return True

                                                            if self.product_id is not None:
                                                                return True

                                                            if self.rma is not None and self.rma._has_data():
                                                                return True

                                                            if self.rma_code is not None:
                                                                return True

                                                            if self.serial_number is not None:
                                                                return True

                                                            if self.snmpoid is not None:
                                                                return True

                                                            if self.top_assem_part_num is not None:
                                                                return True

                                                            if self.top_assem_vid is not None:
                                                                return True

                                                            if self.udi_description is not None:
                                                                return True

                                                            if self.udi_name is not None:
                                                                return True

                                                            if self.vid is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.description is not None:
                                                            return True

                                                        if self.eeprom is not None and self.eeprom._has_data():
                                                            return True

                                                        if self.has_eeprom is not None:
                                                            return True

                                                        if self.inv_card_type is not None:
                                                            return True

                                                        if self.opaque_data is not None:
                                                            return True

                                                        if self.opaque_data_size is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes.InvEepromInfo']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                        return True

                                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                        return True

                                                    if self.fru_info is not None and self.fru_info._has_data():
                                                        return True

                                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                        return True

                                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                        return True

                                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                        return True

                                                    if self.module_done is not None:
                                                        return True

                                                    if self.node_id is not None:
                                                        return True

                                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                                        return True

                                                    if self.threshold is not None and self.threshold._has_data():
                                                        return True

                                                    if self.vm_done is not None:
                                                        return True

                                                    if self.vm_node_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3.Attributes']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.name is None:
                                                    raise YPYModelError('Key property name is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi3[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.name is not None:
                                                    return True

                                                if self.attributes is not None and self.attributes._has_data():
                                                    return True

                                                if self.tsi4s is not None and self.tsi4s._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S.Tsi3']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi3s'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tsi3 is not None:
                                                for child_ref in self.tsi3:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Tsi3S']['meta_info']


                                    class Attributes(object):
                                        """
                                        Attributes
                                        
                                        .. attribute:: env_sensor_info
                                        
                                        	Environment sensor info
                                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfo>`
                                        
                                        .. attribute:: env_sensor_info_xml
                                        
                                        	Environment sensor info XML
                                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml>`
                                        
                                        .. attribute:: fru_info
                                        
                                        	Inventory EDM FRU info
                                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo>`
                                        
                                        .. attribute:: inv_asset_bag
                                        
                                        	Inventory Asset Bag
                                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvAssetBag>`
                                        
                                        .. attribute:: inv_basic_bag
                                        
                                        	Inventory Basic Bag
                                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvBasicBag>`
                                        
                                        .. attribute:: inv_eeprom_info
                                        
                                        	Inventory EDM EEPROM Information Bag
                                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo>`
                                        
                                        .. attribute:: module_done
                                        
                                        	Inventory EDM Module Done Tuple
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: node_id
                                        
                                        	Node ID Tuple
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pwg_info
                                        
                                        	Inventory EDM PWG info
                                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.PwgInfo>`
                                        
                                        .. attribute:: threshold
                                        
                                        	Threshold
                                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold>`
                                        
                                        .. attribute:: vm_done
                                        
                                        	VM Done Tuple
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: vm_node_id
                                        
                                        	VM Node ID Tuple
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfo()
                                            self.env_sensor_info.parent = self
                                            self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml()
                                            self.env_sensor_info_xml.parent = self
                                            self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo()
                                            self.fru_info.parent = self
                                            self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvAssetBag()
                                            self.inv_asset_bag.parent = self
                                            self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvBasicBag()
                                            self.inv_basic_bag.parent = self
                                            self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo()
                                            self.inv_eeprom_info.parent = self
                                            self.module_done = None
                                            self.node_id = None
                                            self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.PwgInfo()
                                            self.pwg_info.parent = self
                                            self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold()
                                            self.threshold.parent = self
                                            self.vm_done = None
                                            self.vm_node_id = None


                                        class EnvSensorInfo(object):
                                            """
                                            Environment sensor info
                                            
                                            .. attribute:: age_time_stamp
                                            
                                            	Age of the sensor value; set to the current time if directly access the value from sensor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: alarm_type
                                            
                                            	Indicates threshold violation
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_type
                                            
                                            	Sensor data type enums
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: device_description
                                            
                                            	Device Name
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: device_id
                                            
                                            	Identifier for this device
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: field_validity_bitmap
                                            
                                            	Sensor valid bitmap
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: precision
                                            
                                            	Sensor precision range
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scale
                                            
                                            	Sensor scale enums
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: status
                                            
                                            	Sensor operation state enums
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: units
                                            
                                            	Units of variable being read
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: update_rate
                                            
                                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: value
                                            
                                            	Current reading of sensor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.age_time_stamp = None
                                                self.alarm_type = None
                                                self.data_type = None
                                                self.device_description = None
                                                self.device_id = None
                                                self.field_validity_bitmap = None
                                                self.precision = None
                                                self.scale = None
                                                self.status = None
                                                self.units = None
                                                self.update_rate = None
                                                self.value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.age_time_stamp is not None:
                                                    return True

                                                if self.alarm_type is not None:
                                                    return True

                                                if self.data_type is not None:
                                                    return True

                                                if self.device_description is not None:
                                                    return True

                                                if self.device_id is not None:
                                                    return True

                                                if self.field_validity_bitmap is not None:
                                                    return True

                                                if self.precision is not None:
                                                    return True

                                                if self.scale is not None:
                                                    return True

                                                if self.status is not None:
                                                    return True

                                                if self.units is not None:
                                                    return True

                                                if self.update_rate is not None:
                                                    return True

                                                if self.value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfo']['meta_info']


                                        class PwgInfo(object):
                                            """
                                            Inventory EDM PWG info
                                            
                                            .. attribute:: power_group_available_current
                                            
                                            	available current
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_group_drawn_current
                                            
                                            	drawn current
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_group_power_units
                                            
                                            	power units
                                            	**type**\:  str
                                            
                                            .. attribute:: power_group_redundancy_mode
                                            
                                            	redundancy mode
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.power_group_available_current = None
                                                self.power_group_drawn_current = None
                                                self.power_group_power_units = None
                                                self.power_group_redundancy_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.power_group_available_current is not None:
                                                    return True

                                                if self.power_group_drawn_current is not None:
                                                    return True

                                                if self.power_group_power_units is not None:
                                                    return True

                                                if self.power_group_redundancy_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.PwgInfo']['meta_info']


                                        class EnvSensorInfoXml(object):
                                            """
                                            Environment sensor info XML
                                            
                                            .. attribute:: data_type
                                            
                                            	Sensor data type
                                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                            
                                            .. attribute:: description
                                            
                                            	Device Name
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: status
                                            
                                            	Sensor operation state
                                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                            
                                            .. attribute:: threshold
                                            
                                            	Threshold information
                                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold>`
                                            
                                            .. attribute:: units
                                            
                                            	Units of variable being read
                                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                            
                                            .. attribute:: update_rate
                                            
                                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: value
                                            
                                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.data_type = None
                                                self.description = None
                                                self.status = None
                                                self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold()
                                                self.threshold.parent = self
                                                self.units = None
                                                self.update_rate = None
                                                self.value = None


                                            class Threshold(object):
                                                """
                                                Threshold information
                                                
                                                .. attribute:: threshold_array
                                                
                                                	Array of threshold
                                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.threshold_array = YList()
                                                    self.threshold_array.parent = self
                                                    self.threshold_array.name = 'threshold_array'


                                                class ThresholdArray(object):
                                                    """
                                                    Array of threshold
                                                    
                                                    .. attribute:: threshold_name
                                                    
                                                    	Threshold name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..50
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-2147483648..2147483647
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_name = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_name is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.threshold_array is not None:
                                                        for child_ref in self.threshold_array:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.data_type is not None:
                                                    return True

                                                if self.description is not None:
                                                    return True

                                                if self.status is not None:
                                                    return True

                                                if self.threshold is not None and self.threshold._has_data():
                                                    return True

                                                if self.units is not None:
                                                    return True

                                                if self.update_rate is not None:
                                                    return True

                                                if self.value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.EnvSensorInfoXml']['meta_info']


                                        class InvAssetBag(object):
                                            """
                                            Inventory Asset Bag
                                            
                                            .. attribute:: manufacturer_assembly_number
                                            
                                            	Manufacture Assembly number
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_assembly_revision
                                            
                                            	Manufacture assembly revision
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_common_language_equipment_identifier
                                            
                                            	Common Language Equipment           Identifier number
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_firmware_identifier
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: manufacturer_software_identifier
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: original_equipment_manufacturer_string
                                            
                                            	String containing OEM information           if applicable
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: part_number
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.manufacturer_assembly_number = None
                                                self.manufacturer_assembly_revision = None
                                                self.manufacturer_common_language_equipment_identifier = None
                                                self.manufacturer_firmware_identifier = None
                                                self.manufacturer_software_identifier = None
                                                self.original_equipment_manufacturer_string = None
                                                self.part_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.manufacturer_assembly_number is not None:
                                                    return True

                                                if self.manufacturer_assembly_revision is not None:
                                                    return True

                                                if self.manufacturer_common_language_equipment_identifier is not None:
                                                    return True

                                                if self.manufacturer_firmware_identifier is not None:
                                                    return True

                                                if self.manufacturer_software_identifier is not None:
                                                    return True

                                                if self.original_equipment_manufacturer_string is not None:
                                                    return True

                                                if self.part_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvAssetBag']['meta_info']


                                        class Threshold(object):
                                            """
                                            Threshold
                                            
                                            .. attribute:: critical_hi
                                            
                                            	Critical High
                                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi>`
                                            
                                            .. attribute:: critical_lo
                                            
                                            	Critical Low
                                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo>`
                                            
                                            .. attribute:: major_hi
                                            
                                            	Major High
                                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi>`
                                            
                                            .. attribute:: major_lo
                                            
                                            	Major Low
                                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo>`
                                            
                                            .. attribute:: minor_hi
                                            
                                            	Minor High
                                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi>`
                                            
                                            .. attribute:: minor_lo
                                            
                                            	Minor Low
                                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo>`
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi()
                                                self.critical_hi.parent = self
                                                self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo()
                                                self.critical_lo.parent = self
                                                self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi()
                                                self.major_hi.parent = self
                                                self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo()
                                                self.major_lo.parent = self
                                                self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi()
                                                self.minor_hi.parent = self
                                                self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo()
                                                self.minor_lo.parent = self


                                            class MajorLo(object):
                                                """
                                                Major Low
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorLo']['meta_info']


                                            class CriticalHi(object):
                                                """
                                                Critical High
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalHi']['meta_info']


                                            class MinorHi(object):
                                                """
                                                Minor High
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorHi']['meta_info']


                                            class MajorHi(object):
                                                """
                                                Major High
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MajorHi']['meta_info']


                                            class CriticalLo(object):
                                                """
                                                Critical Low
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.CriticalLo']['meta_info']


                                            class MinorLo(object):
                                                """
                                                Minor Low
                                                
                                                .. attribute:: thresh_bag
                                                
                                                	Environment threshold info
                                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo.ThreshBag>`
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo.ThreshBag()
                                                    self.thresh_bag.parent = self


                                                class ThreshBag(object):
                                                    """
                                                    Environment threshold info
                                                    
                                                    .. attribute:: threshold_evaluation
                                                    
                                                    	Indicates the result of the most recent evaluation of the thresholD
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_notification_enabled
                                                    
                                                    	Indicates whether or not a notification should result, in case of threshold violation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold_relation
                                                    
                                                    	Indicates relation between sensor value and threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_severity
                                                    
                                                    	Indicates minor, major, critical severities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: threshold_value
                                                    
                                                    	Value of the configured threshold
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.threshold_evaluation = None
                                                        self.threshold_notification_enabled = None
                                                        self.threshold_relation = None
                                                        self.threshold_severity = None
                                                        self.threshold_value = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.threshold_evaluation is not None:
                                                            return True

                                                        if self.threshold_notification_enabled is not None:
                                                            return True

                                                        if self.threshold_relation is not None:
                                                            return True

                                                        if self.threshold_severity is not None:
                                                            return True

                                                        if self.threshold_value is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold.MinorLo']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.critical_hi is not None and self.critical_hi._has_data():
                                                    return True

                                                if self.critical_lo is not None and self.critical_lo._has_data():
                                                    return True

                                                if self.major_hi is not None and self.major_hi._has_data():
                                                    return True

                                                if self.major_lo is not None and self.major_lo._has_data():
                                                    return True

                                                if self.minor_hi is not None and self.minor_hi._has_data():
                                                    return True

                                                if self.minor_lo is not None and self.minor_lo._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.Threshold']['meta_info']


                                        class FruInfo(object):
                                            """
                                            Inventory EDM FRU info
                                            
                                            .. attribute:: card_administrative_state
                                            
                                            	card admin state\: shutdown or not
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: card_monitor_state
                                            
                                            	card is monitored by a manager or left unmonitored
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: card_operational_state
                                            
                                            	card operation state
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: card_reset_reason
                                            
                                            	card reset reason enum
                                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                            
                                            .. attribute:: card_up_time
                                            
                                            	card up time
                                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.CardUpTime>`
                                            
                                            .. attribute:: last_operational_state_change
                                            
                                            	last card oper change state
                                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.LastOperationalStateChange>`
                                            
                                            .. attribute:: power_administrative_state
                                            
                                            	power admin state\: up or down
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_current_measurement
                                            
                                            	power current\: not implemented
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: power_operational_state
                                            
                                            	Power operation state
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.card_administrative_state = None
                                                self.card_monitor_state = None
                                                self.card_operational_state = None
                                                self.card_reset_reason = None
                                                self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.CardUpTime()
                                                self.card_up_time.parent = self
                                                self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.LastOperationalStateChange()
                                                self.last_operational_state_change.parent = self
                                                self.power_administrative_state = None
                                                self.power_current_measurement = None
                                                self.power_operational_state = None


                                            class LastOperationalStateChange(object):
                                                """
                                                last card oper change state
                                                
                                                .. attribute:: time_in_nano_seconds
                                                
                                                	Time Value in Nano\-seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: time_in_seconds
                                                
                                                	Time Value in Seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.time_in_nano_seconds = None
                                                    self.time_in_seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.time_in_nano_seconds is not None:
                                                        return True

                                                    if self.time_in_seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                            class CardUpTime(object):
                                                """
                                                card up time
                                                
                                                .. attribute:: time_in_nano_seconds
                                                
                                                	Time Value in Nano\-seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: time_in_seconds
                                                
                                                	Time Value in Seconds
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.time_in_nano_seconds = None
                                                    self.time_in_seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.time_in_nano_seconds is not None:
                                                        return True

                                                    if self.time_in_seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo.CardUpTime']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.card_administrative_state is not None:
                                                    return True

                                                if self.card_monitor_state is not None:
                                                    return True

                                                if self.card_operational_state is not None:
                                                    return True

                                                if self.card_reset_reason is not None:
                                                    return True

                                                if self.card_up_time is not None and self.card_up_time._has_data():
                                                    return True

                                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                                    return True

                                                if self.power_administrative_state is not None:
                                                    return True

                                                if self.power_current_measurement is not None:
                                                    return True

                                                if self.power_operational_state is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.FruInfo']['meta_info']


                                        class InvBasicBag(object):
                                            """
                                            Inventory Basic Bag
                                            
                                            .. attribute:: alias
                                            
                                            	useful for storing an entity alias 
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: asset_id_str
                                            
                                            	asset Identification string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: asset_identification
                                            
                                            	asset Identification
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ceport
                                            
                                            	1 if ce port found, 0 if not
                                            	**type**\:  bool
                                            
                                            .. attribute:: chip_hardware_revision
                                            
                                            	chip module hw revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: composite_class_code
                                            
                                            	Major&minor class of the entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: description
                                            
                                            	describes in user\-readable terms       what the entity in question does
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: environmental_monitor_path
                                            
                                            	sysdb name of sensor in the envmon EDM
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: firmware_revision
                                            
                                            	firmware revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: group_flag
                                            
                                            	indicates if this entity is group       or not
                                            	**type**\:  bool
                                            
                                            .. attribute:: hardware_revision
                                            
                                            	hw revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: is_field_replaceable_unit
                                            
                                            	1 if Field Replaceable Unit 0, if not
                                            	**type**\:  bool
                                            
                                            .. attribute:: manufacturer_asset_tags
                                            
                                            	Manufacture Asset Tags
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: manufacturer_name
                                            
                                            	manufacturer's name
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: memory_size
                                            
                                            	Size of memory associated with       the entity where applicable
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: model_name
                                            
                                            	model name
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: name
                                            
                                            	name string for the entity
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: new_deviation_number
                                            
                                            	integer value for New Deviation Number 0x88
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: physical_layer_interface_module_type
                                            
                                            	integer value for plim type if     applicable to this entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: redundancystate
                                            
                                            	integer value for Redundancy State if     applicable to this entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: serial_number
                                            
                                            	serial number
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: software_revision
                                            
                                            	software revision string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: unique_id
                                            
                                            	Unique id for an entity
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: unrecognized_fru
                                            
                                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                                            	**type**\:  bool
                                            
                                            .. attribute:: vendor_type
                                            
                                            	maps to the vendor OID string
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: xr_scoped
                                            
                                            	1 if xr scoped, 0 if not
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.alias = None
                                                self.asset_id_str = None
                                                self.asset_identification = None
                                                self.ceport = None
                                                self.chip_hardware_revision = None
                                                self.composite_class_code = None
                                                self.description = None
                                                self.environmental_monitor_path = None
                                                self.firmware_revision = None
                                                self.group_flag = None
                                                self.hardware_revision = None
                                                self.is_field_replaceable_unit = None
                                                self.manufacturer_asset_tags = None
                                                self.manufacturer_name = None
                                                self.memory_size = None
                                                self.model_name = None
                                                self.name = None
                                                self.new_deviation_number = None
                                                self.physical_layer_interface_module_type = None
                                                self.redundancystate = None
                                                self.serial_number = None
                                                self.software_revision = None
                                                self.unique_id = None
                                                self.unrecognized_fru = None
                                                self.vendor_type = None
                                                self.xr_scoped = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.alias is not None:
                                                    return True

                                                if self.asset_id_str is not None:
                                                    return True

                                                if self.asset_identification is not None:
                                                    return True

                                                if self.ceport is not None:
                                                    return True

                                                if self.chip_hardware_revision is not None:
                                                    return True

                                                if self.composite_class_code is not None:
                                                    return True

                                                if self.description is not None:
                                                    return True

                                                if self.environmental_monitor_path is not None:
                                                    return True

                                                if self.firmware_revision is not None:
                                                    return True

                                                if self.group_flag is not None:
                                                    return True

                                                if self.hardware_revision is not None:
                                                    return True

                                                if self.is_field_replaceable_unit is not None:
                                                    return True

                                                if self.manufacturer_asset_tags is not None:
                                                    return True

                                                if self.manufacturer_name is not None:
                                                    return True

                                                if self.memory_size is not None:
                                                    return True

                                                if self.model_name is not None:
                                                    return True

                                                if self.name is not None:
                                                    return True

                                                if self.new_deviation_number is not None:
                                                    return True

                                                if self.physical_layer_interface_module_type is not None:
                                                    return True

                                                if self.redundancystate is not None:
                                                    return True

                                                if self.serial_number is not None:
                                                    return True

                                                if self.software_revision is not None:
                                                    return True

                                                if self.unique_id is not None:
                                                    return True

                                                if self.unrecognized_fru is not None:
                                                    return True

                                                if self.vendor_type is not None:
                                                    return True

                                                if self.xr_scoped is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvBasicBag']['meta_info']


                                        class InvEepromInfo(object):
                                            """
                                            Inventory EDM EEPROM Information Bag
                                            
                                            .. attribute:: description
                                            
                                            	A textual description of physical entity
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: eeprom
                                            
                                            	EEPROM data not from hex data
                                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom>`
                                            
                                            .. attribute:: has_eeprom
                                            
                                            	use eeprom instead of opaque data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inv_card_type
                                            
                                            	Inventory card type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: opaque_data
                                            
                                            	EEPROM hex data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: opaque_data_size
                                            
                                            	size of the EEPROM hex data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom()
                                                self.eeprom.parent = self
                                                self.has_eeprom = None
                                                self.inv_card_type = None
                                                self.opaque_data = None
                                                self.opaque_data_size = None


                                            class Eeprom(object):
                                                """
                                                EEPROM data not from hex data
                                                
                                                .. attribute:: asset_alias
                                                
                                                	Asset Alias
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: asset_id
                                                
                                                	Asset ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address1
                                                
                                                	Base Mac Address #1
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address2
                                                
                                                	Base Mac Address #2
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address3
                                                
                                                	Base Mac Address #3
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: base_mac_address4
                                                
                                                	Base Mac Address #4
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_checksum
                                                
                                                	Block Checksum
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_count
                                                
                                                	Block Count
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_length
                                                
                                                	Block Length
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_signature
                                                
                                                	Block Signature
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: block_version
                                                
                                                	Block Version
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: chassis_sid
                                                
                                                	Chassis serial number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: clei
                                                
                                                	Common Language Equipment Identifier (CLEI) code
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: controller_family
                                                
                                                	Controller family
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: controller_type
                                                
                                                	Controller type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: description
                                                
                                                	A textual description of physical entity
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num1
                                                
                                                	Deviation Number # 1
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num2
                                                
                                                	Deviation Number # 2
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num3
                                                
                                                	Deviation Number # 3
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num4
                                                
                                                	Deviation Number # 4
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num5
                                                
                                                	Deviation Number # 5
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num6
                                                
                                                	Deviation Number # 6
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: dev_num7
                                                
                                                	Deviation Number # 7
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: eci
                                                
                                                	Equipment Catalog Item (ECI) number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: eeprom_size
                                                
                                                	EEPROM Size
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: engineer_use
                                                
                                                	Engineer Use
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: fru_major_type
                                                
                                                	FRU Major Type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: fru_minor_type
                                                
                                                	FRU Minor Type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: hw_version
                                                
                                                	Hardware Version
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: hwid
                                                
                                                	Hardware Revision
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: idprom_format_rev
                                                
                                                	IDPROM Format Revision
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size1
                                                
                                                	Mac Address Block Size #1
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size2
                                                
                                                	Mac Address Block Size #2
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size3
                                                
                                                	Mac Address Block Size #3
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mac_add_blk_size4
                                                
                                                	Mac Address Block Size #4
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: manu_test_data
                                                
                                                	Manufacturing Test Data
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mfg_bits
                                                
                                                	MFG Bits
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: mfg_deviation
                                                
                                                	MFG Deviation
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: oem_string
                                                
                                                	OEM String
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: part_number
                                                
                                                	Part Number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: part_revision
                                                
                                                	Part Revision
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pca_num
                                                
                                                	PCA number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pcavid
                                                
                                                	PCA revision ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pcb_serial_num
                                                
                                                	PCB Serial Number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: pid
                                                
                                                	Product ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: power_consumption
                                                
                                                	Power Consumption
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: power_supply_type
                                                
                                                	Power Supply Type
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: product_id
                                                
                                                	Product ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: rma
                                                
                                                	RMA Data
                                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom.Rma>`
                                                
                                                .. attribute:: rma_code
                                                
                                                	RMA Code
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: serial_number
                                                
                                                	Serial Number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: snmpoid
                                                
                                                	SNMP OID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: top_assem_part_num
                                                
                                                	Top assembly part number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: top_assem_vid
                                                
                                                	Top assembly revision number
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: udi_description
                                                
                                                	UDI description
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: udi_name
                                                
                                                	UDI name
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                .. attribute:: vid
                                                
                                                	Version ID
                                                	**type**\:  str
                                                
                                                	**length:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'invmgr-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asset_alias = None
                                                    self.asset_id = None
                                                    self.base_mac_address1 = None
                                                    self.base_mac_address2 = None
                                                    self.base_mac_address3 = None
                                                    self.base_mac_address4 = None
                                                    self.block_checksum = None
                                                    self.block_count = None
                                                    self.block_length = None
                                                    self.block_signature = None
                                                    self.block_version = None
                                                    self.chassis_sid = None
                                                    self.clei = None
                                                    self.controller_family = None
                                                    self.controller_type = None
                                                    self.description = None
                                                    self.dev_num1 = None
                                                    self.dev_num2 = None
                                                    self.dev_num3 = None
                                                    self.dev_num4 = None
                                                    self.dev_num5 = None
                                                    self.dev_num6 = None
                                                    self.dev_num7 = None
                                                    self.eci = None
                                                    self.eeprom_size = None
                                                    self.engineer_use = None
                                                    self.fru_major_type = None
                                                    self.fru_minor_type = None
                                                    self.hw_version = None
                                                    self.hwid = None
                                                    self.idprom_format_rev = None
                                                    self.mac_add_blk_size1 = None
                                                    self.mac_add_blk_size2 = None
                                                    self.mac_add_blk_size3 = None
                                                    self.mac_add_blk_size4 = None
                                                    self.manu_test_data = None
                                                    self.mfg_bits = None
                                                    self.mfg_deviation = None
                                                    self.oem_string = None
                                                    self.part_number = None
                                                    self.part_revision = None
                                                    self.pca_num = None
                                                    self.pcavid = None
                                                    self.pcb_serial_num = None
                                                    self.pid = None
                                                    self.power_consumption = None
                                                    self.power_supply_type = None
                                                    self.product_id = None
                                                    self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom.Rma()
                                                    self.rma.parent = self
                                                    self.rma_code = None
                                                    self.serial_number = None
                                                    self.snmpoid = None
                                                    self.top_assem_part_num = None
                                                    self.top_assem_vid = None
                                                    self.udi_description = None
                                                    self.udi_name = None
                                                    self.vid = None


                                                class Rma(object):
                                                    """
                                                    RMA Data
                                                    
                                                    .. attribute:: rma_history
                                                    
                                                    	RMA history
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: rma_number
                                                    
                                                    	RMA tracking number format is N\-N\-N
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    .. attribute:: test_history
                                                    
                                                    	Test history
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'invmgr-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.rma_history = None
                                                        self.rma_number = None
                                                        self.test_history = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.rma_history is not None:
                                                            return True

                                                        if self.rma_number is not None:
                                                            return True

                                                        if self.test_history is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asset_alias is not None:
                                                        return True

                                                    if self.asset_id is not None:
                                                        return True

                                                    if self.base_mac_address1 is not None:
                                                        return True

                                                    if self.base_mac_address2 is not None:
                                                        return True

                                                    if self.base_mac_address3 is not None:
                                                        return True

                                                    if self.base_mac_address4 is not None:
                                                        return True

                                                    if self.block_checksum is not None:
                                                        return True

                                                    if self.block_count is not None:
                                                        return True

                                                    if self.block_length is not None:
                                                        return True

                                                    if self.block_signature is not None:
                                                        return True

                                                    if self.block_version is not None:
                                                        return True

                                                    if self.chassis_sid is not None:
                                                        return True

                                                    if self.clei is not None:
                                                        return True

                                                    if self.controller_family is not None:
                                                        return True

                                                    if self.controller_type is not None:
                                                        return True

                                                    if self.description is not None:
                                                        return True

                                                    if self.dev_num1 is not None:
                                                        return True

                                                    if self.dev_num2 is not None:
                                                        return True

                                                    if self.dev_num3 is not None:
                                                        return True

                                                    if self.dev_num4 is not None:
                                                        return True

                                                    if self.dev_num5 is not None:
                                                        return True

                                                    if self.dev_num6 is not None:
                                                        return True

                                                    if self.dev_num7 is not None:
                                                        return True

                                                    if self.eci is not None:
                                                        return True

                                                    if self.eeprom_size is not None:
                                                        return True

                                                    if self.engineer_use is not None:
                                                        return True

                                                    if self.fru_major_type is not None:
                                                        return True

                                                    if self.fru_minor_type is not None:
                                                        return True

                                                    if self.hw_version is not None:
                                                        return True

                                                    if self.hwid is not None:
                                                        return True

                                                    if self.idprom_format_rev is not None:
                                                        return True

                                                    if self.mac_add_blk_size1 is not None:
                                                        return True

                                                    if self.mac_add_blk_size2 is not None:
                                                        return True

                                                    if self.mac_add_blk_size3 is not None:
                                                        return True

                                                    if self.mac_add_blk_size4 is not None:
                                                        return True

                                                    if self.manu_test_data is not None:
                                                        return True

                                                    if self.mfg_bits is not None:
                                                        return True

                                                    if self.mfg_deviation is not None:
                                                        return True

                                                    if self.oem_string is not None:
                                                        return True

                                                    if self.part_number is not None:
                                                        return True

                                                    if self.part_revision is not None:
                                                        return True

                                                    if self.pca_num is not None:
                                                        return True

                                                    if self.pcavid is not None:
                                                        return True

                                                    if self.pcb_serial_num is not None:
                                                        return True

                                                    if self.pid is not None:
                                                        return True

                                                    if self.power_consumption is not None:
                                                        return True

                                                    if self.power_supply_type is not None:
                                                        return True

                                                    if self.product_id is not None:
                                                        return True

                                                    if self.rma is not None and self.rma._has_data():
                                                        return True

                                                    if self.rma_code is not None:
                                                        return True

                                                    if self.serial_number is not None:
                                                        return True

                                                    if self.snmpoid is not None:
                                                        return True

                                                    if self.top_assem_part_num is not None:
                                                        return True

                                                    if self.top_assem_vid is not None:
                                                        return True

                                                    if self.udi_description is not None:
                                                        return True

                                                    if self.udi_name is not None:
                                                        return True

                                                    if self.vid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.eeprom is not None and self.eeprom._has_data():
                                                    return True

                                                if self.has_eeprom is not None:
                                                    return True

                                                if self.inv_card_type is not None:
                                                    return True

                                                if self.opaque_data is not None:
                                                    return True

                                                if self.opaque_data_size is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes.InvEepromInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                                return True

                                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                                return True

                                            if self.fru_info is not None and self.fru_info._has_data():
                                                return True

                                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                                return True

                                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                                return True

                                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                                return True

                                            if self.module_done is not None:
                                                return True

                                            if self.node_id is not None:
                                                return True

                                            if self.pwg_info is not None and self.pwg_info._has_data():
                                                return True

                                            if self.threshold is not None and self.threshold._has_data():
                                                return True

                                            if self.vm_done is not None:
                                                return True

                                            if self.vm_node_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2.Attributes']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.name is None:
                                            raise YPYModelError('Key property name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi2[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.name is not None:
                                            return True

                                        if self.attributes is not None and self.attributes._has_data():
                                            return True

                                        if self.tsi3s is not None and self.tsi3s._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S.Tsi2']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi2s'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tsi2 is not None:
                                        for child_ref in self.tsi2:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Tsi2S']['meta_info']


                            class Attributes(object):
                                """
                                Attributes
                                
                                .. attribute:: env_sensor_info
                                
                                	Environment sensor info
                                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfo>`
                                
                                .. attribute:: env_sensor_info_xml
                                
                                	Environment sensor info XML
                                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml>`
                                
                                .. attribute:: fru_info
                                
                                	Inventory EDM FRU info
                                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.FruInfo>`
                                
                                .. attribute:: inv_asset_bag
                                
                                	Inventory Asset Bag
                                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvAssetBag>`
                                
                                .. attribute:: inv_basic_bag
                                
                                	Inventory Basic Bag
                                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvBasicBag>`
                                
                                .. attribute:: inv_eeprom_info
                                
                                	Inventory EDM EEPROM Information Bag
                                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo>`
                                
                                .. attribute:: module_done
                                
                                	Inventory EDM Module Done Tuple
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**default value**\: 1
                                
                                .. attribute:: node_id
                                
                                	Node ID Tuple
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pwg_info
                                
                                	Inventory EDM PWG info
                                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.PwgInfo>`
                                
                                .. attribute:: threshold
                                
                                	Threshold
                                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold>`
                                
                                .. attribute:: vm_done
                                
                                	VM Done Tuple
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: vm_node_id
                                
                                	VM Node ID Tuple
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfo()
                                    self.env_sensor_info.parent = self
                                    self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml()
                                    self.env_sensor_info_xml.parent = self
                                    self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.FruInfo()
                                    self.fru_info.parent = self
                                    self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvAssetBag()
                                    self.inv_asset_bag.parent = self
                                    self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvBasicBag()
                                    self.inv_basic_bag.parent = self
                                    self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo()
                                    self.inv_eeprom_info.parent = self
                                    self.module_done = None
                                    self.node_id = None
                                    self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.PwgInfo()
                                    self.pwg_info.parent = self
                                    self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold()
                                    self.threshold.parent = self
                                    self.vm_done = None
                                    self.vm_node_id = None


                                class EnvSensorInfo(object):
                                    """
                                    Environment sensor info
                                    
                                    .. attribute:: age_time_stamp
                                    
                                    	Age of the sensor value; set to the current time if directly access the value from sensor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: alarm_type
                                    
                                    	Indicates threshold violation
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_type
                                    
                                    	Sensor data type enums
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: device_description
                                    
                                    	Device Name
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: device_id
                                    
                                    	Identifier for this device
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: field_validity_bitmap
                                    
                                    	Sensor valid bitmap
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: precision
                                    
                                    	Sensor precision range
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scale
                                    
                                    	Sensor scale enums
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status
                                    
                                    	Sensor operation state enums
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: units
                                    
                                    	Units of variable being read
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: update_rate
                                    
                                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: value
                                    
                                    	Current reading of sensor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.age_time_stamp = None
                                        self.alarm_type = None
                                        self.data_type = None
                                        self.device_description = None
                                        self.device_id = None
                                        self.field_validity_bitmap = None
                                        self.precision = None
                                        self.scale = None
                                        self.status = None
                                        self.units = None
                                        self.update_rate = None
                                        self.value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.age_time_stamp is not None:
                                            return True

                                        if self.alarm_type is not None:
                                            return True

                                        if self.data_type is not None:
                                            return True

                                        if self.device_description is not None:
                                            return True

                                        if self.device_id is not None:
                                            return True

                                        if self.field_validity_bitmap is not None:
                                            return True

                                        if self.precision is not None:
                                            return True

                                        if self.scale is not None:
                                            return True

                                        if self.status is not None:
                                            return True

                                        if self.units is not None:
                                            return True

                                        if self.update_rate is not None:
                                            return True

                                        if self.value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfo']['meta_info']


                                class PwgInfo(object):
                                    """
                                    Inventory EDM PWG info
                                    
                                    .. attribute:: power_group_available_current
                                    
                                    	available current
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_group_drawn_current
                                    
                                    	drawn current
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_group_power_units
                                    
                                    	power units
                                    	**type**\:  str
                                    
                                    .. attribute:: power_group_redundancy_mode
                                    
                                    	redundancy mode
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.power_group_available_current = None
                                        self.power_group_drawn_current = None
                                        self.power_group_power_units = None
                                        self.power_group_redundancy_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.power_group_available_current is not None:
                                            return True

                                        if self.power_group_drawn_current is not None:
                                            return True

                                        if self.power_group_power_units is not None:
                                            return True

                                        if self.power_group_redundancy_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.PwgInfo']['meta_info']


                                class EnvSensorInfoXml(object):
                                    """
                                    Environment sensor info XML
                                    
                                    .. attribute:: data_type
                                    
                                    	Sensor data type
                                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                                    
                                    .. attribute:: description
                                    
                                    	Device Name
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: status
                                    
                                    	Sensor operation state
                                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                                    
                                    .. attribute:: threshold
                                    
                                    	Threshold information
                                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold>`
                                    
                                    .. attribute:: units
                                    
                                    	Units of variable being read
                                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                                    
                                    .. attribute:: update_rate
                                    
                                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: value
                                    
                                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data_type = None
                                        self.description = None
                                        self.status = None
                                        self.threshold = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold()
                                        self.threshold.parent = self
                                        self.units = None
                                        self.update_rate = None
                                        self.value = None


                                    class Threshold(object):
                                        """
                                        Threshold information
                                        
                                        .. attribute:: threshold_array
                                        
                                        	Array of threshold
                                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.threshold_array = YList()
                                            self.threshold_array.parent = self
                                            self.threshold_array.name = 'threshold_array'


                                        class ThresholdArray(object):
                                            """
                                            Array of threshold
                                            
                                            .. attribute:: threshold_name
                                            
                                            	Threshold name
                                            	**type**\:  str
                                            
                                            	**length:** 0..50
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_name = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_name is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.threshold_array is not None:
                                                for child_ref in self.threshold_array:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data_type is not None:
                                            return True

                                        if self.description is not None:
                                            return True

                                        if self.status is not None:
                                            return True

                                        if self.threshold is not None and self.threshold._has_data():
                                            return True

                                        if self.units is not None:
                                            return True

                                        if self.update_rate is not None:
                                            return True

                                        if self.value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.EnvSensorInfoXml']['meta_info']


                                class InvAssetBag(object):
                                    """
                                    Inventory Asset Bag
                                    
                                    .. attribute:: manufacturer_assembly_number
                                    
                                    	Manufacture Assembly number
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_assembly_revision
                                    
                                    	Manufacture assembly revision
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_common_language_equipment_identifier
                                    
                                    	Common Language Equipment           Identifier number
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_firmware_identifier
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: manufacturer_software_identifier
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: original_equipment_manufacturer_string
                                    
                                    	String containing OEM information           if applicable
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: part_number
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.manufacturer_assembly_number = None
                                        self.manufacturer_assembly_revision = None
                                        self.manufacturer_common_language_equipment_identifier = None
                                        self.manufacturer_firmware_identifier = None
                                        self.manufacturer_software_identifier = None
                                        self.original_equipment_manufacturer_string = None
                                        self.part_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.manufacturer_assembly_number is not None:
                                            return True

                                        if self.manufacturer_assembly_revision is not None:
                                            return True

                                        if self.manufacturer_common_language_equipment_identifier is not None:
                                            return True

                                        if self.manufacturer_firmware_identifier is not None:
                                            return True

                                        if self.manufacturer_software_identifier is not None:
                                            return True

                                        if self.original_equipment_manufacturer_string is not None:
                                            return True

                                        if self.part_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvAssetBag']['meta_info']


                                class Threshold(object):
                                    """
                                    Threshold
                                    
                                    .. attribute:: critical_hi
                                    
                                    	Critical High
                                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi>`
                                    
                                    .. attribute:: critical_lo
                                    
                                    	Critical Low
                                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo>`
                                    
                                    .. attribute:: major_hi
                                    
                                    	Major High
                                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi>`
                                    
                                    .. attribute:: major_lo
                                    
                                    	Major Low
                                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo>`
                                    
                                    .. attribute:: minor_hi
                                    
                                    	Minor High
                                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi>`
                                    
                                    .. attribute:: minor_lo
                                    
                                    	Minor Low
                                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo>`
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi()
                                        self.critical_hi.parent = self
                                        self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo()
                                        self.critical_lo.parent = self
                                        self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi()
                                        self.major_hi.parent = self
                                        self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo()
                                        self.major_lo.parent = self
                                        self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi()
                                        self.minor_hi.parent = self
                                        self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo()
                                        self.minor_lo.parent = self


                                    class MajorLo(object):
                                        """
                                        Major Low
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorLo']['meta_info']


                                    class CriticalHi(object):
                                        """
                                        Critical High
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalHi']['meta_info']


                                    class MinorHi(object):
                                        """
                                        Minor High
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorHi']['meta_info']


                                    class MajorHi(object):
                                        """
                                        Major High
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MajorHi']['meta_info']


                                    class CriticalLo(object):
                                        """
                                        Critical Low
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.CriticalLo']['meta_info']


                                    class MinorLo(object):
                                        """
                                        Minor Low
                                        
                                        .. attribute:: thresh_bag
                                        
                                        	Environment threshold info
                                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo.ThreshBag>`
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo.ThreshBag()
                                            self.thresh_bag.parent = self


                                        class ThreshBag(object):
                                            """
                                            Environment threshold info
                                            
                                            .. attribute:: threshold_evaluation
                                            
                                            	Indicates the result of the most recent evaluation of the thresholD
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_notification_enabled
                                            
                                            	Indicates whether or not a notification should result, in case of threshold violation
                                            	**type**\:  bool
                                            
                                            .. attribute:: threshold_relation
                                            
                                            	Indicates relation between sensor value and threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_severity
                                            
                                            	Indicates minor, major, critical severities
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: threshold_value
                                            
                                            	Value of the configured threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.threshold_evaluation = None
                                                self.threshold_notification_enabled = None
                                                self.threshold_relation = None
                                                self.threshold_severity = None
                                                self.threshold_value = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.threshold_evaluation is not None:
                                                    return True

                                                if self.threshold_notification_enabled is not None:
                                                    return True

                                                if self.threshold_relation is not None:
                                                    return True

                                                if self.threshold_severity is not None:
                                                    return True

                                                if self.threshold_value is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold.MinorLo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.critical_hi is not None and self.critical_hi._has_data():
                                            return True

                                        if self.critical_lo is not None and self.critical_lo._has_data():
                                            return True

                                        if self.major_hi is not None and self.major_hi._has_data():
                                            return True

                                        if self.major_lo is not None and self.major_lo._has_data():
                                            return True

                                        if self.minor_hi is not None and self.minor_hi._has_data():
                                            return True

                                        if self.minor_lo is not None and self.minor_lo._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.Threshold']['meta_info']


                                class FruInfo(object):
                                    """
                                    Inventory EDM FRU info
                                    
                                    .. attribute:: card_administrative_state
                                    
                                    	card admin state\: shutdown or not
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: card_monitor_state
                                    
                                    	card is monitored by a manager or left unmonitored
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: card_operational_state
                                    
                                    	card operation state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: card_reset_reason
                                    
                                    	card reset reason enum
                                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                                    
                                    .. attribute:: card_up_time
                                    
                                    	card up time
                                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.FruInfo.CardUpTime>`
                                    
                                    .. attribute:: last_operational_state_change
                                    
                                    	last card oper change state
                                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.FruInfo.LastOperationalStateChange>`
                                    
                                    .. attribute:: power_administrative_state
                                    
                                    	power admin state\: up or down
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_current_measurement
                                    
                                    	power current\: not implemented
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: power_operational_state
                                    
                                    	Power operation state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.card_administrative_state = None
                                        self.card_monitor_state = None
                                        self.card_operational_state = None
                                        self.card_reset_reason = None
                                        self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.FruInfo.CardUpTime()
                                        self.card_up_time.parent = self
                                        self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.FruInfo.LastOperationalStateChange()
                                        self.last_operational_state_change.parent = self
                                        self.power_administrative_state = None
                                        self.power_current_measurement = None
                                        self.power_operational_state = None


                                    class LastOperationalStateChange(object):
                                        """
                                        last card oper change state
                                        
                                        .. attribute:: time_in_nano_seconds
                                        
                                        	Time Value in Nano\-seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: time_in_seconds
                                        
                                        	Time Value in Seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.time_in_nano_seconds = None
                                            self.time_in_seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.time_in_nano_seconds is not None:
                                                return True

                                            if self.time_in_seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                                    class CardUpTime(object):
                                        """
                                        card up time
                                        
                                        .. attribute:: time_in_nano_seconds
                                        
                                        	Time Value in Nano\-seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: time_in_seconds
                                        
                                        	Time Value in Seconds
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.time_in_nano_seconds = None
                                            self.time_in_seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.time_in_nano_seconds is not None:
                                                return True

                                            if self.time_in_seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.FruInfo.CardUpTime']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.card_administrative_state is not None:
                                            return True

                                        if self.card_monitor_state is not None:
                                            return True

                                        if self.card_operational_state is not None:
                                            return True

                                        if self.card_reset_reason is not None:
                                            return True

                                        if self.card_up_time is not None and self.card_up_time._has_data():
                                            return True

                                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                            return True

                                        if self.power_administrative_state is not None:
                                            return True

                                        if self.power_current_measurement is not None:
                                            return True

                                        if self.power_operational_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.FruInfo']['meta_info']


                                class InvBasicBag(object):
                                    """
                                    Inventory Basic Bag
                                    
                                    .. attribute:: alias
                                    
                                    	useful for storing an entity alias 
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: asset_id_str
                                    
                                    	asset Identification string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: asset_identification
                                    
                                    	asset Identification
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ceport
                                    
                                    	1 if ce port found, 0 if not
                                    	**type**\:  bool
                                    
                                    .. attribute:: chip_hardware_revision
                                    
                                    	chip module hw revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: composite_class_code
                                    
                                    	Major&minor class of the entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: description
                                    
                                    	describes in user\-readable terms       what the entity in question does
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: environmental_monitor_path
                                    
                                    	sysdb name of sensor in the envmon EDM
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: firmware_revision
                                    
                                    	firmware revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: group_flag
                                    
                                    	indicates if this entity is group       or not
                                    	**type**\:  bool
                                    
                                    .. attribute:: hardware_revision
                                    
                                    	hw revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: is_field_replaceable_unit
                                    
                                    	1 if Field Replaceable Unit 0, if not
                                    	**type**\:  bool
                                    
                                    .. attribute:: manufacturer_asset_tags
                                    
                                    	Manufacture Asset Tags
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: manufacturer_name
                                    
                                    	manufacturer's name
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: memory_size
                                    
                                    	Size of memory associated with       the entity where applicable
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: model_name
                                    
                                    	model name
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: name
                                    
                                    	name string for the entity
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: new_deviation_number
                                    
                                    	integer value for New Deviation Number 0x88
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: physical_layer_interface_module_type
                                    
                                    	integer value for plim type if     applicable to this entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: redundancystate
                                    
                                    	integer value for Redundancy State if     applicable to this entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: serial_number
                                    
                                    	serial number
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: software_revision
                                    
                                    	software revision string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: unique_id
                                    
                                    	Unique id for an entity
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: unrecognized_fru
                                    
                                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                                    	**type**\:  bool
                                    
                                    .. attribute:: vendor_type
                                    
                                    	maps to the vendor OID string
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: xr_scoped
                                    
                                    	1 if xr scoped, 0 if not
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.alias = None
                                        self.asset_id_str = None
                                        self.asset_identification = None
                                        self.ceport = None
                                        self.chip_hardware_revision = None
                                        self.composite_class_code = None
                                        self.description = None
                                        self.environmental_monitor_path = None
                                        self.firmware_revision = None
                                        self.group_flag = None
                                        self.hardware_revision = None
                                        self.is_field_replaceable_unit = None
                                        self.manufacturer_asset_tags = None
                                        self.manufacturer_name = None
                                        self.memory_size = None
                                        self.model_name = None
                                        self.name = None
                                        self.new_deviation_number = None
                                        self.physical_layer_interface_module_type = None
                                        self.redundancystate = None
                                        self.serial_number = None
                                        self.software_revision = None
                                        self.unique_id = None
                                        self.unrecognized_fru = None
                                        self.vendor_type = None
                                        self.xr_scoped = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.alias is not None:
                                            return True

                                        if self.asset_id_str is not None:
                                            return True

                                        if self.asset_identification is not None:
                                            return True

                                        if self.ceport is not None:
                                            return True

                                        if self.chip_hardware_revision is not None:
                                            return True

                                        if self.composite_class_code is not None:
                                            return True

                                        if self.description is not None:
                                            return True

                                        if self.environmental_monitor_path is not None:
                                            return True

                                        if self.firmware_revision is not None:
                                            return True

                                        if self.group_flag is not None:
                                            return True

                                        if self.hardware_revision is not None:
                                            return True

                                        if self.is_field_replaceable_unit is not None:
                                            return True

                                        if self.manufacturer_asset_tags is not None:
                                            return True

                                        if self.manufacturer_name is not None:
                                            return True

                                        if self.memory_size is not None:
                                            return True

                                        if self.model_name is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.new_deviation_number is not None:
                                            return True

                                        if self.physical_layer_interface_module_type is not None:
                                            return True

                                        if self.redundancystate is not None:
                                            return True

                                        if self.serial_number is not None:
                                            return True

                                        if self.software_revision is not None:
                                            return True

                                        if self.unique_id is not None:
                                            return True

                                        if self.unrecognized_fru is not None:
                                            return True

                                        if self.vendor_type is not None:
                                            return True

                                        if self.xr_scoped is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvBasicBag']['meta_info']


                                class InvEepromInfo(object):
                                    """
                                    Inventory EDM EEPROM Information Bag
                                    
                                    .. attribute:: description
                                    
                                    	A textual description of physical entity
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: eeprom
                                    
                                    	EEPROM data not from hex data
                                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom>`
                                    
                                    .. attribute:: has_eeprom
                                    
                                    	use eeprom instead of opaque data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inv_card_type
                                    
                                    	Inventory card type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: opaque_data
                                    
                                    	EEPROM hex data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: opaque_data_size
                                    
                                    	size of the EEPROM hex data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom()
                                        self.eeprom.parent = self
                                        self.has_eeprom = None
                                        self.inv_card_type = None
                                        self.opaque_data = None
                                        self.opaque_data_size = None


                                    class Eeprom(object):
                                        """
                                        EEPROM data not from hex data
                                        
                                        .. attribute:: asset_alias
                                        
                                        	Asset Alias
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: asset_id
                                        
                                        	Asset ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address1
                                        
                                        	Base Mac Address #1
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address2
                                        
                                        	Base Mac Address #2
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address3
                                        
                                        	Base Mac Address #3
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: base_mac_address4
                                        
                                        	Base Mac Address #4
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_checksum
                                        
                                        	Block Checksum
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_count
                                        
                                        	Block Count
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_length
                                        
                                        	Block Length
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_signature
                                        
                                        	Block Signature
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: block_version
                                        
                                        	Block Version
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: chassis_sid
                                        
                                        	Chassis serial number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: clei
                                        
                                        	Common Language Equipment Identifier (CLEI) code
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: controller_family
                                        
                                        	Controller family
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: controller_type
                                        
                                        	Controller type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: description
                                        
                                        	A textual description of physical entity
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num1
                                        
                                        	Deviation Number # 1
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num2
                                        
                                        	Deviation Number # 2
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num3
                                        
                                        	Deviation Number # 3
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num4
                                        
                                        	Deviation Number # 4
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num5
                                        
                                        	Deviation Number # 5
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num6
                                        
                                        	Deviation Number # 6
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: dev_num7
                                        
                                        	Deviation Number # 7
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: eci
                                        
                                        	Equipment Catalog Item (ECI) number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: eeprom_size
                                        
                                        	EEPROM Size
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: engineer_use
                                        
                                        	Engineer Use
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: fru_major_type
                                        
                                        	FRU Major Type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: fru_minor_type
                                        
                                        	FRU Minor Type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: hw_version
                                        
                                        	Hardware Version
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: hwid
                                        
                                        	Hardware Revision
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: idprom_format_rev
                                        
                                        	IDPROM Format Revision
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size1
                                        
                                        	Mac Address Block Size #1
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size2
                                        
                                        	Mac Address Block Size #2
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size3
                                        
                                        	Mac Address Block Size #3
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mac_add_blk_size4
                                        
                                        	Mac Address Block Size #4
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: manu_test_data
                                        
                                        	Manufacturing Test Data
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mfg_bits
                                        
                                        	MFG Bits
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: mfg_deviation
                                        
                                        	MFG Deviation
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: oem_string
                                        
                                        	OEM String
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: part_number
                                        
                                        	Part Number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: part_revision
                                        
                                        	Part Revision
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pca_num
                                        
                                        	PCA number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pcavid
                                        
                                        	PCA revision ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pcb_serial_num
                                        
                                        	PCB Serial Number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: pid
                                        
                                        	Product ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: power_consumption
                                        
                                        	Power Consumption
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: power_supply_type
                                        
                                        	Power Supply Type
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: product_id
                                        
                                        	Product ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: rma
                                        
                                        	RMA Data
                                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom.Rma>`
                                        
                                        .. attribute:: rma_code
                                        
                                        	RMA Code
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: serial_number
                                        
                                        	Serial Number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: snmpoid
                                        
                                        	SNMP OID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: top_assem_part_num
                                        
                                        	Top assembly part number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: top_assem_vid
                                        
                                        	Top assembly revision number
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: udi_description
                                        
                                        	UDI description
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: udi_name
                                        
                                        	UDI name
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        .. attribute:: vid
                                        
                                        	Version ID
                                        	**type**\:  str
                                        
                                        	**length:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'invmgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asset_alias = None
                                            self.asset_id = None
                                            self.base_mac_address1 = None
                                            self.base_mac_address2 = None
                                            self.base_mac_address3 = None
                                            self.base_mac_address4 = None
                                            self.block_checksum = None
                                            self.block_count = None
                                            self.block_length = None
                                            self.block_signature = None
                                            self.block_version = None
                                            self.chassis_sid = None
                                            self.clei = None
                                            self.controller_family = None
                                            self.controller_type = None
                                            self.description = None
                                            self.dev_num1 = None
                                            self.dev_num2 = None
                                            self.dev_num3 = None
                                            self.dev_num4 = None
                                            self.dev_num5 = None
                                            self.dev_num6 = None
                                            self.dev_num7 = None
                                            self.eci = None
                                            self.eeprom_size = None
                                            self.engineer_use = None
                                            self.fru_major_type = None
                                            self.fru_minor_type = None
                                            self.hw_version = None
                                            self.hwid = None
                                            self.idprom_format_rev = None
                                            self.mac_add_blk_size1 = None
                                            self.mac_add_blk_size2 = None
                                            self.mac_add_blk_size3 = None
                                            self.mac_add_blk_size4 = None
                                            self.manu_test_data = None
                                            self.mfg_bits = None
                                            self.mfg_deviation = None
                                            self.oem_string = None
                                            self.part_number = None
                                            self.part_revision = None
                                            self.pca_num = None
                                            self.pcavid = None
                                            self.pcb_serial_num = None
                                            self.pid = None
                                            self.power_consumption = None
                                            self.power_supply_type = None
                                            self.product_id = None
                                            self.rma = Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom.Rma()
                                            self.rma.parent = self
                                            self.rma_code = None
                                            self.serial_number = None
                                            self.snmpoid = None
                                            self.top_assem_part_num = None
                                            self.top_assem_vid = None
                                            self.udi_description = None
                                            self.udi_name = None
                                            self.vid = None


                                        class Rma(object):
                                            """
                                            RMA Data
                                            
                                            .. attribute:: rma_history
                                            
                                            	RMA history
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: rma_number
                                            
                                            	RMA tracking number format is N\-N\-N
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            .. attribute:: test_history
                                            
                                            	Test history
                                            	**type**\:  str
                                            
                                            	**length:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'invmgr-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.rma_history = None
                                                self.rma_number = None
                                                self.test_history = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rma_history is not None:
                                                    return True

                                                if self.rma_number is not None:
                                                    return True

                                                if self.test_history is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asset_alias is not None:
                                                return True

                                            if self.asset_id is not None:
                                                return True

                                            if self.base_mac_address1 is not None:
                                                return True

                                            if self.base_mac_address2 is not None:
                                                return True

                                            if self.base_mac_address3 is not None:
                                                return True

                                            if self.base_mac_address4 is not None:
                                                return True

                                            if self.block_checksum is not None:
                                                return True

                                            if self.block_count is not None:
                                                return True

                                            if self.block_length is not None:
                                                return True

                                            if self.block_signature is not None:
                                                return True

                                            if self.block_version is not None:
                                                return True

                                            if self.chassis_sid is not None:
                                                return True

                                            if self.clei is not None:
                                                return True

                                            if self.controller_family is not None:
                                                return True

                                            if self.controller_type is not None:
                                                return True

                                            if self.description is not None:
                                                return True

                                            if self.dev_num1 is not None:
                                                return True

                                            if self.dev_num2 is not None:
                                                return True

                                            if self.dev_num3 is not None:
                                                return True

                                            if self.dev_num4 is not None:
                                                return True

                                            if self.dev_num5 is not None:
                                                return True

                                            if self.dev_num6 is not None:
                                                return True

                                            if self.dev_num7 is not None:
                                                return True

                                            if self.eci is not None:
                                                return True

                                            if self.eeprom_size is not None:
                                                return True

                                            if self.engineer_use is not None:
                                                return True

                                            if self.fru_major_type is not None:
                                                return True

                                            if self.fru_minor_type is not None:
                                                return True

                                            if self.hw_version is not None:
                                                return True

                                            if self.hwid is not None:
                                                return True

                                            if self.idprom_format_rev is not None:
                                                return True

                                            if self.mac_add_blk_size1 is not None:
                                                return True

                                            if self.mac_add_blk_size2 is not None:
                                                return True

                                            if self.mac_add_blk_size3 is not None:
                                                return True

                                            if self.mac_add_blk_size4 is not None:
                                                return True

                                            if self.manu_test_data is not None:
                                                return True

                                            if self.mfg_bits is not None:
                                                return True

                                            if self.mfg_deviation is not None:
                                                return True

                                            if self.oem_string is not None:
                                                return True

                                            if self.part_number is not None:
                                                return True

                                            if self.part_revision is not None:
                                                return True

                                            if self.pca_num is not None:
                                                return True

                                            if self.pcavid is not None:
                                                return True

                                            if self.pcb_serial_num is not None:
                                                return True

                                            if self.pid is not None:
                                                return True

                                            if self.power_consumption is not None:
                                                return True

                                            if self.power_supply_type is not None:
                                                return True

                                            if self.product_id is not None:
                                                return True

                                            if self.rma is not None and self.rma._has_data():
                                                return True

                                            if self.rma_code is not None:
                                                return True

                                            if self.serial_number is not None:
                                                return True

                                            if self.snmpoid is not None:
                                                return True

                                            if self.top_assem_part_num is not None:
                                                return True

                                            if self.top_assem_vid is not None:
                                                return True

                                            if self.udi_description is not None:
                                                return True

                                            if self.udi_name is not None:
                                                return True

                                            if self.vid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo.Eeprom']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.eeprom is not None and self.eeprom._has_data():
                                            return True

                                        if self.has_eeprom is not None:
                                            return True

                                        if self.inv_card_type is not None:
                                            return True

                                        if self.opaque_data is not None:
                                            return True

                                        if self.opaque_data_size is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes.InvEepromInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                        return True

                                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                        return True

                                    if self.fru_info is not None and self.fru_info._has_data():
                                        return True

                                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                        return True

                                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                        return True

                                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                        return True

                                    if self.module_done is not None:
                                        return True

                                    if self.node_id is not None:
                                        return True

                                    if self.pwg_info is not None and self.pwg_info._has_data():
                                        return True

                                    if self.threshold is not None and self.threshold._has_data():
                                        return True

                                    if self.vm_done is not None:
                                        return True

                                    if self.vm_node_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1.Attributes']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.name is None:
                                    raise YPYModelError('Key property name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi1[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.name is not None:
                                    return True

                                if self.attributes is not None and self.attributes._has_data():
                                    return True

                                if self.tsi2s is not None and self.tsi2s._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S.Tsi1']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:tsi1s'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.tsi1 is not None:
                                for child_ref in self.tsi1:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Tsi1S']['meta_info']


                    class Attributes(object):
                        """
                        Attributes
                        
                        .. attribute:: env_sensor_info
                        
                        	Environment sensor info
                        	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfo>`
                        
                        .. attribute:: env_sensor_info_xml
                        
                        	Environment sensor info XML
                        	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfoXml>`
                        
                        .. attribute:: fru_info
                        
                        	Inventory EDM FRU info
                        	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.FruInfo>`
                        
                        .. attribute:: inv_asset_bag
                        
                        	Inventory Asset Bag
                        	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.InvAssetBag>`
                        
                        .. attribute:: inv_basic_bag
                        
                        	Inventory Basic Bag
                        	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.InvBasicBag>`
                        
                        .. attribute:: inv_eeprom_info
                        
                        	Inventory EDM EEPROM Information Bag
                        	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.InvEepromInfo>`
                        
                        .. attribute:: module_done
                        
                        	Inventory EDM Module Done Tuple
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**default value**\: 1
                        
                        .. attribute:: node_id
                        
                        	Node ID Tuple
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwg_info
                        
                        	Inventory EDM PWG info
                        	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.PwgInfo>`
                        
                        .. attribute:: threshold
                        
                        	Threshold
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold>`
                        
                        .. attribute:: vm_done
                        
                        	VM Done Tuple
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: vm_node_id
                        
                        	VM Node ID Tuple
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.env_sensor_info = Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfo()
                            self.env_sensor_info.parent = self
                            self.env_sensor_info_xml = Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfoXml()
                            self.env_sensor_info_xml.parent = self
                            self.fru_info = Inventory.Racks.Rack.Fantray.Slot.Attributes.FruInfo()
                            self.fru_info.parent = self
                            self.inv_asset_bag = Inventory.Racks.Rack.Fantray.Slot.Attributes.InvAssetBag()
                            self.inv_asset_bag.parent = self
                            self.inv_basic_bag = Inventory.Racks.Rack.Fantray.Slot.Attributes.InvBasicBag()
                            self.inv_basic_bag.parent = self
                            self.inv_eeprom_info = Inventory.Racks.Rack.Fantray.Slot.Attributes.InvEepromInfo()
                            self.inv_eeprom_info.parent = self
                            self.module_done = None
                            self.node_id = None
                            self.pwg_info = Inventory.Racks.Rack.Fantray.Slot.Attributes.PwgInfo()
                            self.pwg_info.parent = self
                            self.threshold = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold()
                            self.threshold.parent = self
                            self.vm_done = None
                            self.vm_node_id = None


                        class EnvSensorInfo(object):
                            """
                            Environment sensor info
                            
                            .. attribute:: age_time_stamp
                            
                            	Age of the sensor value; set to the current time if directly access the value from sensor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: alarm_type
                            
                            	Indicates threshold violation
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: data_type
                            
                            	Sensor data type enums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: device_description
                            
                            	Device Name
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: device_id
                            
                            	Identifier for this device
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: field_validity_bitmap
                            
                            	Sensor valid bitmap
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: precision
                            
                            	Sensor precision range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: scale
                            
                            	Sensor scale enums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status
                            
                            	Sensor operation state enums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: units
                            
                            	Units of variable being read
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: update_rate
                            
                            	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: value
                            
                            	Current reading of sensor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.age_time_stamp = None
                                self.alarm_type = None
                                self.data_type = None
                                self.device_description = None
                                self.device_id = None
                                self.field_validity_bitmap = None
                                self.precision = None
                                self.scale = None
                                self.status = None
                                self.units = None
                                self.update_rate = None
                                self.value = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.age_time_stamp is not None:
                                    return True

                                if self.alarm_type is not None:
                                    return True

                                if self.data_type is not None:
                                    return True

                                if self.device_description is not None:
                                    return True

                                if self.device_id is not None:
                                    return True

                                if self.field_validity_bitmap is not None:
                                    return True

                                if self.precision is not None:
                                    return True

                                if self.scale is not None:
                                    return True

                                if self.status is not None:
                                    return True

                                if self.units is not None:
                                    return True

                                if self.update_rate is not None:
                                    return True

                                if self.value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfo']['meta_info']


                        class PwgInfo(object):
                            """
                            Inventory EDM PWG info
                            
                            .. attribute:: power_group_available_current
                            
                            	available current
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_group_drawn_current
                            
                            	drawn current
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_group_power_units
                            
                            	power units
                            	**type**\:  str
                            
                            .. attribute:: power_group_redundancy_mode
                            
                            	redundancy mode
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.power_group_available_current = None
                                self.power_group_drawn_current = None
                                self.power_group_power_units = None
                                self.power_group_redundancy_mode = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.power_group_available_current is not None:
                                    return True

                                if self.power_group_drawn_current is not None:
                                    return True

                                if self.power_group_power_units is not None:
                                    return True

                                if self.power_group_redundancy_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.PwgInfo']['meta_info']


                        class EnvSensorInfoXml(object):
                            """
                            Environment sensor info XML
                            
                            .. attribute:: data_type
                            
                            	Sensor data type
                            	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                            
                            .. attribute:: description
                            
                            	Device Name
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: status
                            
                            	Sensor operation state
                            	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                            
                            .. attribute:: threshold
                            
                            	Threshold information
                            	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfoXml.Threshold>`
                            
                            .. attribute:: units
                            
                            	Units of variable being read
                            	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                            
                            .. attribute:: update_rate
                            
                            	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: value
                            
                            	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.data_type = None
                                self.description = None
                                self.status = None
                                self.threshold = Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfoXml.Threshold()
                                self.threshold.parent = self
                                self.units = None
                                self.update_rate = None
                                self.value = None


                            class Threshold(object):
                                """
                                Threshold information
                                
                                .. attribute:: threshold_array
                                
                                	Array of threshold
                                	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.threshold_array = YList()
                                    self.threshold_array.parent = self
                                    self.threshold_array.name = 'threshold_array'


                                class ThresholdArray(object):
                                    """
                                    Array of threshold
                                    
                                    .. attribute:: threshold_name
                                    
                                    	Threshold name
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_name = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_name is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.threshold_array is not None:
                                        for child_ref in self.threshold_array:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.data_type is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.status is not None:
                                    return True

                                if self.threshold is not None and self.threshold._has_data():
                                    return True

                                if self.units is not None:
                                    return True

                                if self.update_rate is not None:
                                    return True

                                if self.value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.EnvSensorInfoXml']['meta_info']


                        class InvAssetBag(object):
                            """
                            Inventory Asset Bag
                            
                            .. attribute:: manufacturer_assembly_number
                            
                            	Manufacture Assembly number
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_assembly_revision
                            
                            	Manufacture assembly revision
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_common_language_equipment_identifier
                            
                            	Common Language Equipment           Identifier number
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_firmware_identifier
                            
                            	
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: manufacturer_software_identifier
                            
                            	
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: original_equipment_manufacturer_string
                            
                            	String containing OEM information           if applicable
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: part_number
                            
                            	
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.manufacturer_assembly_number = None
                                self.manufacturer_assembly_revision = None
                                self.manufacturer_common_language_equipment_identifier = None
                                self.manufacturer_firmware_identifier = None
                                self.manufacturer_software_identifier = None
                                self.original_equipment_manufacturer_string = None
                                self.part_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.manufacturer_assembly_number is not None:
                                    return True

                                if self.manufacturer_assembly_revision is not None:
                                    return True

                                if self.manufacturer_common_language_equipment_identifier is not None:
                                    return True

                                if self.manufacturer_firmware_identifier is not None:
                                    return True

                                if self.manufacturer_software_identifier is not None:
                                    return True

                                if self.original_equipment_manufacturer_string is not None:
                                    return True

                                if self.part_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.InvAssetBag']['meta_info']


                        class Threshold(object):
                            """
                            Threshold
                            
                            .. attribute:: critical_hi
                            
                            	Critical High
                            	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalHi>`
                            
                            .. attribute:: critical_lo
                            
                            	Critical Low
                            	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalLo>`
                            
                            .. attribute:: major_hi
                            
                            	Major High
                            	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorHi>`
                            
                            .. attribute:: major_lo
                            
                            	Major Low
                            	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorLo>`
                            
                            .. attribute:: minor_hi
                            
                            	Minor High
                            	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorHi>`
                            
                            .. attribute:: minor_lo
                            
                            	Minor Low
                            	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorLo>`
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.critical_hi = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalHi()
                                self.critical_hi.parent = self
                                self.critical_lo = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalLo()
                                self.critical_lo.parent = self
                                self.major_hi = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorHi()
                                self.major_hi.parent = self
                                self.major_lo = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorLo()
                                self.major_lo.parent = self
                                self.minor_hi = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorHi()
                                self.minor_hi.parent = self
                                self.minor_lo = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorLo()
                                self.minor_lo.parent = self


                            class MajorLo(object):
                                """
                                Major Low
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorLo.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorLo.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorLo']['meta_info']


                            class CriticalHi(object):
                                """
                                Critical High
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalHi.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalHi.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalHi']['meta_info']


                            class MinorHi(object):
                                """
                                Minor High
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorHi.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorHi.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorHi']['meta_info']


                            class MajorHi(object):
                                """
                                Major High
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorHi.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorHi.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MajorHi']['meta_info']


                            class CriticalLo(object):
                                """
                                Critical Low
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalLo.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalLo.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.CriticalLo']['meta_info']


                            class MinorLo(object):
                                """
                                Minor Low
                                
                                .. attribute:: thresh_bag
                                
                                	Environment threshold info
                                	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorLo.ThreshBag>`
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.thresh_bag = Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorLo.ThreshBag()
                                    self.thresh_bag.parent = self


                                class ThreshBag(object):
                                    """
                                    Environment threshold info
                                    
                                    .. attribute:: threshold_evaluation
                                    
                                    	Indicates the result of the most recent evaluation of the thresholD
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_notification_enabled
                                    
                                    	Indicates whether or not a notification should result, in case of threshold violation
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold_relation
                                    
                                    	Indicates relation between sensor value and threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_severity
                                    
                                    	Indicates minor, major, critical severities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: threshold_value
                                    
                                    	Value of the configured threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.threshold_evaluation = None
                                        self.threshold_notification_enabled = None
                                        self.threshold_relation = None
                                        self.threshold_severity = None
                                        self.threshold_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.threshold_evaluation is not None:
                                            return True

                                        if self.threshold_notification_enabled is not None:
                                            return True

                                        if self.threshold_relation is not None:
                                            return True

                                        if self.threshold_severity is not None:
                                            return True

                                        if self.threshold_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.thresh_bag is not None and self.thresh_bag._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold.MinorLo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.critical_hi is not None and self.critical_hi._has_data():
                                    return True

                                if self.critical_lo is not None and self.critical_lo._has_data():
                                    return True

                                if self.major_hi is not None and self.major_hi._has_data():
                                    return True

                                if self.major_lo is not None and self.major_lo._has_data():
                                    return True

                                if self.minor_hi is not None and self.minor_hi._has_data():
                                    return True

                                if self.minor_lo is not None and self.minor_lo._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.Threshold']['meta_info']


                        class FruInfo(object):
                            """
                            Inventory EDM FRU info
                            
                            .. attribute:: card_administrative_state
                            
                            	card admin state\: shutdown or not
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: card_monitor_state
                            
                            	card is monitored by a manager or left unmonitored
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: card_operational_state
                            
                            	card operation state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: card_reset_reason
                            
                            	card reset reason enum
                            	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                            
                            .. attribute:: card_up_time
                            
                            	card up time
                            	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.FruInfo.CardUpTime>`
                            
                            .. attribute:: last_operational_state_change
                            
                            	last card oper change state
                            	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.FruInfo.LastOperationalStateChange>`
                            
                            .. attribute:: power_administrative_state
                            
                            	power admin state\: up or down
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_current_measurement
                            
                            	power current\: not implemented
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: power_operational_state
                            
                            	Power operation state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.card_administrative_state = None
                                self.card_monitor_state = None
                                self.card_operational_state = None
                                self.card_reset_reason = None
                                self.card_up_time = Inventory.Racks.Rack.Fantray.Slot.Attributes.FruInfo.CardUpTime()
                                self.card_up_time.parent = self
                                self.last_operational_state_change = Inventory.Racks.Rack.Fantray.Slot.Attributes.FruInfo.LastOperationalStateChange()
                                self.last_operational_state_change.parent = self
                                self.power_administrative_state = None
                                self.power_current_measurement = None
                                self.power_operational_state = None


                            class LastOperationalStateChange(object):
                                """
                                last card oper change state
                                
                                .. attribute:: time_in_nano_seconds
                                
                                	Time Value in Nano\-seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: time_in_seconds
                                
                                	Time Value in Seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.time_in_nano_seconds = None
                                    self.time_in_seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.time_in_nano_seconds is not None:
                                        return True

                                    if self.time_in_seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                            class CardUpTime(object):
                                """
                                card up time
                                
                                .. attribute:: time_in_nano_seconds
                                
                                	Time Value in Nano\-seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: time_in_seconds
                                
                                	Time Value in Seconds
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.time_in_nano_seconds = None
                                    self.time_in_seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.time_in_nano_seconds is not None:
                                        return True

                                    if self.time_in_seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.FruInfo.CardUpTime']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.card_administrative_state is not None:
                                    return True

                                if self.card_monitor_state is not None:
                                    return True

                                if self.card_operational_state is not None:
                                    return True

                                if self.card_reset_reason is not None:
                                    return True

                                if self.card_up_time is not None and self.card_up_time._has_data():
                                    return True

                                if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                                    return True

                                if self.power_administrative_state is not None:
                                    return True

                                if self.power_current_measurement is not None:
                                    return True

                                if self.power_operational_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.FruInfo']['meta_info']


                        class InvBasicBag(object):
                            """
                            Inventory Basic Bag
                            
                            .. attribute:: alias
                            
                            	useful for storing an entity alias 
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: asset_id_str
                            
                            	asset Identification string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: asset_identification
                            
                            	asset Identification
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ceport
                            
                            	1 if ce port found, 0 if not
                            	**type**\:  bool
                            
                            .. attribute:: chip_hardware_revision
                            
                            	chip module hw revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: composite_class_code
                            
                            	Major&minor class of the entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: description
                            
                            	describes in user\-readable terms       what the entity in question does
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: environmental_monitor_path
                            
                            	sysdb name of sensor in the envmon EDM
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: firmware_revision
                            
                            	firmware revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: group_flag
                            
                            	indicates if this entity is group       or not
                            	**type**\:  bool
                            
                            .. attribute:: hardware_revision
                            
                            	hw revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: is_field_replaceable_unit
                            
                            	1 if Field Replaceable Unit 0, if not
                            	**type**\:  bool
                            
                            .. attribute:: manufacturer_asset_tags
                            
                            	Manufacture Asset Tags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: manufacturer_name
                            
                            	manufacturer's name
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: memory_size
                            
                            	Size of memory associated with       the entity where applicable
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: model_name
                            
                            	model name
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: name
                            
                            	name string for the entity
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: new_deviation_number
                            
                            	integer value for New Deviation Number 0x88
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: physical_layer_interface_module_type
                            
                            	integer value for plim type if     applicable to this entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: redundancystate
                            
                            	integer value for Redundancy State if     applicable to this entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: serial_number
                            
                            	serial number
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: software_revision
                            
                            	software revision string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: unique_id
                            
                            	Unique id for an entity
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: unrecognized_fru
                            
                            	1 if UnrecognizedFRU and 0 for recognizedFRU
                            	**type**\:  bool
                            
                            .. attribute:: vendor_type
                            
                            	maps to the vendor OID string
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: xr_scoped
                            
                            	1 if xr scoped, 0 if not
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.alias = None
                                self.asset_id_str = None
                                self.asset_identification = None
                                self.ceport = None
                                self.chip_hardware_revision = None
                                self.composite_class_code = None
                                self.description = None
                                self.environmental_monitor_path = None
                                self.firmware_revision = None
                                self.group_flag = None
                                self.hardware_revision = None
                                self.is_field_replaceable_unit = None
                                self.manufacturer_asset_tags = None
                                self.manufacturer_name = None
                                self.memory_size = None
                                self.model_name = None
                                self.name = None
                                self.new_deviation_number = None
                                self.physical_layer_interface_module_type = None
                                self.redundancystate = None
                                self.serial_number = None
                                self.software_revision = None
                                self.unique_id = None
                                self.unrecognized_fru = None
                                self.vendor_type = None
                                self.xr_scoped = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.alias is not None:
                                    return True

                                if self.asset_id_str is not None:
                                    return True

                                if self.asset_identification is not None:
                                    return True

                                if self.ceport is not None:
                                    return True

                                if self.chip_hardware_revision is not None:
                                    return True

                                if self.composite_class_code is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.environmental_monitor_path is not None:
                                    return True

                                if self.firmware_revision is not None:
                                    return True

                                if self.group_flag is not None:
                                    return True

                                if self.hardware_revision is not None:
                                    return True

                                if self.is_field_replaceable_unit is not None:
                                    return True

                                if self.manufacturer_asset_tags is not None:
                                    return True

                                if self.manufacturer_name is not None:
                                    return True

                                if self.memory_size is not None:
                                    return True

                                if self.model_name is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.new_deviation_number is not None:
                                    return True

                                if self.physical_layer_interface_module_type is not None:
                                    return True

                                if self.redundancystate is not None:
                                    return True

                                if self.serial_number is not None:
                                    return True

                                if self.software_revision is not None:
                                    return True

                                if self.unique_id is not None:
                                    return True

                                if self.unrecognized_fru is not None:
                                    return True

                                if self.vendor_type is not None:
                                    return True

                                if self.xr_scoped is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.InvBasicBag']['meta_info']


                        class InvEepromInfo(object):
                            """
                            Inventory EDM EEPROM Information Bag
                            
                            .. attribute:: description
                            
                            	A textual description of physical entity
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: eeprom
                            
                            	EEPROM data not from hex data
                            	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.InvEepromInfo.Eeprom>`
                            
                            .. attribute:: has_eeprom
                            
                            	use eeprom instead of opaque data
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inv_card_type
                            
                            	Inventory card type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: opaque_data
                            
                            	EEPROM hex data
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: opaque_data_size
                            
                            	size of the EEPROM hex data
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.eeprom = Inventory.Racks.Rack.Fantray.Slot.Attributes.InvEepromInfo.Eeprom()
                                self.eeprom.parent = self
                                self.has_eeprom = None
                                self.inv_card_type = None
                                self.opaque_data = None
                                self.opaque_data_size = None


                            class Eeprom(object):
                                """
                                EEPROM data not from hex data
                                
                                .. attribute:: asset_alias
                                
                                	Asset Alias
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: asset_id
                                
                                	Asset ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address1
                                
                                	Base Mac Address #1
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address2
                                
                                	Base Mac Address #2
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address3
                                
                                	Base Mac Address #3
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: base_mac_address4
                                
                                	Base Mac Address #4
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_checksum
                                
                                	Block Checksum
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_count
                                
                                	Block Count
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_length
                                
                                	Block Length
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_signature
                                
                                	Block Signature
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: block_version
                                
                                	Block Version
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: chassis_sid
                                
                                	Chassis serial number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: clei
                                
                                	Common Language Equipment Identifier (CLEI) code
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: controller_family
                                
                                	Controller family
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: controller_type
                                
                                	Controller type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: description
                                
                                	A textual description of physical entity
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num1
                                
                                	Deviation Number # 1
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num2
                                
                                	Deviation Number # 2
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num3
                                
                                	Deviation Number # 3
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num4
                                
                                	Deviation Number # 4
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num5
                                
                                	Deviation Number # 5
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num6
                                
                                	Deviation Number # 6
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: dev_num7
                                
                                	Deviation Number # 7
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: eci
                                
                                	Equipment Catalog Item (ECI) number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: eeprom_size
                                
                                	EEPROM Size
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: engineer_use
                                
                                	Engineer Use
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: fru_major_type
                                
                                	FRU Major Type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: fru_minor_type
                                
                                	FRU Minor Type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: hw_version
                                
                                	Hardware Version
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: hwid
                                
                                	Hardware Revision
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: idprom_format_rev
                                
                                	IDPROM Format Revision
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size1
                                
                                	Mac Address Block Size #1
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size2
                                
                                	Mac Address Block Size #2
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size3
                                
                                	Mac Address Block Size #3
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mac_add_blk_size4
                                
                                	Mac Address Block Size #4
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: manu_test_data
                                
                                	Manufacturing Test Data
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mfg_bits
                                
                                	MFG Bits
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: mfg_deviation
                                
                                	MFG Deviation
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: oem_string
                                
                                	OEM String
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: part_number
                                
                                	Part Number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: part_revision
                                
                                	Part Revision
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pca_num
                                
                                	PCA number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pcavid
                                
                                	PCA revision ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pcb_serial_num
                                
                                	PCB Serial Number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: pid
                                
                                	Product ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: power_consumption
                                
                                	Power Consumption
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: power_supply_type
                                
                                	Power Supply Type
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: product_id
                                
                                	Product ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: rma
                                
                                	RMA Data
                                	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Fantray.Slot.Attributes.InvEepromInfo.Eeprom.Rma>`
                                
                                .. attribute:: rma_code
                                
                                	RMA Code
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: serial_number
                                
                                	Serial Number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: snmpoid
                                
                                	SNMP OID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: top_assem_part_num
                                
                                	Top assembly part number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: top_assem_vid
                                
                                	Top assembly revision number
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: udi_description
                                
                                	UDI description
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: udi_name
                                
                                	UDI name
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                .. attribute:: vid
                                
                                	Version ID
                                	**type**\:  str
                                
                                	**length:** 0..255
                                
                                

                                """

                                _prefix = 'invmgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.asset_alias = None
                                    self.asset_id = None
                                    self.base_mac_address1 = None
                                    self.base_mac_address2 = None
                                    self.base_mac_address3 = None
                                    self.base_mac_address4 = None
                                    self.block_checksum = None
                                    self.block_count = None
                                    self.block_length = None
                                    self.block_signature = None
                                    self.block_version = None
                                    self.chassis_sid = None
                                    self.clei = None
                                    self.controller_family = None
                                    self.controller_type = None
                                    self.description = None
                                    self.dev_num1 = None
                                    self.dev_num2 = None
                                    self.dev_num3 = None
                                    self.dev_num4 = None
                                    self.dev_num5 = None
                                    self.dev_num6 = None
                                    self.dev_num7 = None
                                    self.eci = None
                                    self.eeprom_size = None
                                    self.engineer_use = None
                                    self.fru_major_type = None
                                    self.fru_minor_type = None
                                    self.hw_version = None
                                    self.hwid = None
                                    self.idprom_format_rev = None
                                    self.mac_add_blk_size1 = None
                                    self.mac_add_blk_size2 = None
                                    self.mac_add_blk_size3 = None
                                    self.mac_add_blk_size4 = None
                                    self.manu_test_data = None
                                    self.mfg_bits = None
                                    self.mfg_deviation = None
                                    self.oem_string = None
                                    self.part_number = None
                                    self.part_revision = None
                                    self.pca_num = None
                                    self.pcavid = None
                                    self.pcb_serial_num = None
                                    self.pid = None
                                    self.power_consumption = None
                                    self.power_supply_type = None
                                    self.product_id = None
                                    self.rma = Inventory.Racks.Rack.Fantray.Slot.Attributes.InvEepromInfo.Eeprom.Rma()
                                    self.rma.parent = self
                                    self.rma_code = None
                                    self.serial_number = None
                                    self.snmpoid = None
                                    self.top_assem_part_num = None
                                    self.top_assem_vid = None
                                    self.udi_description = None
                                    self.udi_name = None
                                    self.vid = None


                                class Rma(object):
                                    """
                                    RMA Data
                                    
                                    .. attribute:: rma_history
                                    
                                    	RMA history
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: rma_number
                                    
                                    	RMA tracking number format is N\-N\-N
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    .. attribute:: test_history
                                    
                                    	Test history
                                    	**type**\:  str
                                    
                                    	**length:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'invmgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.rma_history = None
                                        self.rma_number = None
                                        self.test_history = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rma_history is not None:
                                            return True

                                        if self.rma_number is not None:
                                            return True

                                        if self.test_history is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.asset_alias is not None:
                                        return True

                                    if self.asset_id is not None:
                                        return True

                                    if self.base_mac_address1 is not None:
                                        return True

                                    if self.base_mac_address2 is not None:
                                        return True

                                    if self.base_mac_address3 is not None:
                                        return True

                                    if self.base_mac_address4 is not None:
                                        return True

                                    if self.block_checksum is not None:
                                        return True

                                    if self.block_count is not None:
                                        return True

                                    if self.block_length is not None:
                                        return True

                                    if self.block_signature is not None:
                                        return True

                                    if self.block_version is not None:
                                        return True

                                    if self.chassis_sid is not None:
                                        return True

                                    if self.clei is not None:
                                        return True

                                    if self.controller_family is not None:
                                        return True

                                    if self.controller_type is not None:
                                        return True

                                    if self.description is not None:
                                        return True

                                    if self.dev_num1 is not None:
                                        return True

                                    if self.dev_num2 is not None:
                                        return True

                                    if self.dev_num3 is not None:
                                        return True

                                    if self.dev_num4 is not None:
                                        return True

                                    if self.dev_num5 is not None:
                                        return True

                                    if self.dev_num6 is not None:
                                        return True

                                    if self.dev_num7 is not None:
                                        return True

                                    if self.eci is not None:
                                        return True

                                    if self.eeprom_size is not None:
                                        return True

                                    if self.engineer_use is not None:
                                        return True

                                    if self.fru_major_type is not None:
                                        return True

                                    if self.fru_minor_type is not None:
                                        return True

                                    if self.hw_version is not None:
                                        return True

                                    if self.hwid is not None:
                                        return True

                                    if self.idprom_format_rev is not None:
                                        return True

                                    if self.mac_add_blk_size1 is not None:
                                        return True

                                    if self.mac_add_blk_size2 is not None:
                                        return True

                                    if self.mac_add_blk_size3 is not None:
                                        return True

                                    if self.mac_add_blk_size4 is not None:
                                        return True

                                    if self.manu_test_data is not None:
                                        return True

                                    if self.mfg_bits is not None:
                                        return True

                                    if self.mfg_deviation is not None:
                                        return True

                                    if self.oem_string is not None:
                                        return True

                                    if self.part_number is not None:
                                        return True

                                    if self.part_revision is not None:
                                        return True

                                    if self.pca_num is not None:
                                        return True

                                    if self.pcavid is not None:
                                        return True

                                    if self.pcb_serial_num is not None:
                                        return True

                                    if self.pid is not None:
                                        return True

                                    if self.power_consumption is not None:
                                        return True

                                    if self.power_supply_type is not None:
                                        return True

                                    if self.product_id is not None:
                                        return True

                                    if self.rma is not None and self.rma._has_data():
                                        return True

                                    if self.rma_code is not None:
                                        return True

                                    if self.serial_number is not None:
                                        return True

                                    if self.snmpoid is not None:
                                        return True

                                    if self.top_assem_part_num is not None:
                                        return True

                                    if self.top_assem_vid is not None:
                                        return True

                                    if self.udi_description is not None:
                                        return True

                                    if self.udi_name is not None:
                                        return True

                                    if self.vid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                    return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.InvEepromInfo.Eeprom']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.eeprom is not None and self.eeprom._has_data():
                                    return True

                                if self.has_eeprom is not None:
                                    return True

                                if self.inv_card_type is not None:
                                    return True

                                if self.opaque_data is not None:
                                    return True

                                if self.opaque_data_size is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes.InvEepromInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                                return True

                            if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                                return True

                            if self.fru_info is not None and self.fru_info._has_data():
                                return True

                            if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                                return True

                            if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                                return True

                            if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                                return True

                            if self.module_done is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.pwg_info is not None and self.pwg_info._has_data():
                                return True

                            if self.threshold is not None and self.threshold._has_data():
                                return True

                            if self.vm_done is not None:
                                return True

                            if self.vm_node_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot.Attributes']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.name is None:
                            raise YPYModelError('Key property name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:slot[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.name is not None:
                            return True

                        if self.attributes is not None and self.attributes._has_data():
                            return True

                        if self.tsi1s is not None and self.tsi1s._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Fantray.Slot']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fantray'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.slot is not None:
                        for child_ref in self.slot:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                    return meta._meta_table['Inventory.Racks.Rack.Fantray']['meta_info']


            class Attributes(object):
                """
                Attributes
                
                .. attribute:: env_sensor_info
                
                	Environment sensor info
                	**type**\:   :py:class:`EnvSensorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.EnvSensorInfo>`
                
                .. attribute:: env_sensor_info_xml
                
                	Environment sensor info XML
                	**type**\:   :py:class:`EnvSensorInfoXml <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.EnvSensorInfoXml>`
                
                .. attribute:: fru_info
                
                	Inventory EDM FRU info
                	**type**\:   :py:class:`FruInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.FruInfo>`
                
                .. attribute:: inv_asset_bag
                
                	Inventory Asset Bag
                	**type**\:   :py:class:`InvAssetBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.InvAssetBag>`
                
                .. attribute:: inv_basic_bag
                
                	Inventory Basic Bag
                	**type**\:   :py:class:`InvBasicBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.InvBasicBag>`
                
                .. attribute:: inv_eeprom_info
                
                	Inventory EDM EEPROM Information Bag
                	**type**\:   :py:class:`InvEepromInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.InvEepromInfo>`
                
                .. attribute:: module_done
                
                	Inventory EDM Module Done Tuple
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**default value**\: 1
                
                .. attribute:: node_id
                
                	Node ID Tuple
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pwg_info
                
                	Inventory EDM PWG info
                	**type**\:   :py:class:`PwgInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.PwgInfo>`
                
                .. attribute:: threshold
                
                	Threshold
                	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold>`
                
                .. attribute:: vm_done
                
                	VM Done Tuple
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: vm_node_id
                
                	VM Node ID Tuple
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'invmgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.env_sensor_info = Inventory.Racks.Rack.Attributes.EnvSensorInfo()
                    self.env_sensor_info.parent = self
                    self.env_sensor_info_xml = Inventory.Racks.Rack.Attributes.EnvSensorInfoXml()
                    self.env_sensor_info_xml.parent = self
                    self.fru_info = Inventory.Racks.Rack.Attributes.FruInfo()
                    self.fru_info.parent = self
                    self.inv_asset_bag = Inventory.Racks.Rack.Attributes.InvAssetBag()
                    self.inv_asset_bag.parent = self
                    self.inv_basic_bag = Inventory.Racks.Rack.Attributes.InvBasicBag()
                    self.inv_basic_bag.parent = self
                    self.inv_eeprom_info = Inventory.Racks.Rack.Attributes.InvEepromInfo()
                    self.inv_eeprom_info.parent = self
                    self.module_done = None
                    self.node_id = None
                    self.pwg_info = Inventory.Racks.Rack.Attributes.PwgInfo()
                    self.pwg_info.parent = self
                    self.threshold = Inventory.Racks.Rack.Attributes.Threshold()
                    self.threshold.parent = self
                    self.vm_done = None
                    self.vm_node_id = None


                class EnvSensorInfo(object):
                    """
                    Environment sensor info
                    
                    .. attribute:: age_time_stamp
                    
                    	Age of the sensor value; set to the current time if directly access the value from sensor
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: alarm_type
                    
                    	Indicates threshold violation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: data_type
                    
                    	Sensor data type enums
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: device_description
                    
                    	Device Name
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: device_id
                    
                    	Identifier for this device
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: field_validity_bitmap
                    
                    	Sensor valid bitmap
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: precision
                    
                    	Sensor precision range
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: scale
                    
                    	Sensor scale enums
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: status
                    
                    	Sensor operation state enums
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: units
                    
                    	Units of variable being read
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: update_rate
                    
                    	Sensor value update rate;set to 0 if sensor value is updated and evaluated immediately
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: value
                    
                    	Current reading of sensor
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.age_time_stamp = None
                        self.alarm_type = None
                        self.data_type = None
                        self.device_description = None
                        self.device_id = None
                        self.field_validity_bitmap = None
                        self.precision = None
                        self.scale = None
                        self.status = None
                        self.units = None
                        self.update_rate = None
                        self.value = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.age_time_stamp is not None:
                            return True

                        if self.alarm_type is not None:
                            return True

                        if self.data_type is not None:
                            return True

                        if self.device_description is not None:
                            return True

                        if self.device_id is not None:
                            return True

                        if self.field_validity_bitmap is not None:
                            return True

                        if self.precision is not None:
                            return True

                        if self.scale is not None:
                            return True

                        if self.status is not None:
                            return True

                        if self.units is not None:
                            return True

                        if self.update_rate is not None:
                            return True

                        if self.value is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Attributes.EnvSensorInfo']['meta_info']


                class PwgInfo(object):
                    """
                    Inventory EDM PWG info
                    
                    .. attribute:: power_group_available_current
                    
                    	available current
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: power_group_drawn_current
                    
                    	drawn current
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: power_group_power_units
                    
                    	power units
                    	**type**\:  str
                    
                    .. attribute:: power_group_redundancy_mode
                    
                    	redundancy mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.power_group_available_current = None
                        self.power_group_drawn_current = None
                        self.power_group_power_units = None
                        self.power_group_redundancy_mode = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:pwg-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.power_group_available_current is not None:
                            return True

                        if self.power_group_drawn_current is not None:
                            return True

                        if self.power_group_power_units is not None:
                            return True

                        if self.power_group_redundancy_mode is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Attributes.PwgInfo']['meta_info']


                class EnvSensorInfoXml(object):
                    """
                    Environment sensor info XML
                    
                    .. attribute:: data_type
                    
                    	Sensor data type
                    	**type**\:   :py:class:`SensorDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorDataEnum>`
                    
                    .. attribute:: description
                    
                    	Device Name
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: status
                    
                    	Sensor operation state
                    	**type**\:   :py:class:`SensorStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.SensorStatusEnum>`
                    
                    .. attribute:: threshold
                    
                    	Threshold information
                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.EnvSensorInfoXml.Threshold>`
                    
                    .. attribute:: units
                    
                    	Units of variable being read
                    	**type**\:   :py:class:`UnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.UnitEnum>`
                    
                    .. attribute:: update_rate
                    
                    	Sensor value update rate; set to 0 if sensor value is updated and evaluated immediately
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: value
                    
                    	Current reading of sensor Displays in decimal(ex 1.234) for powersupply sensor type
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.data_type = None
                        self.description = None
                        self.status = None
                        self.threshold = Inventory.Racks.Rack.Attributes.EnvSensorInfoXml.Threshold()
                        self.threshold.parent = self
                        self.units = None
                        self.update_rate = None
                        self.value = None


                    class Threshold(object):
                        """
                        Threshold information
                        
                        .. attribute:: threshold_array
                        
                        	Array of threshold
                        	**type**\: list of    :py:class:`ThresholdArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray>`
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.threshold_array = YList()
                            self.threshold_array.parent = self
                            self.threshold_array.name = 'threshold_array'


                        class ThresholdArray(object):
                            """
                            Array of threshold
                            
                            .. attribute:: threshold_name
                            
                            	Threshold name
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: threshold_relation
                            
                            	Indicates relation between sensor value and threshold
                            	**type**\:   :py:class:`ThresholdRelationEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdRelationEnum>`
                            
                            .. attribute:: threshold_severity
                            
                            	Indicates minor, major, critical severities
                            	**type**\:   :py:class:`ThresholdSeverityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.ThresholdSeverityEnum>`
                            
                            .. attribute:: threshold_value
                            
                            	Value of the configured threshold
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.threshold_name = None
                                self.threshold_relation = None
                                self.threshold_severity = None
                                self.threshold_value = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold-array'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.threshold_name is not None:
                                    return True

                                if self.threshold_relation is not None:
                                    return True

                                if self.threshold_severity is not None:
                                    return True

                                if self.threshold_value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Attributes.EnvSensorInfoXml.Threshold.ThresholdArray']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.threshold_array is not None:
                                for child_ref in self.threshold_array:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Attributes.EnvSensorInfoXml.Threshold']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:env-sensor-info-xml'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.data_type is not None:
                            return True

                        if self.description is not None:
                            return True

                        if self.status is not None:
                            return True

                        if self.threshold is not None and self.threshold._has_data():
                            return True

                        if self.units is not None:
                            return True

                        if self.update_rate is not None:
                            return True

                        if self.value is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Attributes.EnvSensorInfoXml']['meta_info']


                class InvAssetBag(object):
                    """
                    Inventory Asset Bag
                    
                    .. attribute:: manufacturer_assembly_number
                    
                    	Manufacture Assembly number
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: manufacturer_assembly_revision
                    
                    	Manufacture assembly revision
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: manufacturer_common_language_equipment_identifier
                    
                    	Common Language Equipment           Identifier number
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: manufacturer_firmware_identifier
                    
                    	
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: manufacturer_software_identifier
                    
                    	
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: original_equipment_manufacturer_string
                    
                    	String containing OEM information           if applicable
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: part_number
                    
                    	
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.manufacturer_assembly_number = None
                        self.manufacturer_assembly_revision = None
                        self.manufacturer_common_language_equipment_identifier = None
                        self.manufacturer_firmware_identifier = None
                        self.manufacturer_software_identifier = None
                        self.original_equipment_manufacturer_string = None
                        self.part_number = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-asset-bag'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.manufacturer_assembly_number is not None:
                            return True

                        if self.manufacturer_assembly_revision is not None:
                            return True

                        if self.manufacturer_common_language_equipment_identifier is not None:
                            return True

                        if self.manufacturer_firmware_identifier is not None:
                            return True

                        if self.manufacturer_software_identifier is not None:
                            return True

                        if self.original_equipment_manufacturer_string is not None:
                            return True

                        if self.part_number is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Attributes.InvAssetBag']['meta_info']


                class Threshold(object):
                    """
                    Threshold
                    
                    .. attribute:: critical_hi
                    
                    	Critical High
                    	**type**\:   :py:class:`CriticalHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.CriticalHi>`
                    
                    .. attribute:: critical_lo
                    
                    	Critical Low
                    	**type**\:   :py:class:`CriticalLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.CriticalLo>`
                    
                    .. attribute:: major_hi
                    
                    	Major High
                    	**type**\:   :py:class:`MajorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.MajorHi>`
                    
                    .. attribute:: major_lo
                    
                    	Major Low
                    	**type**\:   :py:class:`MajorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.MajorLo>`
                    
                    .. attribute:: minor_hi
                    
                    	Minor High
                    	**type**\:   :py:class:`MinorHi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.MinorHi>`
                    
                    .. attribute:: minor_lo
                    
                    	Minor Low
                    	**type**\:   :py:class:`MinorLo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.MinorLo>`
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.critical_hi = Inventory.Racks.Rack.Attributes.Threshold.CriticalHi()
                        self.critical_hi.parent = self
                        self.critical_lo = Inventory.Racks.Rack.Attributes.Threshold.CriticalLo()
                        self.critical_lo.parent = self
                        self.major_hi = Inventory.Racks.Rack.Attributes.Threshold.MajorHi()
                        self.major_hi.parent = self
                        self.major_lo = Inventory.Racks.Rack.Attributes.Threshold.MajorLo()
                        self.major_lo.parent = self
                        self.minor_hi = Inventory.Racks.Rack.Attributes.Threshold.MinorHi()
                        self.minor_hi.parent = self
                        self.minor_lo = Inventory.Racks.Rack.Attributes.Threshold.MinorLo()
                        self.minor_lo.parent = self


                    class MajorLo(object):
                        """
                        Major Low
                        
                        .. attribute:: thresh_bag
                        
                        	Environment threshold info
                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.MajorLo.ThreshBag>`
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.thresh_bag = Inventory.Racks.Rack.Attributes.Threshold.MajorLo.ThreshBag()
                            self.thresh_bag.parent = self


                        class ThreshBag(object):
                            """
                            Environment threshold info
                            
                            .. attribute:: threshold_evaluation
                            
                            	Indicates the result of the most recent evaluation of the thresholD
                            	**type**\:  bool
                            
                            .. attribute:: threshold_notification_enabled
                            
                            	Indicates whether or not a notification should result, in case of threshold violation
                            	**type**\:  bool
                            
                            .. attribute:: threshold_relation
                            
                            	Indicates relation between sensor value and threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_severity
                            
                            	Indicates minor, major, critical severities
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_value
                            
                            	Value of the configured threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.threshold_evaluation = None
                                self.threshold_notification_enabled = None
                                self.threshold_relation = None
                                self.threshold_severity = None
                                self.threshold_value = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.threshold_evaluation is not None:
                                    return True

                                if self.threshold_notification_enabled is not None:
                                    return True

                                if self.threshold_relation is not None:
                                    return True

                                if self.threshold_severity is not None:
                                    return True

                                if self.threshold_value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.MajorLo.ThreshBag']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-lo'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.MajorLo']['meta_info']


                    class CriticalHi(object):
                        """
                        Critical High
                        
                        .. attribute:: thresh_bag
                        
                        	Environment threshold info
                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.CriticalHi.ThreshBag>`
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.thresh_bag = Inventory.Racks.Rack.Attributes.Threshold.CriticalHi.ThreshBag()
                            self.thresh_bag.parent = self


                        class ThreshBag(object):
                            """
                            Environment threshold info
                            
                            .. attribute:: threshold_evaluation
                            
                            	Indicates the result of the most recent evaluation of the thresholD
                            	**type**\:  bool
                            
                            .. attribute:: threshold_notification_enabled
                            
                            	Indicates whether or not a notification should result, in case of threshold violation
                            	**type**\:  bool
                            
                            .. attribute:: threshold_relation
                            
                            	Indicates relation between sensor value and threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_severity
                            
                            	Indicates minor, major, critical severities
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_value
                            
                            	Value of the configured threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.threshold_evaluation = None
                                self.threshold_notification_enabled = None
                                self.threshold_relation = None
                                self.threshold_severity = None
                                self.threshold_value = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.threshold_evaluation is not None:
                                    return True

                                if self.threshold_notification_enabled is not None:
                                    return True

                                if self.threshold_relation is not None:
                                    return True

                                if self.threshold_severity is not None:
                                    return True

                                if self.threshold_value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.CriticalHi.ThreshBag']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-hi'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.CriticalHi']['meta_info']


                    class MinorHi(object):
                        """
                        Minor High
                        
                        .. attribute:: thresh_bag
                        
                        	Environment threshold info
                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.MinorHi.ThreshBag>`
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.thresh_bag = Inventory.Racks.Rack.Attributes.Threshold.MinorHi.ThreshBag()
                            self.thresh_bag.parent = self


                        class ThreshBag(object):
                            """
                            Environment threshold info
                            
                            .. attribute:: threshold_evaluation
                            
                            	Indicates the result of the most recent evaluation of the thresholD
                            	**type**\:  bool
                            
                            .. attribute:: threshold_notification_enabled
                            
                            	Indicates whether or not a notification should result, in case of threshold violation
                            	**type**\:  bool
                            
                            .. attribute:: threshold_relation
                            
                            	Indicates relation between sensor value and threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_severity
                            
                            	Indicates minor, major, critical severities
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_value
                            
                            	Value of the configured threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.threshold_evaluation = None
                                self.threshold_notification_enabled = None
                                self.threshold_relation = None
                                self.threshold_severity = None
                                self.threshold_value = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.threshold_evaluation is not None:
                                    return True

                                if self.threshold_notification_enabled is not None:
                                    return True

                                if self.threshold_relation is not None:
                                    return True

                                if self.threshold_severity is not None:
                                    return True

                                if self.threshold_value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.MinorHi.ThreshBag']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-hi'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.MinorHi']['meta_info']


                    class MajorHi(object):
                        """
                        Major High
                        
                        .. attribute:: thresh_bag
                        
                        	Environment threshold info
                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.MajorHi.ThreshBag>`
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.thresh_bag = Inventory.Racks.Rack.Attributes.Threshold.MajorHi.ThreshBag()
                            self.thresh_bag.parent = self


                        class ThreshBag(object):
                            """
                            Environment threshold info
                            
                            .. attribute:: threshold_evaluation
                            
                            	Indicates the result of the most recent evaluation of the thresholD
                            	**type**\:  bool
                            
                            .. attribute:: threshold_notification_enabled
                            
                            	Indicates whether or not a notification should result, in case of threshold violation
                            	**type**\:  bool
                            
                            .. attribute:: threshold_relation
                            
                            	Indicates relation between sensor value and threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_severity
                            
                            	Indicates minor, major, critical severities
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_value
                            
                            	Value of the configured threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.threshold_evaluation = None
                                self.threshold_notification_enabled = None
                                self.threshold_relation = None
                                self.threshold_severity = None
                                self.threshold_value = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.threshold_evaluation is not None:
                                    return True

                                if self.threshold_notification_enabled is not None:
                                    return True

                                if self.threshold_relation is not None:
                                    return True

                                if self.threshold_severity is not None:
                                    return True

                                if self.threshold_value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.MajorHi.ThreshBag']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:major-hi'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.MajorHi']['meta_info']


                    class CriticalLo(object):
                        """
                        Critical Low
                        
                        .. attribute:: thresh_bag
                        
                        	Environment threshold info
                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.CriticalLo.ThreshBag>`
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.thresh_bag = Inventory.Racks.Rack.Attributes.Threshold.CriticalLo.ThreshBag()
                            self.thresh_bag.parent = self


                        class ThreshBag(object):
                            """
                            Environment threshold info
                            
                            .. attribute:: threshold_evaluation
                            
                            	Indicates the result of the most recent evaluation of the thresholD
                            	**type**\:  bool
                            
                            .. attribute:: threshold_notification_enabled
                            
                            	Indicates whether or not a notification should result, in case of threshold violation
                            	**type**\:  bool
                            
                            .. attribute:: threshold_relation
                            
                            	Indicates relation between sensor value and threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_severity
                            
                            	Indicates minor, major, critical severities
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_value
                            
                            	Value of the configured threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.threshold_evaluation = None
                                self.threshold_notification_enabled = None
                                self.threshold_relation = None
                                self.threshold_severity = None
                                self.threshold_value = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.threshold_evaluation is not None:
                                    return True

                                if self.threshold_notification_enabled is not None:
                                    return True

                                if self.threshold_relation is not None:
                                    return True

                                if self.threshold_severity is not None:
                                    return True

                                if self.threshold_value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.CriticalLo.ThreshBag']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:critical-lo'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.CriticalLo']['meta_info']


                    class MinorLo(object):
                        """
                        Minor Low
                        
                        .. attribute:: thresh_bag
                        
                        	Environment threshold info
                        	**type**\:   :py:class:`ThreshBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.Threshold.MinorLo.ThreshBag>`
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.thresh_bag = Inventory.Racks.Rack.Attributes.Threshold.MinorLo.ThreshBag()
                            self.thresh_bag.parent = self


                        class ThreshBag(object):
                            """
                            Environment threshold info
                            
                            .. attribute:: threshold_evaluation
                            
                            	Indicates the result of the most recent evaluation of the thresholD
                            	**type**\:  bool
                            
                            .. attribute:: threshold_notification_enabled
                            
                            	Indicates whether or not a notification should result, in case of threshold violation
                            	**type**\:  bool
                            
                            .. attribute:: threshold_relation
                            
                            	Indicates relation between sensor value and threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_severity
                            
                            	Indicates minor, major, critical severities
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: threshold_value
                            
                            	Value of the configured threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.threshold_evaluation = None
                                self.threshold_notification_enabled = None
                                self.threshold_relation = None
                                self.threshold_severity = None
                                self.threshold_value = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:thresh-bag'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.threshold_evaluation is not None:
                                    return True

                                if self.threshold_notification_enabled is not None:
                                    return True

                                if self.threshold_relation is not None:
                                    return True

                                if self.threshold_severity is not None:
                                    return True

                                if self.threshold_value is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.MinorLo.ThreshBag']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:minor-lo'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.thresh_bag is not None and self.thresh_bag._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold.MinorLo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:threshold'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.critical_hi is not None and self.critical_hi._has_data():
                            return True

                        if self.critical_lo is not None and self.critical_lo._has_data():
                            return True

                        if self.major_hi is not None and self.major_hi._has_data():
                            return True

                        if self.major_lo is not None and self.major_lo._has_data():
                            return True

                        if self.minor_hi is not None and self.minor_hi._has_data():
                            return True

                        if self.minor_lo is not None and self.minor_lo._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Attributes.Threshold']['meta_info']


                class FruInfo(object):
                    """
                    Inventory EDM FRU info
                    
                    .. attribute:: card_administrative_state
                    
                    	card admin state\: shutdown or not
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: card_monitor_state
                    
                    	card is monitored by a manager or left unmonitored
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: card_operational_state
                    
                    	card operation state
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: card_reset_reason
                    
                    	card reset reason enum
                    	**type**\:   :py:class:`CardResetReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.CardResetReasonEnum>`
                    
                    .. attribute:: card_up_time
                    
                    	card up time
                    	**type**\:   :py:class:`CardUpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.FruInfo.CardUpTime>`
                    
                    .. attribute:: last_operational_state_change
                    
                    	last card oper change state
                    	**type**\:   :py:class:`LastOperationalStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.FruInfo.LastOperationalStateChange>`
                    
                    .. attribute:: power_administrative_state
                    
                    	power admin state\: up or down
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: power_current_measurement
                    
                    	power current\: not implemented
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: power_operational_state
                    
                    	Power operation state
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.card_administrative_state = None
                        self.card_monitor_state = None
                        self.card_operational_state = None
                        self.card_reset_reason = None
                        self.card_up_time = Inventory.Racks.Rack.Attributes.FruInfo.CardUpTime()
                        self.card_up_time.parent = self
                        self.last_operational_state_change = Inventory.Racks.Rack.Attributes.FruInfo.LastOperationalStateChange()
                        self.last_operational_state_change.parent = self
                        self.power_administrative_state = None
                        self.power_current_measurement = None
                        self.power_operational_state = None


                    class LastOperationalStateChange(object):
                        """
                        last card oper change state
                        
                        .. attribute:: time_in_nano_seconds
                        
                        	Time Value in Nano\-seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_in_seconds
                        
                        	Time Value in Seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.time_in_nano_seconds = None
                            self.time_in_seconds = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:last-operational-state-change'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.time_in_nano_seconds is not None:
                                return True

                            if self.time_in_seconds is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Attributes.FruInfo.LastOperationalStateChange']['meta_info']


                    class CardUpTime(object):
                        """
                        card up time
                        
                        .. attribute:: time_in_nano_seconds
                        
                        	Time Value in Nano\-seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_in_seconds
                        
                        	Time Value in Seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.time_in_nano_seconds = None
                            self.time_in_seconds = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:card-up-time'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.time_in_nano_seconds is not None:
                                return True

                            if self.time_in_seconds is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Attributes.FruInfo.CardUpTime']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:fru-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.card_administrative_state is not None:
                            return True

                        if self.card_monitor_state is not None:
                            return True

                        if self.card_operational_state is not None:
                            return True

                        if self.card_reset_reason is not None:
                            return True

                        if self.card_up_time is not None and self.card_up_time._has_data():
                            return True

                        if self.last_operational_state_change is not None and self.last_operational_state_change._has_data():
                            return True

                        if self.power_administrative_state is not None:
                            return True

                        if self.power_current_measurement is not None:
                            return True

                        if self.power_operational_state is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Attributes.FruInfo']['meta_info']


                class InvBasicBag(object):
                    """
                    Inventory Basic Bag
                    
                    .. attribute:: alias
                    
                    	useful for storing an entity alias 
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: asset_id_str
                    
                    	asset Identification string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: asset_identification
                    
                    	asset Identification
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ceport
                    
                    	1 if ce port found, 0 if not
                    	**type**\:  bool
                    
                    .. attribute:: chip_hardware_revision
                    
                    	chip module hw revision string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: composite_class_code
                    
                    	Major&minor class of the entity
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: description
                    
                    	describes in user\-readable terms       what the entity in question does
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: environmental_monitor_path
                    
                    	sysdb name of sensor in the envmon EDM
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: firmware_revision
                    
                    	firmware revision string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: group_flag
                    
                    	indicates if this entity is group       or not
                    	**type**\:  bool
                    
                    .. attribute:: hardware_revision
                    
                    	hw revision string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: is_field_replaceable_unit
                    
                    	1 if Field Replaceable Unit 0, if not
                    	**type**\:  bool
                    
                    .. attribute:: manufacturer_asset_tags
                    
                    	Manufacture Asset Tags
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: manufacturer_name
                    
                    	manufacturer's name
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: memory_size
                    
                    	Size of memory associated with       the entity where applicable
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: model_name
                    
                    	model name
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: name
                    
                    	name string for the entity
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: new_deviation_number
                    
                    	integer value for New Deviation Number 0x88
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: physical_layer_interface_module_type
                    
                    	integer value for plim type if     applicable to this entity
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: redundancystate
                    
                    	integer value for Redundancy State if     applicable to this entity
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: serial_number
                    
                    	serial number
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: software_revision
                    
                    	software revision string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: unique_id
                    
                    	Unique id for an entity
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: unrecognized_fru
                    
                    	1 if UnrecognizedFRU and 0 for recognizedFRU
                    	**type**\:  bool
                    
                    .. attribute:: vendor_type
                    
                    	maps to the vendor OID string
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: xr_scoped
                    
                    	1 if xr scoped, 0 if not
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.alias = None
                        self.asset_id_str = None
                        self.asset_identification = None
                        self.ceport = None
                        self.chip_hardware_revision = None
                        self.composite_class_code = None
                        self.description = None
                        self.environmental_monitor_path = None
                        self.firmware_revision = None
                        self.group_flag = None
                        self.hardware_revision = None
                        self.is_field_replaceable_unit = None
                        self.manufacturer_asset_tags = None
                        self.manufacturer_name = None
                        self.memory_size = None
                        self.model_name = None
                        self.name = None
                        self.new_deviation_number = None
                        self.physical_layer_interface_module_type = None
                        self.redundancystate = None
                        self.serial_number = None
                        self.software_revision = None
                        self.unique_id = None
                        self.unrecognized_fru = None
                        self.vendor_type = None
                        self.xr_scoped = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-basic-bag'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.alias is not None:
                            return True

                        if self.asset_id_str is not None:
                            return True

                        if self.asset_identification is not None:
                            return True

                        if self.ceport is not None:
                            return True

                        if self.chip_hardware_revision is not None:
                            return True

                        if self.composite_class_code is not None:
                            return True

                        if self.description is not None:
                            return True

                        if self.environmental_monitor_path is not None:
                            return True

                        if self.firmware_revision is not None:
                            return True

                        if self.group_flag is not None:
                            return True

                        if self.hardware_revision is not None:
                            return True

                        if self.is_field_replaceable_unit is not None:
                            return True

                        if self.manufacturer_asset_tags is not None:
                            return True

                        if self.manufacturer_name is not None:
                            return True

                        if self.memory_size is not None:
                            return True

                        if self.model_name is not None:
                            return True

                        if self.name is not None:
                            return True

                        if self.new_deviation_number is not None:
                            return True

                        if self.physical_layer_interface_module_type is not None:
                            return True

                        if self.redundancystate is not None:
                            return True

                        if self.serial_number is not None:
                            return True

                        if self.software_revision is not None:
                            return True

                        if self.unique_id is not None:
                            return True

                        if self.unrecognized_fru is not None:
                            return True

                        if self.vendor_type is not None:
                            return True

                        if self.xr_scoped is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Attributes.InvBasicBag']['meta_info']


                class InvEepromInfo(object):
                    """
                    Inventory EDM EEPROM Information Bag
                    
                    .. attribute:: description
                    
                    	A textual description of physical entity
                    	**type**\:  str
                    
                    	**length:** 0..255
                    
                    .. attribute:: eeprom
                    
                    	EEPROM data not from hex data
                    	**type**\:   :py:class:`Eeprom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.InvEepromInfo.Eeprom>`
                    
                    .. attribute:: has_eeprom
                    
                    	use eeprom instead of opaque data
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inv_card_type
                    
                    	Inventory card type
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: opaque_data
                    
                    	EEPROM hex data
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: opaque_data_size
                    
                    	size of the EEPROM hex data
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'invmgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.description = None
                        self.eeprom = Inventory.Racks.Rack.Attributes.InvEepromInfo.Eeprom()
                        self.eeprom.parent = self
                        self.has_eeprom = None
                        self.inv_card_type = None
                        self.opaque_data = None
                        self.opaque_data_size = None


                    class Eeprom(object):
                        """
                        EEPROM data not from hex data
                        
                        .. attribute:: asset_alias
                        
                        	Asset Alias
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: asset_id
                        
                        	Asset ID
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: base_mac_address1
                        
                        	Base Mac Address #1
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: base_mac_address2
                        
                        	Base Mac Address #2
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: base_mac_address3
                        
                        	Base Mac Address #3
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: base_mac_address4
                        
                        	Base Mac Address #4
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: block_checksum
                        
                        	Block Checksum
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: block_count
                        
                        	Block Count
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: block_length
                        
                        	Block Length
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: block_signature
                        
                        	Block Signature
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: block_version
                        
                        	Block Version
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: chassis_sid
                        
                        	Chassis serial number
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: clei
                        
                        	Common Language Equipment Identifier (CLEI) code
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: controller_family
                        
                        	Controller family
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: controller_type
                        
                        	Controller type
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: description
                        
                        	A textual description of physical entity
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: dev_num1
                        
                        	Deviation Number # 1
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: dev_num2
                        
                        	Deviation Number # 2
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: dev_num3
                        
                        	Deviation Number # 3
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: dev_num4
                        
                        	Deviation Number # 4
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: dev_num5
                        
                        	Deviation Number # 5
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: dev_num6
                        
                        	Deviation Number # 6
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: dev_num7
                        
                        	Deviation Number # 7
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: eci
                        
                        	Equipment Catalog Item (ECI) number
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: eeprom_size
                        
                        	EEPROM Size
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: engineer_use
                        
                        	Engineer Use
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: fru_major_type
                        
                        	FRU Major Type
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: fru_minor_type
                        
                        	FRU Minor Type
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: hw_version
                        
                        	Hardware Version
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: hwid
                        
                        	Hardware Revision
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: idprom_format_rev
                        
                        	IDPROM Format Revision
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: mac_add_blk_size1
                        
                        	Mac Address Block Size #1
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: mac_add_blk_size2
                        
                        	Mac Address Block Size #2
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: mac_add_blk_size3
                        
                        	Mac Address Block Size #3
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: mac_add_blk_size4
                        
                        	Mac Address Block Size #4
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: manu_test_data
                        
                        	Manufacturing Test Data
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: mfg_bits
                        
                        	MFG Bits
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: mfg_deviation
                        
                        	MFG Deviation
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: oem_string
                        
                        	OEM String
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: part_number
                        
                        	Part Number
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: part_revision
                        
                        	Part Revision
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: pca_num
                        
                        	PCA number
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: pcavid
                        
                        	PCA revision ID
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: pcb_serial_num
                        
                        	PCB Serial Number
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: pid
                        
                        	Product ID
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: power_consumption
                        
                        	Power Consumption
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: power_supply_type
                        
                        	Power Supply Type
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: product_id
                        
                        	Product ID
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: rma
                        
                        	RMA Data
                        	**type**\:   :py:class:`Rma <ydk.models.cisco_ios_xr.Cisco_IOS_XR_invmgr_oper.Inventory.Racks.Rack.Attributes.InvEepromInfo.Eeprom.Rma>`
                        
                        .. attribute:: rma_code
                        
                        	RMA Code
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: serial_number
                        
                        	Serial Number
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: snmpoid
                        
                        	SNMP OID
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: top_assem_part_num
                        
                        	Top assembly part number
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: top_assem_vid
                        
                        	Top assembly revision number
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: udi_description
                        
                        	UDI description
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: udi_name
                        
                        	UDI name
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        .. attribute:: vid
                        
                        	Version ID
                        	**type**\:  str
                        
                        	**length:** 0..255
                        
                        

                        """

                        _prefix = 'invmgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.asset_alias = None
                            self.asset_id = None
                            self.base_mac_address1 = None
                            self.base_mac_address2 = None
                            self.base_mac_address3 = None
                            self.base_mac_address4 = None
                            self.block_checksum = None
                            self.block_count = None
                            self.block_length = None
                            self.block_signature = None
                            self.block_version = None
                            self.chassis_sid = None
                            self.clei = None
                            self.controller_family = None
                            self.controller_type = None
                            self.description = None
                            self.dev_num1 = None
                            self.dev_num2 = None
                            self.dev_num3 = None
                            self.dev_num4 = None
                            self.dev_num5 = None
                            self.dev_num6 = None
                            self.dev_num7 = None
                            self.eci = None
                            self.eeprom_size = None
                            self.engineer_use = None
                            self.fru_major_type = None
                            self.fru_minor_type = None
                            self.hw_version = None
                            self.hwid = None
                            self.idprom_format_rev = None
                            self.mac_add_blk_size1 = None
                            self.mac_add_blk_size2 = None
                            self.mac_add_blk_size3 = None
                            self.mac_add_blk_size4 = None
                            self.manu_test_data = None
                            self.mfg_bits = None
                            self.mfg_deviation = None
                            self.oem_string = None
                            self.part_number = None
                            self.part_revision = None
                            self.pca_num = None
                            self.pcavid = None
                            self.pcb_serial_num = None
                            self.pid = None
                            self.power_consumption = None
                            self.power_supply_type = None
                            self.product_id = None
                            self.rma = Inventory.Racks.Rack.Attributes.InvEepromInfo.Eeprom.Rma()
                            self.rma.parent = self
                            self.rma_code = None
                            self.serial_number = None
                            self.snmpoid = None
                            self.top_assem_part_num = None
                            self.top_assem_vid = None
                            self.udi_description = None
                            self.udi_name = None
                            self.vid = None


                        class Rma(object):
                            """
                            RMA Data
                            
                            .. attribute:: rma_history
                            
                            	RMA history
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: rma_number
                            
                            	RMA tracking number format is N\-N\-N
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            .. attribute:: test_history
                            
                            	Test history
                            	**type**\:  str
                            
                            	**length:** 0..255
                            
                            

                            """

                            _prefix = 'invmgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.rma_history = None
                                self.rma_number = None
                                self.test_history = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:rma'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.rma_history is not None:
                                    return True

                                if self.rma_number is not None:
                                    return True

                                if self.test_history is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                                return meta._meta_table['Inventory.Racks.Rack.Attributes.InvEepromInfo.Eeprom.Rma']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:eeprom'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.asset_alias is not None:
                                return True

                            if self.asset_id is not None:
                                return True

                            if self.base_mac_address1 is not None:
                                return True

                            if self.base_mac_address2 is not None:
                                return True

                            if self.base_mac_address3 is not None:
                                return True

                            if self.base_mac_address4 is not None:
                                return True

                            if self.block_checksum is not None:
                                return True

                            if self.block_count is not None:
                                return True

                            if self.block_length is not None:
                                return True

                            if self.block_signature is not None:
                                return True

                            if self.block_version is not None:
                                return True

                            if self.chassis_sid is not None:
                                return True

                            if self.clei is not None:
                                return True

                            if self.controller_family is not None:
                                return True

                            if self.controller_type is not None:
                                return True

                            if self.description is not None:
                                return True

                            if self.dev_num1 is not None:
                                return True

                            if self.dev_num2 is not None:
                                return True

                            if self.dev_num3 is not None:
                                return True

                            if self.dev_num4 is not None:
                                return True

                            if self.dev_num5 is not None:
                                return True

                            if self.dev_num6 is not None:
                                return True

                            if self.dev_num7 is not None:
                                return True

                            if self.eci is not None:
                                return True

                            if self.eeprom_size is not None:
                                return True

                            if self.engineer_use is not None:
                                return True

                            if self.fru_major_type is not None:
                                return True

                            if self.fru_minor_type is not None:
                                return True

                            if self.hw_version is not None:
                                return True

                            if self.hwid is not None:
                                return True

                            if self.idprom_format_rev is not None:
                                return True

                            if self.mac_add_blk_size1 is not None:
                                return True

                            if self.mac_add_blk_size2 is not None:
                                return True

                            if self.mac_add_blk_size3 is not None:
                                return True

                            if self.mac_add_blk_size4 is not None:
                                return True

                            if self.manu_test_data is not None:
                                return True

                            if self.mfg_bits is not None:
                                return True

                            if self.mfg_deviation is not None:
                                return True

                            if self.oem_string is not None:
                                return True

                            if self.part_number is not None:
                                return True

                            if self.part_revision is not None:
                                return True

                            if self.pca_num is not None:
                                return True

                            if self.pcavid is not None:
                                return True

                            if self.pcb_serial_num is not None:
                                return True

                            if self.pid is not None:
                                return True

                            if self.power_consumption is not None:
                                return True

                            if self.power_supply_type is not None:
                                return True

                            if self.product_id is not None:
                                return True

                            if self.rma is not None and self.rma._has_data():
                                return True

                            if self.rma_code is not None:
                                return True

                            if self.serial_number is not None:
                                return True

                            if self.snmpoid is not None:
                                return True

                            if self.top_assem_part_num is not None:
                                return True

                            if self.top_assem_vid is not None:
                                return True

                            if self.udi_description is not None:
                                return True

                            if self.udi_name is not None:
                                return True

                            if self.vid is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                            return meta._meta_table['Inventory.Racks.Rack.Attributes.InvEepromInfo.Eeprom']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:inv-eeprom-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.description is not None:
                            return True

                        if self.eeprom is not None and self.eeprom._has_data():
                            return True

                        if self.has_eeprom is not None:
                            return True

                        if self.inv_card_type is not None:
                            return True

                        if self.opaque_data is not None:
                            return True

                        if self.opaque_data_size is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                        return meta._meta_table['Inventory.Racks.Rack.Attributes.InvEepromInfo']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-invmgr-oper:attributes'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.env_sensor_info is not None and self.env_sensor_info._has_data():
                        return True

                    if self.env_sensor_info_xml is not None and self.env_sensor_info_xml._has_data():
                        return True

                    if self.fru_info is not None and self.fru_info._has_data():
                        return True

                    if self.inv_asset_bag is not None and self.inv_asset_bag._has_data():
                        return True

                    if self.inv_basic_bag is not None and self.inv_basic_bag._has_data():
                        return True

                    if self.inv_eeprom_info is not None and self.inv_eeprom_info._has_data():
                        return True

                    if self.module_done is not None:
                        return True

                    if self.node_id is not None:
                        return True

                    if self.pwg_info is not None and self.pwg_info._has_data():
                        return True

                    if self.threshold is not None and self.threshold._has_data():
                        return True

                    if self.vm_done is not None:
                        return True

                    if self.vm_node_id is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                    return meta._meta_table['Inventory.Racks.Rack.Attributes']['meta_info']

            @property
            def _common_path(self):
                if self.name is None:
                    raise YPYModelError('Key property name is None')

                return '/Cisco-IOS-XR-invmgr-oper:inventory/Cisco-IOS-XR-invmgr-oper:racks/Cisco-IOS-XR-invmgr-oper:rack[Cisco-IOS-XR-invmgr-oper:name = ' + str(self.name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.name is not None:
                    return True

                if self.attributes is not None and self.attributes._has_data():
                    return True

                if self.entity is not None and self.entity._has_data():
                    return True

                if self.fantray is not None and self.fantray._has_data():
                    return True

                if self.powershelf is not None and self.powershelf._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
                return meta._meta_table['Inventory.Racks.Rack']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-invmgr-oper:inventory/Cisco-IOS-XR-invmgr-oper:racks'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.rack is not None:
                for child_ref in self.rack:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
            return meta._meta_table['Inventory.Racks']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-invmgr-oper:inventory'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.entities is not None and self.entities._has_data():
            return True

        if self.racks is not None and self.racks._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_invmgr_oper as meta
        return meta._meta_table['Inventory']['meta_info']


